@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Package implementing the conda GUI logic.
 """
 
-
 import json
 import os
 
@@ -67,7 +66,7 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("create", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, resultDict = dlg.getResult()
         
         if ok:
@@ -390,7 +389,7 @@ class Conda(QObject):
             
             dlg = CondaExecDialog("update", self.__ui)
             dlg.start(args)
-            dlg.exec_()
+            dlg.exec()
             ok, _ = dlg.getResult()
         else:
             ok = False
@@ -430,7 +429,7 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("update", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, _ = dlg.getResult()
         
         return ok
@@ -471,7 +470,7 @@ class Conda(QObject):
             
             dlg = CondaExecDialog("install", self.__ui)
             dlg.start(args)
-            dlg.exec_()
+            dlg.exec()
             ok, _ = dlg.getResult()
         else:
             ok = False
@@ -511,7 +510,7 @@ class Conda(QObject):
                     "Do you really want to uninstall these packages and"
                     " their dependencies?"),
                 packages)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 args = [
                     "remove",
                     "--json",
@@ -527,7 +526,7 @@ class Conda(QObject):
                 
                 dlg = CondaExecDialog("remove", self.__ui)
                 dlg.start(args)
-                dlg.exec_()
+                dlg.exec()
                 ok, _ = dlg.getResult()
             else:
                 ok = False
@@ -623,7 +622,7 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("update", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
         ok, _ = dlg.getResult()
         
         return ok
@@ -732,4 +731,4 @@ class Conda(QObject):
         
         dlg = CondaExecDialog("clean", self.__ui)
         dlg.start(args)
-        dlg.exec_()
+        dlg.exec()
