@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the chat dialog.
 """
 
-
 from PyQt5.QtCore import Qt, pyqtSlot, pyqtSignal, QDateTime, QPoint, QFileInfo
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QWidget, QListWidgetItem, QMenu, QApplication
@@ -59,13 +58,13 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         self.setupUi(self)
         
         self.shareButton.setIcon(
-            UI.PixmapCache.getIcon("sharedEditDisconnected.png"))
+            UI.PixmapCache.getIcon("sharedEditDisconnected"))
         self.startEditButton.setIcon(
-            UI.PixmapCache.getIcon("sharedEditStart.png"))
+            UI.PixmapCache.getIcon("sharedEditStart"))
         self.sendEditButton.setIcon(
-            UI.PixmapCache.getIcon("sharedEditSend.png"))
+            UI.PixmapCache.getIcon("sharedEditSend"))
         self.cancelEditButton.setIcon(
-            UI.PixmapCache.getIcon("sharedEditCancel.png"))
+            UI.PixmapCache.getIcon("sharedEditCancel"))
         
         self.__ui = ui
         self.__client = CooperationClient(self)
@@ -177,7 +176,7 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         
         QListWidgetItem(
             UI.PixmapCache.getIcon(
-                "chatUser{0}.png".format(1 + self.usersList.count() % 6)),
+                "chatUser{0}".format(1 + self.usersList.count() % 6)),
             nick, self.usersList)
         
         if not self.__connected:
@@ -185,7 +184,7 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         
         if not self.isVisible():
             self.__ui.showNotification(
-                UI.PixmapCache.getPixmap("cooperation48.png"),
+                UI.PixmapCache.getPixmap("cooperation48"),
                 self.tr("New User"), self.tr("{0} has joined.")
                     .format(nick))
 
@@ -216,7 +215,7 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         
         if not self.isVisible():
             self.__ui.showNotification(
-                UI.PixmapCache.getPixmap("cooperation48.png"),
+                UI.PixmapCache.getPixmap("cooperation48"),
                 self.tr("User Left"), self.tr("{0} has left.")
                     .format(nick))
     
@@ -239,7 +238,7 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         
         if not self.isVisible():
             self.__ui.showNotification(
-                UI.PixmapCache.getPixmap("cooperation48.png"),
+                UI.PixmapCache.getPixmap("cooperation48"),
                 self.tr("Message from <{0}>").format(from_), message)
     
     @pyqtSlot(str)
@@ -417,10 +416,10 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         if checked:
             self.shareButton.setIcon(
-                UI.PixmapCache.getIcon("sharedEditConnected.png"))
+                UI.PixmapCache.getIcon("sharedEditConnected"))
         else:
             self.shareButton.setIcon(
-                UI.PixmapCache.getIcon("sharedEditDisconnected.png"))
+                UI.PixmapCache.getIcon("sharedEditDisconnected"))
         self.startEditButton.setEnabled(checked)
         
         self.shareEditor.emit(checked)
@@ -477,10 +476,10 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         self.shareButton.setChecked(sharing)
         if sharing:
             self.shareButton.setIcon(
-                UI.PixmapCache.getIcon("sharedEditConnected.png"))
+                UI.PixmapCache.getIcon("sharedEditConnected"))
         else:
             self.shareButton.setIcon(
-                UI.PixmapCache.getIcon("sharedEditDisconnected.png"))
+                UI.PixmapCache.getIcon("sharedEditDisconnected"))
         self.startEditButton.setChecked(editing)
         
         self.shareButton.setEnabled(shareable and not editing)
@@ -495,22 +494,22 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         self.__chatMenu = QMenu(self)
         self.__copyChatAct = self.__chatMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy"), self.__copyChat)
         self.__chatMenu.addSeparator()
         self.__cutAllChatAct = self.__chatMenu.addAction(
-            UI.PixmapCache.getIcon("editCut.png"),
+            UI.PixmapCache.getIcon("editCut"),
             self.tr("Cut all"), self.__cutAllChat)
         self.__copyAllChatAct = self.__chatMenu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy all"), self.__copyAllChat)
         self.__chatMenu.addSeparator()
         self.__clearChatAct = self.__chatMenu.addAction(
-            UI.PixmapCache.getIcon("editDelete.png"),
+            UI.PixmapCache.getIcon("editDelete"),
             self.tr("Clear"), self.__clearChat)
         self.__chatMenu.addSeparator()
         self.__saveChatAct = self.__chatMenu.addAction(
-            UI.PixmapCache.getIcon("fileSave.png"),
+            UI.PixmapCache.getIcon("fileSave"),
             self.tr("Save"), self.__saveChat)
         
         self.on_chatEdit_copyAvailable(False)
@@ -574,10 +573,9 @@ class ChatWidget(QWidget, Ui_ChatWidget):
                     fname = Utilities.toNativeSeparators(fname)
                 
                 try:
-                    f = open(fname, "w", encoding="utf-8")
-                    f.write(txt)
-                    f.close()
-                except IOError as err:
+                    with open(fname, "w", encoding="utf-8") as f:
+                        f.write(txt)
+                except OSError as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Error saving Chat"),
@@ -617,13 +615,13 @@ class ChatWidget(QWidget, Ui_ChatWidget):
         """
         self.__usersMenu = QMenu(self)
         self.__kickUserAct = self.__usersMenu.addAction(
-            UI.PixmapCache.getIcon("chatKickUser.png"),
+            UI.PixmapCache.getIcon("chatKickUser"),
             self.tr("Kick User"), self.__kickUser)
         self.__banUserAct = self.__usersMenu.addAction(
-            UI.PixmapCache.getIcon("chatBanUser.png"),
+            UI.PixmapCache.getIcon("chatBanUser"),
             self.tr("Ban User"), self.__banUser)
         self.__banKickUserAct = self.__usersMenu.addAction(
-            UI.PixmapCache.getIcon("chatBanKickUser.png"),
+            UI.PixmapCache.getIcon("chatBanKickUser"),
             self.tr("Ban and Kick User"), self.__banKickUser)
     
     @pyqtSlot(QPoint)
