@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,11 +15,12 @@ import codecs
 import traceback
 import os
 import json
-import imp
 import re
 import atexit
 import signal
 import time
+import types
+import importlib
 
 
 import DebugClientCapabilities
@@ -31,73 +32,37 @@ from FlexCompleter import Completer
 from DebugUtilities import prepareJsonCommand
 from BreakpointWatch import Breakpoint, Watch
 
-if sys.version_info[0] == 2:
-    from inspect import getargvalues, formatargvalues
-else:
-    unichr = chr
-    from DebugUtilities import getargvalues, formatargvalues
+from DebugUtilities import getargvalues, formatargvalues
 
 DebugClientInstance = None
 
 ###############################################################################
 
 
-def DebugClientRawInput(prompt="", echo=True):
+def DebugClientInput(prompt=""):
     """
-    Replacement for the standard raw_input builtin.
+    Replacement for the standard input() builtin.
     
     This function works with the split debugger.
     
-    @param prompt prompt to be shown. (string)
-    @param echo flag indicating echoing of the input (boolean)
-    @return result of the raw_input() call
-    """
-    if DebugClientInstance is None or not DebugClientInstance.redirect:
-        return DebugClientOrigRawInput(prompt)
-
-    return DebugClientInstance.raw_input(prompt, echo)
-
-
-def DebugClientInput(prompt="", echo=True):
-    """
-    Replacement for the standard input builtin.
-    
-    This function works with the split debugger.
-    
-    @param prompt prompt to be shown (string)
-    @param echo flag indicating to echo the output (boolean)
+    @param prompt prompt to be shown
+    @type str
     @return result of the input() call
+    @rtype str
     """
     if DebugClientInstance is None or not DebugClientInstance.redirect:
         return DebugClientOrigInput(prompt)
 
-    return DebugClientInstance.input(prompt, echo)
+    return DebugClientInstance.input(prompt)
 
-# Use our own input() and on Python 2 raw_input().
-if sys.version_info[0] == 2:
-    try:
-        DebugClientOrigRawInput = __builtins__.__dict__['raw_input']
-        __builtins__.__dict__['raw_input'] = DebugClientRawInput
-    except (AttributeError, KeyError):
-        import __main__
-        DebugClientOrigRawInput = __main__.__builtins__.__dict__['raw_input']
-        __main__.__builtins__.__dict__['raw_input'] = DebugClientRawInput
-
-    try:
-        DebugClientOrigInput = __builtins__.__dict__['input']
-        __builtins__.__dict__['input'] = DebugClientInput
-    except (AttributeError, KeyError):
-        import __main__
-        DebugClientOrigInput = __main__.__builtins__.__dict__['input']
-        __main__.__builtins__.__dict__['input'] = DebugClientInput
-else:
-    try:
-        DebugClientOrigInput = __builtins__.__dict__['input']
-        __builtins__.__dict__['input'] = DebugClientRawInput
-    except (AttributeError, KeyError):
-        import __main__
-        DebugClientOrigInput = __main__.__builtins__.__dict__['input']
-        __main__.__builtins__.__dict__['input'] = DebugClientRawInput
+# Use our own input().
+try:
+    DebugClientOrigInput = __builtins__.__dict__['input']
+    __builtins__.__dict__['input'] = DebugClientInput
+except (AttributeError, KeyError):
+    import __main__
+    DebugClientOrigInput = __main__.__builtins__.__dict__['input']
+    __main__.__builtins__.__dict__['input'] = DebugClientInput
 
 ###############################################################################
 
@@ -198,7 +163,7 @@ class DebugClientBase(object):
         self.framenr = 0
         
         # The context to run the debugged program in.
-        self.debugMod = imp.new_module('__main__')
+        self.debugMod = types.ModuleType('__main__')
         self.debugMod.__dict__['__builtins__'] = __builtins__
 
         # The list of complete lines to execute.
@@ -225,6 +190,8 @@ class DebugClientBase(object):
         
         self.callTraceEnabled = None
         
+        self.disassembly = None
+        
         self.variant = 'You should not see this'
         
         self.compile_command = codeop.CommandCompiler()
@@ -253,12 +220,11 @@ class DebugClientBase(object):
         else:
             default = 'utf-8'
             try:
-                f = open(filename, 'rb')
-                # read the first and second line
-                text = f.readline()
-                text = "{0}{1}".format(text, f.readline())
-                f.close()
-            except IOError:
+                with open(filename, 'rb') as f:
+                    # read the first and second line
+                    text = f.readline()
+                    text = "{0}{1}".format(text, f.readline())
+            except OSError:
                 self.__coding = default
                 return
             
@@ -269,9 +235,9 @@ class DebugClientBase(object):
                     return
             self.__coding = default
         
-    def raw_input(self, prompt, echo):
+    def input(self, prompt, echo=True):
         """
-        Public method to implement raw_input() / input() using the event loop.
+        Public method to implement input() using the event loop.
         
         @param prompt the prompt to be shown (string)
         @param echo Flag indicating echoing of the input (boolean)
@@ -284,15 +250,6 @@ class DebugClientBase(object):
         self.eventLoop(True)
         return self.rawLine
 
-    def input(self, prompt):
-        """
-        Public method to implement input() (Python 2) using the event loop.
-        
-        @param prompt the prompt to be shown (string)
-        @return the entered string evaluated as a Python expresion
-        """
-        return eval(self.raw_input(prompt, True))
-        
     def sessionClose(self, terminate=True):
         """
         Public method to close the session with the debugger and optionally
@@ -302,7 +259,7 @@ class DebugClientBase(object):
         """
         try:
             self.set_quit()
-        except Exception:
+        except Exception:       # secok
             pass
 
         self.debugging = False
@@ -329,13 +286,6 @@ class DebugClientBase(object):
         with codecs.open(filename, encoding=self.__coding) as fp:
             statement = fp.read()
         
-        if sys.version_info[0] == 2:
-            lines = statement.splitlines(True)
-            for lineno, line in enumerate(lines[:2]):
-                lines[lineno] = self.coding_re.sub('', line)
-
-            statement = unicode('').join(lines)  # __IGNORE_WARNING__
-        
         try:
             code = compile(statement + '\n', filename, mode)
         except SyntaxError:
@@ -377,9 +327,6 @@ class DebugClientBase(object):
         
         method = commandDict["method"]
         params = commandDict["params"]
-        if "filename" in params and sys.version_info[0] == 2:
-            params["filename"] = params["filename"].encode(
-                sys.getfilesystemencoding())
         
         if method == "RequestVariables":
             self.__dumpVariables(
@@ -402,8 +349,18 @@ class DebugClientBase(object):
                     "stack": stack,
                 })
         
+        elif method == "RequestDisassembly":
+            if self.disassembly is not None:
+                self.sendJsonCommand("ResponseDisassembly", {
+                    "disassembly": self.disassembly
+                })
+            else:
+                self.sendJsonCommand("ResponseDisassembly", {
+                    "disassembly": {}
+                })
+        
         elif method == "RequestCapabilities":
-            clientType = "Python2" if sys.version_info[0] == 2 else "Python3"
+            clientType = "Python3"
             self.sendJsonCommand("ResponseCapabilities", {
                 "capabilities": self.__clientCapabilities(),
                 "clientType": clientType
@@ -444,6 +401,7 @@ class DebugClientBase(object):
         elif method == "RequestLoad":
             self._fncache = {}
             self.dircache = []
+            self.disassembly = None
             sys.argv = []
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
@@ -484,6 +442,7 @@ class DebugClientBase(object):
                 self.mainThread.run(code, self.debugMod.__dict__, debug=True)
 
         elif method == "RequestRun":
+            self.disassembly = None
             sys.argv = []
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
@@ -518,7 +477,8 @@ class DebugClientBase(object):
                 self.mainThread.run(code, self.debugMod.__dict__, debug=False)
 
         elif method == "RequestCoverage":
-            from coverage import coverage
+            from coverage import Coverage
+            self.disassembly = None
             sys.argv = []
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
@@ -535,7 +495,7 @@ class DebugClientBase(object):
             self.__interceptSignals()
             
             # generate a coverage object
-            self.cover = coverage(
+            self.cover = Coverage(
                 auto_data=True,
                 data_file="{0}.coverage".format(
                     os.path.splitext(sys.argv[0])[0]))
@@ -555,6 +515,7 @@ class DebugClientBase(object):
         elif method == "RequestProfile":
             sys.setprofile(None)
             import PyProfile
+            self.disassembly = None
             sys.argv = []
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
@@ -578,13 +539,10 @@ class DebugClientBase(object):
             self.debugMod.__dict__['__file__'] = sys.argv[0]
             sys.modules['__main__'] = self.debugMod
             script = ''
-            if sys.version_info[0] == 2:
-                script = 'execfile({0!r})'.format(sys.argv[0])
-            else:
-                with codecs.open(sys.argv[0], encoding=self.__coding) as fp:
-                    script = fp.read()
-                if script and not script.endswith('\n'):
-                    script += '\n'
+            with codecs.open(sys.argv[0], encoding=self.__coding) as fp:
+                script = fp.read()
+            if script and not script.endswith('\n'):
+                script += '\n'
             
             if script:
                 self.running = sys.argv[0]
@@ -628,7 +586,7 @@ class DebugClientBase(object):
 
                     try:
                         if self.running is None:
-                            exec(code, self.debugMod.__dict__)
+                            exec(code, self.debugMod.__dict__)      # secok
                         else:
                             if self.currentThread is None:
                                 # program has terminated
@@ -656,15 +614,15 @@ class DebugClientBase(object):
                             if "sys" in _globals:
                                 __stdout = _globals["sys"].stdout
                                 _globals["sys"].stdout = self.writestream
-                                exec(code, _globals, _locals)
+                                exec(code, _globals, _locals)       # secok
                                 _globals["sys"].stdout = __stdout
                             elif "sys" in _locals:
                                 __stdout = _locals["sys"].stdout
                                 _locals["sys"].stdout = self.writestream
-                                exec(code, _globals, _locals)
+                                exec(code, _globals, _locals)       # secok
                                 _locals["sys"].stdout = __stdout
                             else:
-                                exec(code, _globals, _locals)
+                                exec(code, _globals, _locals)       # secok
                             
                             self.currentThread.storeFrameLocals(self.framenr)
                     except SystemExit as exc:
@@ -880,8 +838,9 @@ class DebugClientBase(object):
                             discoveryStart, top_level_dir=top_level_dir)
                 else:
                     if params["filename"]:
-                        utModule = imp.load_source(
+                        spec = importlib.util.spec_from_file_location(
                             params["testname"], params["filename"])
+                        utModule = importlib.util.module_from_spec(spec)
                     else:
                         utModule = None
                     if params["failed"]:
@@ -906,8 +865,8 @@ class DebugClientBase(object):
             
             # generate a coverage object
             if params["coverage"]:
-                from coverage import coverage
-                self.cover = coverage(
+                from coverage import Coverage
+                self.cover = Coverage(
                     auto_data=True,
                     data_file="{0}.coverage".format(
                         os.path.splitext(params["coveragefile"])[0]))
@@ -928,6 +887,7 @@ class DebugClientBase(object):
         
         elif method == "RequestUTRun":
             from DCTestResult import DCTestResult
+            self.disassembly = None
             self.testResult = DCTestResult(self, params["failfast"])
             if self.cover:
                 self.cover.start()
@@ -989,6 +949,16 @@ class DebugClientBase(object):
                     )
         return testCases
     
+    def setDisassembly(self, disassembly):
+        """
+        Public method to store a disassembly of the code object raising an
+        exception.
+        
+        @param disassembly dictionary containing the disassembly information
+        @type dict
+        """
+        self.disassembly = disassembly
+    
     def sendJsonCommand(self, method, params):
         """
         Public method to send a single command or response to the IDE.
@@ -1199,7 +1169,7 @@ class DebugClientBase(object):
             
             try:
                 rrdy, wrdy, xrdy = select.select([self.readstream], wrdy, [])
-            except (select.error, KeyboardInterrupt, socket.error):
+            except (KeyboardInterrupt, OSError):
                 selectErrors += 1
                 if selectErrors <= 10:      # arbitrarily selected
                     # just carry on
@@ -1242,7 +1212,7 @@ class DebugClientBase(object):
         # immediate return if nothing is ready.
         try:
             rrdy, wrdy, xrdy = select.select([self.readstream], wrdy, [], 0)
-        except (select.error, KeyboardInterrupt, socket.error):
+        except (KeyboardInterrupt, OSError):
             return
 
         if self.readstream in rrdy:
@@ -1367,9 +1337,6 @@ class DebugClientBase(object):
         @return the converted filename (string)
         """
         if os.path.isabs(fn):
-            if sys.version_info[0] == 2:
-                fn = fn.decode(sys.getfilesystemencoding())
-            
             return fn
 
         # Check the cache.
@@ -1382,9 +1349,6 @@ class DebugClientBase(object):
             nafn = os.path.normcase(afn)
 
             if os.path.exists(nafn):
-                if sys.version_info[0] == 2:
-                    afn = afn.decode(sys.getfilesystemencoding())
-                
                 self._fncache[fn] = afn
                 d = os.path.dirname(afn)
                 if (d not in sys.path) and (d not in self.dircache):
@@ -1585,7 +1549,7 @@ class DebugClientBase(object):
         
     def __formatQtVariable(self, value, qttype):
         """
-        Private method to produce a formatted output of a simple Qt4/Qt5 type.
+        Private method to produce a formatted output of a simple Qt5 type.
         
         @param value variable to be formatted
         @param qttype type of the Qt variable to be formatted (string)
@@ -1596,7 +1560,7 @@ class DebugClientBase(object):
         varlist = []
         if qttype == 'QChar':
             varlist.append(
-                ("", "QChar", "{0}".format(unichr(value.unicode()))))
+                ("", "QChar", "{0}".format(chr(value.unicode()))))
             varlist.append(("", "int", "{0:d}".format(value.unicode())))
         elif qttype == 'QByteArray':
             varlist.append(
@@ -1687,7 +1651,7 @@ class DebugClientBase(object):
                     ("internalId", "int", "{0}".format(value.internalId())))
                 varlist.append(("internalPointer", "void *",
                                 "{0}".format(value.internalPointer())))
-        elif qttype == 'QRegExp':
+        elif qttype in ('QRegExp', "QRegularExpression"):
             varlist.append(("pattern", "str", "{0}".format(value.pattern())))
         
         # GUI stuff
@@ -1789,7 +1753,7 @@ class DebugClientBase(object):
             
             # special handling for '__builtins__' (it's way too big)
             if key == '__builtins__':
-                rvalue = '<module __builtin__ (built-in)>'
+                rvalue = '<module builtins (built-in)>'
                 valtype = 'module'
                 if ConfigVarTypeStrings.index(valtype) in filterList:
                     continue
@@ -1812,7 +1776,7 @@ class DebugClientBase(object):
                     if ConfigVarTypeStrings.index(valtype) in filterList:
                         continue
                 except ValueError:
-                    if valtype == "sip.enumtype":
+                    if valtype in ("sip.enumtype", "sip.wrappertype"):
                         if ConfigVarTypeStrings.index('class') in filterList:
                             continue
                     elif (valtype == "sip.methoddescriptor" or
@@ -2053,16 +2017,14 @@ class DebugClientBase(object):
         self.__interceptSignals()
         
         # This will eventually enter a local event loop.
-        # Note the use of backquotes to cause a repr of self.running. The
-        # need for this is on Windows os where backslash is the path separator.
-        # They will get inadvertantly stripped away during the eval causing
-        # IOErrors if self.running is passed as a normal str.
         self.debugMod.__dict__['__file__'] = self.running
         sys.modules['__main__'] = self.debugMod
-        res = self.mainThread.run(
-            'exec(open(' + repr(self.running) + ').read())',
-            self.debugMod.__dict__)
-        self.progTerminated(res)
+        code = self.__compileFileSource(self.running)
+        if code:
+            res = self.mainThread.run(code, self.debugMod.__dict__, debug=True)
+            self.progTerminated(res)
+        else:
+            self.progTerminated(42)     # should not happen
 
     def run_call(self, scriptname, func, *args):
         """
@@ -2267,6 +2229,3 @@ class DebugClientBase(object):
         sysPath.insert(0, firstEntry)
         sysPath.insert(0, '')
         return sysPath
-
-#
-# eflag: noqa = M702
