@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,23 +19,17 @@ ConfigVarTypeStrings = [
     'method', 'property', 'generator',
     'function', 'builtin_function_or_method', 'code', 'module',
     'ellipsis', 'traceback', 'frame', 'other', 'frozenset', 'bytes',
-    # Special case for Python 2: don't add 'instancemethod' to
-    # ConfigVarTypeFilters and leave it always at last position
-    'instancemethod'
 ]
 
 BatchSize = 200
 ConfigQtNames = (
-    'PyQt5.', 'PyQt4.', 'PySide2.', 'PySide.', 'Shiboken.EnumType'
+    'PyQt5.', 'PySide2.', 'Shiboken.EnumType'
 )
 ConfigKnownQtTypes = (
     '.QChar', '.QByteArray', '.QString', '.QStringList', '.QPoint', '.QPointF',
     '.QRect', '.QRectF', '.QSize', '.QSizeF', '.QColor', '.QDate', '.QTime',
     '.QDateTime', '.QDir', '.QFile', '.QFont', '.QUrl', '.QModelIndex',
-    '.QRegExp', '.QAction', '.QKeySequence', '.QDomAttr', '.QDomCharacterData',
-    '.QDomComment', '.QDomDocument', '.QDomElement', '.QDomText',
-    '.QHostAddress', '.EnumType'
+    '.QRegExp', '.QRegularExpression', '.QAction', '.QKeySequence',
+    '.QDomAttr', '.QDomCharacterData', '.QDomComment', '.QDomDocument',
+    '.QDomElement', '.QDomText', '.QHostAddress', '.EnumType'
 )
-
-#
-# eflag: noqa = M702
