@@ -1,23 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing classes and functions to dump variable contents.
 """
 
-import sys
-
 from DebugConfig import ConfigQtNames, ConfigKnownQtTypes, BatchSize
 
 #
 # This code was inspired by pydevd.
 #
 
-if sys.version_info[0] > 2:
-    basestring = str
-
 ############################################################
 ## Classes implementing resolvers for various compund types
 ############################################################
@@ -58,7 +53,7 @@ class BaseResolver(object):
             try:
                 attribute = getattr(var, name)
                 d[name] = attribute
-            except Exception:
+            except Exception:       # secok
                 pass    # if we can't get it, simply ignore it
         
         return d
@@ -91,7 +86,7 @@ class DefaultResolver(BaseResolver):
             try:
                 attribute = getattr(var, name)
                 d[name] = attribute
-            except Exception:
+            except Exception:       # secok
                 pass    # if we can't get it, simply ignore it
         
         yield -1, d
@@ -141,7 +136,7 @@ class DictResolver(BaseResolver):
         @return string representation of the given key
         @rtype str
         """
-        if isinstance(key, basestring):
+        if isinstance(key, str):
             key = repr(key)
             # Special handling for Python2 unicode strings and bytes object
             # Raw and f-Strings are always converted to (unicode) str
@@ -653,12 +648,12 @@ def _initTypeMap():
     
     try:
         _TypeMap.append((long, None))           # __IGNORE_WARNING__
-    except Exception:
+    except Exception:       # secok
         pass    # not available on all Python versions
 
     try:
         _TypeMap.append((unicode, None))        # __IGNORE_WARNING__
-    except Exception:
+    except Exception:       # secok
         pass    # not available on all Python versions
 
     try:
@@ -704,8 +699,10 @@ def getType(obj):
     typeStr = str(typeObject).split(' ', 1)[-1]
     typeStr = typeStr[1:-2]
     
-    if (typeStr.startswith(ConfigQtNames) and
-            typeStr.endswith(ConfigKnownQtTypes)):
+    if (
+        typeStr.startswith(ConfigQtNames) and
+        typeStr.endswith(ConfigKnownQtTypes)
+    ):
         resolver = None
     else:
         if _TypeMap is None:
@@ -718,6 +715,3 @@ def getType(obj):
             resolver = defaultResolver
     
     return typeName, typeStr, resolver
-
-#
-# eflag: noqa = M702
