@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -23,7 +23,8 @@ def getuser():
     First try various environment variables, then the password
     database.  This works on Windows as long as USERNAME is set.
     
-    @return username (string)
+    @return username
+    @rtype str
     """
     # this is copied from the oroginal getpass.py
     
@@ -43,15 +44,15 @@ def getpass(prompt='Password: '):
     """
     Function to prompt for a password, with echo turned off.
     
-    @param prompt Prompt to be shown to the user (string)
-    @return Password entered by the user (string)
+    @param prompt Prompt to be shown to the user
+    @type str
+    @return Password entered by the user
+    @rtype str
     """
-    return input(prompt, False)
+    return input(prompt, False)     # secok
     
 
 unix_getpass = getpass
 win_getpass = getpass
 default_getpass = getpass
-
-#
-# eflag: noqa = M702
+fallback_getpass = getpass
