@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Breakpoint viewer widget.
 """
 
-
 from PyQt5.QtCore import (
     pyqtSignal, Qt, QItemSelectionModel, QSortFilterProxyModel, QFileInfo
 )
@@ -238,7 +237,7 @@ class BreakPointViewer(QTreeView):
         dlg = EditBreakpointDialog((self.fnHistory[0], None), None,
                                    self.condHistory, self, modal=1,
                                    addMode=1, filenameHistory=self.fnHistory)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             fn, line, cond, temp, enabled, count = dlg.getAddData()
             if fn is not None:
                 if fn in self.fnHistory:
@@ -291,7 +290,7 @@ class BreakPointViewer(QTreeView):
             dlg = EditBreakpointDialog(
                 (fn, line), (cond, temp, enabled, count),
                 self.condHistory, self, modal=True)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 cond, temp, enabled, count = dlg.getData()
                 if cond:
                     if cond in self.condHistory:
