@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Call Trace viewer widget.
 """
 
+import re
 
-from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QRegExp, QFileInfo
+from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QFileInfo
 from PyQt5.QtWidgets import QWidget, QTreeWidgetItem
 
 from E5Gui.E5Application import e5App
@@ -58,7 +59,7 @@ class CallTraceViewer(QWidget, Ui_CallTraceViewer):
         self.__callStack = []
         
         self.__entryFormat = "{0}:{1} ({2})"
-        self.__entryRe = QRegExp(r"""(.+):(\d+)\s\((.*)\)""")
+        self.__entryRe = re.compile(r"""(.+):(\d+)\s\((.*)\)""")
         
         self.__projectMode = False
         self.__project = None
@@ -165,20 +166,19 @@ class CallTraceViewer(QWidget, Ui_CallTraceViewer):
                     fname = Utilities.toNativeSeparators(fname)
                 
                 try:
-                    f = open(fname, "w", encoding="utf-8")
-                    itm = self.callTrace.topLevelItem(0)
-                    while itm is not None:
-                        isCall = itm.data(0, Qt.UserRole)
-                        if isCall:
-                            call = "->"
-                        else:
-                            call = "<-"
-                        f.write("{0} {1} || {2}\n".format(
-                            call,
-                            itm.text(1), itm.text(2)))
-                        itm = self.callTrace.itemBelow(itm)
-                    f.close()
-                except IOError as err:
+                    with open(fname, "w", encoding="utf-8") as f:
+                        itm = self.callTrace.topLevelItem(0)
+                        while itm is not None:
+                            isCall = itm.data(0, Qt.UserRole)
+                            if isCall:
+                                call = "->"
+                            else:
+                                call = "<-"
+                            f.write("{0} {1} || {2}\n".format(
+                                call,
+                                itm.text(1), itm.text(2)))
+                            itm = self.callTrace.itemBelow(itm)
+                except OSError as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Error saving Call Trace Info"),
@@ -197,8 +197,9 @@ class CallTraceViewer(QWidget, Ui_CallTraceViewer):
         """
         if item is not None and column > 0:
             columnStr = item.text(column)
-            if self.__entryRe.exactMatch(columnStr.strip()):
-                filename, lineno, func = self.__entryRe.capturedTexts()[1:]
+            match = self.__entryRe.fullmatch(columnStr.strip())
+            if match:
+                filename, lineno, func = match.groups()
                 try:
                     lineno = int(lineno)
                 except ValueError:
