@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the debug server.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal, QModelIndex
@@ -58,6 +57,8 @@ class DebugServer(QTcpServer):
     @signal clientStatement(bool) emitted after an interactive command has
         been executed. The parameter is 0 to indicate that the command is
         complete and 1 if it needs more input.
+    @signal clientDisassembly(disassembly) emitted after the client has sent
+        a disassembly of the code raising an exception
     @signal clientException(exception) emitted after an exception occured on
         the client side
     @signal clientSyntaxError(exception) emitted after a syntax error has been
@@ -128,6 +129,7 @@ class DebugServer(QTcpServer):
     clientVariables = pyqtSignal(int, list)
     clientVariable = pyqtSignal(int, list)
     clientStatement = pyqtSignal(bool)
+    clientDisassembly = pyqtSignal(dict)
     clientException = pyqtSignal(str, str, list)
     clientSyntaxError = pyqtSignal(str, str, int, int)
     clientSignal = pyqtSignal(str, str, int, str, str)
@@ -1257,7 +1259,17 @@ class DebugServer(QTcpServer):
         """
         self.debuggerInterface.remoteClientVariable(
             scope, filterList, var, framenr, self.__maxVariableSize)
-        
+    
+    def remoteClientDisassembly(self):
+        """
+        Public method to ask the client for the latest traceback disassembly.
+        """
+        try:
+            self.debuggerInterface.remoteClientDisassembly()
+        except AttributeError:
+            # remote client doesn't support that
+            pass
+    
     def remoteClientSetFilter(self, scope, filterStr):
         """
         Public method to set a variables filter list.
@@ -1499,6 +1511,16 @@ class DebugServer(QTcpServer):
         """
         self.clientStatement.emit(more)
         
+    def signalClientDisassembly(self, disassembly):
+        """
+        Public method to process the disassembly info from the client.
+        
+        @param disassembly dictionary containing the disassembly information
+        @type dict
+        """
+        if self.running:
+            self.clientDisassembly.emit(disassembly)
+    
     def signalClientException(self, exceptionType, exceptionMessage,
                               stackTrace):
         """
