@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the debugger UI.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal, QObject, Qt
@@ -1047,7 +1046,7 @@ class DebugUI(QObject):
                         self.ui, Program,
                         self.tr('<p><b>{0}</b> has terminated with an exit'
                                 ' status of {1}.</p>{2}')
-                            .format(Utilities.normabspath(self.ui.currentProg),
+                            .format(os.path.abspath(self.ui.currentProg),
                                     status, info))
             else:
                 if message:
@@ -1078,7 +1077,7 @@ class DebugUI(QObject):
                         self.appendStdout.emit(self.tr(
                             '"{0}" has terminated with an exit status of'
                             ' {1}.\n{2}\n').format(
-                            Utilities.normabspath(self.ui.currentProg), status,
+                            os.path.abspath(self.ui.currentProg), status,
                             info))
 
     def __clientSyntaxError(self, message, filename, lineNo, characterNo):
@@ -1164,7 +1163,7 @@ class DebugUI(QObject):
                             pass
                         if "__IGNORE_EXCEPTION__" in lineFlags:
                             res = E5MessageBox.No
-                except (UnicodeError, IOError):
+                except (UnicodeError, OSError):
                     pass
                 if res != E5MessageBox.No:
                     self.viewmanager.setFileLine(
@@ -1215,6 +1214,7 @@ class DebugUI(QObject):
                     stack.append((fn, ln, func, args))
                 self.clientStack.emit(stack)
                 self.__getClientVariables()
+                self.__getClientDisassembly()
                 self.ui.setDebugProfile()
                 self.debugActGrp.setEnabled(True)
                 return
@@ -1326,7 +1326,13 @@ class DebugUI(QObject):
             self.debugViewer.showVariable(variables, True)
         elif scope == 0:
             self.debugViewer.showVariable(variables, False)
-            
+    
+    def __getClientDisassembly(self):
+        """
+        Private method to ask the client for the latest traceback disassembly.
+        """
+        self.debugServer.remoteClientDisassembly()
+    
     def __clientBreakConditionError(self, filename, lineno):
         """
         Private method to handle a condition error of a breakpoint.
@@ -1357,7 +1363,7 @@ class DebugUI(QObject):
         dlg = EditBreakpointDialog(
             (fn, line), (cond, temp, enabled, count),
             [], self.ui, modal=True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             cond, temp, enabled, count = dlg.getData()
             model.setBreakPointByIndex(index, fn, line,
                                        (cond, temp, enabled, count))
@@ -1391,7 +1397,7 @@ class DebugUI(QObject):
         from .EditWatchpointDialog import EditWatchpointDialog
         dlg = EditWatchpointDialog(
             (cond, temp, enabled, count, special), self.ui)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             cond, temp, enabled, count, special = dlg.getData()
             
             # check for duplicates
@@ -1426,7 +1432,7 @@ class DebugUI(QObject):
         from .VariablesFilterDialog import VariablesFilterDialog
         dlg = VariablesFilterDialog(self.ui, 'Filter Dialog', True)
         dlg.setSelection(self.localsVarFilter, self.globalsVarFilter)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.localsVarFilter, self.globalsVarFilter = dlg.getSelection()
             self.debugViewer.setVariablesFilter(
                 self.globalsVarFilter, self.localsVarFilter)
@@ -1437,7 +1443,7 @@ class DebugUI(QObject):
         """
         from .ExceptionsFilterDialog import ExceptionsFilterDialog
         dlg = ExceptionsFilterDialog(self.excList, ignore=False)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.excList = dlg.getExceptionsList()[:]   # keep a copy
         
     def __configureIgnoredExceptions(self):
@@ -1446,7 +1452,7 @@ class DebugUI(QObject):
         """
         from .ExceptionsFilterDialog import ExceptionsFilterDialog
         dlg = ExceptionsFilterDialog(self.excIgnoreList, ignore=True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.excIgnoreList = dlg.getExceptionsList()[:]   # keep a copy
         
     def __toggleBreakpoint(self):
@@ -1568,7 +1574,7 @@ class DebugUI(QObject):
             cap, self.lastUsedVenvName, self.argvHistory, self.wdHistory,
             self.envHistory, self.exceptions, self.ui, 2,
             autoClearShell=self.autoClearShell)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (lastUsedVenvName, argv, wd, env, exceptions, clearShell,
              console) = dlg.getData()
             eraseCoverage = dlg.getCoverageData()
@@ -1703,7 +1709,7 @@ class DebugUI(QObject):
             cap, self.lastUsedVenvName, self.argvHistory, self.wdHistory,
             self.envHistory, self.exceptions, self.ui, 3,
             autoClearShell=self.autoClearShell)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (lastUsedVenvName, argv, wd, env, exceptions, clearShell,
              console) = dlg.getData()
             eraseTimings = dlg.getProfilingData()
@@ -1840,7 +1846,7 @@ class DebugUI(QObject):
             autoClearShell=self.autoClearShell,
             autoFork=self.forkAutomatically,
             forkChild=self.forkIntoChild)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (lastUsedVenvName, argv, wd, env, exceptions, clearShell,
              console) = dlg.getData()
             forkAutomatically, forkIntoChild = dlg.getRunData()
@@ -1979,7 +1985,7 @@ class DebugUI(QObject):
             tracePython=self.tracePython, autoClearShell=self.autoClearShell,
             autoContinue=self.autoContinue, autoFork=self.forkAutomatically,
             forkChild=self.forkIntoChild)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (lastUsedVenvName, argv, wd, env, exceptions, clearShell,
              console) = dlg.getData()
             tracePython, autoContinue, forkAutomatically, forkIntoChild = (
