@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,7 +20,6 @@ The views avaliable are:
 </ul>
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal
@@ -224,6 +223,16 @@ class DebugViewer(QWidget):
         self.__tabWidget.setTabToolTip(
             index, self.exceptionLogger.windowTitle())
         
+        from UI.PythonDisViewer import PythonDisViewer, PythonDisViewerModes
+        # add the Python disassembly viewer
+        self.disassemblyViewer = PythonDisViewer(
+            None, mode=PythonDisViewerModes.TracebackMode)
+        index = self.__tabWidget.addTab(
+            self.disassemblyViewer,
+            UI.PixmapCache.getIcon("disassembly"), '')
+        self.__tabWidget.setTabToolTip(
+            index, self.disassemblyViewer.windowTitle())
+        
         self.__tabWidget.setCurrentWidget(self.glvWidget)
         
         # add the threads viewer
@@ -281,6 +290,7 @@ class DebugViewer(QWidget):
         self.__threadList.clear()
         self.__tabWidget.setCurrentWidget(self.glvWidget)
         self.breakpointViewer.handleResetUI()
+        self.disassemblyViewer.clear()
         
     def initCallStackViewer(self, projectMode):
         """
@@ -433,6 +443,8 @@ class DebugViewer(QWidget):
         self.setLocalsFilter()
         self.showVariablesTab(False)
         
+        self.disassemblyViewer.clear()
+        
     def currentWidget(self):
         """
         Public method to get a reference to the current widget.
