@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Python3 debugger interface for the debug server.
 """
 
-
 import sys
 import os
 import logging
 
 from PyQt5.QtCore import (
-    QObject, QTextCodec, QProcess, QProcessEnvironment, QTimer
+    QObject, QProcess, QProcessEnvironment, QTimer
 )
 from PyQt5.QtWidgets import QInputDialog
 
@@ -33,10 +32,10 @@ ClientDefaultCapabilities = DebugClientCapabilities.HasAll
 
 class DebuggerInterfacePython(QObject):
     """
-    Class implementing the debugger interface for the debug server for Python 2
-    and Python 3.
+    Class implementing the debugger interface for the debug server for
+    Python 3.
     """
-    def __init__(self, debugServer, passive, pythonVariant):
+    def __init__(self, debugServer, passive):
         """
         Constructor
         
@@ -44,8 +43,6 @@ class DebuggerInterfacePython(QObject):
         @type DebugServer
         @param passive flag indicating passive connection mode
         @type bool
-        @param pythonVariant Python variant to instantiate for
-        @type str (one of Python2 or Python3)
         """
         super(DebuggerInterfacePython, self).__init__()
         
@@ -55,7 +52,6 @@ class DebuggerInterfacePython(QObject):
         self.debugServer = debugServer
         self.passive = passive
         self.process = None
-        self.__variant = pythonVariant
         self.__startedVenv = ""
         
         self.qsock = None
@@ -67,9 +63,6 @@ class DebuggerInterfacePython(QObject):
         # set translation function
         self.translate = self.__identityTranslation
         
-        self.codec = QTextCodec.codecForName(
-            str(Preferences.getSystem("StringEncoding")))
-        
         if passive:
             # set translation function
             if Preferences.getDebugger("PathTranslation"):
@@ -171,15 +164,11 @@ class DebuggerInterfacePython(QObject):
         global origPathEnv
         
         if not venvName:
-            if self.__variant == "Python2":
-                venvName = Preferences.getDebugger("Python2VirtualEnv")
-            else:
-                venvName = Preferences.getDebugger("Python3VirtualEnv")
+            venvName = Preferences.getDebugger("Python3VirtualEnv")
         venvManager = e5App().getObject("VirtualEnvManager")
         interpreter = venvManager.getVirtualenvInterpreter(venvName)
         execPath = venvManager.getVirtualenvExecPath(venvName)
-        if (interpreter == "" and
-                int(self.__variant[-1]) == sys.version_info[0]):
+        if interpreter == "":
             # use the interpreter used to run eric for identical variants
             interpreter = sys.executable.replace("w.exe", ".exe")
         if interpreter == "":
@@ -187,36 +176,25 @@ class DebuggerInterfacePython(QObject):
                 None,
                 self.tr("Start Debugger"),
                 self.tr(
-                    """<p>No suitable {0} environment configured.</p>""")
-                .format(self.__variant))
+                    """<p>No suitable Python3 environment configured.</p>""")
+            )
             return None, False, ""
         
-        if self.__variant == "Python2":
-            debugClientType = Preferences.getDebugger("DebugClientType")
-        else:
-            debugClientType = Preferences.getDebugger("DebugClientType3")
+        debugClientType = Preferences.getDebugger("DebugClientType3")
         if debugClientType == "standard":
             debugClient = os.path.join(getConfig('ericDir'),
                                        "DebugClients", "Python",
                                        "DebugClient.py")
         else:
-            if self.__variant == "Python2":
-                debugClient = Preferences.getDebugger("DebugClient")
-            else:
-                debugClient = Preferences.getDebugger("DebugClient3")
+            debugClient = Preferences.getDebugger("DebugClient3")
             if debugClient == "":
                 debugClient = os.path.join(sys.path[0],
                                            "DebugClients", "Python",
                                            "DebugClient.py")
         
-        if self.__variant == "Python2":
-            redirect = str(Preferences.getDebugger("PythonRedirect"))
-            noencoding = (Preferences.getDebugger("PythonNoEncoding") and
-                          '--no-encoding' or '')
-        else:
-            redirect = str(Preferences.getDebugger("Python3Redirect"))
-            noencoding = (Preferences.getDebugger("Python3NoEncoding") and
-                          '--no-encoding' or '')
+        redirect = str(Preferences.getDebugger("Python3Redirect"))
+        noencoding = (Preferences.getDebugger("Python3NoEncoding") and
+                      '--no-encoding' or '')
         
         if Preferences.getDebugger("RemoteDbgEnabled"):
             ipaddr = self.debugServer.getHostAddress(False)
@@ -354,9 +332,7 @@ class DebuggerInterfacePython(QObject):
         if not venvName:
             venvName = project.getDebugProperty("VIRTUALENV")
         if not venvName:
-            if project.getProjectLanguage() == "Python2":
-                venvName = Preferences.getDebugger("Python2VirtualEnv")
-            elif project.getProjectLanguage() == "Python3":
+            if project.getProjectLanguage() == "Python3":
                 venvName = Preferences.getDebugger("Python3VirtualEnv")
         
         redirect = str(project.getDebugProperty("REDIRECT"))
@@ -366,17 +342,18 @@ class DebuggerInterfacePython(QObject):
         venvManager = e5App().getObject("VirtualEnvManager")
         interpreter = venvManager.getVirtualenvInterpreter(venvName)
         execPath = venvManager.getVirtualenvExecPath(venvName)
-        if (interpreter == "" and
-            project.getProjectLanguage().startswith("Python") and
-                sys.version_info[0] == int(project.getProjectLanguage()[-1])):
+        if (
+            interpreter == "" and
+            project.getProjectLanguage().startswith("Python")
+        ):
             interpreter = sys.executable.replace("w.exe", ".exe")
         if interpreter == "":
             E5MessageBox.critical(
                 None,
                 self.tr("Start Debugger"),
                 self.tr(
-                    """<p>No suitable {0} environment configured.</p>""")
-                .format(self.__variant))
+                    """<p>No suitable Python3 environment configured.</p>""")
+            )
             return None, self.__isNetworked, ""
         
         if project.getDebugProperty("REMOTEDEBUGGER"):
@@ -519,11 +496,12 @@ class DebuggerInterfacePython(QObject):
         """
         Public slot to flush the queue.
         """
-        # Send commands that were waiting for the connection.
-        for cmd in self.queue:
-            self.__writeJsonCommandToSocket(cmd)
-        
-        self.queue = []
+        if self.qsock is not None:
+            # Send commands that were waiting for the connection.
+            for cmd in self.queue:
+                self.__writeJsonCommandToSocket(cmd)
+            
+            self.queue = []
     
     def shutdown(self):
         """
@@ -880,6 +858,12 @@ class DebuggerInterfacePython(QObject):
             "maxSize": maxSize,
         })
     
+    def remoteClientDisassembly(self):
+        """
+        Public method to ask the client for the latest traceback disassembly.
+        """
+        self.__sendJsonCommand("RequestDisassembly", {})
+    
     def remoteClientSetFilter(self, scope, filterStr):
         """
         Public method to set a variables filter list.
@@ -1051,10 +1035,8 @@ class DebuggerInterfacePython(QObject):
         """
         while self.qsock and self.qsock.canReadLine():
             qs = self.qsock.readLine()
-            if self.codec is not None:
-                line = self.codec.toUnicode(qs)
-            else:
-                line = bytes(qs).decode()
+            line = bytes(qs).decode(
+                encoding=Preferences.getSystem("StringEncoding"))
             
             logging.debug("<Debug-Server> %s", line)
 ##            print("Server: ", line)          ##debug
@@ -1182,6 +1164,9 @@ class DebuggerInterfacePython(QObject):
         elif method == "ResponseClearWatch":
             self.debugServer.signalClientClearWatch(params["condition"])
         
+        elif method == "ResponseDisassembly":
+            self.debugServer.signalClientDisassembly(params["disassembly"])
+        
         elif method == "ResponseException":
             if params:
                 exctype = params["type"]
@@ -1304,21 +1289,6 @@ class DebuggerInterfacePython(QObject):
         self.qsock.flush()
 
 
-def createDebuggerInterfacePython2(debugServer, passive):
-    """
-    Module function to create a debugger interface instance.
-    
-        
-    @param debugServer reference to the debug server
-    @type DebugServer
-    @param passive flag indicating passive connection mode
-    @type bool
-    @return instantiated debugger interface
-    @rtype DebuggerInterfacePython
-    """
-    return DebuggerInterfacePython(debugServer, passive, "Python2")
-    
-
 def createDebuggerInterfacePython3(debugServer, passive):
     """
     Module function to create a debugger interface instance.
@@ -1331,7 +1301,7 @@ def createDebuggerInterfacePython3(debugServer, passive):
     @return instantiated debugger interface
     @rtype DebuggerInterfacePython
     """
-    return DebuggerInterfacePython(debugServer, passive, "Python3")
+    return DebuggerInterfacePython(debugServer, passive)
 
 
 def getRegistryData():
@@ -1344,13 +1314,6 @@ def getRegistryData():
         function
     @rtype list of tuple of (str, int, list of str, function)
     """
-    py2Exts = []
-    for ext in Preferences.getDebugger("PythonExtensions").split():
-        if ext.startswith("."):
-            py2Exts.append(ext)
-        else:
-            py2Exts.append(".{0}".format(ext))
-    
     py3Exts = []
     for ext in Preferences.getDebugger("Python3Extensions").split():
         if ext.startswith("."):
@@ -1359,15 +1322,7 @@ def getRegistryData():
             py3Exts.append(".{0}".format(ext))
     
     registryData = []
-    if py2Exts and (Preferences.getDebugger("Python2VirtualEnv") or
-                    sys.version_info[0] == 2):
-        registryData.append(
-            ("Python2", ClientDefaultCapabilities, py2Exts,
-             createDebuggerInterfacePython2)
-        )
-    
-    if py3Exts and (Preferences.getDebugger("Python3VirtualEnv") or
-                    sys.version_info[0] >= 3):
+    if py3Exts:
         registryData.append(
             ("Python3", ClientDefaultCapabilities, py3Exts,
                 createDebuggerInterfacePython3)
