@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,10 +8,6 @@ Package implementing the source code documentation tools.
 """
 
 supportedExtensionsDictForApis = {
-    "Python2": [".py2", ".pyw2", ".ptl"],
     "Python3": [".py", ".pyw", ".py3", ".pyw3"],
     "Ruby": [".rb"]
 }
-
-#
-# eflag: noqa = M702
