@@ -1,19 +1,15 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a path picker widget.
 """
 
-
 import os
 
-try:
-    from enum import Enum
-except ImportError:
-    from ThirdParty.enum import Enum
+from enum import Enum
 
 from PyQt5.QtCore import pyqtSignal, Qt, QFileInfo, QCoreApplication, QDir
 from PyQt5.QtWidgets import QWidget, QHBoxLayout, QToolButton, QSizePolicy
