@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a sidebar class.
 """
 
-
 from PyQt5.QtCore import (
     QEvent, QSize, Qt, QByteArray, QDataStream, QIODevice, QTimer
 )
@@ -54,7 +53,7 @@ class E5SideBar(QWidget):
         self.__autoHideButton = QToolButton()
         self.__autoHideButton.setCheckable(True)
         self.__autoHideButton.setIcon(
-            UI.PixmapCache.getIcon("autoHideOff.png"))
+            UI.PixmapCache.getIcon("autoHideOff"))
         self.__autoHideButton.setChecked(True)
         self.__autoHideButton.setToolTip(
             self.tr("Deselect to activate automatic collapsing"))
@@ -647,10 +646,10 @@ class E5SideBar(QWidget):
         self.__autoHide = not checked
         if self.__autoHide:
             self.__autoHideButton.setIcon(
-                UI.PixmapCache.getIcon("autoHideOn.png"))
+                UI.PixmapCache.getIcon("autoHideOn"))
         else:
             self.__autoHideButton.setIcon(
-                UI.PixmapCache.getIcon("autoHideOff.png"))
+                UI.PixmapCache.getIcon("autoHideOff"))
     
     def __appFocusChanged(self, old, now):
         """
