@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a toolbar configuration dialog.
 """
 
-
 from PyQt5.QtCore import pyqtSlot, Qt
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import (
@@ -72,10 +71,10 @@ class E5ToolBarDialog(QDialog, Ui_E5ToolBarDialog):
         self.__toolBarItemToWidgetActionID = {}
         # maps toolbar item IDs to widget action IDs
         
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
-        self.leftButton.setIcon(UI.PixmapCache.getIcon("1leftarrow.png"))
-        self.rightButton.setIcon(UI.PixmapCache.getIcon("1rightarrow.png"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.leftButton.setIcon(UI.PixmapCache.getIcon("1leftarrow"))
+        self.rightButton.setIcon(UI.PixmapCache.getIcon("1rightarrow"))
         
         self.__restoreDefaultsButton = self.buttonBox.button(
             QDialogButtonBox.RestoreDefaults)
