@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to show and edit all certificates.
 """
 
-
 from PyQt5.QtCore import (
     pyqtSlot, Qt, QByteArray, QFile, QFileInfo, QIODevice
 )
@@ -45,22 +44,22 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
         self.setupUi(self)
         
         self.serversViewButton.setIcon(
-            UI.PixmapCache.getIcon("certificates.png"))
+            UI.PixmapCache.getIcon("certificates"))
         self.serversDeleteButton.setIcon(
-            UI.PixmapCache.getIcon("certificateDelete.png"))
+            UI.PixmapCache.getIcon("certificateDelete"))
         self.serversExportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateExport.png"))
+            UI.PixmapCache.getIcon("certificateExport"))
         self.serversImportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateImport.png"))
+            UI.PixmapCache.getIcon("certificateImport"))
         
         self.caViewButton.setIcon(
-            UI.PixmapCache.getIcon("certificates.png"))
+            UI.PixmapCache.getIcon("certificates"))
         self.caDeleteButton.setIcon(
-            UI.PixmapCache.getIcon("certificateDelete.png"))
+            UI.PixmapCache.getIcon("certificateDelete"))
         self.caExportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateExport.png"))
+            UI.PixmapCache.getIcon("certificateExport"))
         self.caImportButton.setIcon(
-            UI.PixmapCache.getIcon("certificateImport.png"))
+            UI.PixmapCache.getIcon("certificateImport"))
         
         self.__populateServerCertificatesTree()
         self.__populateCaCertificatesTree()
@@ -138,7 +137,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
                 self.serversCertificatesTree.currentItem().data(
                     0, self.CertRole))
             dlg = E5SslCertificatesInfoDialog(cert, self)
-            dlg.exec_()
+            dlg.exec()
         except ImportError:
             pass
     
@@ -342,7 +341,7 @@ class E5SslCertificatesDialog(QDialog, Ui_E5SslCertificatesDialog):
             cert = QSslCertificate.fromData(
                 self.caCertificatesTree.currentItem().data(0, self.CertRole))
             dlg = E5SslCertificatesInfoDialog(cert, self)
-            dlg.exec_()
+            dlg.exec()
         except ImportError:
             pass
     
