@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,17 +11,17 @@ Module defining common data to be used by all modules.
 # Note: Do not import any eric stuff in here!!!!!!!
 #
 
-
 import sys
 import os
 import re
 import shutil
 
 from PyQt5.QtCore import (
-    QDir, QLibraryInfo, QByteArray, QCoreApplication, QT_VERSION_STR,
-    QT_VERSION, QProcess, qVersion
+    QDir, QByteArray, QCoreApplication, QT_VERSION, QProcess, qVersion
 )
 
+from eric6config import getConfig
+
 # names of the various settings objects
 settingsNameOrganization = "Eric6"
 settingsNameGlobal = "eric6"
@@ -215,6 +215,24 @@ def getConfigDir():
     return hp
 
 
+def getInstallInfoFilePath():
+    """
+    Public method to get the path name of the install info file.
+    
+    @return file path of the install info file
+    @rtype str
+    """
+    filename = "eric6install.{0}.json".format(
+        getConfig("ericDir")
+        .replace(":", "_")
+        .replace("\\", "_")
+        .replace("/", "_")
+        .replace(" ", "_")
+        .strip("_")
+    )
+    return os.path.join(getConfigDir(), filename)
+
+
 def setConfigDir(d):
     """
     Module function to set the name of the directory storing the config data.
@@ -288,7 +306,8 @@ def getQtBinariesPath():
     """
     Module function to get the path of the Qt binaries.
     
-    @return path of the Qt binaries (string)
+    @return path of the Qt binaries
+    @rtype str
     """
     import Preferences
     
@@ -297,55 +316,34 @@ def getQtBinariesPath():
     # step 1: check, if the user has configured a tools path
     path = Preferences.getQt("QtToolsDir")
     
-    if not path and isWindowsPlatform():
-        # step 2.1: check for PyQt5 Windows installer (designer is test object)
-        modDir = getPyQt5ModulesDirectory()
-        if os.path.exists(os.path.join(modDir, "bin", "designer.exe")):
-            path = os.path.join(modDir, "bin")
-        elif os.path.exists(os.path.join(modDir, "designer.exe")):
-            path = modDir
-        
-        if not path:
-            import distutils.sysconfig
-            # step 2.2.1: check for the pyqt5-tools wheel (new variant)
-            # (Windows only)
-            pyqt5ToolsPath = os.path.join(
-                distutils.sysconfig.get_python_lib(True), "pyqt5_tools")
-            if os.path.exists(os.path.join(pyqt5ToolsPath, "designer.exe")):
-                path = pyqt5ToolsPath
-            if not path:
-                # step 2.2.2: check for the pyqt5-tools wheel (old variant)
-                # (Windows only)
-                pyqt5ToolsPath = os.path.join(
-                    distutils.sysconfig.get_python_lib(True), "pyqt5-tools")
-                if os.path.exists(os.path.join(pyqt5ToolsPath,
-                                               "designer.exe")):
-                    path = pyqt5ToolsPath
-    
+    # step 2: try the qt5_applications package
     if not path:
-        # step 3: get the path from Qt
-        # Note: no Qt tools are to be found there for PyQt 5.7.0
-        path = QLibraryInfo.location(QLibraryInfo.BinariesPath)
-        if not os.path.exists(path):
-            path = ""
+        try:
+            import qt5_applications
+            path = os.path.join(os.path.dirname(qt5_applications.__file__),
+                                "Qt", "bin")
+        except ImportError:
+            # qt5-applications is not installed; just go to the next step
+            pass
+    
+    # step 3: determine from used Python interpreter (designer is test object)
+    if not path:
+        program = "designer"
+        if isWindowsPlatform():
+            program += ".exe"
+            dirName = os.path.dirname(sys.executable)
+            if os.path.exists(os.path.join(dirName, program)):
+                path = dirName
+            elif os.path.exists(os.path.join(dirName, "Scripts", program)):
+                path = os.path.join(dirName, "Scripts")
+        else:
+            dirName = os.path.dirname(sys.executable)
+            if os.path.exists(os.path.join(dirName, program)):
+                path = dirName
     
     return QDir.toNativeSeparators(path)
 
 
-def translate(*args):
-    """
-    Module function to handle different PyQt 4/5 QCoreApplication.translate
-    parameter.
-    
-    @param args tuple of arguments from QCoreApplication.translate (tuple)
-    @return translated string (string)
-    """
-    if QT_VERSION_STR.startswith('4.'):
-        args = list(args)
-        args.insert(3, QCoreApplication.CodecForTr)
-    return QCoreApplication.translate(*args)
-
-
 ###############################################################################
 ## functions for version handling
 ###############################################################################
@@ -371,7 +369,11 @@ def versionToTuple(version, length=3):
     # step 1: extract suffix
     version = re.split(r"[^\d.]", version)[0]
     for part in version.split("."):
-        versionParts.append(int(part))
+        try:
+            versionParts.append(int(part.strip()))
+        except ValueError:
+            # skip non-integer parts
+            pass
     versionParts.extend([0] * length)
     
     return tuple(versionParts[:length])
