@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a graphics item for an association between two items.
 """
 
-
 from PyQt5.QtCore import QPointF, QRectF, QLineF
 from PyQt5.QtWidgets import QGraphicsItem
 
@@ -41,7 +40,7 @@ class AssociationItem(E5ArrowItem):
     ending at the second.
     """
     def __init__(self, itemA, itemB, assocType=Normal, topToBottom=False,
-                 parent=None):
+                 colors=None, parent=None):
         """
         Constructor
         
@@ -53,9 +52,13 @@ class AssociationItem(E5ArrowItem):
             <li>Generalisation</li>
             <li>Imports</li>
             </ul>
-        @keyparam topToBottom flag indicating to draw the association
-            from item A top to item B bottom (boolean)
-        @keyparam parent reference to the parent object (QGraphicsItem)
+        @param topToBottom flag indicating to draw the association
+            from item A top to item B bottom
+        @type bool
+        @param colors tuple containing the foreground and background colors
+        @type tuple of (QColor, QColor)
+        @param parent reference to the parent object
+        @type QGraphicsItem
         """
         if assocType == Normal:
             arrowType = NormalArrow
@@ -68,7 +71,7 @@ class AssociationItem(E5ArrowItem):
             arrowFilled = False
         
         E5ArrowItem.__init__(self, QPointF(0, 0), QPointF(100, 100),
-                             arrowFilled, arrowType, parent)
+                             arrowFilled, arrowType, colors, parent)
         
         self.setFlag(QGraphicsItem.ItemIsMovable, False)
         self.setFlag(QGraphicsItem.ItemIsSelectable, False)
