@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog showing a pixmap.
 """
 
-
 from PyQt5.QtCore import Qt, QSize, QEvent
 from PyQt5.QtGui import QPalette, QImage, QPixmap, QPainter, QFont, QColor
 from PyQt5.QtWidgets import (
@@ -320,7 +319,7 @@ class PixmapDiagram(E5MainWindow):
         printer.setPrinterName(Preferences.getPrinter("PrinterName"))
         
         printDialog = QPrintDialog(printer, self)
-        if printDialog.exec_():
+        if printDialog.exec():
             self.__print(printer)
         
     def __printPreviewDiagram(self):
@@ -350,7 +349,7 @@ class PixmapDiagram(E5MainWindow):
         
         preview = QPrintPreviewDialog(printer, self)
         preview.paintRequested[QPrinter].connect(self.__print)
-        preview.exec_()
+        preview.exec()
         
     def __print(self, printer):
         """
