@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the hex editor main window.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -71,7 +70,7 @@ class HexEditMainWindow(E5MainWindow):
         }
         
         self.__fromEric = fromEric
-        self.setWindowIcon(UI.PixmapCache.getIcon("hexEditor.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("hexEditor"))
         
         if not self.__fromEric:
             self.setStyle(Preferences.getUI("Style"),
@@ -158,7 +157,7 @@ class HexEditMainWindow(E5MainWindow):
         """
         self.newWindowAct = E5Action(
             self.tr('New Window'),
-            UI.PixmapCache.getIcon("newWindow.png"),
+            UI.PixmapCache.getIcon("newWindow"),
             self.tr('New &Window'),
             0, 0, self, 'hexEditor_file_new_window')
         self.newWindowAct.setStatusTip(self.tr(
@@ -174,7 +173,7 @@ class HexEditMainWindow(E5MainWindow):
         # correct texts will be set later
         self.openAct = E5Action(
             self.tr('Open'),
-            UI.PixmapCache.getIcon("open.png"),
+            UI.PixmapCache.getIcon("open"),
             self.tr('&Open...'),
             QKeySequence(self.tr("Ctrl+O", "File|Open")),
             0, self, 'hexEditor_file_open')
@@ -190,7 +189,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.saveAct = E5Action(
             self.tr('Save'),
-            UI.PixmapCache.getIcon("fileSave.png"),
+            UI.PixmapCache.getIcon("fileSave"),
             self.tr('&Save'),
             QKeySequence(self.tr("Ctrl+S", "File|Save")),
             0, self, 'hexEditor_file_save')
@@ -204,7 +203,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.saveAsAct = E5Action(
             self.tr('Save As'),
-            UI.PixmapCache.getIcon("fileSaveAs.png"),
+            UI.PixmapCache.getIcon("fileSaveAs"),
             self.tr('Save &As...'),
             QKeySequence(self.tr("Shift+Ctrl+S", "File|Save As")),
             0, self, 'hexEditor_file_save_as')
@@ -234,7 +233,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.closeAct = E5Action(
             self.tr('Close'),
-            UI.PixmapCache.getIcon("close.png"),
+            UI.PixmapCache.getIcon("close"),
             self.tr('&Close'),
             QKeySequence(self.tr("Ctrl+W", "File|Close")),
             0, self, 'hexEditor_file_close')
@@ -275,7 +274,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.exitAct = E5Action(
             self.tr('Quit'),
-            UI.PixmapCache.getIcon("exit.png"),
+            UI.PixmapCache.getIcon("exit"),
             self.tr('&Quit'),
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")),
             0, self, 'hexEditor_file_quit')
@@ -294,7 +293,7 @@ class HexEditMainWindow(E5MainWindow):
         """
         self.undoAct = E5Action(
             self.tr('Undo'),
-            UI.PixmapCache.getIcon("editUndo.png"),
+            UI.PixmapCache.getIcon("editUndo"),
             self.tr('&Undo'),
             QKeySequence(self.tr("Ctrl+Z", "Edit|Undo")),
             QKeySequence(self.tr("Alt+Backspace", "Edit|Undo")),
@@ -309,7 +308,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.redoAct = E5Action(
             self.tr('Redo'),
-            UI.PixmapCache.getIcon("editRedo.png"),
+            UI.PixmapCache.getIcon("editRedo"),
             self.tr('&Redo'),
             QKeySequence(self.tr("Ctrl+Shift+Z", "Edit|Redo")),
             0, self, 'hexEditor_edit_redo')
@@ -338,7 +337,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.cutAct = E5Action(
             self.tr('Cut'),
-            UI.PixmapCache.getIcon("editCut.png"),
+            UI.PixmapCache.getIcon("editCut"),
             self.tr('Cu&t'),
             QKeySequence(self.tr("Ctrl+X", "Edit|Cut")),
             QKeySequence(self.tr("Shift+Del", "Edit|Cut")),
@@ -353,7 +352,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.copyAct = E5Action(
             self.tr('Copy'),
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr('&Copy'),
             QKeySequence(self.tr("Ctrl+C", "Edit|Copy")),
             QKeySequence(self.tr("Ctrl+Ins", "Edit|Copy")),
@@ -368,7 +367,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.pasteAct = E5Action(
             self.tr('Paste'),
-            UI.PixmapCache.getIcon("editPaste.png"),
+            UI.PixmapCache.getIcon("editPaste"),
             self.tr('&Paste'),
             QKeySequence(self.tr("Ctrl+V", "Edit|Paste")),
             QKeySequence(self.tr("Shift+Ins", "Edit|Paste")),
@@ -383,7 +382,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.selectAllAct = E5Action(
             self.tr('Select All'),
-            UI.PixmapCache.getIcon("editSelectAll.png"),
+            UI.PixmapCache.getIcon("editSelectAll"),
             self.tr('&Select All'),
             QKeySequence(self.tr("Ctrl+A", "Edit|Select All")),
             0,
@@ -445,7 +444,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.searchAct = E5Action(
             self.tr('Search'),
-            UI.PixmapCache.getIcon("find.png"),
+            UI.PixmapCache.getIcon("find"),
             self.tr('&Search...'),
             QKeySequence(self.tr("Ctrl+F", "Search|Search")),
             0,
@@ -461,7 +460,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.searchNextAct = E5Action(
             self.tr('Search next'),
-            UI.PixmapCache.getIcon("findNext.png"),
+            UI.PixmapCache.getIcon("findNext"),
             self.tr('Search &next'),
             QKeySequence(self.tr("F3", "Search|Search next")),
             0,
@@ -478,7 +477,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.searchPrevAct = E5Action(
             self.tr('Search previous'),
-            UI.PixmapCache.getIcon("findPrev.png"),
+            UI.PixmapCache.getIcon("findPrev"),
             self.tr('Search &previous'),
             QKeySequence(self.tr("Shift+F3", "Search|Search previous")),
             0,
@@ -512,7 +511,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.gotoAct = E5Action(
             self.tr('Goto Offset'),
-            UI.PixmapCache.getIcon("goto.png"),
+            UI.PixmapCache.getIcon("goto"),
             self.tr('&Goto Offset...'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+G", "Search|Goto Offset")),
@@ -575,7 +574,7 @@ class HexEditMainWindow(E5MainWindow):
         
         self.whatsThisAct = E5Action(
             self.tr('What\'s This?'),
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'),
             QKeySequence(self.tr("Shift+F1", "Help|What's This?'")),
             0, self, 'hexEditor_help_whats_this')
@@ -597,7 +596,7 @@ class HexEditMainWindow(E5MainWindow):
         """
         self.prefAct = E5Action(
             self.tr('Preferences'),
-            UI.PixmapCache.getIcon("configure.png"),
+            UI.PixmapCache.getIcon("configure"),
             self.tr('&Preferences...'),
             0, 0, self, 'hexEditor_settings_preferences')
         self.prefAct.setStatusTip(self.tr(
@@ -1369,7 +1368,7 @@ class HexEditMainWindow(E5MainWindow):
             self.__preferencesChangedByLocalPreferencesDialog)
         dlg.show()
         dlg.showConfigurationPageByName("hexEditorPage")
-        dlg.exec_()
+        dlg.exec()
         QCoreApplication.processEvents()
         if dlg.result() == QDialog.Accepted:
             dlg.setPreferences()
@@ -1392,9 +1391,10 @@ class HexEditMainWindow(E5MainWindow):
         @return the requested history list
         @rtype list of tuples of (int, str)
         """
-        assert key in ['search', 'replace']
+        if key in ['search', 'replace']:
+            return self.__srHistory[key]
         
-        return self.__srHistory[key]
+        return []
     
     @pyqtSlot()
     def __showFileMenu(self):
