@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -662,10 +662,9 @@ class HexEditWidget(QAbstractScrollArea):
         @param ch byte to insert
         @type int in the range 0x00 to 0xff
         """
-        assert ch in range(0, 256)
-        
-        self.__undoStack.insert(pos, ch)
-        self.__refresh()
+        if ch in range(0, 256):
+            self.__undoStack.insert(pos, ch)
+            self.__refresh()
     
     def remove(self, pos, length=1):
         """
@@ -688,10 +687,9 @@ class HexEditWidget(QAbstractScrollArea):
         @param ch byte to replace with
         @type int in the range 0x00 to 0xff
         """
-        assert ch in range(0, 256)
-        
-        self.__undoStack.overwrite(pos, ch)
-        self.__refresh()
+        if ch in range(0, 256):
+            self.__undoStack.overwrite(pos, ch)
+            self.__refresh()
     
     def insertByteArray(self, pos, byteArray):
         """
