@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the icon editor main window.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -59,7 +58,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.fromEric = fromEric
         self.initShortcutsOnly = initShortcutsOnly
-        self.setWindowIcon(UI.PixmapCache.getIcon("iconEditor.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("iconEditor"))
         
         if self.initShortcutsOnly:
             self.__initActions()
@@ -193,7 +192,7 @@ class IconEditorWindow(E5MainWindow):
         """
         self.newAct = E5Action(
             self.tr('New'),
-            UI.PixmapCache.getIcon("new.png"),
+            UI.PixmapCache.getIcon("new"),
             self.tr('&New'),
             QKeySequence(self.tr("Ctrl+N", "File|New")),
             0, self, 'iconEditor_file_new')
@@ -207,7 +206,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.newWindowAct = E5Action(
             self.tr('New Window'),
-            UI.PixmapCache.getIcon("newWindow.png"),
+            UI.PixmapCache.getIcon("newWindow"),
             self.tr('New &Window'),
             0, 0, self, 'iconEditor_file_new_window')
         self.newWindowAct.setStatusTip(self.tr(
@@ -221,7 +220,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.openAct = E5Action(
             self.tr('Open'),
-            UI.PixmapCache.getIcon("open.png"),
+            UI.PixmapCache.getIcon("open"),
             self.tr('&Open...'),
             QKeySequence(self.tr("Ctrl+O", "File|Open")),
             0, self, 'iconEditor_file_open')
@@ -236,7 +235,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.saveAct = E5Action(
             self.tr('Save'),
-            UI.PixmapCache.getIcon("fileSave.png"),
+            UI.PixmapCache.getIcon("fileSave"),
             self.tr('&Save'),
             QKeySequence(self.tr("Ctrl+S", "File|Save")),
             0, self, 'iconEditor_file_save')
@@ -250,7 +249,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.saveAsAct = E5Action(
             self.tr('Save As'),
-            UI.PixmapCache.getIcon("fileSaveAs.png"),
+            UI.PixmapCache.getIcon("fileSaveAs"),
             self.tr('Save &As...'),
             QKeySequence(self.tr("Shift+Ctrl+S", "File|Save As")),
             0, self, 'iconEditor_file_save_as')
@@ -265,7 +264,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.closeAct = E5Action(
             self.tr('Close'),
-            UI.PixmapCache.getIcon("close.png"),
+            UI.PixmapCache.getIcon("close"),
             self.tr('&Close'),
             QKeySequence(self.tr("Ctrl+W", "File|Close")),
             0, self, 'iconEditor_file_close')
@@ -306,7 +305,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.exitAct = E5Action(
             self.tr('Quit'),
-            UI.PixmapCache.getIcon("exit.png"),
+            UI.PixmapCache.getIcon("exit"),
             self.tr('&Quit'),
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")),
             0, self, 'iconEditor_file_quit')
@@ -325,7 +324,7 @@ class IconEditorWindow(E5MainWindow):
         """
         self.undoAct = E5Action(
             self.tr('Undo'),
-            UI.PixmapCache.getIcon("editUndo.png"),
+            UI.PixmapCache.getIcon("editUndo"),
             self.tr('&Undo'),
             QKeySequence(self.tr("Ctrl+Z", "Edit|Undo")),
             QKeySequence(self.tr("Alt+Backspace", "Edit|Undo")),
@@ -340,7 +339,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.redoAct = E5Action(
             self.tr('Redo'),
-            UI.PixmapCache.getIcon("editRedo.png"),
+            UI.PixmapCache.getIcon("editRedo"),
             self.tr('&Redo'),
             QKeySequence(self.tr("Ctrl+Shift+Z", "Edit|Redo")),
             0, self, 'iconEditor_edit_redo')
@@ -354,7 +353,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.cutAct = E5Action(
             self.tr('Cut'),
-            UI.PixmapCache.getIcon("editCut.png"),
+            UI.PixmapCache.getIcon("editCut"),
             self.tr('Cu&t'),
             QKeySequence(self.tr("Ctrl+X", "Edit|Cut")),
             QKeySequence(self.tr("Shift+Del", "Edit|Cut")),
@@ -369,7 +368,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.copyAct = E5Action(
             self.tr('Copy'),
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr('&Copy'),
             QKeySequence(self.tr("Ctrl+C", "Edit|Copy")),
             QKeySequence(self.tr("Ctrl+Ins", "Edit|Copy")),
@@ -384,7 +383,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.pasteAct = E5Action(
             self.tr('Paste'),
-            UI.PixmapCache.getIcon("editPaste.png"),
+            UI.PixmapCache.getIcon("editPaste"),
             self.tr('&Paste'),
             QKeySequence(self.tr("Ctrl+V", "Edit|Paste")),
             QKeySequence(self.tr("Shift+Ins", "Edit|Paste")),
@@ -412,7 +411,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.deleteAct = E5Action(
             self.tr('Clear'),
-            UI.PixmapCache.getIcon("editDelete.png"),
+            UI.PixmapCache.getIcon("editDelete"),
             self.tr('Cl&ear'),
             QKeySequence(self.tr("Alt+Shift+C", "Edit|Clear")),
             0,
@@ -443,7 +442,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.resizeAct = E5Action(
             self.tr('Change Size'),
-            UI.PixmapCache.getIcon("transformResize.png"),
+            UI.PixmapCache.getIcon("transformResize"),
             self.tr('Change Si&ze...'),
             0, 0,
             self, 'iconEditor_edit_change_size')
@@ -457,7 +456,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.grayscaleAct = E5Action(
             self.tr('Grayscale'),
-            UI.PixmapCache.getIcon("grayscale.png"),
+            UI.PixmapCache.getIcon("grayscale"),
             self.tr('&Grayscale'),
             0, 0,
             self, 'iconEditor_edit_grayscale')
@@ -494,7 +493,7 @@ class IconEditorWindow(E5MainWindow):
         """
         self.zoomInAct = E5Action(
             self.tr('Zoom in'),
-            UI.PixmapCache.getIcon("zoomIn.png"),
+            UI.PixmapCache.getIcon("zoomIn"),
             self.tr('Zoom &in'),
             QKeySequence(self.tr("Ctrl++", "View|Zoom in")),
             0, self, 'iconEditor_view_zoom_in')
@@ -508,7 +507,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.zoomOutAct = E5Action(
             self.tr('Zoom out'),
-            UI.PixmapCache.getIcon("zoomOut.png"),
+            UI.PixmapCache.getIcon("zoomOut"),
             self.tr('Zoom &out'),
             QKeySequence(self.tr("Ctrl+-", "View|Zoom out")),
             0, self, 'iconEditor_view_zoom_out')
@@ -522,7 +521,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.zoomResetAct = E5Action(
             self.tr('Zoom reset'),
-            UI.PixmapCache.getIcon("zoomReset.png"),
+            UI.PixmapCache.getIcon("zoomReset"),
             self.tr('Zoom &reset'),
             QKeySequence(self.tr("Ctrl+0", "View|Zoom reset")),
             0, self, 'iconEditor_view_zoom_reset')
@@ -538,7 +537,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.showGridAct = E5Action(
             self.tr('Show Grid'),
-            UI.PixmapCache.getIcon("grid.png"),
+            UI.PixmapCache.getIcon("grid"),
             self.tr('Show &Grid'),
             0, 0,
             self, 'iconEditor_view_show_grid')
@@ -565,7 +564,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawPencilAct = E5Action(
             self.tr('Freehand'),
-            UI.PixmapCache.getIcon("drawBrush.png"),
+            UI.PixmapCache.getIcon("drawBrush"),
             self.tr('&Freehand'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_pencil')
@@ -580,7 +579,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawColorPickerAct = E5Action(
             self.tr('Color Picker'),
-            UI.PixmapCache.getIcon("colorPicker.png"),
+            UI.PixmapCache.getIcon("colorPicker"),
             self.tr('&Color Picker'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_color_picker')
@@ -597,7 +596,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawRectangleAct = E5Action(
             self.tr('Rectangle'),
-            UI.PixmapCache.getIcon("drawRectangle.png"),
+            UI.PixmapCache.getIcon("drawRectangle"),
             self.tr('&Rectangle'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_rectangle')
@@ -612,7 +611,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawFilledRectangleAct = E5Action(
             self.tr('Filled Rectangle'),
-            UI.PixmapCache.getIcon("drawRectangleFilled.png"),
+            UI.PixmapCache.getIcon("drawRectangleFilled"),
             self.tr('F&illed Rectangle'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_filled_rectangle')
@@ -628,7 +627,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawCircleAct = E5Action(
             self.tr('Circle'),
-            UI.PixmapCache.getIcon("drawCircle.png"),
+            UI.PixmapCache.getIcon("drawCircle"),
             self.tr('Circle'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_circle')
@@ -643,7 +642,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawFilledCircleAct = E5Action(
             self.tr('Filled Circle'),
-            UI.PixmapCache.getIcon("drawCircleFilled.png"),
+            UI.PixmapCache.getIcon("drawCircleFilled"),
             self.tr('Fille&d Circle'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_filled_circle')
@@ -659,7 +658,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawEllipseAct = E5Action(
             self.tr('Ellipse'),
-            UI.PixmapCache.getIcon("drawEllipse.png"),
+            UI.PixmapCache.getIcon("drawEllipse"),
             self.tr('&Ellipse'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_ellipse')
@@ -674,7 +673,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawFilledEllipseAct = E5Action(
             self.tr('Filled Ellipse'),
-            UI.PixmapCache.getIcon("drawEllipseFilled.png"),
+            UI.PixmapCache.getIcon("drawEllipseFilled"),
             self.tr('Fille&d Elli&pse'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_filled_ellipse')
@@ -690,7 +689,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawFloodFillAct = E5Action(
             self.tr('Flood Fill'),
-            UI.PixmapCache.getIcon("drawFill.png"),
+            UI.PixmapCache.getIcon("drawFill"),
             self.tr('Fl&ood Fill'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_flood_fill')
@@ -706,7 +705,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawLineAct = E5Action(
             self.tr('Line'),
-            UI.PixmapCache.getIcon("drawLine.png"),
+            UI.PixmapCache.getIcon("drawLine"),
             self.tr('&Line'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_line')
@@ -721,7 +720,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawEraserAct = E5Action(
             self.tr('Eraser (Transparent)'),
-            UI.PixmapCache.getIcon("drawEraser.png"),
+            UI.PixmapCache.getIcon("drawEraser"),
             self.tr('Eraser (&Transparent)'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_eraser')
@@ -736,7 +735,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawRectangleSelectionAct = E5Action(
             self.tr('Rectangular Selection'),
-            UI.PixmapCache.getIcon("selectRectangle.png"),
+            UI.PixmapCache.getIcon("selectRectangle"),
             self.tr('Rect&angular Selection'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_selection_rectangle')
@@ -753,7 +752,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.drawCircleSelectionAct = E5Action(
             self.tr('Circular Selection'),
-            UI.PixmapCache.getIcon("selectCircle.png"),
+            UI.PixmapCache.getIcon("selectCircle"),
             self.tr('Rect&angular Selection'),
             0, 0,
             self.drawingActGrp, 'iconEditor_tools_selection_circle')
@@ -801,7 +800,7 @@ class IconEditorWindow(E5MainWindow):
         
         self.whatsThisAct = E5Action(
             self.tr('What\'s This?'),
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'),
             QKeySequence(self.tr("Shift+F1", "Help|What's This?'")),
             0, self, 'iconEditor_help_whats_this')
@@ -971,9 +970,9 @@ class IconEditorWindow(E5MainWindow):
         self.__updatePosition(0, 0)
         
         self.__zoomWidget = E5ZoomWidget(
-            UI.PixmapCache.getPixmap("zoomOut.png"),
-            UI.PixmapCache.getPixmap("zoomIn.png"),
-            UI.PixmapCache.getPixmap("zoomReset.png"), self)
+            UI.PixmapCache.getPixmap("zoomOut"),
+            UI.PixmapCache.getPixmap("zoomIn"),
+            UI.PixmapCache.getPixmap("zoomReset"), self)
         self.__zoomWidget.setMinimum(IconEditorGrid.ZoomMinimum)
         self.__zoomWidget.setMaximum(IconEditorGrid.ZoomMaximum)
         self.__zoomWidget.setDefault(IconEditorGrid.ZoomDefault)
