@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a file manager for MicroPython devices.
 """
 
-
 import os
 import shutil
 
@@ -609,7 +608,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
         self.__localDelDirTreeAct.setEnabled(isDir)
         self.__localDelFileAct.setEnabled(isFile)
         
-        self.__localMenu.exec_(self.localFileTreeWidget.mapToGlobal(pos))
+        self.__localMenu.exec(self.localFileTreeWidget.mapToGlobal(pos))
     
     @pyqtSlot()
     def __changeLocalDirectory(self, localDevice=False):
@@ -662,7 +661,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                 os.mkdir(dirPath)
                 self.__listLocalFiles(cwdWidget.text(),
                                       localDevice=localDevice)
-            except (OSError, IOError) as exc:
+            except OSError as exc:
                 E5MessageBox.critical(
                     self,
                     self.tr("Create Directory"),
@@ -695,7 +694,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                 self.tr(
                     "Do you really want to delete this directory tree?"),
                 [dirname])
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 try:
                     shutil.rmtree(dirname)
                     self.__listLocalFiles(cwdWidget.text(),
@@ -733,12 +732,12 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                 self.tr(
                     "Do you really want to delete this file?"),
                 [filename])
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 try:
                     os.remove(filename)
                     self.__listLocalFiles(cwdWidget.text(),
                                           localDevice=localDevice)
-                except (OSError, IOError) as exc:
+                except OSError as exc:
                     E5MessageBox.critical(
                         self,
                         self.tr("Delete File"),
@@ -784,7 +783,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
             self.__devDelDirTreeAct.setEnabled(isDir)
         self.__devDelFileAct.setEnabled(isFile)
         
-        self.__deviceMenu.exec_(self.deviceFileTreeWidget.mapToGlobal(pos))
+        self.__deviceMenu.exec(self.deviceFileTreeWidget.mapToGlobal(pos))
     
     @pyqtSlot()
     def __changeDeviceDirectory(self):
@@ -848,7 +847,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                     self.tr(
                         "Do you really want to delete this directory?"),
                     [dirname])
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     self.__fileManager.rmdir(dirname)
     
     @pyqtSlot()
@@ -876,7 +875,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                     self.tr(
                         "Do you really want to delete this directory tree?"),
                     [dirname])
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     self.__fileManager.rmdir(dirname, recursive=True)
     
     @pyqtSlot()
@@ -903,7 +902,7 @@ class MicroPythonFileManagerWidget(QWidget, Ui_MicroPythonFileManagerWidget):
                     self.tr(
                         "Do you really want to delete this file?"),
                     [filename])
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     self.__fileManager.delete(filename)
     
     @pyqtSlot(bool)
