@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the MicroPython REPL widget.
 """
 
-
 import re
 import time
 import os
@@ -16,7 +15,7 @@ from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QPoint, QEvent
 from PyQt5.QtGui import QColor, QKeySequence, QTextCursor, QBrush
 from PyQt5.QtWidgets import (
     QWidget, QMenu, QApplication, QHBoxLayout, QSpacerItem, QSizePolicy,
-    QTextEdit, QToolButton
+    QTextEdit, QToolButton, QDialog
 )
 
 from E5Gui.E5ZoomWidget import E5ZoomWidget
@@ -136,6 +135,42 @@ AnsiColorSchemes = {
         16: QBrush(QColor(0, 255, 255)),
         17: QBrush(QColor(255, 255, 255)),
     },
+    "Ubuntu (dark)": {
+        0: QBrush(QColor(96, 96, 96)),
+        1: QBrush(QColor(235, 58, 45)),
+        2: QBrush(QColor(57, 181, 74)),
+        3: QBrush(QColor(255, 199, 29)),
+        4: QBrush(QColor(25, 56, 230)),
+        5: QBrush(QColor(200, 64, 193)),
+        6: QBrush(QColor(48, 200, 255)),
+        7: QBrush(QColor(204, 204, 204)),
+        10: QBrush(QColor(128, 128, 128)),
+        11: QBrush(QColor(255, 0, 0)),
+        12: QBrush(QColor(0, 255, 0)),
+        13: QBrush(QColor(255, 255, 0)),
+        14: QBrush(QColor(0, 0, 255)),
+        15: QBrush(QColor(255, 0, 255)),
+        16: QBrush(QColor(0, 255, 255)),
+        17: QBrush(QColor(255, 255, 255)),
+    },
+    "Breeze (dark)": {
+        0: QBrush(QColor(35, 38, 39)),
+        1: QBrush(QColor(237, 21, 21)),
+        2: QBrush(QColor(17, 209, 22)),
+        3: QBrush(QColor(246, 116, 0)),
+        4: QBrush(QColor(29, 153, 243)),
+        5: QBrush(QColor(155, 89, 182)),
+        6: QBrush(QColor(26, 188, 156)),
+        7: QBrush(QColor(252, 252, 252)),
+        10: QBrush(QColor(127, 140, 141)),
+        11: QBrush(QColor(192, 57, 43)),
+        12: QBrush(QColor(28, 220, 154)),
+        13: QBrush(QColor(253, 188, 75)),
+        14: QBrush(QColor(61, 174, 233)),
+        15: QBrush(QColor(142, 68, 173)),
+        16: QBrush(QColor(22, 160, 133)),
+        17: QBrush(QColor(255, 255, 255)),
+    },
 }
 
 
@@ -213,6 +248,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         self.__currentZoom = 0
         
         self.__fileManagerWidget = None
+        self.__chartWidget = None
         
         if HAS_QTSERIALPORT:
             self.__interface = MicroPythonCommandsInterface(self)
@@ -258,7 +294,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         self.deviceInfoLabel.clear()
         
         self.deviceTypeComboBox.addItem("", "")
-        devices = MicroPythonDevices.getFoundDevices()
+        devices, unknownDevices = MicroPythonDevices.getFoundDevices()
         if devices:
             self.deviceInfoLabel.setText(
                 self.tr("%n supported device(s) detected.", "", len(devices)))
@@ -288,6 +324,39 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         
         self.on_deviceTypeComboBox_activated(index)
         self.deviceTypeComboBox.setCurrentIndex(index)
+        
+        if unknownDevices:
+            ignoredUnknown = {
+                tuple(d)
+                for d in Preferences.getMicroPython("IgnoredUnknownDevices")
+            }
+            newUnknownDevices = set(unknownDevices) - ignoredUnknown
+            if newUnknownDevices:
+                button = E5MessageBox.information(
+                    self,
+                    self.tr("Unknown MicroPython Device"),
+                    self.tr(
+                        '<p>Detected these unknown serial devices</p>'
+                        '<ul>'
+                        '<li>{0}</li>'
+                        '</ul>'
+                        '<p>Please report them together with the board name'
+                        ' and a short description to <a href="mailto:'
+                        'eric-bugs@eric-ide.python-projects.org"> the eric'
+                        ' bug reporting address</a> if it is a MicroPython'
+                        ' board.</p>'
+                    ).format("</li><li>".join([
+                        self.tr("{0} ({1:04x}/{2:04x})").format(desc, vid, pid)
+                        for vid, pid, desc in newUnknownDevices])),
+                    E5MessageBox.StandardButtons(
+                        E5MessageBox.Ignore |
+                        E5MessageBox.Ok
+                    )
+                )
+                if button == E5MessageBox.Ignore:
+                    ignoredUnknown = list(ignoredUnknown | newUnknownDevices)
+                    Preferences.setMicroPython("IgnoredUnknownDevices",
+                                               ignoredUnknown)
     
     def __handlePreferencesChanged(self):
         """
@@ -303,6 +372,9 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
             self.replEdit.setLineWrapMode(QTextEdit.WidgetWidth)
         else:
             self.replEdit.setLineWrapMode(QTextEdit.NoWrap)
+        
+        if self.__chartWidget is not None:
+            self.__chartWidget.preferencesChanged()
     
     def commandsInterface(self):
         """
@@ -370,7 +442,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         if "files" in kwargs:
             self.filesButton.setEnabled(kwargs["files"])
         if "chart" in kwargs:
-            self.chartButton.setEnabled(kwargs["chart"])
+            self.chartButton.setEnabled(kwargs["chart"] and HAS_QTCHART)
     
     @pyqtSlot(QPoint)
     def __showContextMenu(self, pos):
@@ -392,7 +464,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         menu.addAction(self.tr("Copy"), self.replEdit.copy, copyKeys)
         menu.addAction(self.tr("Paste"), self.__paste, pasteKeys)
         menu.addSeparator()
-        menu.exec_(self.replEdit.mapToGlobal(pos))
+        menu.exec(self.replEdit.mapToGlobal(pos))
     
     def __setConnected(self, connected):
         """
@@ -1135,6 +1207,9 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 self.tr("Show Documentation"), self.__showDocumentation)
             act.setEnabled(self.__device.hasDocumentationUrl())
         self.__superMenu.addSeparator()
+        self.__superMenu.addAction(self.tr("Ignored Serial Devices"),
+                                   self.__manageIgnored)
+        self.__superMenu.addSeparator()
         self.__superMenu.addAction(self.tr("Configure"), self.__configure)
     
     @pyqtSlot()
@@ -1411,7 +1486,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         dlg = E5ProcessDialog(self.tr("'mpy-cross' Output"), title)
         res = dlg.startProcess(program, compileArgs)
         if res:
-            dlg.exec_()
+            dlg.exec()
     
     @pyqtSlot()
     def __compileFile2Mpy(self):
@@ -1467,6 +1542,21 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         url = self.__device.getFirmwareUrl()
         e5App().getObject("UserInterface").launchHelpViewer(url)
     
+    @pyqtSlot()
+    def __manageIgnored(self):
+        """
+        Private slot to manage the list of ignored serial devices.
+        """
+        from .IgnoredDevicesDialog import IgnoredDevicesDialog
+        
+        dlg = IgnoredDevicesDialog(
+            Preferences.getMicroPython("IgnoredUnknownDevices"),
+            self)
+        if dlg.exec() == QDialog.Accepted:
+            ignoredDevices = dlg.getDevices()
+            Preferences.setMicroPython("IgnoredUnknownDevices",
+                                       ignoredDevices)
+    
     @pyqtSlot()
     def __configure(self):
         """
