@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the IRC window.
 """
 
-
 import re
 import logging
 
@@ -61,7 +60,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         
         self.__leaveButton = QToolButton(self)
         self.__leaveButton.setIcon(
-            UI.PixmapCache.getIcon("ircCloseChannel.png"))
+            UI.PixmapCache.getIcon("ircCloseChannel"))
         self.__leaveButton.setToolTip(
             self.tr("Press to leave the current channel"))
         self.__leaveButton.clicked.connect(self.__leaveChannel)
@@ -113,7 +112,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         self.__prefixRe = re.compile(r""".*\sPREFIX=\((.*)\)([^ ]+).*""")
         self.__chanTypesRe = re.compile(r""".*\sCHANTYPES=([^ ]+).*""")
         
-        ircPic = UI.PixmapCache.getPixmap("irc128.png")
+        ircPic = UI.PixmapCache.getPixmap("irc128")
         self.__emptyLabel = QLabel()
         self.__emptyLabel.setPixmap(ircPic)
         self.__emptyLabel.setAlignment(Qt.AlignVCenter | Qt.AlignHCenter)
@@ -285,7 +284,7 @@ class IrcWidget(QWidget, Ui_IrcWidget):
         """
         from .IrcNetworkListDialog import IrcNetworkListDialog
         dlg = IrcNetworkListDialog(self.__ircNetworkManager, self)
-        dlg.exec_()
+        dlg.exec()
     
     def __networkDataChanged(self):
         """
