@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Package implementing the pip GUI logic.
 """
 
-
 import os
 import sys
 import json
 
 from PyQt5.QtCore import pyqtSlot, QObject, QProcess, QUrl, QCoreApplication
-from PyQt5.QtWidgets import QDialog
+from PyQt5.QtWidgets import QDialog, QInputDialog, QLineEdit
 from PyQt5.QtNetwork import (
     QNetworkAccessManager, QNetworkRequest, QNetworkReply
 )
@@ -206,19 +205,21 @@ class Pip(QObject):
         
         return interpreter
     
-    def getVirtualenvNames(self, noRemote=False):
+    def getVirtualenvNames(self, noRemote=False, noConda=False):
         """
         Public method to get a sorted list of virtual environment names.
         
         @param noRemote flag indicating to exclude environments for remote
             debugging
         @type bool
+        @param noConda flag indicating to exclude Conda environments
+        @type bool
         @return sorted list of virtual environment names
         @rtype list of str
         """
         return sorted(
             e5App().getObject("VirtualEnvManager").getVirtualenvNames(
-                noRemote=noRemote))
+                noRemote=noRemote, noConda=noConda))
     
     def installPip(self, venvName, userSite=False):
         """
@@ -252,7 +253,7 @@ class Pip(QObject):
     
         res = dia.startProcesses(commands)
         if res:
-            dia.exec_()
+            dia.exec()
     
     @pyqtSlot()
     def repairPip(self, venvName):
@@ -278,7 +279,7 @@ class Pip(QObject):
         dia = PipDialog(self.tr('Repair PIP'))
         res = dia.startProcess(interpreter, args)
         if res:
-            dia.exec_()
+            dia.exec()
     
     def __checkUpgradePyQt(self, packages):
         """
@@ -343,7 +344,7 @@ class Pip(QObject):
         dia = PipDialog(self.tr('Upgrade Packages'))
         res = dia.startProcess(interpreter, args)
         if res:
-            dia.exec_()
+            dia.exec()
         return res
     
     def installPackages(self, packages, venvName="", userSite=False,
@@ -378,7 +379,7 @@ class Pip(QObject):
             dia = PipDialog(self.tr('Install Packages'))
             res = dia.startProcess(interpreter, args)
             if res:
-                dia.exec_()
+                dia.exec()
     
     def installRequirements(self, venvName):
         """
@@ -389,7 +390,7 @@ class Pip(QObject):
         """
         from .PipFileSelectionDialog import PipFileSelectionDialog
         dlg = PipFileSelectionDialog(self, "requirements")
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             requirements, user = dlg.getData()
             if requirements and os.path.exists(requirements):
                 interpreter = self.getVirtualenvInterpreter(venvName)
@@ -407,7 +408,7 @@ class Pip(QObject):
                 dia = PipDialog(self.tr('Install Packages from Requirements'))
                 res = dia.startProcess(interpreter, args)
                 if res:
-                    dia.exec_()
+                    dia.exec()
     
     def uninstallPackages(self, packages, venvName):
         """
@@ -431,7 +432,7 @@ class Pip(QObject):
                 self.tr(
                     "Do you really want to uninstall these packages?"),
                 packages)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 interpreter = self.getVirtualenvInterpreter(venvName)
                 if not interpreter:
                     return False
@@ -439,7 +440,7 @@ class Pip(QObject):
                 dia = PipDialog(self.tr('Uninstall Packages'))
                 res = dia.startProcess(interpreter, args)
                 if res:
-                    dia.exec_()
+                    dia.exec()
         return res
     
     def uninstallRequirements(self, venvName):
@@ -453,14 +454,13 @@ class Pip(QObject):
             from .PipFileSelectionDialog import PipFileSelectionDialog
             dlg = PipFileSelectionDialog(self, "requirements",
                                          install=False)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 requirements, _user = dlg.getData()
                 if requirements and os.path.exists(requirements):
                     try:
-                        f = open(requirements, "r")
-                        reqs = f.read().splitlines()
-                        f.close()
-                    except (OSError, IOError):
+                        with open(requirements, "r") as f:
+                            reqs = f.read().splitlines()
+                    except OSError:
                         return
                     
                     from UI.DeleteFilesConfirmationDialog import (
@@ -472,7 +472,7 @@ class Pip(QObject):
                         self.tr(
                             "Do you really want to uninstall these packages?"),
                         reqs)
-                    if dlg.exec_() == QDialog.Accepted:
+                    if dlg.exec() == QDialog.Accepted:
                         interpreter = self.getVirtualenvInterpreter(venvName)
                         if not interpreter:
                             return
@@ -483,7 +483,7 @@ class Pip(QObject):
                             self.tr('Uninstall Packages from Requirements'))
                         res = dia.startProcess(interpreter, args)
                         if res:
-                            dia.exec_()
+                            dia.exec()
     
     def getIndexUrl(self):
         """
@@ -655,8 +655,101 @@ class Pip(QObject):
                            'replace')
                 try:
                     result = json.loads(data)
-                except Exception:
+                except Exception:           # secok
                     # ignore JSON exceptions
                     pass
         
         return result
+    
+    #######################################################################
+    ## Cache handling methods below
+    #######################################################################
+    
+    def showCacheInfo(self, venvName):
+        """
+        Public method to show some information about the pip cache.
+        
+        @param venvName name of the virtual environment to be used
+        @type str
+        """
+        if venvName:
+            interpreter = self.getVirtualenvInterpreter(venvName)
+            if interpreter:
+                args = ["-m", "pip", "cache", "info"]
+                dia = PipDialog(self.tr("Cache Info"))
+                res = dia.startProcess(interpreter, args, showArgs=False)
+                if res:
+                    dia.exec()
+    
+    def cacheList(self, venvName):
+        """
+        Public method to list files contained in the pip cache.
+        
+        @param venvName name of the virtual environment to be used
+        @type str
+        """
+        if venvName:
+            interpreter = self.getVirtualenvInterpreter(venvName)
+            if interpreter:
+                pattern, ok = QInputDialog.getText(
+                    None,
+                    self.tr("List Cached Files"),
+                    self.tr("Enter a file pattern (empty for all):"),
+                    QLineEdit.Normal)
+                
+                if ok:
+                    args = ["-m", "pip", "cache", "list"]
+                    if pattern.strip():
+                        args.append(pattern.strip())
+                    dia = PipDialog(self.tr("List Cached Files"))
+                    res = dia.startProcess(interpreter, args,
+                                           showArgs=False)
+                    if res:
+                        dia.exec()
+    
+    def cacheRemove(self, venvName):
+        """
+        Public method to remove files from the pip cache.
+        
+        @param venvName name of the virtual environment to be used
+        @type str
+        """
+        if venvName:
+            interpreter = self.getVirtualenvInterpreter(venvName)
+            if interpreter:
+                pattern, ok = QInputDialog.getText(
+                    None,
+                    self.tr("Remove Cached Files"),
+                    self.tr("Enter a file pattern:"),
+                    QLineEdit.Normal)
+                
+                if ok and pattern.strip():
+                    args = ["-m", "pip", "cache", "remove", pattern.strip()]
+                    dia = PipDialog(self.tr("Remove Cached Files"))
+                    res = dia.startProcess(interpreter, args,
+                                           showArgs=False)
+                    if res:
+                        dia.exec()
+    
+    def cachePurge(self, venvName):
+        """
+        Public method to remove all files from the pip cache.
+        
+        @param venvName name of the virtual environment to be used
+        @type str
+        """
+        if venvName:
+            interpreter = self.getVirtualenvInterpreter(venvName)
+            if interpreter:
+                ok = E5MessageBox.yesNo(
+                    None,
+                    self.tr("Purge Cache"),
+                    self.tr("Do you really want to purge the pip cache? All"
+                            " files need to be downloaded again."))
+                if ok:
+                    args = ["-m", "pip", "cache", "purge"]
+                    dia = PipDialog(self.tr("Purge Cache"))
+                    res = dia.startProcess(interpreter, args,
+                                           showArgs=False)
+                    if res:
+                        dia.exec()
