@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the pip packages management widget.
 """
 
-
 import textwrap
 import os
+import re
 
-from PyQt5.QtCore import pyqtSlot, Qt, QEventLoop, QRegExp
-from PyQt5.QtGui import QCursor
+from PyQt5.QtCore import pyqtSlot, Qt
 from PyQt5.QtWidgets import (
     QWidget, QToolButton, QApplication, QHeaderView, QTreeWidgetItem,
     QInputDialog, QMenu, QDialog
@@ -20,12 +19,15 @@ from PyQt5.QtWidgets import (
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 from E5Network.E5XmlRpcClient import E5XmlRpcClient
 
 from .Ui_PipPackagesWidget import Ui_PipPackagesWidget
 
 import UI.PixmapCache
+import Globals
+import Preferences
 
 
 class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
@@ -135,7 +137,11 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         if projectVenv:
             self.environmentsComboBox.addItem(projectVenv)
         self.environmentsComboBox.addItems(
-            self.__pip.getVirtualenvNames(noRemote=True))
+            self.__pip.getVirtualenvNames(
+                noRemote=True,
+                noConda=Preferences.getPip("ExcludeCondaEnvironments")
+            )
+        )
     
     def __isPipAvailable(self):
         """
@@ -154,6 +160,24 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         
         return available
     
+    def __availablePipVersion(self):
+        """
+        Private method to get the pip version of the selected environment.
+        
+        @return tuple containing the version number or tuple with all zeros
+            in case pip is not available
+        @rtype tuple of int
+        """
+        pipVersionTuple = (0, 0, 0)
+        venvName = self.environmentsComboBox.currentText()
+        if venvName:
+            pipList = self.packagesList.findItems(
+                "pip", Qt.MatchExactly | Qt.MatchCaseSensitive)
+            if len(pipList) > 0:
+                pipVersionTuple = Globals.versionToTuple(pipList[0].text(1))
+        
+        return pipVersionTuple
+    
     #######################################################################
     ## Slots handling widget signals below
     #######################################################################
@@ -213,47 +237,45 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         if venvName:
             interpreter = self.__pip.getVirtualenvInterpreter(venvName)
             if interpreter:
-                QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
                 self.statusLabel.show()
                 self.statusLabel.setText(
                     self.tr("Getting installed packages..."))
-                QApplication.processEvents()
                 
-                # 1. populate with installed packages
-                self.packagesList.setUpdatesEnabled(False)
-                installedPackages = self.__pip.getInstalledPackages(
-                    venvName,
-                    localPackages=self.localCheckBox.isChecked(),
-                    notRequired=self.notRequiredCheckBox.isChecked(),
-                    usersite=self.userCheckBox.isChecked(),
-                )
-                for package, version in installedPackages:
-                    QTreeWidgetItem(self.packagesList, [package, version])
-                self.packagesList.setUpdatesEnabled(True)
-                self.statusLabel.setText(
-                    self.tr("Getting outdated packages..."))
-                QApplication.processEvents()
-                
-                # 2. update with update information
-                self.packagesList.setUpdatesEnabled(False)
-                outdatedPackages = self.__pip.getOutdatedPackages(
-                    venvName,
-                    localPackages=self.localCheckBox.isChecked(),
-                    notRequired=self.notRequiredCheckBox.isChecked(),
-                    usersite=self.userCheckBox.isChecked(),
-                )
-                for package, _version, latest in outdatedPackages:
-                    items = self.packagesList.findItems(
-                        package, Qt.MatchExactly | Qt.MatchCaseSensitive)
-                    if items:
-                        itm = items[0]
-                        itm.setText(2, latest)
-                
-                self.packagesList.sortItems(0, Qt.AscendingOrder)
-                for col in range(self.packagesList.columnCount()):
-                    self.packagesList.resizeColumnToContents(col)
-                self.packagesList.setUpdatesEnabled(True)
-                QApplication.restoreOverrideCursor()
+                with E5OverrideCursor():
+                    # 1. populate with installed packages
+                    self.packagesList.setUpdatesEnabled(False)
+                    installedPackages = self.__pip.getInstalledPackages(
+                        venvName,
+                        localPackages=self.localCheckBox.isChecked(),
+                        notRequired=self.notRequiredCheckBox.isChecked(),
+                        usersite=self.userCheckBox.isChecked(),
+                    )
+                    for package, version in installedPackages:
+                        QTreeWidgetItem(self.packagesList, [package, version])
+                    self.packagesList.setUpdatesEnabled(True)
+                    self.statusLabel.setText(
+                        self.tr("Getting outdated packages..."))
+                    QApplication.processEvents()
+                    
+                    # 2. update with update information
+                    self.packagesList.setUpdatesEnabled(False)
+                    outdatedPackages = self.__pip.getOutdatedPackages(
+                        venvName,
+                        localPackages=self.localCheckBox.isChecked(),
+                        notRequired=self.notRequiredCheckBox.isChecked(),
+                        usersite=self.userCheckBox.isChecked(),
+                    )
+                    for package, _version, latest in outdatedPackages:
+                        items = self.packagesList.findItems(
+                            package, Qt.MatchExactly | Qt.MatchCaseSensitive)
+                        if items:
+                            itm = items[0]
+                            itm.setText(2, latest)
+                    
+                    self.packagesList.sortItems(0, Qt.AscendingOrder)
+                    for col in range(self.packagesList.columnCount()):
+                        self.packagesList.resizeColumnToContents(col)
+                    self.packagesList.setUpdatesEnabled(True)
                 self.statusLabel.hide()
         
         self.__updateActionButtons()
@@ -315,54 +337,55 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             if not interpreter:
                 return
             
-            QApplication.setOverrideCursor(Qt.WaitCursor)
-            
             args = ["-m", "pip", "show"]
             if self.verboseCheckBox.isChecked():
                 args.append("--verbose")
             if self.installedFilesCheckBox.isChecked():
                 args.append("--files")
             args.append(itm.text(0))
-            success, output = self.__pip.runProcess(args, interpreter)
             
-            if success and output:
-                mode = self.ShowProcessGeneralMode
-                for line in output.splitlines():
-                    line = line.rstrip()
-                    if line != "---":
-                        if mode != self.ShowProcessGeneralMode:
-                            if line[0] == " ":
-                                QTreeWidgetItem(
-                                    self.infoWidget,
-                                    [" ", line.strip()])
-                            else:
-                                mode = self.ShowProcessGeneralMode
-                        if mode == self.ShowProcessGeneralMode:
-                            try:
-                                label, info = line.split(": ", 1)
-                            except ValueError:
-                                label = line[:-1]
-                                info = ""
-                            label = label.lower()
-                            if label in self.__infoLabels:
-                                QTreeWidgetItem(
-                                    self.infoWidget,
-                                    [self.__infoLabels[label], info])
-                            if label == "files":
-                                mode = self.ShowProcessFilesListMode
-                            elif label == "classifiers":
-                                mode = self.ShowProcessClassifiersMode
-                            elif label == "entry-points":
-                                mode = self.ShowProcessEntryPointsMode
-                self.infoWidget.scrollToTop()
-            
-            header = self.infoWidget.header()
-            header.setStretchLastSection(False)
-            header.resizeSections(QHeaderView.ResizeToContents)
-            if header.sectionSize(0) + header.sectionSize(1) < header.width():
-                header.setStretchLastSection(True)
-            
-            QApplication.restoreOverrideCursor()
+            with E5OverrideCursor():
+                success, output = self.__pip.runProcess(args, interpreter)
+                
+                if success and output:
+                    mode = self.ShowProcessGeneralMode
+                    for line in output.splitlines():
+                        line = line.rstrip()
+                        if line != "---":
+                            if mode != self.ShowProcessGeneralMode:
+                                if line[0] == " ":
+                                    QTreeWidgetItem(
+                                        self.infoWidget,
+                                        [" ", line.strip()])
+                                else:
+                                    mode = self.ShowProcessGeneralMode
+                            if mode == self.ShowProcessGeneralMode:
+                                try:
+                                    label, info = line.split(": ", 1)
+                                except ValueError:
+                                    label = line[:-1]
+                                    info = ""
+                                label = label.lower()
+                                if label in self.__infoLabels:
+                                    QTreeWidgetItem(
+                                        self.infoWidget,
+                                        [self.__infoLabels[label], info])
+                                if label == "files":
+                                    mode = self.ShowProcessFilesListMode
+                                elif label == "classifiers":
+                                    mode = self.ShowProcessClassifiersMode
+                                elif label == "entry-points":
+                                    mode = self.ShowProcessEntryPointsMode
+                    self.infoWidget.scrollToTop()
+                
+                header = self.infoWidget.header()
+                header.setStretchLastSection(False)
+                header.resizeSections(QHeaderView.ResizeToContents)
+                if (
+                    header.sectionSize(0) + header.sectionSize(1) <
+                    header.width()
+                ):
+                    header.setStretchLastSection(True)
         
         self.__updateActionButtons()
     
@@ -420,17 +443,14 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         self.environmentsComboBox.clear()
         self.packagesList.clear()
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        QApplication.processEvents()
+        with E5OverrideCursor():
+            self.__populateEnvironments()
+            
+            index = self.environmentsComboBox.findText(
+                currentEnvironment, Qt.MatchExactly | Qt.MatchCaseSensitive)
+            if index != -1:
+                self.environmentsComboBox.setCurrentIndex(index)
         
-        self.__populateEnvironments()
-        
-        index = self.environmentsComboBox.findText(
-            currentEnvironment, Qt.MatchExactly | Qt.MatchCaseSensitive)
-        if index != -1:
-            self.environmentsComboBox.setCurrentIndex(index)
-        
-        QApplication.restoreOverrideCursor()
         self.__updateActionButtons()
     
     @pyqtSlot()
@@ -561,7 +581,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         Private slot initiating a search via a press of the Return key.
         """
-        self.__search()
+        if (
+            (bool(self.searchEditName.text()) or
+             bool(self.searchEditSummary.text())) and
+            self.__isPipAvailable()
+        ):
+            self.__search()
     
     @pyqtSlot(str)
     def on_searchEditSummary_textChanged(self, txt):
@@ -578,7 +603,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         Private slot initiating a search via a press of the Return key.
         """
-        self.__search()
+        if (
+            (bool(self.searchEditName.text()) or
+             bool(self.searchEditSummary.text())) and
+            self.__isPipAvailable()
+        ):
+            self.__search()
     
     @pyqtSlot()
     def on_searchButton_clicked(self):
@@ -602,8 +632,6 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         self.searchInfoLabel.clear()
         
         self.searchButton.setEnabled(False)
-        QApplication.setOverrideCursor(Qt.WaitCursor)
-        QApplication.processEvents(QEventLoop.ExcludeUserInputEvents)
         
         self.__queryName = [
             term for term in self.searchEditName.text().strip().split()
@@ -654,7 +682,6 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
                         count = 0
                         QApplication.processEvents()
             else:
-                QApplication.restoreOverrideCursor()
                 E5MessageBox.warning(
                     self,
                     self.tr("Search PyPI"),
@@ -664,7 +691,6 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
                     self.tr("""<p>The package search did not return"""
                             """ anything.</p>"""))
         else:
-            QApplication.restoreOverrideCursor()
             E5MessageBox.warning(
                 self,
                 self.tr("Search PyPI"),
@@ -690,8 +716,6 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         Private slot performing the search finishing actions.
         """
-        QApplication.restoreOverrideCursor()
-        
         self.__updateSearchActionButtons()
         self.__updateSearchButton()
         
@@ -706,7 +730,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         @param errorString error message
         @type str
         """
-        self.__finish()
+        self.__finishSearch()
         E5MessageBox.warning(
             self,
             self.tr("Search PyPI"),
@@ -769,8 +793,8 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             
         for queryTerm in self.__querySummary:
             if queryTerm.lower() in summary.lower():
-                if QRegExp(r'\b{0}\b'.format(QRegExp.escape(queryTerm)),
-                           Qt.CaseInsensitive).indexIn(summary) != -1:
+                if re.search(r'\b{0}\b'.format(re.escape(queryTerm)),
+                             summary, re.IGNORECASE) is not None:
                     # word match gets even higher score
                     score += 2
                 else:
@@ -807,6 +831,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             if packages:
                 self.__pip.installPackages(packages, venvName=venvName,
                                            userSite=userSite)
+                self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def on_showDetailsButton_clicked(self):
@@ -866,12 +891,10 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         @param packageVersion version of the package
         @type str
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
-        QApplication.processEvents(QEventLoop.ExcludeUserInputEvents)
+        with E5OverrideCursor():
+            packageData = self.__pip.getPackageDetails(
+                packageName, packageVersion)
         
-        packageData = self.__pip.getPackageDetails(packageName, packageVersion)
-        
-        QApplication.restoreOverrideCursor()
         if packageData:
             from .PipPackageDetailsDialog import PipPackageDetailsDialog
             
@@ -928,6 +951,19 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
             self.tr("Generate Requirements..."),
             self.__generateRequirements)
         self.__pipMenu.addSeparator()
+        self.__cacheInfoAct = self.__pipMenu.addAction(
+            self.tr("Show Cache Info..."),
+            self.__showCacheInfo)
+        self.__cacheShowListAct = self.__pipMenu.addAction(
+            self.tr("Show Cached Files..."),
+            self.__showCacheList)
+        self.__cacheRemoveAct = self.__pipMenu.addAction(
+            self.tr("Remove Cached Files..."),
+            self.__removeCachedFiles)
+        self.__cachePurgeAct = self.__pipMenu.addAction(
+            self.tr("Purge Cache..."),
+            self.__purgeCache)
+        self.__pipMenu.addSeparator()
         # editUserConfigAct
         self.__pipMenu.addAction(
             self.tr("Edit User Configuration..."),
@@ -951,6 +987,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         enable = bool(self.environmentsComboBox.currentText())
         enablePip = self.__isPipAvailable()
+        enablePipCache = self.__availablePipVersion() >= (20, 1, 0)
         
         self.__installPipAct.setEnabled(not enablePip)
         self.__installPipUserAct.setEnabled(not enablePip)
@@ -963,6 +1000,11 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         self.__uninstallRequirementsAct.setEnabled(enablePip)
         self.__generateRequirementsAct.setEnabled(enablePip)
         
+        self.__cacheInfoAct.setEnabled(enablePipCache)
+        self.__cacheShowListAct.setEnabled(enablePipCache)
+        self.__cacheRemoveAct.setEnabled(enablePipCache)
+        self.__cachePurgeAct.setEnabled(enablePipCache)
+        
         self.__editVirtualenvConfigAct.setEnabled(enable)
     
     @pyqtSlot()
@@ -973,6 +1015,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installPip(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installPipUser(self):
@@ -983,6 +1026,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installPip(venvName, userSite=True)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __repairPip(self):
@@ -993,6 +1037,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.repairPip(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installPackages(self):
@@ -1003,11 +1048,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         if venvName:
             from .PipPackagesInputDialog import PipPackagesInputDialog
             dlg = PipPackagesInputDialog(self, self.tr("Install Packages"))
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 packages, user = dlg.getData()
                 if packages:
                     self.__pip.installPackages(packages, venvName=venvName,
                                                userSite=user)
+                    self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installLocalPackage(self):
@@ -1018,11 +1064,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         if venvName:
             from .PipFileSelectionDialog import PipFileSelectionDialog
             dlg = PipFileSelectionDialog(self, "package")
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 package, user = dlg.getData()
                 if package and os.path.exists(package):
                     self.__pip.installPackages([package], venvName=venvName,
                                                userSite=user)
+                    self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __installRequirements(self):
@@ -1032,6 +1079,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.installRequirements(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __uninstallRequirements(self):
@@ -1041,6 +1089,7 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         venvName = self.environmentsComboBox.currentText()
         if venvName:
             self.__pip.uninstallRequirements(venvName)
+            self.on_refreshButton_clicked()
     
     @pyqtSlot()
     def __generateRequirements(self):
@@ -1106,10 +1155,9 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         
         if not os.path.exists(cfgFile):
             try:
-                f = open(cfgFile, "w")
-                f.write("[global]\n")
-                f.close()
-            except (IOError, OSError):
+                with open(cfgFile, "w") as f:
+                    f.write("[global]\n")
+            except OSError:
                 # ignore these
                 pass
         
@@ -1130,3 +1178,39 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         Private slot to open the configuration page.
         """
         e5App().getObject("UserInterface").showPreferences("pipPage")
+    
+    @pyqtSlot()
+    def __showCacheInfo(self):
+        """
+        Private slot to show information about the cache.
+        """
+        venvName = self.environmentsComboBox.currentText()
+        if venvName:
+            self.__pip.showCacheInfo(venvName)
+    
+    @pyqtSlot()
+    def __showCacheList(self):
+        """
+        Private slot to show a list of cached files.
+        """
+        venvName = self.environmentsComboBox.currentText()
+        if venvName:
+            self.__pip.cacheList(venvName)
+    
+    @pyqtSlot()
+    def __removeCachedFiles(self):
+        """
+        Private slot to remove files from the pip cache.
+        """
+        venvName = self.environmentsComboBox.currentText()
+        if venvName:
+            self.__pip.cacheRemove(venvName)
+    
+    @pyqtSlot()
+    def __purgeCache(self):
+        """
+        Private slot to empty the pip cache.
+        """
+        venvName = self.environmentsComboBox.currentText()
+        if venvName:
+            self.__pip.cachePurge(venvName)
