@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Plugin installation dialog.
 """
 
-
 import os
 import sys
 import shutil
@@ -465,18 +464,16 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                             d = os.path.dirname(outname)
                             if not os.path.exists(d):
                                 self.__makedirs(d)
-                            f = open(outname, "wb")
-                            f.write(zipFile.read(name))
-                            f.close()
+                            with open(outname, "wb") as f:
+                                f.write(zipFile.read(name))
                             self.__installedFiles.append(outname)
                 self.progress.setValue(tot)
                 # now compile user interface files
                 compileUiFiles(os.path.join(destination, packageName), True)
             else:
                 outname = os.path.join(destination, pluginFileName)
-                f = open(outname, "w", encoding="utf-8")
-                f.write(pluginSource)
-                f.close()
+                with open(outname, "w", encoding="utf-8") as f:
+                    f.write(pluginSource)
                 self.__installedFiles.append(outname)
         except os.error as why:
             self.__rollback()
@@ -486,7 +483,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     "Error installing plugin. Reason: {0}").format(str(why)),
                 False
             )
-        except IOError as why:
+        except OSError as why:
             self.__rollback()
             return (
                 False,
@@ -603,7 +600,7 @@ class PluginInstallWidget(QWidget, Ui_PluginInstallDialog):
                     os.remove(fnamec)
             
             os.remove(pluginFile)
-        except (IOError, OSError, os.error):
+        except (OSError, os.error):
             # ignore some exceptions
             pass
 
