@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
-
 """
 Module implementing a dialog showing the available plugins.
 """
 
-
 import sys
 import os
 import zipfile
@@ -394,7 +392,7 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
             ui = None
         if ui and ui.notificationsEnabled():
             ui.showNotification(
-                UI.PixmapCache.getPixmap("plugin48.png"),
+                UI.PixmapCache.getPixmap("plugin48"),
                 self.tr("Download Plugin Files"),
                 self.tr("""The requested plugins were downloaded."""))
         
@@ -651,22 +649,22 @@ class PluginRepositoryWidget(QWidget, Ui_PluginRepositoryDialog):
         
         updateStatus = self.__updateStatus(filename, version)
         if updateStatus == PluginRepositoryWidget.PluginStatusUpToDate:
-            itm.setIcon(1, UI.PixmapCache.getIcon("empty.png"))
+            itm.setIcon(1, UI.PixmapCache.getIcon("empty"))
             itm.setToolTip(1, self.tr("up-to-date"))
         elif updateStatus == PluginRepositoryWidget.PluginStatusNew:
-            itm.setIcon(1, UI.PixmapCache.getIcon("download.png"))
+            itm.setIcon(1, UI.PixmapCache.getIcon("download"))
             itm.setToolTip(1, self.tr("new download available"))
             self.__newItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusLocalUpdate:
-            itm.setIcon(1, UI.PixmapCache.getIcon("updateLocal.png"))
+            itm.setIcon(1, UI.PixmapCache.getIcon("updateLocal"))
             itm.setToolTip(1, self.tr("update installable"))
             self.__updateLocalItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusRemoteUpdate:
-            itm.setIcon(1, UI.PixmapCache.getIcon("updateRemote.png"))
+            itm.setIcon(1, UI.PixmapCache.getIcon("updateRemote"))
             itm.setToolTip(1, self.tr("updated download available"))
             self.__updateRemoteItems += 1
         elif updateStatus == PluginRepositoryWidget.PluginStatusError:
-            itm.setIcon(1, UI.PixmapCache.getIcon("warning.png"))
+            itm.setIcon(1, UI.PixmapCache.getIcon("warning"))
             itm.setToolTip(1, self.tr("error determining status"))
     
     def __updateStatus(self, filename, version):
@@ -1000,7 +998,7 @@ def PluginRepositoryDownloadCleanup(quiet=False):
         for removeFile in removeFiles:
             try:
                 os.remove(os.path.join(downloadPath, removeFile))
-            except (IOError, OSError) as err:
+            except OSError as err:
                 if not quiet:
                     E5MessageBox.critical(
                         None,
@@ -1029,7 +1027,7 @@ def PluginRepositoryDownloadCleanup(quiet=False):
                     for removeFile in removeFiles:
                         try:
                             os.remove(os.path.join(downloadPath, removeFile))
-                        except (IOError, OSError) as err:
+                        except OSError as err:
                             if not quiet:
                                 E5MessageBox.critical(
                                     None,
