@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an 'About Eric' dialog.
 """
 
-
 from PyQt5.QtCore import Qt, QCoreApplication
 from PyQt5.QtWidgets import QDialog
 
@@ -753,7 +752,7 @@ class AboutDialog(QDialog, Ui_AboutDialog):
         
         self.ericLabel.setText(titleText)
         self.ericPixmap.setPixmap(
-            UI.PixmapCache.getPixmap("eric.png").scaled(48, 48))
+            UI.PixmapCache.getPixmap("eric").scaled(48, 48))
         
         ####################################################################
         ## ABOUT
