@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a simple Python syntax checker.
 """
 
-
 import os
 import fnmatch
 
@@ -133,9 +132,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         
         itm = QTreeWidgetItem(self.__lastFileItem)
         if isWarning:
-            itm.setIcon(0, UI.PixmapCache.getIcon("warning.png"))
+            itm.setIcon(0, UI.PixmapCache.getIcon("warning"))
         else:
-            itm.setIcon(0, UI.PixmapCache.getIcon("syntaxError.png"))
+            itm.setIcon(0, UI.PixmapCache.getIcon("syntaxError"))
         itm.setData(0, Qt.DisplayRole, line)
         itm.setData(1, Qt.DisplayRole, error)
         itm.setData(2, Qt.DisplayRole, sourcecode)
@@ -249,7 +248,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             try:
                 self.source = Utilities.readEncodedFile(self.filename)[0]
                 self.source = Utilities.normalizeCode(self.source)
-            except (UnicodeError, IOError) as msg:
+            except (UnicodeError, OSError) as msg:
                 self.noResults = False
                 self.__createResultItem(
                     self.filename, 1, 0,
@@ -283,7 +282,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             try:
                 source = Utilities.readEncodedFile(filename)[0]
                 source = Utilities.normalizeCode(source)
-            except (UnicodeError, IOError) as msg:
+            except (UnicodeError, OSError) as msg:
                 self.noResults = False
                 self.__createResultItem(
                     self.filename, 1, 0,
@@ -355,7 +354,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                     source = Utilities.readEncodedFile(fn)[0]
                     source = Utilities.normalizeCode(source)
                     source = source.splitlines()
-                except (UnicodeError, IOError):
+                except (UnicodeError, OSError):
                     source = ""
             else:
                 source = self.source.splitlines()
@@ -464,7 +463,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         vm = e5App().getObject("ViewManager")
         
         if itm.parent():
-            fn = Utilities.normabspath(itm.data(0, self.filenameRole))
+            fn = os.path.abspath(itm.data(0, self.filenameRole))
             lineno = itm.data(0, self.lineRole)
             index = itm.data(0, self.indexRole)
             error = itm.data(0, self.errorRole)
@@ -477,7 +476,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             else:
                 editor.toggleSyntaxError(lineno, index, True, error, show=True)
         else:
-            fn = Utilities.normabspath(itm.data(0, self.filenameRole))
+            fn = os.path.abspath(itm.data(0, self.filenameRole))
             vm.openSourceFile(fn)
             editor = vm.getOpenEditor(fn)
             for index in range(itm.childCount()):
@@ -509,7 +508,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             selectedIndexes = list(range(self.resultList.topLevelItemCount()))
         for index in selectedIndexes:
             itm = self.resultList.topLevelItem(index)
-            fn = Utilities.normabspath(itm.data(0, self.filenameRole))
+            fn = os.path.abspath(itm.data(0, self.filenameRole))
             vm.openSourceFile(fn, 1)
             editor = vm.getOpenEditor(fn)
             editor.clearSyntaxError()
@@ -532,7 +531,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         for index in range(self.resultList.topLevelItemCount()):
             itm = self.resultList.topLevelItem(index)
             errorFiles.append(
-                Utilities.normabspath(itm.data(0, self.filenameRole)))
+                os.path.abspath(itm.data(0, self.filenameRole)))
         for file in openFiles:
             if file not in errorFiles:
                 editor = vm.getOpenEditor(file)
