@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the log history.
 """
 
-
 import os
 import collections
+import re
 
 from PyQt5.QtCore import (
-    pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, QSize, QPoint, QFileInfo
+    pyqtSlot, Qt, QDate, QProcess, QTimer, QSize, QPoint, QFileInfo
 )
 from PyQt5.QtGui import (
-    QCursor, QColor, QPixmap, QPainter, QPen, QIcon, QTextCursor, QPalette
+    QColor, QPixmap, QPainter, QPen, QIcon, QTextCursor, QPalette
 )
 from PyQt5.QtWidgets import (
     QWidget, QDialogButtonBox, QHeaderView, QTreeWidgetItem, QApplication,
@@ -24,6 +24,7 @@ from PyQt5.QtWidgets import (
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5OverrideCursor import E5OverrideCursorProcess
 
 from Globals import strToQByteArray
 
@@ -116,8 +117,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.__logTreeHasDarkBackground = e5App().usesDarkPalette()
         
         font = Preferences.getEditorOtherFonts("MonospacedFont")
-        self.diffEdit.setFontFamily(font.family())
-        self.diffEdit.setFontPointSize(font.pointSize())
+        self.diffEdit.document().setDefaultFont(font)
         
         self.diffHighlighter = GitDiffHighlighter(self.diffEdit.document())
         self.__diffGenerator = GitDiffGenerator(vcs, self)
@@ -194,10 +194,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         # roles used in the file tree
         self.__diffFileLineRole = Qt.UserRole
         
-        self.process = QProcess()
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        self.__process = E5OverrideCursorProcess()
+        self.__process.finished.connect(self.__procFinished)
+        self.__process.readyReadStandardOutput.connect(self.__readStdout)
+        self.__process.readyReadStandardError.connect(self.__readStderr)
         
         self.flags = {
             'A': self.tr('Added'),
@@ -383,12 +383,12 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         @param e close event (QCloseEvent)
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         self.vcs.getPlugin().setPreferences(
             "LogBrowserGeometry", self.saveGeometry())
@@ -782,9 +782,6 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         QApplication.processEvents()
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        QApplication.processEvents()
-        
         self.buf = []
         self.cancelled = False
         self.errors.clear()
@@ -810,12 +807,12 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             args.append('--')
             args.append(self.__filename)
         
-        self.process.kill()
+        self.__process.kill()
         
-        self.process.setWorkingDirectory(self.repodir)
+        self.__process.setWorkingDirectory(self.repodir)
         
-        self.process.start('git', args)
-        procStarted = self.process.waitForStarted(5000)
+        self.__process.start('git', args)
+        procStarted = self.__process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
@@ -881,14 +878,12 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         the button.
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
-        
-        QApplication.restoreOverrideCursor()
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -1052,10 +1047,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         
         It reads the output of the process and inserts it into a buffer.
         """
-        self.process.setReadChannel(QProcess.StandardOutput)
+        self.__process.setReadChannel(QProcess.StandardOutput)
         
-        while self.process.canReadLine():
-            line = str(self.process.readLine(),
+        while self.__process.canReadLine():
+            line = str(self.__process.readLine(),
                        Preferences.getSystem("IOEncoding"),
                        'replace')
             self.buf.append(line)
@@ -1067,8 +1062,8 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         It reads the error output of the process and inserts it into the
         error pane.
         """
-        if self.process is not None:
-            s = str(self.process.readAllStandardError(),
+        if self.__process is not None:
+            s = str(self.__process.readAllStandardError(),
                     Preferences.getSystem("IOEncoding"),
                     'replace')
             self.__showError(s)
@@ -1147,7 +1142,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
             self.errors.ensureCursorVisible()
         self.errorGroup.show()
         
-        self.process.write(strToQByteArray(inputTxt))
+        self.__process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
@@ -1182,25 +1177,25 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         txt = self.fieldCombo.itemData(self.fieldCombo.currentIndex())
         if txt == "author":
             fieldIndex = self.AuthorColumn
-            searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+            searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
         elif txt == "committer":
             fieldIndex = self.CommitterColumn
-            searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+            searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
         elif txt == "commitId":
             fieldIndex = self.CommitIdColumn
             txt = self.rxEdit.text()
             if txt.startswith("^"):
-                searchRx = QRegExp(r"^\s*{0}".format(txt[1:]),
-                                   Qt.CaseInsensitive)
+                searchRx = re.compile(r"^\s*{0}".format(txt[1:]),
+                                      re.IGNORECASE)
             else:
-                searchRx = QRegExp(txt, Qt.CaseInsensitive)
+                searchRx = re.compile(txt, re.IGNORECASE)
         elif txt == "file":
             fieldIndex = self.__changesRole
-            searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+            searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             indexIsRole = True
         else:
             fieldIndex = self.__subjectRole
-            searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+            searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             indexIsRole = True
         
         return fieldIndex, searchRx, indexIsRole
@@ -1233,7 +1228,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                 if (
                     topItem.text(self.DateColumn) <= to_ and
                     topItem.text(self.DateColumn) >= from_ and
-                    searchRx.indexIn(txt) > -1
+                    searchRx.search(txt) is not None
                 ):
                     topItem.setHidden(False)
                     if topItem is currentItem:
@@ -2047,7 +2042,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
                     txt = topItem.data(0, self.__subjectRole)
             else:
                 txt = topItem.text(fieldIndex)
-            if searchRx.indexIn(txt) > -1:
+            if searchRx.search(txt) is not None:
                 self.logTree.setCurrentItem(self.logTree.topLevelItem(index))
                 break
         else:
@@ -2310,11 +2305,10 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         
         eol = e5App().getObject("Project").getEolString()
         try:
-            f = open(fname, "w", encoding="utf-8", newline="")
-            f.write(eol.join(self.diffEdit.toPlainText().splitlines()))
-            f.write(eol)
-            f.close()
-        except IOError as why:
+            with open(fname, "w", encoding="utf-8", newline="") as f:
+                f.write(eol.join(self.diffEdit.toPlainText().splitlines()))
+                f.write(eol)
+        except OSError as why:
             E5MessageBox.critical(
                 self, self.tr('Save Diff'),
                 self.tr(
