@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a dialog to show the output of the git status command
 process.
 """
 
-
 import os
 import tempfile
 
@@ -90,10 +89,8 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
             self.__pathColumn, Qt.AscendingOrder)
         
         font = Preferences.getEditorOtherFonts("MonospacedFont")
-        self.lDiffEdit.setFontFamily(font.family())
-        self.lDiffEdit.setFontPointSize(font.pointSize())
-        self.rDiffEdit.setFontFamily(font.family())
-        self.rDiffEdit.setFontPointSize(font.pointSize())
+        self.lDiffEdit.document().setDefaultFont(font)
+        self.rDiffEdit.document().setDefaultFont(font)
         self.lDiffEdit.customContextMenuRequested.connect(
             self.__showLDiffContextMenu)
         self.rDiffEdit.customContextMenuRequested.connect(
@@ -101,29 +98,29 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
         
         self.__lDiffMenu = QMenu()
         self.__stageLinesAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr("Stage Selected Lines"),
             self.__stageHunkOrLines)
         self.__revertLinesAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr("Revert Selected Lines"),
             self.__revertHunkOrLines)
         self.__stageHunkAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr("Stage Hunk"),
             self.__stageHunkOrLines)
         self.__revertHunkAct = self.__lDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr("Revert Hunk"),
             self.__revertHunkOrLines)
         
         self.__rDiffMenu = QMenu()
         self.__unstageLinesAct = self.__rDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr("Unstage Selected Lines"),
             self.__unstageHunkOrLines)
         self.__unstageHunkAct = self.__rDiffMenu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr("Unstage Hunk"),
             self.__unstageHunkOrLines)
         
@@ -257,7 +254,7 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
             "Adjusts the width of all columns to their contents"))
         
         self.actionsButton.setIcon(
-            UI.PixmapCache.getIcon("actionsToolButton.png"))
+            UI.PixmapCache.getIcon("actionsToolButton"))
         self.actionsButton.setMenu(self.__actionsMenu)
     
     def closeEvent(self, e):
@@ -359,7 +356,7 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
             itm.setIcon(self.__statusWorkColumn,
                         UI.PixmapCache.getIcon(
                             os.path.join("VcsPlugins", "vcsGit", "icons",
-                                         "conflict.png")))
+                                         "conflict.svg")))
         itm.setData(0, self.ConflictRole, status in self.ConflictStates)
     
     def start(self, fn):
@@ -1151,9 +1148,8 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
         if patch:
             patchFile = self.__tmpPatchFileName()
             try:
-                f = open(patchFile, "w")
-                f.write(patch)
-                f.close()
+                with open(patchFile, "w") as f:
+                    f.write(patch)
                 self.vcs.gitApply(self.dname, patchFile, cached=True,
                                   noDialog=True)
                 self.on_refreshButton_clicked()
@@ -1174,9 +1170,8 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
         if patch:
             patchFile = self.__tmpPatchFileName()
             try:
-                f = open(patchFile, "w")
-                f.write(patch)
-                f.close()
+                with open(patchFile, "w") as f:
+                    f.write(patch)
                 self.vcs.gitApply(self.dname, patchFile, cached=True,
                                   reverse=True, noDialog=True)
                 self.on_refreshButton_clicked()
@@ -1207,9 +1202,8 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
             if patch:
                 patchFile = self.__tmpPatchFileName()
                 try:
-                    f = open(patchFile, "w")
-                    f.write(patch)
-                    f.close()
+                    with open(patchFile, "w") as f:
+                        f.write(patch)
                     self.vcs.gitApply(self.dname, patchFile, reverse=True,
                                       noDialog=True)
                     self.on_refreshButton_clicked()
