@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project browser helper for Git.
 """
 
-
 import os
 
 from PyQt5.QtWidgets import QMenu, QDialog
@@ -172,7 +171,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -180,28 +179,28 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add/Stage to repository'),
             self._VCSAdd)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Unstage changes'),
             self.__GitUnstage)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository only'),
             self.__GitForget)
         self.vcsMenuActions.append(act)
@@ -212,30 +211,30 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff.png"),
+            UI.PixmapCache.getIcon("vcsSbsDiff"),
             self.tr('Show differences side-by-side'), self.__GitSbsDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__GitExtendedDiff)
         self.vcsMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsSbsDiff.png"),
+            UI.PixmapCache.getIcon("vcsSbsDiff"),
             self.tr('Show differences side-by-side (extended)'),
             self.__GitSbsExtendedDiff)
         self.vcsMenuActions.append(act)
@@ -246,11 +245,9 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsMenuActions.append(self.annotateAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self.__GitRevert)
         self.vcsMenuActions.append(act)
-        menu.addSeparator()
-        
         menu.addSeparator()
         menu.addAction(self.tr('Select all local file entries'),
                        self.browser.selectLocalEntries)
@@ -280,7 +277,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -288,48 +285,48 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add/Stage to repository'), self._VCSAdd)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Unstage changes'),
             self.__GitUnstage)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository only'),
             self.__GitForget)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__GitExtendedDiff)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self.__GitRevert)
         self.vcsMultiMenuActions.append(act)
         menu.addSeparator()
@@ -360,7 +357,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -398,7 +395,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -406,22 +403,22 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add/Stage to repository'), self._VCSAdd)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Unstage changes'),
             self.__GitUnstage)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMenuActions.append(act)
@@ -432,27 +429,27 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'), self._VCSLogBrowser)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__GitExtendedDiff)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self.__GitRevert)
         self.vcsDirMenuActions.append(act)
         menu.addSeparator()
@@ -488,7 +485,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -496,43 +493,43 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
         menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'),
             self._VCSCommit)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add/Stage to repository'), self._VCSAdd)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Unstage changes'),
             self.__GitUnstage)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove from repository (and disk)'),
             self._VCSRemove)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show status'), self._VCSStatus)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences'), self._VCSDiff)
         self.vcsDirMultiMenuActions.append(act)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             self.__GitExtendedDiff)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Revert changes'), self.__GitRevert)
         self.vcsDirMultiMenuActions.append(act)
         menu.addSeparator()
@@ -592,7 +589,7 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
                     " from the repository?"),
                 files)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.vcs.vcsRemove(names, stageOnly=True)
         
         for fn in names:
@@ -620,12 +617,14 @@ class GitProjectBrowserHelper(VcsProjectBrowserHelper):
             fn = itm.dirName()
         isFile = os.path.isfile(fn)
         movefiles = self.browser.project.getFiles(fn)
+        self.browser.project.stopFileSystemMonitoring()
         if self.vcs.vcsMove(fn, self.project):
             if isFile:
                 self.browser.closeSourceWindow.emit(fn)
             else:
                 for mf in movefiles:
                     self.browser.closeSourceWindow.emit(mf)
+        self.browser.project.startFileSystemMonitoring()
     
     def __GitExtendedDiff(self):
         """
