@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project helper for Git.
 """
 
-
 import os
 
 from PyQt5.QtCore import QFileInfo
@@ -71,7 +70,7 @@ class GitProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = E5Action(
             self.tr('New from repository'),
-            UI.PixmapCache.getIcon("vcsCheckout.png"),
+            UI.PixmapCache.getIcon("vcsCheckout"),
             self.tr('&New from repository...'), 0, 0,
             self, 'git_new')
         self.vcsNewAct.setStatusTip(self.tr(
@@ -87,7 +86,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitFetchAct = E5Action(
             self.tr('Fetch changes'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Fetch changes'),
             0, 0, self, 'git_fetch')
         self.gitFetchAct.setStatusTip(self.tr(
@@ -103,7 +102,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitPullAct = E5Action(
             self.tr('Pull changes'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Pull changes'),
             0, 0, self, 'git_pull')
         self.gitPullAct.setStatusTip(self.tr(
@@ -119,7 +118,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsCommitAct = E5Action(
             self.tr('Commit changes to repository'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Commit changes to repository...'), 0, 0, self,
             'git_commit')
         self.vcsCommitAct.setStatusTip(self.tr(
@@ -135,7 +134,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitPushAct = E5Action(
             self.tr('Push changes'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Push changes'),
             0, 0, self, 'git_push')
         self.gitPushAct.setStatusTip(self.tr(
@@ -151,7 +150,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsExportAct = E5Action(
             self.tr('Export from repository'),
-            UI.PixmapCache.getIcon("vcsExport.png"),
+            UI.PixmapCache.getIcon("vcsExport"),
             self.tr('&Export from repository...'),
             0, 0, self, 'git_export_repo')
         self.vcsExportAct.setStatusTip(self.tr(
@@ -166,7 +165,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitLogBrowserAct = E5Action(
             self.tr('Show log browser'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'),
             0, 0, self, 'git_log_browser')
         self.gitLogBrowserAct.setStatusTip(self.tr(
@@ -183,7 +182,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitReflogBrowserAct = E5Action(
             self.tr('Show reflog browser'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show reflog browser'),
             0, 0, self, 'git_reflog_browser')
         self.gitReflogBrowserAct.setStatusTip(self.tr(
@@ -200,7 +199,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsDiffAct = E5Action(
             self.tr('Show differences'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show &differences...'),
             0, 0, self, 'git_diff')
         self.vcsDiffAct.setStatusTip(self.tr(
@@ -216,7 +215,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitExtDiffAct = E5Action(
             self.tr('Show differences (extended)'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended) ...'),
             0, 0, self, 'git_extendeddiff')
         self.gitExtDiffAct.setStatusTip(self.tr(
@@ -232,7 +231,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsStatusAct = E5Action(
             self.tr('Show status'),
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show &status...'),
             0, 0, self, 'git_status')
         self.vcsStatusAct.setStatusTip(self.tr(
@@ -247,7 +246,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsSwitchAct = E5Action(
             self.tr('Switch'),
-            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            UI.PixmapCache.getIcon("vcsSwitch"),
             self.tr('S&witch...'),
             0, 0, self, 'git_switch')
         self.vcsSwitchAct.setStatusTip(self.tr(
@@ -263,7 +262,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsTagAct = E5Action(
             self.tr('Tag in repository'),
-            UI.PixmapCache.getIcon("vcsTag.png"),
+            UI.PixmapCache.getIcon("vcsTag"),
             self.tr('&Tag in repository...'),
             0, 0, self, 'git_tag')
         self.vcsTagAct.setStatusTip(self.tr(
@@ -352,7 +351,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitBranchAct = E5Action(
             self.tr('Branch in repository'),
-            UI.PixmapCache.getIcon("vcsBranch.png"),
+            UI.PixmapCache.getIcon("vcsBranch"),
             self.tr('&Branch in repository...'),
             0, 0, self, 'git_branch')
         self.gitBranchAct.setStatusTip(self.tr(
@@ -396,7 +395,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsRevertAct = E5Action(
             self.tr('Revert changes'),
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Re&vert changes'),
             0, 0, self, 'git_revert')
         self.vcsRevertAct.setStatusTip(self.tr(
@@ -411,7 +410,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitUnstageAct = E5Action(
             self.tr('Unstage changes'),
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('&Unstage changes'),
             0, 0, self, 'git_revert')
         self.gitUnstageAct.setStatusTip(self.tr(
@@ -426,7 +425,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.vcsMergeAct = E5Action(
             self.tr('Merge'),
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Mer&ge changes...'),
             0, 0, self, 'git_merge')
         self.vcsMergeAct.setStatusTip(self.tr(
@@ -632,7 +631,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitCherryPickAct = E5Action(
             self.tr('Copy Commits'),
-            UI.PixmapCache.getIcon("vcsGraft.png"),
+            UI.PixmapCache.getIcon("vcsGraft"),
             self.tr('Copy Commits'),
             0, 0, self, 'git_cherrypick')
         self.gitCherryPickAct.setStatusTip(self.tr(
@@ -1083,7 +1082,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         self.gitBisectLogBrowserAct = E5Action(
             self.tr('Show bisect log browser'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show bisect log browser'),
             0, 0, self, 'git_bisect_log_browser')
         self.gitBisectLogBrowserAct.setStatusTip(self.tr(
@@ -1424,7 +1423,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.subMenus.append(bisectMenu)
         
         tagsMenu = QMenu(self.tr("Tags"), menu)
-        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag.png"))
+        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag"))
         tagsMenu.setTearOffEnabled(True)
         tagsMenu.addAction(self.vcsTagAct)
         tagsMenu.addAction(self.gitTagListAct)
@@ -1432,7 +1431,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.subMenus.append(tagsMenu)
         
         branchesMenu = QMenu(self.tr("Branches"), menu)
-        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch.png"))
+        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch"))
         branchesMenu.setTearOffEnabled(True)
         branchesMenu.addAction(self.gitBranchAct)
         branchesMenu.addSeparator()
@@ -1465,7 +1464,7 @@ class GitProjectHelper(VcsProjectHelper):
         remotesMenu.addAction(self.gitRemotePruneAct)
         
         cherrypickMenu = QMenu(self.tr("Cherry-pick"), menu)
-        cherrypickMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft.png"))
+        cherrypickMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft"))
         cherrypickMenu.setTearOffEnabled(True)
         cherrypickMenu.addAction(self.gitCherryPickAct)
         cherrypickMenu.addAction(self.gitCherryPickContinueAct)
@@ -1508,7 +1507,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -1601,7 +1600,7 @@ class GitProjectHelper(VcsProjectHelper):
         self.__toolbar.setVisible(False)
         
         ui.registerToolbar("git", self.__toolbar.windowTitle(),
-                           self.__toolbar)
+                           self.__toolbar, "vcs")
         ui.addToolBar(self.__toolbar)
     
     def removeToolbar(self, ui, toolbarManager):
