@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -382,7 +382,7 @@ class HgTagBranchListDialog(QDialog, Ui_HgTagBranchListDialog):
             self.tr(
                 "Do you really want to close all listed branches?"),
             branches)
-        yes = dlg.exec_() == QDialog.Accepted
+        yes = dlg.exec() == QDialog.Accepted
         if yes:
             self.vcs.getExtensionObject("closehead").hgCloseheads(
                 self.__repoDir, branches)
