@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the largefiles extension interface.
 """
 
-
 import os
 
 from PyQt5.QtCore import QTimer
@@ -55,7 +54,7 @@ class Largefiles(HgExtension):
         
         from .LfConvertDataDialog import LfConvertDataDialog
         dlg = LfConvertDataDialog(projectDir, direction)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             newName, minSize, patterns = dlg.getData()
             newProjectFile = os.path.join(
                 newName, os.path.basename(projectFile))
@@ -75,7 +74,7 @@ class Largefiles(HgExtension):
             dia = HgDialog(self.tr('Convert Project - Converting'), self.vcs)
             res = dia.startProcess(args, repodir)
             if res:
-                dia.exec_()
+                dia.exec()
                 res = dia.normalExit() and os.path.isdir(
                     os.path.join(newName, self.vcs.adminDir))
             
@@ -87,7 +86,7 @@ class Largefiles(HgExtension):
                                self.vcs, useClient=False)
                 res = dia.startProcess(args, newName)
                 if res:
-                    dia.exec_()
+                    dia.exec()
                     res = dia.normalExit() and os.path.isfile(newProjectFile)
             
             # step 3: close current project and open new one
@@ -137,7 +136,7 @@ class Largefiles(HgExtension):
             self.vcs)
         res = dia.startProcess(args, repodir)
         if res:
-            dia.exec_()
+            dia.exec()
     
     def hgLfPull(self, projectDir, revisions=None):
         """
@@ -159,7 +158,7 @@ class Largefiles(HgExtension):
         else:
             from .LfRevisionsInputDialog import LfRevisionsInputDialog
             dlg = LfRevisionsInputDialog()
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 revs = dlg.getRevisions()
         
         if revs:
@@ -172,7 +171,7 @@ class Largefiles(HgExtension):
             dia = HgDialog(self.tr("Pulling large files"), self.vcs)
             res = dia.startProcess(args, repodir)
             if res:
-                dia.exec_()
+                dia.exec()
     
     def hgLfVerify(self, projectDir, mode):
         """
@@ -203,4 +202,4 @@ class Largefiles(HgExtension):
             self.vcs)
         res = dia.startProcess(args, repodir)
         if res:
-            dia.exec_()
+            dia.exec()
