@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project helper for Mercurial.
 """
 
-
 import os
 
 from PyQt5.QtWidgets import QMenu, QToolBar
@@ -40,7 +39,6 @@ class HgProjectHelper(VcsProjectHelper):
         
         # instantiate the extensions
         from .QueuesExtension.ProjectHelper import QueuesProjectHelper
-        from .FetchExtension.ProjectHelper import FetchProjectHelper
         from .PurgeExtension.ProjectHelper import PurgeProjectHelper
         from .GpgExtension.ProjectHelper import GpgProjectHelper
         from .RebaseExtension.ProjectHelper import RebaseProjectHelper
@@ -51,7 +49,6 @@ class HgProjectHelper(VcsProjectHelper):
         from .CloseheadExtension.ProjectHelper import CloseheadProjectHelper
         self.__extensions = {
             "mq": QueuesProjectHelper(),
-            "fetch": FetchProjectHelper(),
             "purge": PurgeProjectHelper(),
             "gpg": GpgProjectHelper(),
             "rebase": RebaseProjectHelper(),
@@ -124,7 +121,7 @@ class HgProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = E5Action(
             self.tr('New from repository'),
-            UI.PixmapCache.getIcon("vcsCheckout.png"),
+            UI.PixmapCache.getIcon("vcsCheckout"),
             self.tr('&New from repository...'), 0, 0,
             self, 'mercurial_new')
         self.vcsNewAct.setStatusTip(self.tr(
@@ -140,7 +137,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgIncomingAct = E5Action(
             self.tr('Show incoming log'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Show incoming log'),
             0, 0, self, 'mercurial_incoming')
         self.hgIncomingAct.setStatusTip(self.tr(
@@ -156,7 +153,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPullAct = E5Action(
             self.tr('Pull changes'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('Pull changes'),
             0, 0, self, 'mercurial_pull')
         self.hgPullAct.setStatusTip(self.tr(
@@ -172,7 +169,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsUpdateAct = E5Action(
             self.tr('Update from repository'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('&Update from repository'), 0, 0, self,
             'mercurial_update')
         self.vcsUpdateAct.setStatusTip(self.tr(
@@ -188,7 +185,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsCommitAct = E5Action(
             self.tr('Commit changes to repository'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('&Commit changes to repository...'), 0, 0, self,
             'mercurial_commit')
         self.vcsCommitAct.setStatusTip(self.tr(
@@ -204,7 +201,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgOutgoingAct = E5Action(
             self.tr('Show outgoing log'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Show outgoing log'),
             0, 0, self, 'mercurial_outgoing')
         self.hgOutgoingAct.setStatusTip(self.tr(
@@ -220,7 +217,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPushAct = E5Action(
             self.tr('Push changes'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Push changes'),
             0, 0, self, 'mercurial_push')
         self.hgPushAct.setStatusTip(self.tr(
@@ -236,7 +233,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPushForcedAct = E5Action(
             self.tr('Push changes (force)'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Push changes (force)'),
             0, 0, self, 'mercurial_push_forced')
         self.hgPushForcedAct.setStatusTip(self.tr(
@@ -252,7 +249,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsExportAct = E5Action(
             self.tr('Export from repository'),
-            UI.PixmapCache.getIcon("vcsExport.png"),
+            UI.PixmapCache.getIcon("vcsExport"),
             self.tr('&Export from repository...'),
             0, 0, self, 'mercurial_export_repo')
         self.vcsExportAct.setStatusTip(self.tr(
@@ -267,7 +264,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgLogBrowserAct = E5Action(
             self.tr('Show log browser'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'),
             0, 0, self, 'mercurial_log_browser')
         self.hgLogBrowserAct.setStatusTip(self.tr(
@@ -284,7 +281,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsDiffAct = E5Action(
             self.tr('Show differences'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show &difference'),
             0, 0, self, 'mercurial_diff')
         self.vcsDiffAct.setStatusTip(self.tr(
@@ -300,7 +297,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgExtDiffAct = E5Action(
             self.tr('Show differences (extended)'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             0, 0, self, 'mercurial_extendeddiff')
         self.hgExtDiffAct.setStatusTip(self.tr(
@@ -316,7 +313,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsStatusAct = E5Action(
             self.tr('Show status'),
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show &status...'),
             0, 0, self, 'mercurial_status')
         self.vcsStatusAct.setStatusTip(self.tr(
@@ -331,7 +328,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgSummaryAct = E5Action(
             self.tr('Show Summary'),
-            UI.PixmapCache.getIcon("vcsSummary.png"),
+            UI.PixmapCache.getIcon("vcsSummary"),
             self.tr('Show summary...'),
             0, 0, self, 'mercurial_summary')
         self.hgSummaryAct.setStatusTip(self.tr(
@@ -389,7 +386,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsRevertAct = E5Action(
             self.tr('Revert changes'),
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Re&vert changes'),
             0, 0, self, 'mercurial_revert')
         self.vcsRevertAct.setStatusTip(self.tr(
@@ -404,7 +401,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsMergeAct = E5Action(
             self.tr('Merge'),
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Mer&ge changes...'),
             0, 0, self, 'mercurial_merge')
         self.vcsMergeAct.setStatusTip(self.tr(
@@ -449,7 +446,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgReMergeAct = E5Action(
             self.tr('Re-Merge'),
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Re-Merge'),
             0, 0, self, 'mercurial_remerge')
         self.hgReMergeAct.setStatusTip(self.tr(
@@ -510,7 +507,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsTagAct = E5Action(
             self.tr('Tag in repository'),
-            UI.PixmapCache.getIcon("vcsTag.png"),
+            UI.PixmapCache.getIcon("vcsTag"),
             self.tr('&Tag in repository...'),
             0, 0, self, 'mercurial_tag')
         self.vcsTagAct.setStatusTip(self.tr(
@@ -553,7 +550,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBranchAct = E5Action(
             self.tr('Create branch'),
-            UI.PixmapCache.getIcon("vcsBranch.png"),
+            UI.PixmapCache.getIcon("vcsBranch"),
             self.tr('Create &branch...'),
             0, 0, self, 'mercurial_branch')
         self.hgBranchAct.setStatusTip(self.tr(
@@ -569,7 +566,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPushBranchAct = E5Action(
             self.tr('Push new branch'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('Push new branch'),
             0, 0, self, 'mercurial_push_branch')
         self.hgPushBranchAct.setStatusTip(self.tr(
@@ -615,7 +612,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.vcsSwitchAct = E5Action(
             self.tr('Switch'),
-            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            UI.PixmapCache.getIcon("vcsSwitch"),
             self.tr('S&witch...'),
             0, 0, self, 'mercurial_switch')
         self.vcsSwitchAct.setStatusTip(self.tr(
@@ -790,7 +787,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBundleAct = E5Action(
             self.tr('Create changegroup'),
-            UI.PixmapCache.getIcon("vcsCreateChangegroup.png"),
+            UI.PixmapCache.getIcon("vcsCreateChangegroup"),
             self.tr('Create changegroup...'),
             0, 0, self, 'mercurial_bundle')
         self.hgBundleAct.setStatusTip(self.tr(
@@ -806,7 +803,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPreviewBundleAct = E5Action(
             self.tr('Preview changegroup'),
-            UI.PixmapCache.getIcon("vcsPreviewChangegroup.png"),
+            UI.PixmapCache.getIcon("vcsPreviewChangegroup"),
             self.tr('Preview changegroup...'),
             0, 0, self, 'mercurial_preview_bundle')
         self.hgPreviewBundleAct.setStatusTip(self.tr(
@@ -822,7 +819,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgUnbundleAct = E5Action(
             self.tr('Apply changegroups'),
-            UI.PixmapCache.getIcon("vcsApplyChangegroup.png"),
+            UI.PixmapCache.getIcon("vcsApplyChangegroup"),
             self.tr('Apply changegroups...'),
             0, 0, self, 'mercurial_unbundle')
         self.hgUnbundleAct.setStatusTip(self.tr(
@@ -949,7 +946,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgImportAct = E5Action(
             self.tr('Import Patch'),
-            UI.PixmapCache.getIcon("vcsImportPatch.png"),
+            UI.PixmapCache.getIcon("vcsImportPatch"),
             self.tr('Import Patch...'),
             0, 0, self, 'mercurial_import')
         self.hgImportAct.setStatusTip(self.tr(
@@ -965,7 +962,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgExportAct = E5Action(
             self.tr('Export Patches'),
-            UI.PixmapCache.getIcon("vcsExportPatch.png"),
+            UI.PixmapCache.getIcon("vcsExportPatch"),
             self.tr('Export Patches...'),
             0, 0, self, 'mercurial_export')
         self.hgExportAct.setStatusTip(self.tr(
@@ -994,7 +991,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgGraftAct = E5Action(
             self.tr('Copy Changesets'),
-            UI.PixmapCache.getIcon("vcsGraft.png"),
+            UI.PixmapCache.getIcon("vcsGraft"),
             self.tr('Copy Changesets'),
             0, 0, self, 'mercurial_graft')
         self.hgGraftAct.setStatusTip(self.tr(
@@ -1055,7 +1052,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgAddSubrepoAct = E5Action(
             self.tr('Add'),
-            UI.PixmapCache.getIcon("vcsAdd.png"),
+            UI.PixmapCache.getIcon("vcsAdd"),
             self.tr('Add...'),
             0, 0, self, 'mercurial_add_subrepo')
         self.hgAddSubrepoAct.setStatusTip(self.tr(
@@ -1070,7 +1067,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgRemoveSubreposAct = E5Action(
             self.tr('Remove'),
-            UI.PixmapCache.getIcon("vcsRemove.png"),
+            UI.PixmapCache.getIcon("vcsRemove"),
             self.tr('Remove...'),
             0, 0, self, 'mercurial_remove_subrepos')
         self.hgRemoveSubreposAct.setStatusTip(self.tr(
@@ -1086,7 +1083,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgArchiveAct = E5Action(
             self.tr('Create unversioned archive'),
-            UI.PixmapCache.getIcon("vcsExport.png"),
+            UI.PixmapCache.getIcon("vcsExport"),
             self.tr('Create unversioned archive...'),
             0, 0, self, 'mercurial_archive')
         self.hgArchiveAct.setStatusTip(self.tr(
@@ -1102,7 +1099,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarksListAct = E5Action(
             self.tr('List bookmarks'),
-            UI.PixmapCache.getIcon("listBookmarks.png"),
+            UI.PixmapCache.getIcon("listBookmarks"),
             self.tr('List bookmarks...'),
             0, 0, self, 'mercurial_list_bookmarks')
         self.hgBookmarksListAct.setStatusTip(self.tr(
@@ -1117,7 +1114,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgBookmarkDefineAct = E5Action(
             self.tr('Define bookmark'),
-            UI.PixmapCache.getIcon("addBookmark.png"),
+            UI.PixmapCache.getIcon("addBookmark"),
             self.tr('Define bookmark...'),
             0, 0, self, 'mercurial_define_bookmark')
         self.hgBookmarkDefineAct.setStatusTip(self.tr(
@@ -1132,7 +1129,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgBookmarkDeleteAct = E5Action(
             self.tr('Delete bookmark'),
-            UI.PixmapCache.getIcon("deleteBookmark.png"),
+            UI.PixmapCache.getIcon("deleteBookmark"),
             self.tr('Delete bookmark...'),
             0, 0, self, 'mercurial_delete_bookmark')
         self.hgBookmarkDeleteAct.setStatusTip(self.tr(
@@ -1147,7 +1144,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgBookmarkRenameAct = E5Action(
             self.tr('Rename bookmark'),
-            UI.PixmapCache.getIcon("renameBookmark.png"),
+            UI.PixmapCache.getIcon("renameBookmark"),
             self.tr('Rename bookmark...'),
             0, 0, self, 'mercurial_rename_bookmark')
         self.hgBookmarkRenameAct.setStatusTip(self.tr(
@@ -1162,7 +1159,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgBookmarkMoveAct = E5Action(
             self.tr('Move bookmark'),
-            UI.PixmapCache.getIcon("moveBookmark.png"),
+            UI.PixmapCache.getIcon("moveBookmark"),
             self.tr('Move bookmark...'),
             0, 0, self, 'mercurial_move_bookmark')
         self.hgBookmarkMoveAct.setStatusTip(self.tr(
@@ -1178,7 +1175,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarkIncomingAct = E5Action(
             self.tr('Show incoming bookmarks'),
-            UI.PixmapCache.getIcon("incomingBookmark.png"),
+            UI.PixmapCache.getIcon("incomingBookmark"),
             self.tr('Show incoming bookmarks'),
             0, 0, self, 'mercurial_incoming_bookmarks')
         self.hgBookmarkIncomingAct.setStatusTip(self.tr(
@@ -1195,7 +1192,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarkPullAct = E5Action(
             self.tr('Pull bookmark'),
-            UI.PixmapCache.getIcon("pullBookmark.png"),
+            UI.PixmapCache.getIcon("pullBookmark"),
             self.tr('Pull bookmark'),
             0, 0, self, 'mercurial_pull_bookmark')
         self.hgBookmarkPullAct.setStatusTip(self.tr(
@@ -1211,7 +1208,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarkPullCurrentAct = E5Action(
             self.tr('Pull current bookmark'),
-            UI.PixmapCache.getIcon("pullBookmark.png"),
+            UI.PixmapCache.getIcon("pullBookmark"),
             self.tr('Pull current bookmark'),
             0, 0, self, 'mercurial_pull_current_bookmark')
         self.hgBookmarkPullCurrentAct.setStatusTip(self.tr(
@@ -1227,7 +1224,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarkOutgoingAct = E5Action(
             self.tr('Show outgoing bookmarks'),
-            UI.PixmapCache.getIcon("outgoingBookmark.png"),
+            UI.PixmapCache.getIcon("outgoingBookmark"),
             self.tr('Show outgoing bookmarks'),
             0, 0, self, 'mercurial_outgoing_bookmarks')
         self.hgBookmarkOutgoingAct.setStatusTip(self.tr(
@@ -1244,7 +1241,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgBookmarkPushAct = E5Action(
             self.tr('Push bookmark'),
-            UI.PixmapCache.getIcon("pushBookmark.png"),
+            UI.PixmapCache.getIcon("pushBookmark"),
             self.tr('Push bookmark'),
             0, 0, self, 'mercurial_push_bookmark')
         self.hgBookmarkPushAct.setStatusTip(self.tr(
@@ -1260,7 +1257,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgBookmarkPushCurrentAct = E5Action(
             self.tr('Push current bookmark'),
-            UI.PixmapCache.getIcon("pushBookmark.png"),
+            UI.PixmapCache.getIcon("pushBookmark"),
             self.tr('Push current bookmark'),
             0, 0, self, 'mercurial_push_current_bookmark')
         self.hgBookmarkPushCurrentAct.setStatusTip(self.tr(
@@ -1277,7 +1274,7 @@ class HgProjectHelper(VcsProjectHelper):
     
         self.hgDeleteBackupsAct = E5Action(
             self.tr('Delete all backups'),
-            UI.PixmapCache.getIcon("clearPrivateData.png"),
+            UI.PixmapCache.getIcon("clearPrivateData"),
             self.tr('Delete all backups'),
             0, 0, self, 'mercurial_delete_all_backups')
         self.hgDeleteBackupsAct.setStatusTip(self.tr(
@@ -1380,14 +1377,14 @@ class HgProjectHelper(VcsProjectHelper):
         self.subMenus.append(bisectMenu)
         
         tagsMenu = QMenu(self.tr("Tags"), menu)
-        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag.png"))
+        tagsMenu.setIcon(UI.PixmapCache.getIcon("vcsTag"))
         tagsMenu.setTearOffEnabled(True)
         tagsMenu.addAction(self.vcsTagAct)
         tagsMenu.addAction(self.hgTagListAct)
         self.subMenus.append(tagsMenu)
         
         branchesMenu = QMenu(self.tr("Branches"), menu)
-        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch.png"))
+        branchesMenu.setIcon(UI.PixmapCache.getIcon("vcsBranch"))
         branchesMenu.setTearOffEnabled(True)
         branchesMenu.addAction(self.hgBranchAct)
         branchesMenu.addAction(self.hgPushBranchAct)
@@ -1396,7 +1393,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.subMenus.append(branchesMenu)
         
         bookmarksMenu = QMenu(self.tr("Bookmarks"), menu)
-        bookmarksMenu.setIcon(UI.PixmapCache.getIcon("bookmark22.png"))
+        bookmarksMenu.setIcon(UI.PixmapCache.getIcon("bookmark22"))
         bookmarksMenu.setTearOffEnabled(True)
         bookmarksMenu.addAction(self.hgBookmarkDefineAct)
         bookmarksMenu.addAction(self.hgBookmarkDeleteAct)
@@ -1428,7 +1425,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.vcs.activeExtensionsChanged.connect(self.__showExtensionMenu)
         
         graftMenu = QMenu(self.tr("Copy Changesets"), menu)
-        graftMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft.png"))
+        graftMenu.setIcon(UI.PixmapCache.getIcon("vcsGraft"))
         graftMenu.setTearOffEnabled(True)
         graftMenu.addAction(self.hgGraftAct)
         graftMenu.addAction(self.hgGraftContinueAct)
@@ -1442,7 +1439,7 @@ class HgProjectHelper(VcsProjectHelper):
         subrepoMenu.addAction(self.hgRemoveSubreposAct)
         
         mergeMenu = QMenu(self.tr("Merge Changesets"), menu)
-        mergeMenu.setIcon(UI.PixmapCache.getIcon("vcsMerge.png"))
+        mergeMenu.setIcon(UI.PixmapCache.getIcon("vcsMerge"))
         mergeMenu.setTearOffEnabled(True)
         mergeMenu.addAction(self.vcsMergeAct)
         mergeMenu.addAction(self.hgShowConflictsAct)
@@ -1455,7 +1452,7 @@ class HgProjectHelper(VcsProjectHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -1579,7 +1576,7 @@ class HgProjectHelper(VcsProjectHelper):
         self.__toolbar.setVisible(False)
         
         ui.registerToolbar("mercurial", self.__toolbar.windowTitle(),
-                           self.__toolbar)
+                           self.__toolbar, "vcs")
         ui.addToolBar(self.__toolbar)
     
     def removeToolbar(self, ui, toolbarManager):
