@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project helper for Subversion.
 """
 
-
 import os
 
 from PyQt5.QtWidgets import QToolBar
@@ -49,7 +48,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         """
         self.vcsNewAct = E5Action(
             self.tr('New from repository'),
-            UI.PixmapCache.getIcon("vcsCheckout.png"),
+            UI.PixmapCache.getIcon("vcsCheckout"),
             self.tr('&New from repository...'), 0, 0, self,
             'pysvn_new')
         self.vcsNewAct.setStatusTip(self.tr(
@@ -65,7 +64,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsUpdateAct = E5Action(
             self.tr('Update from repository'),
-            UI.PixmapCache.getIcon("vcsUpdate.png"),
+            UI.PixmapCache.getIcon("vcsUpdate"),
             self.tr('&Update from repository'), 0, 0, self,
             'pysvn_update')
         self.vcsUpdateAct.setStatusTip(self.tr(
@@ -81,7 +80,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsCommitAct = E5Action(
             self.tr('Commit changes to repository'),
-            UI.PixmapCache.getIcon("vcsCommit.png"),
+            UI.PixmapCache.getIcon("vcsCommit"),
             self.tr('&Commit changes to repository...'), 0, 0, self,
             'pysvn_commit')
         self.vcsCommitAct.setStatusTip(self.tr(
@@ -97,7 +96,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnLogBrowserAct = E5Action(
             self.tr('Show log browser'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
+            UI.PixmapCache.getIcon("vcsLog"),
             self.tr('Show log browser'),
             0, 0, self, 'pysvn_log_browser')
         self.svnLogBrowserAct.setStatusTip(self.tr(
@@ -114,7 +113,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsDiffAct = E5Action(
             self.tr('Show differences'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show &difference'),
             0, 0, self, 'pysvn_diff')
         self.vcsDiffAct.setStatusTip(self.tr(
@@ -130,7 +129,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnExtDiffAct = E5Action(
             self.tr('Show differences (extended)'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (extended)'),
             0, 0, self, 'pysvn_extendeddiff')
         self.svnExtDiffAct.setStatusTip(self.tr(
@@ -146,7 +145,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnUrlDiffAct = E5Action(
             self.tr('Show differences (URLs)'),
-            UI.PixmapCache.getIcon("vcsDiff.png"),
+            UI.PixmapCache.getIcon("vcsDiff"),
             self.tr('Show differences (URLs)'),
             0, 0, self, 'pysvn_urldiff')
         self.svnUrlDiffAct.setStatusTip(self.tr(
@@ -162,7 +161,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsStatusAct = E5Action(
             self.tr('Show status'),
-            UI.PixmapCache.getIcon("vcsStatus.png"),
+            UI.PixmapCache.getIcon("vcsStatus"),
             self.tr('Show &status'),
             0, 0, self, 'pysvn_status')
         self.vcsStatusAct.setStatusTip(self.tr(
@@ -177,7 +176,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnChangeListsAct = E5Action(
             self.tr('Show change lists'),
-            UI.PixmapCache.getIcon("vcsChangeLists.png"),
+            UI.PixmapCache.getIcon("vcsChangeLists"),
             self.tr('Show change lists'),
             0, 0, self, 'pysvn_changelists')
         self.svnChangeListsAct.setStatusTip(self.tr(
@@ -193,7 +192,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnRepoInfoAct = E5Action(
             self.tr('Show repository info'),
-            UI.PixmapCache.getIcon("vcsRepo.png"),
+            UI.PixmapCache.getIcon("vcsRepo"),
             self.tr('Show repository info'),
             0, 0, self, 'pysvn_repoinfo')
         self.svnRepoInfoAct.setStatusTip(self.tr(
@@ -209,7 +208,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsTagAct = E5Action(
             self.tr('Tag in repository'),
-            UI.PixmapCache.getIcon("vcsTag.png"),
+            UI.PixmapCache.getIcon("vcsTag"),
             self.tr('&Tag in repository...'),
             0, 0, self, 'pysvn_tag')
         self.vcsTagAct.setStatusTip(self.tr(
@@ -224,7 +223,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsExportAct = E5Action(
             self.tr('Export from repository'),
-            UI.PixmapCache.getIcon("vcsExport.png"),
+            UI.PixmapCache.getIcon("vcsExport"),
             self.tr('&Export from repository...'),
             0, 0, self, 'pysvn_export')
         self.vcsExportAct.setStatusTip(self.tr(
@@ -252,7 +251,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsRevertAct = E5Action(
             self.tr('Revert changes'),
-            UI.PixmapCache.getIcon("vcsRevert.png"),
+            UI.PixmapCache.getIcon("vcsRevert"),
             self.tr('Re&vert changes'),
             0, 0, self, 'pysvn_revert')
         self.vcsRevertAct.setStatusTip(self.tr(
@@ -267,7 +266,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsMergeAct = E5Action(
             self.tr('Merge'),
-            UI.PixmapCache.getIcon("vcsMerge.png"),
+            UI.PixmapCache.getIcon("vcsMerge"),
             self.tr('Mer&ge changes...'),
             0, 0, self, 'pysvn_merge')
         self.vcsMergeAct.setStatusTip(self.tr(
@@ -283,7 +282,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.vcsSwitchAct = E5Action(
             self.tr('Switch'),
-            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            UI.PixmapCache.getIcon("vcsSwitch"),
             self.tr('S&witch...'),
             0, 0, self, 'pysvn_switch')
         self.vcsSwitchAct.setStatusTip(self.tr(
@@ -425,7 +424,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnRelocateAct = E5Action(
             self.tr('Relocate'),
-            UI.PixmapCache.getIcon("vcsSwitch.png"),
+            UI.PixmapCache.getIcon("vcsSwitch"),
             self.tr('Relocate...'),
             0, 0, self, 'pysvn_relocate')
         self.svnRelocateAct.setStatusTip(self.tr(
@@ -441,7 +440,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         self.svnRepoBrowserAct = E5Action(
             self.tr('Repository Browser'),
-            UI.PixmapCache.getIcon("vcsRepoBrowser.png"),
+            UI.PixmapCache.getIcon("vcsRepoBrowser"),
             self.tr('Repository Browser...'),
             0, 0, self, 'pysvn_repo_browser')
         self.svnRepoBrowserAct.setStatusTip(self.tr(
@@ -493,7 +492,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -585,7 +584,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         self.__toolbar.setVisible(False)
         
         ui.registerToolbar("pysvn", self.__toolbar.windowTitle(),
-                           self.__toolbar)
+                           self.__toolbar, "vcs")
         ui.addToolBar(self.__toolbar)
     
     def removeToolbar(self, ui, toolbarManager):
