@@ -1,25 +1,23 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to browse the log history.
 """
 
-
+import re
 import os
 
-from PyQt5.QtCore import (
-    QTimer, QDate, QProcess, QRegExp, Qt, pyqtSlot, QPoint
-)
-from PyQt5.QtGui import QCursor
+from PyQt5.QtCore import pyqtSlot, Qt, QTimer, QDate, QProcess, QPoint
 from PyQt5.QtWidgets import (
     QHeaderView, QLineEdit, QWidget, QApplication, QDialogButtonBox,
     QTreeWidgetItem
 )
 
 from E5Gui import E5MessageBox
+from E5Gui.E5OverrideCursor import E5OverrideCursorProcess
 
 from .Ui_SvnLogBrowserDialog import Ui_SvnLogBrowserDialog
 
@@ -47,8 +45,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(False)
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
         
         self.filesTree.headerItem().setText(self.filesTree.columnCount(), "")
         self.filesTree.header().setSortIndicator(0, Qt.AscendingOrder)
@@ -64,28 +62,28 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.__messageRole = Qt.UserRole
         self.__changesRole = Qt.UserRole + 1
         
-        self.process = QProcess()
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        self.__process = E5OverrideCursorProcess()
+        self.__process.finished.connect(self.__procFinished)
+        self.__process.readyReadStandardOutput.connect(self.__readStdout)
+        self.__process.readyReadStandardError.connect(self.__readStderr)
         
-        self.rx_sep1 = QRegExp('\\-+\\s*')
-        self.rx_sep2 = QRegExp('=+\\s*')
-        self.rx_rev1 = QRegExp(
+        self.rx_sep1 = re.compile('\\-+\\s*')
+        self.rx_sep2 = re.compile('=+\\s*')
+        self.rx_rev1 = re.compile(
             r'rev ([0-9]+):  ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "rev" followed by one or more decimals followed by a colon followed
         # anything up to " | " (twice) followed by one or more decimals
         # followed by anything
-        self.rx_rev2 = QRegExp(
+        self.rx_rev2 = re.compile(
             r'r([0-9]+) \| ([^|]*) \| ([^|]*) \| ([0-9]+) .*')
         # "r" followed by one or more decimals followed by " | " followed
         # anything up to " | " (twice) followed by one or more decimals
         # followed by anything
-        self.rx_flags1 = QRegExp(
+        self.rx_flags1 = re.compile(
             r"""   ([ADM])\s(.*)\s+\(\w+\s+(.*):([0-9]+)\)\s*""")
         # three blanks followed by A or D or M followed by path followed by
         # path copied from followed by copied from revision
-        self.rx_flags2 = QRegExp('   ([ADM]) (.*)\\s*')
+        self.rx_flags2 = re.compile('   ([ADM]) (.*)\\s*')
         # three blanks followed by A or D or M followed by path
         
         self.flags = {
@@ -136,12 +134,12 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         @param e close event (QCloseEvent)
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         self.__position = self.pos()
         
@@ -277,11 +275,8 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         self.buttonBox.button(QDialogButtonBox.Cancel).setDefault(True)
         QApplication.processEvents()
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        QApplication.processEvents()
-        
         self.intercept = False
-        self.process.kill()
+        self.__process.kill()
         
         self.buf = []
         self.cancelled = False
@@ -301,13 +296,13 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
             args.append('--stop-on-copy')
         args.append(self.fname)
         
-        self.process.setWorkingDirectory(self.dname)
+        self.__process.setWorkingDirectory(self.dname)
         
         self.inputGroup.setEnabled(True)
         self.inputGroup.show()
         
-        self.process.start('svn', args)
-        procStarted = self.process.waitForStarted(5000)
+        self.__process.start('svn', args)
+        procStarted = self.__process.waitForStarted(5000)
         if not procStarted:
             self.inputGroup.setEnabled(False)
             self.inputGroup.hide()
@@ -361,14 +356,12 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         button.
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
-        
-        QApplication.restoreOverrideCursor()
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
         self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
@@ -388,37 +381,47 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         log = {"message": []}
         changedPaths = []
         for s in self.buf:
-            if self.rx_rev1.exactMatch(s):
-                log["revision"] = self.rx_rev.cap(1)
-                log["author"] = self.rx_rev.cap(2)
-                log["date"] = self.rx_rev.cap(3)
+            match = (
+                self.rx_rev1.fullmatch(s) or
+                self.rx_rev2.fullmatch(s) or
+                self.rx_flags1.fullmatch(s) or
+                self.rx_flags2.fullmatch(s) or
+                self.rx_sep1.fullmatch(s) or
+                self.rx_sep2.fullmatch(s)
+            )
+            if match is None:
+                if s.strip().endswith(":") or not s.strip():
+                    continue
+                else:
+                    log["message"].append(s)
+            elif match.re is self.rx_rev1:
+                log["revision"] = match.group(1)
+                log["author"] = match.group(2)
+                log["date"] = match.group(3)
                 # number of lines is ignored
-            elif self.rx_rev2.exactMatch(s):
-                log["revision"] = self.rx_rev2.cap(1)
-                log["author"] = self.rx_rev2.cap(2)
-                log["date"] = " ".join(self.rx_rev2.cap(3).split()[:2])
+            elif match.re is self.rx_rev2:
+                log["revision"] = match.group(1)
+                log["author"] = match.group(2)
+                log["date"] = " ".join(match.group(3).split()[:2])
                 # number of lines is ignored
-            elif self.rx_flags1.exactMatch(s):
+            elif match.re is self.rx_flags1:
                 changedPaths.append({
-                    "action":
-                    self.rx_flags1.cap(1).strip(),
-                    "path":
-                    self.rx_flags1.cap(2).strip(),
-                    "copyfrom_path":
-                    self.rx_flags1.cap(3).strip(),
-                    "copyfrom_revision":
-                    self.rx_flags1.cap(4).strip(),
+                    "action": match.group(1).strip(),
+                    "path": match.group(2).strip(),
+                    "copyfrom_path": match.group(3).strip(),
+                    "copyfrom_revision": match.group(4).strip(),
                 })
-            elif self.rx_flags2.exactMatch(s):
+            elif match.re is self.rx_flags2:
                 changedPaths.append({
-                    "action":
-                    self.rx_flags2.cap(1).strip(),
-                    "path":
-                    self.rx_flags2.cap(2).strip(),
+                    "action": match.group(1).strip(),
+                    "path": match.group(2).strip(),
                     "copyfrom_path": "",
                     "copyfrom_revision": "",
                 })
-            elif self.rx_sep1.exactMatch(s) or self.rx_sep2.exactMatch(s):
+            elif (
+                match.re is self.rx_sep1 or
+                match.re is self.rx_sep2
+            ):
                 if len(log) > 1:
                     self.__generateLogItem(
                         log["author"], log["date"], log["message"],
@@ -438,11 +441,6 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
                     noEntries += 1
                     log = {"message": []}
                     changedPaths = []
-            else:
-                if s.strip().endswith(":") or not s.strip():
-                    continue
-                else:
-                    log["message"].append(s)
         
         self.__resizeColumnsLog()
         self.__resortLog()
@@ -471,10 +469,10 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         
         It reads the output of the process and inserts it into a buffer.
         """
-        self.process.setReadChannel(QProcess.StandardOutput)
+        self.__process.setReadChannel(QProcess.StandardOutput)
         
-        while self.process.canReadLine():
-            line = str(self.process.readLine(),
+        while self.__process.canReadLine():
+            line = str(self.__process.readLine(),
                        Preferences.getSystem("IOEncoding"),
                        'replace')
             self.buf.append(line)
@@ -486,9 +484,9 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
         It reads the error output of the process and inserts it into the
         error pane.
         """
-        if self.process is not None:
+        if self.__process is not None:
             self.errorGroup.show()
-            s = str(self.process.readAllStandardError(),
+            s = str(self.__process.readAllStandardError(),
                     Preferences.getSystem("IOEncoding"),
                     'replace')
             self.errors.insertPlainText(s)
@@ -662,18 +660,18 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
             txt = self.fieldCombo.currentText()
             if txt == self.tr("Author"):
                 fieldIndex = 1
-                searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+                searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             elif txt == self.tr("Revision"):
                 fieldIndex = 0
                 txt = self.rxEdit.text()
                 if txt.startswith("^"):
-                    searchRx = QRegExp(
-                        r"^\s*{0}".format(txt[1:]), Qt.CaseInsensitive)
+                    searchRx = re.compile(
+                        r"^\s*{0}".format(txt[1:]), re.IGNORECASE)
                 else:
-                    searchRx = QRegExp(txt, Qt.CaseInsensitive)
+                    searchRx = re.compile(txt, re.IGNORECASE)
             else:
                 fieldIndex = 3
-                searchRx = QRegExp(self.rxEdit.text(), Qt.CaseInsensitive)
+                searchRx = re.compile(self.rxEdit.text(), re.IGNORECASE)
             
             currentItem = self.logTree.currentItem()
             for topIndex in range(self.logTree.topLevelItemCount()):
@@ -681,7 +679,7 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
                 if (
                     topItem.text(2) <= to_ and
                     topItem.text(2) >= from_ and
-                    searchRx.indexIn(topItem.text(fieldIndex)) > -1
+                    searchRx.match(topItem.text(fieldIndex)) is not None
                 ):
                     topItem.setHidden(False)
                     if topItem is currentItem:
@@ -753,7 +751,7 @@ class SvnLogBrowserDialog(QWidget, Ui_SvnLogBrowserDialog):
             self.errors.ensureCursorVisible()
         self.errorGroup.show()
         
-        self.process.write(strToQByteArray(inputTxt))
+        self.__process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
