@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the subversion repository browser dialog.
 """
 
-
+import re
 import os
 
-from PyQt5.QtGui import QCursor
+from PyQt5.QtCore import pyqtSlot, Qt, QTimer, QProcess
 from PyQt5.QtWidgets import (
-    QHeaderView, QLineEdit, QDialog, QApplication, QDialogButtonBox,
-    QTreeWidgetItem
+    QHeaderView, QLineEdit, QDialog, QDialogButtonBox, QTreeWidgetItem
 )
-from PyQt5.QtCore import QTimer, QProcess, QRegExp, Qt, pyqtSlot
 
 from E5Gui import E5MessageBox
+from E5Gui.E5OverrideCursor import E5OverrideCursorProcess
 
 from .Ui_SvnRepoBrowserDialog import Ui_SvnRepoBrowserDialog
 
@@ -49,10 +48,10 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         self.vcs = vcs
         self.mode = mode
         
-        self.process = QProcess()
-        self.process.finished.connect(self.__procFinished)
-        self.process.readyReadStandardOutput.connect(self.__readStdout)
-        self.process.readyReadStandardError.connect(self.__readStderr)
+        self.__process = E5OverrideCursorProcess()
+        self.__process.finished.connect(self.__procFinished)
+        self.__process.readyReadStandardOutput.connect(self.__readStdout)
+        self.__process.readyReadStandardError.connect(self.__readStderr)
         
         if self.mode == "select":
             self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
@@ -68,10 +67,10 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         self.__ignoreExpand = False
         self.intercept = False
         
-        self.__rx_dir = QRegExp(
+        self.__rx_dir = re.compile(
             r"""\s*([0-9]+)\s+(\w+)\s+"""
             r"""((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
-        self.__rx_file = QRegExp(
+        self.__rx_file = re.compile(
             r"""\s*([0-9]+)\s+(\w+)\s+([0-9]+)\s"""
             r"""((?:\w+\s+\d+|[0-9.]+\s+\w+)\s+[0-9:]+)\s+(.+)\s*""")
     
@@ -82,12 +81,12 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         @param e close event (QCloseEvent)
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         e.accept()
         
@@ -195,7 +194,6 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
                     self.errors.insertPlainText(error)
                     self.errors.ensureCursorVisible()
         else:
-            QApplication.restoreOverrideCursor()
             E5MessageBox.critical(
                 self,
                 self.tr('Process Generation Error'),
@@ -215,9 +213,6 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         """
         self.errorGroup.hide()
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        QApplication.processEvents()
-        
         self.repoUrl = url
         
         if parent is None:
@@ -250,7 +245,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         
         self.intercept = False
         
-        self.process.kill()
+        self.__process.kill()
         
         args = []
         args.append('list')
@@ -259,8 +254,8 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             args.append('--verbose')
         args.append(url)
         
-        self.process.start('svn', args)
-        procStarted = self.process.waitForStarted(5000)
+        self.__process.start('svn', args)
+        procStarted = self.__process.waitForStarted(5000)
         if not procStarted:
             self.__finish()
             self.inputGroup.setEnabled(False)
@@ -370,19 +365,18 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         button.
         """
         if (
-            self.process is not None and
-            self.process.state() != QProcess.NotRunning
+            self.__process is not None and
+            self.__process.state() != QProcess.NotRunning
         ):
-            self.process.terminate()
-            QTimer.singleShot(2000, self.process.kill)
-            self.process.waitForFinished(3000)
+            self.__process.terminate()
+            QTimer.singleShot(2000, self.__process.kill)
+            self.__process.waitForFinished(3000)
         
         self.inputGroup.setEnabled(False)
         self.inputGroup.hide()
         
         self.__resizeColumns()
         self.__resort()
-        QApplication.restoreOverrideCursor()
     
     def __procFinished(self, exitCode, exitStatus):
         """
@@ -400,33 +394,38 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         It reads the output of the process, formats it and inserts it into
         the contents pane.
         """
-        if self.process is not None:
-            self.process.setReadChannel(QProcess.StandardOutput)
+        if self.__process is not None:
+            self.__process.setReadChannel(QProcess.StandardOutput)
             
-            while self.process.canReadLine():
-                s = str(self.process.readLine(),
+            while self.__process.canReadLine():
+                s = str(self.__process.readLine(),
                         Preferences.getSystem("IOEncoding"),
                         'replace')
-                if self.__rx_dir.exactMatch(s):
-                    revision = self.__rx_dir.cap(1)
-                    author = self.__rx_dir.cap(2)
-                    date = self.__rx_dir.cap(3)
-                    name = self.__rx_dir.cap(4).strip()
+                match = (
+                    self.__rx_dir.fullmatch(s) or
+                    self.__rx_file.fullmatch(s)
+                )
+                if match is None:
+                    continue
+                elif match.re is self.__rx_dir:
+                    revision = match.group(1)
+                    author = match.group(2)
+                    date = match.group(3)
+                    name = match.group(4).strip()
                     if name.endswith("/"):
                         name = name[:-1]
                     size = ""
                     nodekind = "dir"
                     if name == ".":
                         continue
-                elif self.__rx_file.exactMatch(s):
-                    revision = self.__rx_file.cap(1)
-                    author = self.__rx_file.cap(2)
-                    size = self.__rx_file.cap(3)
-                    date = self.__rx_file.cap(4)
-                    name = self.__rx_file.cap(5).strip()
+                elif match.re is self.__rx_file:
+                    revision = match.group(1)
+                    author = match.group(2)
+                    size = match.group(3)
+                    date = match.group(4)
+                    name = match.group(5).strip()
                     nodekind = "file"
-                else:
-                    continue
+                
                 url = "{0}/{1}".format(self.repoUrl, name)
                 self.__generateItem(
                     name, revision, author, size, date, nodekind, url)
@@ -438,8 +437,8 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
         It reads the error output of the process and inserts it into the
         error pane.
         """
-        if self.process is not None:
-            s = str(self.process.readAllStandardError(),
+        if self.__process is not None:
+            s = str(self.__process.readAllStandardError(),
                     Preferences.getSystem("IOEncoding"),
                     'replace')
             self.errors.insertPlainText(s)
@@ -472,7 +471,7 @@ class SvnRepoBrowserDialog(QDialog, Ui_SvnRepoBrowserDialog):
             self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(strToQByteArray(inputTxt))
+        self.__process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
