@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the version control systems interface to Subversion.
 """
 
-
 import os
 import re
 import shutil
 from urllib.parse import quote
 
-from PyQt5.QtCore import pyqtSignal, QProcess, QRegExp, QCoreApplication
+from PyQt5.QtCore import pyqtSignal, QProcess, QCoreApplication
 from PyQt5.QtWidgets import QLineEdit, QDialog, QInputDialog, QApplication
 
 from E5Gui.E5Application import e5App
@@ -99,9 +98,9 @@ class Subversion(VersionControl):
         self.logBrowser = None
         
         # regular expression object for evaluation of the status output
-        self.rx_status1 = QRegExp(
+        self.rx_status1 = re.compile(
             '(.{8})\\s+([0-9-]+)\\s+([0-9?]+)\\s+(\\S+)\\s+(.+)')
-        self.rx_status2 = QRegExp('(.{8})\\s+(.+)\\s*')
+        self.rx_status2 = re.compile('(.{8})\\s+(.+)\\s*')
         self.statusCache = {}
         
         self.__commitData = {}
@@ -324,7 +323,7 @@ class Subversion(VersionControl):
                 self.tr('Importing project into Subversion repository'))
             res = dia.startProcess(args, os.path.join(tmpDir, project))
             if res:
-                dia.exec_()
+                dia.exec()
             status = dia.normalExit()
         
         shutil.rmtree(tmpDir, True)
@@ -389,7 +388,7 @@ class Subversion(VersionControl):
                 self.tr('Checking project out of Subversion repository'))
             res = dia.startProcess(args)
             if res:
-                dia.exec_()
+                dia.exec()
             return dia.normalExit()
         
     def vcsExport(self, vcsDataDict, projectDir):
@@ -444,7 +443,7 @@ class Subversion(VersionControl):
             self.tr('Exporting project from Subversion repository'))
         res = dia.startProcess(args)
         if res:
-            dia.exec_()
+            dia.exec()
         return dia.normalExit()
         
     def vcsCommit(self, name, message, noDialog=False):
@@ -568,7 +567,7 @@ class Subversion(VersionControl):
                 self.tr('Commiting changes to Subversion repository'))
             res = dia.startProcess(args, dname)
             if res:
-                dia.exec_()
+                dia.exec()
         self.committed.emit()
         self.checkVCSStatus()
         
@@ -605,7 +604,7 @@ class Subversion(VersionControl):
                 self.tr('Synchronizing with the Subversion repository'))
             res = dia.startProcess(args, dname, True)
             if res:
-                dia.exec_()
+                dia.exec()
                 res = dia.hasAddOrDelete()
         self.checkVCSStatus()
         return res
@@ -705,7 +704,7 @@ class Subversion(VersionControl):
                         ' repository'))
             res = dia.startProcess(args, wdir)
             if res:
-                dia.exec_()
+                dia.exec()
         
     def vcsAddBinary(self, name, isDir=False):
         """
@@ -796,7 +795,7 @@ class Subversion(VersionControl):
             self.tr('Adding directory trees to the Subversion repository'))
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def vcsRemove(self, name, project=False, noDialog=False):
         """
@@ -832,7 +831,7 @@ class Subversion(VersionControl):
                         ' repository'))
             res = dia.startProcess(args)
             if res:
-                dia.exec_()
+                dia.exec()
                 res = dia.normalExit()
         
         return res
@@ -847,7 +846,7 @@ class Subversion(VersionControl):
         @param noDialog flag indicating quiet operations
         @return flag indicating successfull operation (boolean)
         """
-        rx_prot = QRegExp('(file:|svn:|svn+ssh:|http:|https:).+')
+        rx_prot = re.compile('(file:|svn:|svn+ssh:|http:|https:).+')
         opts = self.options['global'][:]
         force = '--force' in opts
         if force:
@@ -862,13 +861,13 @@ class Subversion(VersionControl):
         else:
             from .SvnCopyDialog import SvnCopyDialog
             dlg = SvnCopyDialog(name, None, True, force)
-            accepted = (dlg.exec_() == QDialog.Accepted)
+            accepted = (dlg.exec() == QDialog.Accepted)
             if accepted:
                 target, force = dlg.getData()
             if not target:
                 return False
         
-        if not rx_prot.exactMatch(target):
+        if rx_prot.fullmatch(target) is None:
             isDir = os.path.isdir(name)
         else:
             isDir = False
@@ -879,7 +878,7 @@ class Subversion(VersionControl):
             self.addArguments(args, opts)
             if force:
                 args.append('--force')
-            if rx_prot.exactMatch(target):
+            if rx_prot.fullmatch(target) is not None:
                 args.append('--message')
                 args.append('Moving {0} to {1}'.format(name, target))
                 target = self.__svnURL(target)
@@ -893,9 +892,9 @@ class Subversion(VersionControl):
                                 .format(name))
                 res = dia.startProcess(args)
                 if res:
-                    dia.exec_()
+                    dia.exec()
                     res = dia.normalExit()
-            if res and not rx_prot.exactMatch(target):
+            if res and rx_prot.fullmatch(target) is None:
                 if target.startswith(project.getProjectPath()):
                     if isDir:
                         project.moveDirectory(name, target)
@@ -983,7 +982,7 @@ class Subversion(VersionControl):
         from .SvnTagDialog import SvnTagDialog
         dlg = SvnTagDialog(self.allTagsBranchesList, url,
                            self.otherData["standardLayout"])
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             tag, tagOp = dlg.getParameters()
             if tag in self.allTagsBranchesList:
                 self.allTagsBranchesList.remove(tag)
@@ -992,8 +991,9 @@ class Subversion(VersionControl):
             return
         
         if self.otherData["standardLayout"]:
-            rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
-            if not rx_base.exactMatch(reposURL):
+            rx_base = re.compile('(.+)/(trunk|tags|branches).*')
+            match = rx_base.fullmatch(reposURL)
+            if match is None:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Error"),
@@ -1003,7 +1003,7 @@ class Subversion(VersionControl):
                         """ be aborted"""))
                 return
             
-            reposRoot = rx_base.cap(1)
+            reposRoot = match.group(1)
             if tagOp in [1, 4]:
                 url = '{0}/tags/{1}'.format(reposRoot, quote(tag))
             elif tagOp in [2, 8]:
@@ -1032,7 +1032,7 @@ class Subversion(VersionControl):
                         .format(name))
         res = dia.startProcess(args)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def vcsRevert(self, name):
         """
@@ -1064,7 +1064,7 @@ class Subversion(VersionControl):
                 self.tr("Do you really want to revert all changes to"
                         " these files or directories?"),
                 names)
-            yes = dlg.exec_() == QDialog.Accepted
+            yes = dlg.exec() == QDialog.Accepted
         else:
             yes = E5MessageBox.yesNo(
                 None,
@@ -1075,7 +1075,7 @@ class Subversion(VersionControl):
             dia = SvnDialog(self.tr('Reverting changes'))
             res = dia.startProcess(args)
             if res:
-                dia.exec_()
+                dia.exec()
             self.checkVCSStatus()
     
     def vcsSwitch(self, name):
@@ -1105,7 +1105,7 @@ class Subversion(VersionControl):
         from .SvnSwitchDialog import SvnSwitchDialog
         dlg = SvnSwitchDialog(self.allTagsBranchesList, url,
                               self.otherData["standardLayout"])
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             tag, tagType = dlg.getParameters()
             if tag in self.allTagsBranchesList:
                 self.allTagsBranchesList.remove(tag)
@@ -1114,8 +1114,9 @@ class Subversion(VersionControl):
             return False
         
         if self.otherData["standardLayout"]:
-            rx_base = QRegExp('(.+)/(trunk|tags|branches).*')
-            if not rx_base.exactMatch(reposURL):
+            rx_base = re.compile('(.+)/(trunk|tags|branches).*')
+            match = rx_base.fullmatch(reposURL)
+            if match is None:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Error"),
@@ -1125,7 +1126,7 @@ class Subversion(VersionControl):
                         """ be aborted"""))
                 return False
             
-            reposRoot = rx_base.cap(1)
+            reposRoot = match.group(1)
             tn = tag
             if tagType == 1:
                 url = '{0}/tags/{1}'.format(reposRoot, quote(tag))
@@ -1150,7 +1151,7 @@ class Subversion(VersionControl):
                         .format(tn))
         res = dia.startProcess(args, setLanguage=True)
         if res:
-            dia.exec_()
+            dia.exec()
             res = dia.hasAddOrDelete()
         self.checkVCSStatus()
         return res
@@ -1171,7 +1172,7 @@ class Subversion(VersionControl):
         from .SvnMergeDialog import SvnMergeDialog
         dlg = SvnMergeDialog(
             self.mergeList[0], self.mergeList[1], self.mergeList[2], force)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             urlrev1, urlrev2, target, force = dlg.getParameters()
         else:
             return
@@ -1184,7 +1185,7 @@ class Subversion(VersionControl):
             self.mergeList[1].remove(urlrev2)
         self.mergeList[1].insert(0, urlrev2)
         
-        rx_rev = QRegExp('\\d+|HEAD')
+        rx_rev = re.compile('\\d+|HEAD')
         
         args = []
         args.append('merge')
@@ -1194,7 +1195,7 @@ class Subversion(VersionControl):
             args.append('postpone')
         if force:
             args.append('--force')
-        if rx_rev.exactMatch(urlrev1):
+        if rx_rev.fullmatch(urlrev1) is not None:
             args.append('-r')
             args.append('{0}:{1}'.format(urlrev1, urlrev2))
             if not target:
@@ -1214,7 +1215,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Merging {0}').format(name))
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def vcsRegisteredState(self, name):
         """
@@ -1354,14 +1355,17 @@ class Subversion(VersionControl):
                     output = str(process.readAllStandardOutput(), ioEncoding,
                                  'replace')
                     for line in output.splitlines():
-                        if self.rx_status1.exactMatch(line):
-                            flags = str(self.rx_status1.cap(1))
-                            path = self.rx_status1.cap(5).strip()
-                        elif self.rx_status2.exactMatch(line):
-                            flags = str(self.rx_status2.cap(1))
-                            path = self.rx_status2.cap(2).strip()
+                        match = self.rx_status1.fullmatch(line)
+                        if match is not None:
+                            flags = match.group(1)
+                            path = match.group(5).strip()
                         else:
-                            continue
+                            match = self.rx_status2.fullmatch(line)
+                            if match is not None:
+                                flags = match.group(1)
+                                path = match.group(2).strip()
+                            else:
+                                continue
                         name = os.path.normcase(path)
                         if flags[0] not in "?I":
                             if name in names:
@@ -1420,14 +1424,17 @@ class Subversion(VersionControl):
                     output = str(process.readAllStandardOutput(), ioEncoding,
                                  'replace')
                     for line in output.splitlines():
-                        if self.rx_status1.exactMatch(line):
-                            flags = self.rx_status1.cap(1)
-                            path = self.rx_status1.cap(5).strip()
-                        elif self.rx_status2.exactMatch(line):
-                            flags = self.rx_status2.cap(1)
-                            path = self.rx_status2.cap(2).strip()
+                        match = self.rx_status1.fullmatch(line)
+                        if match is not None:
+                            flags = match.group(1)
+                            path = match.group(5).strip()
                         else:
-                            continue
+                            match = self.rx_status2.fullmatch(line)
+                            if match is not None:
+                                flags = match.group(1)
+                                path = match.group(2).strip()
+                            else:
+                                continue
                         name = os.path.normcase(path)
                         if flags[0] not in "?I":
                             if name in names:
@@ -1481,7 +1488,7 @@ class Subversion(VersionControl):
                         .format(name))
         res = dia.startProcess(args)
         if res:
-            dia.exec_()
+            dia.exec()
     
     def vcsCommandLine(self, name):
         """
@@ -1491,7 +1498,7 @@ class Subversion(VersionControl):
         """
         from .SvnCommandDialog import SvnCommandDialog
         dlg = SvnCommandDialog(self.commandHistory, self.wdHistory, name)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             command, wd = dlg.getData()
             commandList = Utilities.parseOptionString(command)
             
@@ -1510,7 +1517,7 @@ class Subversion(VersionControl):
             dia = SvnDialog(self.tr('Subversion command'))
             res = dia.startProcess(args, wd)
             if res:
-                dia.exec_()
+                dia.exec()
         
     def vcsOptionsDialog(self, project, archive, editable=False, parent=None):
         """
@@ -1685,7 +1692,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Resolving conficts'))
         res = dia.startProcess(args)
         if res:
-            dia.exec_()
+            dia.exec()
         self.checkVCSStatus()
     
     def svnCopy(self, name, project):
@@ -1697,16 +1704,17 @@ class Subversion(VersionControl):
         @return flag indicating successfull operation (boolean)
         """
         from .SvnCopyDialog import SvnCopyDialog
-        rx_prot = QRegExp('(file:|svn:|svn+ssh:|http:|https:).+')
+        rx_prot = re.compile('(file:|svn:|svn+ssh:|http:|https:).+')
         dlg = SvnCopyDialog(name)
         res = False
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             target, force = dlg.getData()
             
             args = []
             args.append('copy')
             self.addArguments(args, self.options['global'])
-            if rx_prot.exactMatch(target):
+            match = rx_prot.fullmatch(target)
+            if match is not None:
                 args.append('--message')
                 args.append('Copying {0} to {1}'.format(name, target))
                 target = self.__svnURL(target)
@@ -1717,11 +1725,11 @@ class Subversion(VersionControl):
                             .format(name))
             res = dia.startProcess(args)
             if res:
-                dia.exec_()
+                dia.exec()
                 res = dia.normalExit()
                 if (
                     res and
-                    not rx_prot.exactMatch(target) and
+                    match is None and
                     target.startswith(project.getProjectPath())
                 ):
                     if os.path.isdir(name):
@@ -1753,7 +1761,7 @@ class Subversion(VersionControl):
         """
         from .SvnPropSetDialog import SvnPropSetDialog
         dlg = SvnPropSetDialog()
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             propName, fileFlag, propValue = dlg.getData()
             if not propName:
                 E5MessageBox.critical(
@@ -1782,7 +1790,7 @@ class Subversion(VersionControl):
             dia = SvnDialog(self.tr('Subversion Set Property'))
             res = dia.startProcess(args, dname)
             if res:
-                dia.exec_()
+                dia.exec()
         
     def svnDelProp(self, name, recursive=False):
         """
@@ -1824,7 +1832,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Subversion Delete Property'))
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def svnListTagBranch(self, path, tags=True):
         """
@@ -1900,7 +1908,7 @@ class Subversion(VersionControl):
                     return
         from .SvnRevisionSelectionDialog import SvnRevisionSelectionDialog
         dlg = SvnRevisionSelectionDialog()
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             revisions = dlg.getRevisions()
             from .SvnDiffDialog import SvnDiffDialog
             self.diff = SvnDiffDialog(self)
@@ -1940,7 +1948,7 @@ class Subversion(VersionControl):
         from .SvnUrlSelectionDialog import SvnUrlSelectionDialog
         dlg = SvnUrlSelectionDialog(self, self.tagsList, self.branchesList,
                                     dname)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             urls, summary = dlg.getURLs()
             from .SvnDiffDialog import SvnDiffDialog
             self.diff = SvnDiffDialog(self)
@@ -2007,7 +2015,7 @@ class Subversion(VersionControl):
         if extended:
             from .SvnRevisionSelectionDialog import SvnRevisionSelectionDialog
             dlg = SvnRevisionSelectionDialog()
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 rev1, rev2 = dlg.getRevisions()
                 if rev1 == "WORKING":
                     rev1 = ""
@@ -2040,11 +2048,10 @@ class Subversion(VersionControl):
             name2 = "{0} (rev. {1})".format(name, rev2)
         else:
             try:
-                f1 = open(name, "r", encoding="utf-8")
-                output2 = f1.read()
-                f1.close()
+                with open(name, "r", encoding="utf-8") as f1:
+                    output2 = f1.read()
                 name2 = name
-            except IOError:
+            except OSError:
                 E5MessageBox.critical(
                     self.__ui,
                     self.tr("Subversion Side-by-Side Difference"),
@@ -2101,7 +2108,7 @@ class Subversion(VersionControl):
             self.tr('Locking in the Subversion repository'), parent)
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def svnUnlock(self, name, breakIt=False, parent=None):
         """
@@ -2129,7 +2136,7 @@ class Subversion(VersionControl):
             self.tr('Unlocking in the Subversion repository'), parent)
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def svnRelocate(self, projectPath):
         """
@@ -2140,7 +2147,7 @@ class Subversion(VersionControl):
         from .SvnRelocateDialog import SvnRelocateDialog
         currUrl = self.svnGetReposName(projectPath)
         dlg = SvnRelocateDialog(currUrl)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             newUrl, inside = dlg.getData()
             args = []
             args.append('switch')
@@ -2153,7 +2160,7 @@ class Subversion(VersionControl):
             dia = SvnDialog(self.tr('Relocating'))
             res = dia.startProcess(args)
             if res:
-                dia.exec_()
+                dia.exec()
         
     def svnRepoBrowser(self, projectPath=None):
         """
@@ -2206,7 +2213,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Remove from changelist'))
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def svnAddToChangelist(self, names):
         """
@@ -2241,7 +2248,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Remove from changelist'))
         res = dia.startProcess(args, dname)
         if res:
-            dia.exec_()
+            dia.exec()
         
     def svnShowChangelists(self, path):
         """
@@ -2262,7 +2269,7 @@ class Subversion(VersionControl):
         @return list of defined change list names (list of strings)
         """
         changelists = []
-        rx_changelist = QRegExp('--- \\S+ .([\\w\\s]+).:\\s*')
+        rx_changelist = re.compile('--- \\S+ .([\\w\\s]+).:\\s*')
         # three dashes, Changelist (translated), quote,
         # changelist name, quote, :
         
@@ -2284,8 +2291,9 @@ class Subversion(VersionControl):
                              'replace')
                 if output:
                     for line in output.splitlines():
-                        if rx_changelist.exactMatch(line):
-                            changelist = rx_changelist.cap(1)
+                        match = rx_changelist.fullmatch(line)
+                        if match is not None:
+                            changelist = match.group(1)
                             if changelist not in changelists:
                                 changelists.append(changelist)
         
@@ -2304,7 +2312,7 @@ class Subversion(VersionControl):
         dia = SvnDialog(self.tr('Upgrade'))
         res = dia.startProcess(args, path)
         if res:
-            dia.exec_()
+            dia.exec()
 
     ###########################################################################
     ## Private Subversion specific methods are below.
