@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the listspace viewmanager class.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, QFileInfo, QEvent, Qt
@@ -182,6 +181,8 @@ class Listspace(ViewManager):
         editor's text
     @signal editorLineChanged(str,int) emitted to signal a change of an
         editor's current line (line is given one based)
+    @signal editorLineChangedEd(Editor,int) emitted to signal a change of an
+        editor's current line (line is given one based)
     """
     changeCaption = pyqtSignal(str)
     editorChanged = pyqtSignal(str)
@@ -205,6 +206,7 @@ class Listspace(ViewManager):
     editorLanguageChanged = pyqtSignal(Editor)
     editorTextChanged = pyqtSignal(Editor)
     editorLineChanged = pyqtSignal(str, int)
+    editorLineChangedEd = pyqtSignal(Editor, int)
     
     def __init__(self, parent):
         """
@@ -253,23 +255,23 @@ class Listspace(ViewManager):
         """
         self.__menu = QMenu(self)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabClose.png"),
+            UI.PixmapCache.getIcon("tabClose"),
             self.tr('Close'), self.__contextMenuClose)
         self.closeOthersMenuAct = self.__menu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther.png"),
+            UI.PixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"),
             self.__contextMenuCloseOthers)
         self.__menu.addAction(
             self.tr('Close All'), self.__contextMenuCloseAll)
         self.__menu.addSeparator()
         self.saveMenuAct = self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSave.png"),
+            UI.PixmapCache.getIcon("fileSave"),
             self.tr('Save'), self.__contextMenuSave)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSaveAs.png"),
+            UI.PixmapCache.getIcon("fileSaveAs"),
             self.tr('Save As...'), self.__contextMenuSaveAs)
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("fileSaveAll.png"),
+            UI.PixmapCache.getIcon("fileSaveAll"),
             self.tr('Save All'), self.__contextMenuSaveAll)
         self.__menu.addSeparator()
         self.openRejectionsMenuAct = self.__menu.addAction(
@@ -277,7 +279,7 @@ class Listspace(ViewManager):
             self.__contextMenuOpenRejections)
         self.__menu.addSeparator()
         self.__menu.addAction(
-            UI.PixmapCache.getIcon("print.png"),
+            UI.PixmapCache.getIcon("print"),
             self.tr('Print'), self.__contextMenuPrintFile)
         self.__menu.addSeparator()
         self.copyPathAct = self.__menu.addAction(
@@ -497,6 +499,7 @@ class Listspace(ViewManager):
             fn = editor.getFileName()
             if fn:
                 self.editorLineChanged.emit(fn, lineno + 1)
+            self.editorLineChangedEd.emit(editor, lineno + 1)
         
     def _showView(self, win, fn=None):
         """
@@ -596,13 +599,13 @@ class Listspace(ViewManager):
         index = self.editors.index(editor)
         keys = []
         if m:
-            keys.append("fileModified.png")
+            keys.append("fileModified")
         if editor.hasSyntaxErrors():
-            keys.append("syntaxError22.png")
+            keys.append("syntaxError22")
         elif editor.hasWarnings():
-            keys.append("warning22.png")
+            keys.append("warning22")
         if not keys:
-            keys.append("empty.png")
+            keys.append("empty")
         item = self.viewlist.item(index)
         if item:
             item.setIcon(UI.PixmapCache.getCombinedIcon(keys))
@@ -620,13 +623,13 @@ class Listspace(ViewManager):
         index = self.editors.index(editor)
         keys = []
         if editor.isModified():
-            keys.append("fileModified.png")
+            keys.append("fileModified")
         if editor.hasSyntaxErrors():
-            keys.append("syntaxError22.png")
+            keys.append("syntaxError22")
         elif editor.hasWarnings():
-            keys.append("warning22.png")
+            keys.append("warning22")
         if not keys:
-            keys.append("empty.png")
+            keys.append("empty")
         item = self.viewlist.item(index)
         if item:
             item.setIcon(UI.PixmapCache.getCombinedIcon(keys))
