@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for entering character classes.
 """
 
-
-from PyQt5.QtCore import QRegExp
-from PyQt5.QtGui import QRegExpValidator
+from PyQt5.QtCore import QRegularExpression
+from PyQt5.QtGui import QRegularExpressionValidator
 from PyQt5.QtWidgets import (
     QWidget, QDialog, QVBoxLayout, QHBoxLayout, QScrollArea, QPushButton,
     QSpacerItem, QSizePolicy, QComboBox, QLineEdit, QLabel
@@ -62,9 +61,12 @@ class QRegularExpressionWizardCharactersDialog(
             (self.tr("Not POSIX Named Set"), "-psn"),
         ])
         
-        self.charValidator = QRegExpValidator(QRegExp(".{0,1}"), self)
-        self.hexValidator = QRegExpValidator(QRegExp("[0-9a-fA-F]{0,4}"), self)
-        self.octValidator = QRegExpValidator(QRegExp("[0-3]?[0-7]{0,2}"), self)
+        self.charValidator = QRegularExpressionValidator(
+            QRegularExpression(".{0,1}"), self)
+        self.hexValidator = QRegularExpressionValidator(
+            QRegularExpression("[0-9a-fA-F]{0,4}"), self)
+        self.octValidator = QRegularExpressionValidator(
+            QRegularExpression("[0-3]?[0-7]{0,2}"), self)
         
         # generate dialog part for single characters
         self.singlesBoxLayout = QVBoxLayout(self.singlesBox)
