@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the QRegularExpression wizard dialog.
 """
 
-
 import os
 import re
 import sys
@@ -221,7 +220,7 @@ class QRegularExpressionWizardWidget(QWidget,
             QRegularExpressionWizardCharactersDialog
         )
         dlg = QRegularExpressionWizardCharactersDialog(self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.__insertString(dlg.getCharacters())
     
     @pyqtSlot()
@@ -240,7 +239,7 @@ class QRegularExpressionWizardWidget(QWidget,
             QRegularExpressionWizardRepeatDialog
         )
         dlg = QRegularExpressionWizardRepeatDialog(self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             self.__insertString(dlg.getRepeat())
     
     @pyqtSlot()
@@ -423,12 +422,11 @@ class QRegularExpressionWizardWidget(QWidget,
                 if not res:
                     return
             
+            fname = Utilities.toNativeSeparators(fname)
             try:
-                f = open(
-                    Utilities.toNativeSeparators(fname), "w", encoding="utf-8")
-                f.write(self.regexpTextEdit.toPlainText())
-                f.close()
-            except IOError as err:
+                with open(fname, "w", encoding="utf-8") as f:
+                    f.write(self.regexpTextEdit.toPlainText())
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
@@ -447,13 +445,12 @@ class QRegularExpressionWizardWidget(QWidget,
             "",
             self.tr("RegExp Files (*.rx);;All Files (*)"))
         if fname:
+            fname = Utilities.toNativeSeparators(fname)
             try:
-                f = open(
-                    Utilities.toNativeSeparators(fname), "r", encoding="utf-8")
-                regexp = f.read()
-                f.close()
+                with open(fname, "r", encoding="utf-8") as f:
+                    regexp = f.read()
                 self.regexpTextEdit.setPlainText(regexp)
-            except IOError as err:
+            except OSError as err:
                 E5MessageBox.information(
                     self,
                     self.tr("Save regular expression"),
