@@ -1,25 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2013 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the setup.py wizard dialog.
 """
 
-
 import os
 import datetime
 
 from PyQt5.QtCore import pyqtSlot, Qt, QUrl
 from PyQt5.QtWidgets import (
-    QDialog, QDialogButtonBox, QTreeWidgetItem, QListWidgetItem, QApplication
+    QDialog, QDialogButtonBox, QTreeWidgetItem, QListWidgetItem
 )
 from PyQt5.QtNetwork import QNetworkRequest, QNetworkReply
 
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5Completers import E5DirCompleter
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 from .Ui_SetupWizardDialog import Ui_SetupWizardDialog
 
@@ -147,10 +147,9 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         filename = os.path.join(os.path.dirname(__file__),
                                 "data", "trove_classifiers.txt")
         try:
-            f = open(filename, "r")
-            lines = f.readlines()
-            f.close()
-        except (IOError, OSError) as err:
+            with open(filename, "r") as f:
+                lines = f.readlines()
+        except OSError as err:
             E5MessageBox.warning(
                 self,
                 self.tr("Reading Trove Classifiers"),
@@ -555,16 +554,15 @@ class SetupWizardDialog(QDialog, Ui_SetupWizardDialog):
         """
         Private slot to discover packages automatically.
         """
-        self.autodiscoverPackagesButton.setEnabled(False)
-        QApplication.setOverrideCursor(Qt.WaitCursor)
-        startDir = self.packageRootEdit.text() or self.__getStartDir()
-        if startDir:
-            self.packagesList.clear()
-            for dirpath, _dirnames, filenames in os.walk(startDir):
-                if "__init__.py" in filenames:
-                    self.__addPackage(dirpath)
-        self.autodiscoverPackagesButton.setEnabled(True)
-        QApplication.restoreOverrideCursor()
+        with E5OverrideCursor():
+            self.autodiscoverPackagesButton.setEnabled(False)
+            startDir = self.packageRootEdit.text() or self.__getStartDir()
+            if startDir:
+                self.packagesList.clear()
+                for dirpath, _dirnames, filenames in os.walk(startDir):
+                    if "__init__.py" in filenames:
+                        self.__addPackage(dirpath)
+            self.autodiscoverPackagesButton.setEnabled(True)
     
     @pyqtSlot()
     def on_packageRootDirButton_clicked(self):
