@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog for the configuration of eric6.
 """
 
-
 import os
 import types
 
@@ -16,7 +15,7 @@ from PyQt5.QtGui import QPixmap
 from PyQt5.QtWidgets import (
     QSizePolicy, QSpacerItem, QWidget, QTreeWidget, QStackedWidget, QDialog,
     QSplitter, QScrollArea, QApplication, QDialogButtonBox, QFrame,
-    QVBoxLayout, QTreeWidgetItem, QLabel
+    QVBoxLayout, QTreeWidgetItem, QLabel, QAbstractScrollArea
 )
 
 from E5Gui.E5Application import e5App
@@ -97,14 +96,6 @@ class ConfigurationWidget(QWidget):
         @keyparam expandedEntries list of entries to be shown expanded
             (list of strings)
         """
-        assert displayMode in (
-            ConfigurationWidget.DefaultMode,
-            ConfigurationWidget.HelpBrowserMode,
-            ConfigurationWidget.TrayStarterMode,
-            ConfigurationWidget.HexEditorMode,
-            ConfigurationWidget.WebBrowserMode,
-        )
-        
         super(ConfigurationWidget, self).__init__(parent)
         self.fromEric = fromEric
         self.displayMode = displayMode
@@ -140,235 +131,232 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
                 "applicationPage":
-                [self.tr("Application"), "preferences-application.png",
+                [self.tr("Application"), "preferences-application",
                  "ApplicationPage", None, None],
                 "condaPage":
-                [self.tr("Conda"), "miniconda.png",
+                [self.tr("Conda"), "miniconda",
                  "CondaPage", None, None],
                 "cooperationPage":
-                [self.tr("Cooperation"), "preferences-cooperation.png",
+                [self.tr("Cooperation"), "preferences-cooperation",
                  "CooperationPage", None, None],
                 "corbaPage":
-                [self.tr("CORBA"), "preferences-orbit.png",
+                [self.tr("CORBA"), "preferences-orbit",
                  "CorbaPage", None, None],
                 "diffPage":
-                [self.tr("Diff"), "diffFiles.png",
+                [self.tr("Diff"), "diffFiles",
                  "DiffColoursPage", None, None],
                 "emailPage":
-                [self.tr("Email"), "preferences-mail_generic.png",
+                [self.tr("Email"), "preferences-mail_generic",
                  "EmailPage", None, None],
                 "graphicsPage":
-                [self.tr("Graphics"), "preferences-graphics.png",
+                [self.tr("Graphics"), "preferences-graphics",
                  "GraphicsPage", None, None],
                 "hexEditorPage":
-                [self.tr("Hex Editor"), "hexEditor.png",
+                [self.tr("Hex Editor"), "hexEditor",
                  "HexEditorPage", None, None],
                 "iconsPage":
-                [self.tr("Icons"), "preferences-icons.png",
+                [self.tr("Icons"), "preferences-icons",
                  "IconsPage", None, None],
                 "ircPage":
-                [self.tr("IRC"), "irc.png",
+                [self.tr("IRC"), "irc",
                  "IrcPage", None, None],
                 "logViewerPage":
-                [self.tr("Log-Viewer"), "preferences-logviewer.png",
+                [self.tr("Log-Viewer"), "preferences-logviewer",
                  "LogViewerPage", None, None],
                 "microPythonPage":
                 [self.tr("MicroPython"), "micropython",
                  "MicroPythonPage", None, None],
                 "mimeTypesPage":
-                [self.tr("Mimetypes"), "preferences-mimetypes.png",
+                [self.tr("Mimetypes"), "preferences-mimetypes",
                  "MimeTypesPage", None, None],
                 "networkPage":
-                [self.tr("Network"), "preferences-network.png",
+                [self.tr("Network"), "preferences-network",
                  "NetworkPage", None, None],
                 "notificationsPage":
                 [self.tr("Notifications"),
-                 "preferences-notifications.png",
+                 "preferences-notifications",
                  "NotificationsPage", None, None],
                 "pipPage":
-                [self.tr("Python Package Management"), "pypi.png",
+                [self.tr("Python Package Management"), "pypi",
                  "PipPage", None, None],
                 "pluginManagerPage":
                 [self.tr("Plugin Manager"),
-                 "preferences-pluginmanager.png",
+                 "preferences-pluginmanager",
                  "PluginManagerPage", None, None],
                 "printerPage":
-                [self.tr("Printer"), "preferences-printer.png",
+                [self.tr("Printer"), "preferences-printer",
                  "PrinterPage", None, None],
                 "protobufPage":
-                [self.tr("Protobuf"), "protobuf.png",
+                [self.tr("Protobuf"), "protobuf",
                  "ProtobufPage", None, None],
                 "pythonPage":
-                [self.tr("Python"), "preferences-python.png",
+                [self.tr("Python"), "preferences-python",
                  "PythonPage", None, None],
                 "qtPage":
-                [self.tr("Qt"), "preferences-qtlogo.png",
+                [self.tr("Qt"), "preferences-qtlogo",
                  "QtPage", None, None],
                 "securityPage":
-                [self.tr("Security"), "preferences-security.png",
+                [self.tr("Security"), "preferences-security",
                  "SecurityPage", None, None],
                 "shellPage":
-                [self.tr("Shell"), "preferences-shell.png",
+                [self.tr("Shell"), "preferences-shell",
                  "ShellPage", None, None],
                 "tasksPage":
-                [self.tr("Tasks"), "task.png",
+                [self.tr("Tasks"), "task",
                  "TasksPage", None, None],
                 "templatesPage":
-                [self.tr("Templates"), "preferences-template.png",
+                [self.tr("Templates"), "preferences-template",
                  "TemplatesPage", None, None],
                 "trayStarterPage":
-                [self.tr("Tray Starter"), "erict.png",
+                [self.tr("Tray Starter"), "erict",
                  "TrayStarterPage", None, None],
                 "vcsPage":
                 [self.tr("Version Control Systems"),
-                 "preferences-vcs.png",
+                 "preferences-vcs",
                  "VcsPage", None, None],
                 
                 "0debuggerPage":
-                [self.tr("Debugger"), "preferences-debugger.png",
+                [self.tr("Debugger"), "preferences-debugger",
                  None, None, None],
                 "debuggerGeneralPage":
-                [self.tr("General"), "preferences-debugger.png",
+                [self.tr("General"), "preferences-debugger",
                  "DebuggerGeneralPage", "0debuggerPage", None],
-                "debuggerPython2Page":
-                [self.tr("Python2"), "preferences-pyDebugger.png",
-                 "DebuggerPython2Page", "0debuggerPage", None],
                 "debuggerPython3Page":
-                [self.tr("Python3"), "preferences-pyDebugger.png",
+                [self.tr("Python3"), "preferences-pyDebugger",
                  "DebuggerPython3Page", "0debuggerPage", None],
                 
                 "0editorPage":
-                [self.tr("Editor"), "preferences-editor.png",
+                [self.tr("Editor"), "preferences-editor",
                  None, None, None],
                 "editorAPIsPage":
-                [self.tr("APIs"), "preferences-api.png",
+                [self.tr("APIs"), "preferences-api",
                  "EditorAPIsPage", "0editorPage", None],
                 "editorAutocompletionPage":
                 [self.tr("Autocompletion"),
-                 "preferences-autocompletion.png",
+                 "preferences-autocompletion",
                  "EditorAutocompletionPage", "0editorPage", None],
                 "editorAutocompletionQScintillaPage":
-                [self.tr("QScintilla"), "qscintilla.png",
+                [self.tr("QScintilla"), "qscintilla",
                  "EditorAutocompletionQScintillaPage",
                  "editorAutocompletionPage", None],
                 "editorCalltipsPage":
-                [self.tr("Calltips"), "preferences-calltips.png",
+                [self.tr("Calltips"), "preferences-calltips",
                  "EditorCalltipsPage", "0editorPage", None],
                 "editorCalltipsQScintillaPage":
-                [self.tr("QScintilla"), "qscintilla.png",
+                [self.tr("QScintilla"), "qscintilla",
                  "EditorCalltipsQScintillaPage", "editorCalltipsPage", None],
                 "editorDocViewerPage":
-                [self.tr("Documentation Viewer"), "codeDocuViewer.png",
+                [self.tr("Documentation Viewer"), "codeDocuViewer",
                  "EditorDocViewerPage", "0editorPage", None],
                 "editorGeneralPage":
-                [self.tr("General"), "preferences-general.png",
+                [self.tr("General"), "preferences-general",
                  "EditorGeneralPage", "0editorPage", None],
                 "editorFilePage":
                 [self.tr("Filehandling"),
-                 "preferences-filehandling.png",
+                 "preferences-filehandling",
                  "EditorFilePage", "0editorPage", None],
                 "editorSearchPage":
-                [self.tr("Searching"), "preferences-search.png",
+                [self.tr("Searching"), "preferences-search",
                  "EditorSearchPage", "0editorPage", None],
                 "editorSpellCheckingPage":
                 [self.tr("Spell checking"),
-                 "preferences-spellchecking.png",
+                 "preferences-spellchecking",
                  "EditorSpellCheckingPage", "0editorPage", None],
                 "editorStylesPage":
-                [self.tr("Style"), "preferences-styles.png",
+                [self.tr("Style"), "preferences-styles",
                  "EditorStylesPage", "0editorPage", None],
                 "editorSyntaxPage":
-                [self.tr("Code Checkers"), "preferences-debugger.png",
+                [self.tr("Code Checkers"), "preferences-debugger",
                  "EditorSyntaxPage", "0editorPage", None],
                 "editorTypingPage":
-                [self.tr("Typing"), "preferences-typing.png",
+                [self.tr("Typing"), "preferences-typing",
                  "EditorTypingPage", "0editorPage", None],
                 "editorExportersPage":
-                [self.tr("Exporters"), "preferences-exporters.png",
+                [self.tr("Exporters"), "preferences-exporters",
                  "EditorExportersPage", "0editorPage", None],
                 
                 "1editorLexerPage":
                 [self.tr("Highlighters"),
-                 "preferences-highlighting-styles.png",
+                 "preferences-highlighting-styles",
                  None, "0editorPage", None],
                 "editorHighlightersPage":
                 [self.tr("Filetype Associations"),
-                 "preferences-highlighter-association.png",
+                 "preferences-highlighter-association",
                  "EditorHighlightersPage", "1editorLexerPage", None],
                 "editorHighlightingStylesPage":
                 [self.tr("Styles"),
-                 "preferences-highlighting-styles.png",
+                 "preferences-highlighting-styles",
                  "EditorHighlightingStylesPage", "1editorLexerPage", None],
                 "editorKeywordsPage":
-                [self.tr("Keywords"), "preferences-keywords.png",
+                [self.tr("Keywords"), "preferences-keywords",
                  "EditorKeywordsPage", "1editorLexerPage", None],
                 "editorPropertiesPage":
-                [self.tr("Properties"), "preferences-properties.png",
+                [self.tr("Properties"), "preferences-properties",
                  "EditorPropertiesPage", "1editorLexerPage", None],
                 
                 "1editorMouseClickHandlers":
                 [self.tr("Mouse Click Handlers"),
-                 "preferences-mouse-click-handler.png",
+                 "preferences-mouse-click-handler",
                  "EditorMouseClickHandlerPage", "0editorPage", None],
                 
                 "0helpPage":
-                [self.tr("Help"), "preferences-help.png",
+                [self.tr("Help"), "preferences-help",
                  None, None, None],
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
-                 "preferences-helpdocumentation.png",
+                 "preferences-helpdocumentation",
                  "HelpDocumentationPage", "0helpPage", None],
                 "helpViewersPage":
                 [self.tr("Help Viewers"),
-                 "preferences-helpviewers.png",
+                 "preferences-helpviewers",
                  "HelpViewersPage", "0helpPage", None],
                 
                 "0projectPage":
-                [self.tr("Project"), "preferences-project.png",
+                [self.tr("Project"), "preferences-project",
                  None, None, None],
                 "projectBrowserPage":
-                [self.tr("Project Viewer"), "preferences-project.png",
+                [self.tr("Project Viewer"), "preferences-project",
                  "ProjectBrowserPage", "0projectPage", None],
                 "projectPage":
-                [self.tr("Project"), "preferences-project.png",
+                [self.tr("Project"), "preferences-project",
                  "ProjectPage", "0projectPage", None],
                 "multiProjectPage":
                 [self.tr("Multiproject"),
-                 "preferences-multiproject.png",
+                 "preferences-multiproject",
                  "MultiProjectPage", "0projectPage", None],
                 
                 "0interfacePage":
-                [self.tr("Interface"), "preferences-interface.png",
+                [self.tr("Interface"), "preferences-interface",
                  None, None, None],
                 "interfacePage":
-                [self.tr("Interface"), "preferences-interface.png",
+                [self.tr("Interface"), "preferences-interface",
                  "InterfacePage", "0interfacePage", None],
                 "viewmanagerPage":
-                [self.tr("Viewmanager"), "preferences-viewmanager.png",
+                [self.tr("Viewmanager"), "preferences-viewmanager",
                  "ViewmanagerPage", "0interfacePage", None],
             }
             if self.__webEngine:
                 self.configItems.update({
                     "0webBrowserPage":
-                    [self.tr("Web Browser"), "ericWeb.png",
+                    [self.tr("Web Browser"), "ericWeb",
                      None, None, None],
                     "webBrowserAppearancePage":
-                    [self.tr("Appearance"), "preferences-styles.png",
+                    [self.tr("Appearance"), "preferences-styles",
                      "WebBrowserAppearancePage", "0webBrowserPage", None],
                     "webBrowserPage":
-                    [self.tr("eric6 Web Browser"), "ericWeb.png",
+                    [self.tr("eric6 Web Browser"), "ericWeb",
                      "WebBrowserPage", "0webBrowserPage", None],
                     "webBrowserFlashCookieManagerPage":
                     [self.tr("Flash Cookie Manager"),
-                     "flashCookie16.png",
+                     "flashCookie16",
                      "WebBrowserFlashCookieManagerPage", "0webBrowserPage",
                      None],
                     "webBrowserVirusTotalPage":
-                    [self.tr("VirusTotal Interface"), "virustotal.png",
+                    [self.tr("VirusTotal Interface"), "virustotal",
                      "WebBrowserVirusTotalPage", "0webBrowserPage", None],
                     "webBrowserSpellCheckingPage":
                     [self.tr("Spell checking"),
-                     "preferences-spellchecking.png",
+                     "preferences-spellchecking",
                      "WebBrowserSpellCheckingPage", "0webBrowserPage",
                      None],
                 })
@@ -385,41 +373,41 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
                 "interfacePage":
-                [self.tr("Interface"), "preferences-interface.png",
-                 "HelpInterfacePage", None, None],
+                [self.tr("Interface"), "preferences-interface",
+                 "WebBrowserInterfacePage", None, None],
                 "networkPage":
-                [self.tr("Network"), "preferences-network.png",
+                [self.tr("Network"), "preferences-network",
                  "NetworkPage", None, None],
                 "printerPage":
-                [self.tr("Printer"), "preferences-printer.png",
+                [self.tr("Printer"), "preferences-printer",
                  "PrinterPage", None, None],
                 "securityPage":
-                [self.tr("Security"), "preferences-security.png",
+                [self.tr("Security"), "preferences-security",
                  "SecurityPage", None, None],
                 
                 "helpDocumentationPage":
                 [self.tr("Help Documentation"),
-                 "preferences-helpdocumentation.png",
+                 "preferences-helpdocumentation",
                  "HelpDocumentationPage", None, None],
                 
                 "webBrowserAppearancePage":
-                [self.tr("Appearance"), "preferences-styles.png",
+                [self.tr("Appearance"), "preferences-styles",
                  "WebBrowserAppearancePage", None, None],
                 "webBrowserPage":
-                [self.tr("eric6 Web Browser"), "ericWeb.png",
+                [self.tr("eric6 Web Browser"), "ericWeb",
                  "WebBrowserPage", None, None],
                 
                 "webBrowserFlashCookieManagerPage":
                 [self.tr("Flash Cookie Manager"),
-                 "flashCookie16.png",
+                 "flashCookie16",
                  "WebBrowserFlashCookieManagerPage", None, None],
                 "webBrowserVirusTotalPage":
-                [self.tr("VirusTotal Interface"), "virustotal.png",
+                [self.tr("VirusTotal Interface"), "virustotal",
                  "WebBrowserVirusTotalPage", None, None],
                 
                 "webBrowserSpellCheckingPage":
                 [self.tr("Spell checking"),
-                 "preferences-spellchecking.png",
+                 "preferences-spellchecking",
                  "WebBrowserSpellCheckingPage", None, None],
             }
         
@@ -432,7 +420,7 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
                 "trayStarterPage":
-                [self.tr("Tray Starter"), "erict.png",
+                [self.tr("Tray Starter"), "erict",
                  "TrayStarterPage", None, None],
             }
         
@@ -445,7 +433,7 @@ class ConfigurationWidget(QWidget):
                 # create the configuration page. This must have the method
                 # 'save' to save the settings.
                 "hexEditorPage":
-                [self.tr("Hex Editor"), "hexEditor.png",
+                [self.tr("Hex Editor"), "hexEditor",
                  "HexEditorPage", None, None],
             }
         
@@ -474,6 +462,7 @@ class ConfigurationWidget(QWidget):
         
         # set the initial size of the splitter
         self.configSplitter.setSizes([200, 600])
+        self.configSplitter.splitterMoved.connect(self.__resizeConfigStack)
         
         self.configList.itemActivated.connect(self.__showConfigurationPage)
         self.configList.itemClicked.connect(self.__showConfigurationPage)
@@ -507,7 +496,7 @@ class ConfigurationWidget(QWidget):
         widget.
         """
         self.setObjectName("ConfigurationDialog")
-        self.resize(900, 650)
+        self.resize(900, 750)
         self.verticalLayout_2 = QVBoxLayout(self)
         self.verticalLayout_2.setSpacing(6)
         self.verticalLayout_2.setContentsMargins(6, 6, 6, 6)
@@ -536,6 +525,8 @@ class ConfigurationWidget(QWidget):
         self.scrollArea.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
         self.scrollArea.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOn)
         self.scrollArea.setWidgetResizable(False)
+        self.scrollArea.setSizeAdjustPolicy(
+            QAbstractScrollArea.AdjustToContents)
         self.scrollArea.setObjectName("scrollArea")
         
         self.configStack = QStackedWidget()
@@ -734,18 +725,7 @@ class ConfigurationWidget(QWidget):
                     if item.data(0, Qt.UserRole) == pageName:
                         self.configList.setCurrentItem(item)
         self.configStack.setCurrentWidget(page)
-        ssize = self.scrollArea.size()
-        if self.scrollArea.horizontalScrollBar():
-            ssize.setHeight(
-                ssize.height() -
-                self.scrollArea.horizontalScrollBar().height() - 2)
-        if self.scrollArea.verticalScrollBar():
-            ssize.setWidth(
-                ssize.width() -
-                self.scrollArea.verticalScrollBar().width() - 2)
-        psize = page.minimumSizeHint()
-        self.configStack.resize(max(ssize.width(), psize.width()),
-                                max(ssize.height(), psize.height()))
+        self.__resizeConfigStack()
         
         if page != self.emptyPage:
             page.polishPage()
@@ -762,7 +742,33 @@ class ConfigurationWidget(QWidget):
                 sb.setValue(0)
         
         self.__currentConfigurationPageName = pageName
+    
+    def resizeEvent(self, evt):
+        """
+        Protected method to handle the resizing of the widget.
         
+        @param evt reference to the event object
+        @type QResizeEvent
+        """
+        self.__resizeConfigStack()
+    
+    def __resizeConfigStack(self):
+        """
+        Private method to resize the stack of configuration pages.
+        """
+        ssize = self.scrollArea.size()
+        if self.scrollArea.horizontalScrollBar():
+            ssize.setHeight(
+                ssize.height() -
+                self.scrollArea.horizontalScrollBar().height() - 2)
+        if self.scrollArea.verticalScrollBar():
+            ssize.setWidth(
+                ssize.width() -
+                self.scrollArea.verticalScrollBar().width() - 2)
+        psize = self.configStack.currentWidget().minimumSizeHint()
+        self.configStack.resize(max(ssize.width(), psize.width()),
+                                max(ssize.height(), psize.height()))
+    
     def getConfigurationPageName(self):
         """
         Public method to get the page name of the current page.
