@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Editor Highlighting Styles configuration page.
 """
 
-
 from PyQt5.QtCore import pyqtSlot, Qt, QFileInfo, QFile, QIODevice
 from PyQt5.QtGui import QPalette, QFont
 from PyQt5.QtWidgets import (
@@ -612,20 +611,23 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         @rtype list of int and tuple of (int, int)
         """
         itm = self.styleElementList.currentItem()
-        parent = itm.parent()
-        if parent is None:
-            currentData = (
-                None, self.styleElementList.indexOfTopLevelItem(itm))
+        if itm:
+            parent = itm.parent()
+            if parent is None:
+                currentData = (
+                    None, self.styleElementList.indexOfTopLevelItem(itm))
+            else:
+                currentData = (
+                    self.styleElementList.indexOfTopLevelItem(parent),
+                    parent.indexOfChild(itm)
+                )
+            
+            savedState = [
+                self.lexerLanguageComboBox.currentIndex(),
+                currentData,
+            ]
         else:
-            currentData = (
-                self.styleElementList.indexOfTopLevelItem(parent),
-                parent.indexOfChild(itm)
-            )
-        
-        savedState = [
-            self.lexerLanguageComboBox.currentIndex(),
-            currentData,
-        ]
+            savedState = []
         return savedState
     
     def setState(self, state):
@@ -634,17 +636,18 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         
         @param state state data generated by saveState
         """
-        self.lexerLanguageComboBox.setCurrentIndex(state[0])
-        self.on_lexerLanguageComboBox_activated(
-            self.lexerLanguageComboBox.currentText())
-        
-        parentIndex, index = state[1]
-        if parentIndex is None:
-            itm = self.styleElementList.topLevelItem(index)
-        else:
-            parent = self.styleElementList.topLevelItem(parentIndex)
-            itm = parent.child(index)
-        self.styleElementList.setCurrentItem(itm)
+        if state:
+            self.lexerLanguageComboBox.setCurrentIndex(state[0])
+            self.on_lexerLanguageComboBox_activated(
+                self.lexerLanguageComboBox.currentText())
+            
+            parentIndex, index = state[1]
+            if parentIndex is None:
+                itm = self.styleElementList.topLevelItem(index)
+            else:
+                parent = self.styleElementList.topLevelItem(parentIndex)
+                itm = parent.child(index)
+            self.styleElementList.setCurrentItem(itm)
     
     #######################################################################
     ## Methods to add, delete and edit sub-styles and their definitions
@@ -658,7 +661,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         style, substyle = self.__currentStyles()
         dlg = SubstyleDefinitionDialog(
             self.lexer, style, substyle, parent=self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             description, words = dlg.getData()
             substyle = self.lexer.addSubstyle(style)
             self.lexer.setDescription(description, style, substyle)
@@ -702,7 +705,7 @@ class EditorHighlightingStylesPage(ConfigurationPageBase,
         style, substyle = self.__currentStyles()
         dlg = SubstyleDefinitionDialog(
             self.lexer, style, substyle, parent=self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             description, words = dlg.getData()
             self.lexer.setDescription(description, style, substyle)
             self.lexer.setWords(words, style, substyle)
