@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2015 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2015 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Package implementing the pip configuration page.
 """
 
-
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_PipPage import Ui_PipPage
 
@@ -35,6 +34,8 @@ class PipPage(ConfigurationPageBase, Ui_PipPage):
         
         # set initial values
         self.indexEdit.setText(Preferences.getPip("PipSearchIndex"))
+        self.noCondaCheckBox.setChecked(
+            Preferences.getPip("ExcludeCondaEnvironments"))
     
     def save(self):
         """
@@ -42,6 +43,8 @@ class PipPage(ConfigurationPageBase, Ui_PipPage):
         """
         Preferences.setPip(
             "PipSearchIndex", self.indexEdit.text().strip())
+        Preferences.setPip(
+            "ExcludeCondaEnvironments", self.noCondaCheckBox.isChecked())
 
 
 def create(dlg):
