@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the  Web Browser configuration page.
 """
 
-
 from PyQt5.QtCore import pyqtSlot, QLocale
 
 from .ConfigurationPageBase import ConfigurationPageBase
@@ -171,7 +170,7 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         self.expireHistory.setCurrentIndex(idx)
         
         for language in range(2, QLocale.LastLanguage + 1):
-            countries = [l.country() for l in QLocale.matchingLocales(
+            countries = [loc.country() for loc in QLocale.matchingLocales(
                 language, QLocale.AnyScript, QLocale.AnyCountry)]
             if len(countries) > 0:
                 self.languageCombo.addItem(
@@ -190,7 +189,7 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             ):
                 self.imageSearchComboBox.addItem(
                     UI.PixmapCache.getIcon(
-                        "{0}.png".format(engineName.lower())),
+                        "{0}".format(engineName.lower())),
                     engineName)
             index = self.imageSearchComboBox.findText(
                 Preferences.getWebBrowser("ImageSearchEngine"))
@@ -464,6 +463,13 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         """
         self.homePageEdit.setText(Preferences.Prefs.helpDefaults["HomePage"])
     
+    @pyqtSlot()
+    def on_setSpeedDialPageButton_clicked(self):
+        """
+        Private slot documentation goes here.
+        """
+        self.homePageEdit.setText("eric:speeddial")
+    
     @pyqtSlot(int)
     def on_startupCombo_currentIndexChanged(self, index):
         """
@@ -472,13 +478,6 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         
         @param index index of the selected entry (integer)
         """
-        # set state of the home page related items
-        enable = index == 1
-        self.homePageLabel.setEnabled(enable)
-        self.homePageEdit.setEnabled(enable)
-        self.defaultHomeButton.setEnabled(enable)
-        self.setCurrentPageButton.setEnabled(enable)
-        
         # set state of the session related items
         self.loadTabOnActivationCheckBox.setEnabled(
             index in [3, 4])
@@ -491,7 +490,7 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         from WebBrowser.Network.SendRefererWhitelistDialog import (
             SendRefererWhitelistDialog
         )
-        SendRefererWhitelistDialog(self).exec_()
+        SendRefererWhitelistDialog(self).exec()
 
 
 def create(dlg):
