@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to generate code for a Qt5 dialog.
 """
 
-
 import sys
 import os
 import json
 
 from PyQt5.QtCore import (
-    pyqtSlot, Qt, QMetaObject, QRegExp, QSortFilterProxyModel, QProcess,
-    QProcessEnvironment
+    pyqtSlot, Qt, QMetaObject, QRegularExpression, QSortFilterProxyModel,
+    QProcess, QProcessEnvironment
 )
 from PyQt5.QtGui import QStandardItemModel, QStandardItem, QBrush, QColor
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox
@@ -422,10 +421,9 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                             """ project type "{0}".</p>""")
                         .format(self.project.getProjectType()))
                     return
-                tmplFile = open(tmplName, 'r', encoding="utf-8")
-                template = tmplFile.read()
-                tmplFile.close()
-            except IOError as why:
+                with open(tmplName, 'r', encoding="utf-8") as tmplFile:
+                    template = tmplFile.read()
+            except OSError as why:
                 E5MessageBox.critical(
                     self,
                     self.tr("Code Generation"),
@@ -458,12 +456,11 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         else:
             # extend existing file
             try:
-                srcFile = open(self.srcFile, 'r', encoding="utf-8")
-                sourceImpl = srcFile.readlines()
-                srcFile.close()
+                with open(self.srcFile, 'r', encoding="utf-8") as srcFile:
+                    sourceImpl = srcFile.readlines()
                 if not sourceImpl[-1].endswith("\n"):
                     sourceImpl[-1] = "{0}{1}".format(sourceImpl[-1], "\n")
-            except IOError as why:
+            except OSError as why:
                 E5MessageBox.critical(
                     self,
                     self.tr("Code Generation"),
@@ -548,25 +545,24 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
             sourceImpl[appendAtIndex:appendAtIndex] = slotsCode
         
         # write the new code
+        if self.project.useSystemEol():
+            newline = None
+        else:
+            newline = self.project.getEolString()
+        fn = self.filenameEdit.text()
         try:
-            if self.project.useSystemEol():
-                newline = None
-            else:
-                newline = self.project.getEolString()
-            srcFile = open(self.filenameEdit.text(), 'w', encoding="utf-8",
-                           newline=newline)
-            srcFile.write("".join(sourceImpl))
-            srcFile.close()
-        except IOError as why:
+            with open(fn, 'w', encoding="utf-8", newline=newline) as srcFile:
+                srcFile.write("".join(sourceImpl))
+        except OSError as why:
             E5MessageBox.critical(
                 self,
                 self.tr("Code Generation"),
                 self.tr("""<p>Could not write the source file "{0}".</p>"""
                         """<p>Reason: {1}</p>""")
-                .format(self.filenameEdit.text(), str(why)))
+                .format(fn, str(why)))
             return
         
-        self.project.appendFile(self.filenameEdit.text())
+        self.project.appendFile(fn)
         
     @pyqtSlot(int)
     def on_classNameCombo_activated(self, index):
@@ -591,8 +587,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         
         @param text changed text (string)
         """
-        re = QRegExp(text, Qt.CaseInsensitive, QRegExp.RegExp2)
-        self.proxyModel.setFilterRegExp(re)
+        rx = QRegularExpression(text, QRegularExpression.CaseInsensitiveOption)
+        self.proxyModel.setFilterRegularExpression(rx)
         
     @pyqtSlot()
     def on_newButton_clicked(self):
@@ -603,7 +599,7 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         objName = self.__objectName()
         if objName:
             dlg = NewDialogClassDialog(objName, file, path, self)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 className, fileName = dlg.getData()
                 
                 self.classNameCombo.clear()
