@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the browser model.
 """
 
-
 import os
 import re
 
@@ -131,9 +130,9 @@ class ProjectBrowserSimpleDirectoryItem(BrowserItem, ProjectBrowserItemMixin):
         self.type_ = ProjectBrowserItemSimpleDirectory
         if os.path.lexists(self._dirName) and os.path.islink(self._dirName):
             self.symlink = True
-            self.icon = UI.PixmapCache.getSymlinkIcon("dirClosed.png")
+            self.icon = UI.PixmapCache.getSymlinkIcon("dirClosed")
         else:
-            self.icon = UI.PixmapCache.getIcon("dirClosed.png")
+            self.icon = UI.PixmapCache.getIcon("dirClosed")
     
     def setName(self, dinfo, full=True):
         """
@@ -244,6 +243,7 @@ class ProjectBrowserModel(BrowserModel):
         self.project = parent
         
         self.watchedItems = {}
+        self.__watcherActive = True
         self.watcher = QFileSystemWatcher(self)
         self.watcher.directoryChanged.connect(self.directoryChanged)
         
@@ -589,7 +589,7 @@ class ProjectBrowserModel(BrowserModel):
             return
         
         index = self.createIndex(itm.row(), 0, itm)
-        itm.setName(newFilename)
+        itm.setName(newFilename, full=False)
         self.dataChanged.emit(index, index)
         self.repopulateItem(newFilename)
     
@@ -668,12 +668,27 @@ class ProjectBrowserModel(BrowserModel):
         
         return index
     
+    def startFileSystemMonitoring(self):
+        """
+        Public method to (re)start monitoring the project file system.
+        """
+        self.__watcherActive = True
+    
+    def stopFileSystemMonitoring(self):
+        """
+        Public method to stop monitoring the project file system.
+        """
+        self.__watcherActive = False
+        
     def directoryChanged(self, path):
         """
         Public slot to handle the directoryChanged signal of the watcher.
         
         @param path path of the directory (string)
         """
+        if not self.__watcherActive:
+            return
+        
         if path not in self.watchedItems:
             # just ignore the situation we don't have a reference to the item
             return
