@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing the a class used to display the interfaces (IDL) part
 of the project.
 """
 
-
 import os
 import glob
 
@@ -338,7 +337,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except Exception:
+        except Exception:           # secok
             pass
         
     def __showContextMenu(self):
@@ -464,7 +463,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
                     " the project?"),
             files)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             for fn2, fn in zip(fullNames, files):
                 self.closeSourceWindow.emit(fn2)
                 self.project.deleteFile(fn)
@@ -534,7 +533,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
                         " successful."))
             else:
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("corba48.png"),
+                    UI.PixmapCache.getPixmap("corba48"),
                     self.tr("Interface Compilation"),
                     self.tr(
                         "The compilation of the interface file was"
@@ -548,7 +547,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
                         "The compilation of the interface file failed."))
             else:
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("corba48.png"),
+                    UI.PixmapCache.getPixmap("corba48"),
                     self.tr("Interface Compilation"),
                     self.tr(
                         "The compilation of the interface file failed."))
@@ -693,7 +692,7 @@ class ProjectInterfacesBrowser(ProjectBaseBrowser):
         dlg = IdlCompilerOptionsDialog(
             params["IncludeDirs"][:], params["DefinedNames"][:],
             params["UndefinedNames"][:], self.project, self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             include, defined, undefined = dlg.getData()
             if include != params["IncludeDirs"]:
                 params["IncludeDirs"] = include[:]
