@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a class used to display the parts of the project, that
 don't fit the other categories.
 """
 
-
 from PyQt5.QtCore import QModelIndex, pyqtSignal, QUrl
 from PyQt5.QtGui import QDesktopServices
 from PyQt5.QtWidgets import QDialog, QMenu
@@ -357,7 +356,7 @@ class ProjectOthersBrowser(ProjectBaseBrowser):
                 " project?"),
             names)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             for itm, fn2, fn in zip(items[:], fullNames, names):
                 if isinstance(itm, ProjectBrowserFileItem):
                     self.closeSourceWindow.emit(fn2)
