@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class used to display the resources part of the project.
 """
 
-
 import os
 
 from PyQt5.QtCore import QThread, QFileInfo, pyqtSignal, QProcess
@@ -493,14 +492,14 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                     newline = None
                 else:
                     newline = self.project.getEolString()
-                rcfile = open(fname, 'w', encoding="utf-8", newline=newline)
-                rcfile.write('<!DOCTYPE RCC>\n')
-                rcfile.write('<RCC version="1.0">\n')
-                rcfile.write('<qresource>\n')
-                rcfile.write('</qresource>\n')
-                rcfile.write('</RCC>\n')
-                rcfile.close()
-            except IOError as e:
+                with open(fname, 'w', encoding="utf-8",
+                          newline=newline) as rcfile:
+                    rcfile.write('<!DOCTYPE RCC>\n')
+                    rcfile.write('<RCC version="1.0">\n')
+                    rcfile.write('<qresource>\n')
+                    rcfile.write('</qresource>\n')
+                    rcfile.write('</RCC>\n')
+            except OSError as e:
                 E5MessageBox.critical(
                     self,
                     self.tr("New Resource"),
@@ -538,7 +537,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                 " project?"),
             files)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             for fn2, fn in zip(fullNames, files):
                 self.closeSourceWindow.emit(fn2)
                 self.project.deleteFile(fn)
@@ -596,10 +595,9 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                     newline = None
                 else:
                     newline = self.project.getEolString()
-                f = open(ofn, "w", encoding="utf-8", newline=newline)
-                for line in self.buf.splitlines():
-                    f.write(line + "\n")
-                f.close()
+                with open(ofn, "w", encoding="utf-8", newline=newline) as f:
+                    for line in self.buf.splitlines():
+                        f.write(line + "\n")
                 if self.compiledFile not in self.project.pdata["SOURCES"]:
                     self.project.appendFile(ofn)
                 if not self.noDialog and not ui.notificationsEnabled():
@@ -614,7 +612,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                         self.tr("Resource Compilation"),
                         self.tr("The compilation of the resource file"
                                 " was successful."))
-            except IOError as msg:
+            except OSError as msg:
                 if not self.noDialog:
                     E5MessageBox.information(
                         self,
@@ -816,10 +814,9 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         @return flag indicating some file is newer (boolean)
         """
         try:
-            f = open(filename, "r", encoding="utf-8")
-            buf = f.read()
-            f.close()
-        except IOError:
+            with open(filename, "r", encoding="utf-8") as f:
+                buf = f.read()
+        except OSError:
             return False
         
         qrcDirName = os.path.dirname(filename)
@@ -928,7 +925,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         params = self.project.pdata["RCCPARAMS"]
         
         dlg = RccCompilerOptionsDialog(params)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             threshold, compression, noCompression, root = dlg.getData()
             if threshold != params["CompressionThreshold"]:
                 params["CompressionThreshold"] = threshold
