@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class used to display the Sources part of the project.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal
@@ -135,7 +134,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             self.__showApplicationDiagram)
         self.graphicsMenu.addSeparator()
         self.graphicsMenu.addAction(
-            UI.PixmapCache.getIcon("open.png"),
+            UI.PixmapCache.getIcon("open"),
             self.tr("Load Diagram..."), self.__loadDiagram)
         self.graphicsMenu.aboutToShow.connect(self.__showContextMenuGraphics)
         
@@ -305,7 +304,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             self.__showApplicationDiagram)
         self.graphicsMenu.addSeparator()
         self.graphicsMenu.addAction(
-            UI.PixmapCache.getIcon("fileOpen.png"),
+            UI.PixmapCache.getIcon("fileOpen"),
             self.tr("Load Diagram..."), self.__loadDiagram)
         
         self.sourceMenu.addSeparator()
@@ -670,7 +669,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except Exception:
+        except Exception:           # secok
             pass
         
     def __showContextMenu(self):
@@ -736,8 +735,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                 (coEnable or
                  os.path.isfile("{0}.coverage".format(basename)) or
                  os.path.isfile("{0}.coverage".format(tbasename))) and
-                (self.project.isPy3Project() or
-                 self.project.isPy2Project())
+                self.project.isPy3Project()
             )
         
         # now check the selected item
@@ -752,7 +750,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             coEnable = (
                 (coEnable or
                  os.path.isfile("{0}.coverage".format(basename))) and
-                (itm.isPython3File() or itm.isPython2File())
+                itm.isPython3File()
             )
         
         self.profileMenuAction.setEnabled(prEnable)
@@ -770,9 +768,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
         
         for itm in itmList:
             if isinstance(itm, BrowserFileItem):
-                if itm.isPython2File():
-                    self.sourceFile[str].emit(itm.fileName())
-                elif itm.isPython3File():
+                if itm.isPython3File():
                     self.sourceFile[str].emit(itm.fileName())
                 elif itm.isRubyFile():
                     self.sourceFile[str, int, str].emit(
@@ -818,7 +814,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
             dn = dn[1:]
         from .NewPythonPackageDialog import NewPythonPackageDialog
         dlg = NewPythonPackageDialog(dn, self)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             packageName = dlg.getData()
             nameParts = packageName.split(".")
             packagePath = self.project.ppath
@@ -841,9 +837,9 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                 packageFile = os.path.join(packagePath, "__init__.py")
                 if not os.path.exists(packageFile):
                     try:
-                        f = open(packageFile, "w", encoding="utf-8")
-                        f.close()
-                    except IOError as err:
+                        with open(packageFile, "w", encoding="utf-8"):
+                            pass
+                    except OSError as err:
                         E5MessageBox.critical(
                             self,
                             self.tr("Add new Python package"),
@@ -919,7 +915,7 @@ class ProjectSourcesBrowser(ProjectBaseBrowser):
                 "Do you really want to delete these files from the project?"),
             files)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             for fn2, fn in zip(fullNames, files):
                 self.closeSourceWindow.emit(fn2)
                 self.project.deleteFile(fn)
