@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a class used to display the translations part of the
 project.
 """
 
-
 import os
 import shutil
 import fnmatch
@@ -102,8 +101,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         self.menu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             act = self.menu.addAction(
                 self.tr('Generate translation'), self.__generateSelected)
@@ -230,8 +228,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
         self.backMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             act = self.backMenu.addAction(
                 self.tr('Generate all translations'),
@@ -292,8 +289,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         # create the menu for multiple selected files
         self.multiMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             act = self.multiMenu.addAction(
                 self.tr('Generate translations'),
@@ -377,8 +373,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
 
         self.dirMenu = QMenu(self)
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             act = self.dirMenu.addAction(
                 self.tr('Generate all translations'),
@@ -488,7 +483,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                         self.backMenu.popup(self.mapToGlobal(coord))
                 else:
                     self.backMenu.popup(self.mapToGlobal(coord))
-        except Exception:
+        except Exception:           # secok
             pass
         
     def __showContextMenu(self):
@@ -496,8 +491,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the menu aboutToShow signal.
         """
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             tsFiles = 0
             qmFiles = 0
@@ -541,8 +535,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the multiMenu aboutToShow signal.
         """
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             tsFiles = 0
             qmFiles = 0
@@ -584,8 +577,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the dirMenu aboutToShow signal.
         """
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocDirMenuActions:
@@ -605,8 +597,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         Private slot called by the backMenu aboutToShow signal.
         """
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             if self.pylupdateProcRunning:
                 for act in self.tsprocBackMenuActions:
@@ -690,7 +681,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     " from the project?"),
             translationFiles)
         
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             for fn in translationFiles:
                 self.closeSourceWindow.emit(fn)
                 self.project.deleteLanguageFile(fn)
@@ -818,17 +809,16 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             if not os.path.exists(outDir):
                 os.makedirs(outDir)
             try:
-                pf = open(outFile, "w", encoding="utf-8")
-                for key, fileList in sections:
-                    if len(fileList) > 0:
-                        pf.write('{0} = '.format(key))
-                        pf.write(' \\\n\t'.join(
-                            [f.replace(os.sep, '/') for f in fileList]))
-                        pf.write('\n\n')
+                with open(outFile, "w", encoding="utf-8") as pf:
+                    for key, fileList in sections:
+                        if len(fileList) > 0:
+                            pf.write('{0} = '.format(key))
+                            pf.write(' \\\n\t'.join(
+                                [f.replace(os.sep, '/') for f in fileList]))
+                            pf.write('\n\n')
                 
-                pf.close()
                 self.__tmpProjects.append(outFile)
-            except IOError:
+            except OSError:
                 E5MessageBox.critical(
                     self,
                     self.tr("Write temporary project file"),
@@ -880,7 +870,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
     def __readStderrLupdate(self, proc):
         """
         Private slot to handle the readyReadStandardError signal of the
-        pylupdate4/pylupdate5/pyside-lupdate/pyside2-lupdate process.
+        pylupdate5/pyside2-lupdate process.
         
         @param proc reference to the process
         @type QProcess
@@ -939,7 +929,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             ui = e5App().getObject("UserInterface")
             if ui.notificationsEnabled():
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("linguist48.png"),
+                    UI.PixmapCache.getPixmap("linguist48"),
                     self.tr("Translation file generation"),
                     self.tr(
                         "The generation of the translation files (*.ts)"
@@ -969,7 +959,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                     self.__tmpProjects.remove(
                         self.__pylupdateProcesses[index][1])
                     os.remove(self.__pylupdateProcesses[index][1])
-                except EnvironmentError:
+                except OSError:
                     pass
                 del self.__pylupdateProcesses[index]
                 break
@@ -979,7 +969,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         
     def __generateTSFile(self, noobsolete=False, generateAll=True):
         """
-        Private method used to run pylupdate4/pylupdate5/pyside-lupdate to
+        Private method used to run pylupdate5/pyside2-lupdate to
         generate the .ts files.
         
         @param noobsolete flag indicating whether obsolete entries should be
@@ -1021,7 +1011,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         # generate a minimal temporary projectfile suitable for pylupdate
         self.__tmpProjects = []
         if self.project.getProjectLanguage() in [
-            "Python", "Python2", "Python3"
+            "Python", "Python3"
         ]:
             ok = self.__writeTempProjectFile(langs, [".py"])
         else:
@@ -1029,18 +1019,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         if not ok:
             return
         
-        if self.project.getProjectType() in ["Qt4", "Qt4C"]:
-            self.pylupdate = Utilities.generatePyQtToolPath('pylupdate4')
-        elif self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
+        if self.project.getProjectType() in ["PyQt5", "PyQt5C"]:
             self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
         elif self.project.getProjectType() in ["E6Plugin"]:
             self.pylupdate = Utilities.generatePyQtToolPath('pylupdate5')
-        elif self.project.getProjectType() in ["PySide", "PySideC"]:
-            self.pylupdate = Utilities.generatePySideToolPath(
-                'pyside-lupdate', "1")
         elif self.project.getProjectType() in ["PySide2", "PySide2C"]:
             self.pylupdate = Utilities.generatePySideToolPath(
-                'pyside2-lupdate', "2")
+                'pyside2-lupdate')
         else:
             return
 
@@ -1080,7 +1065,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 try:
                     self.__tmpProjects.remove(tempProjectFile)
                     os.remove(tempProjectFile)
-                except EnvironmentError:
+                except OSError:
                     pass
         
     def __generateAll(self):
@@ -1136,7 +1121,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             ui = e5App().getObject("UserInterface")
             if ui.notificationsEnabled():
                 ui.showNotification(
-                    UI.PixmapCache.getPixmap("linguist48.png"),
+                    UI.PixmapCache.getPixmap("linguist48"),
                     self.tr("Translation file release"),
                     self.tr("The release of the translation files (*.qm)"
                             " was successful."))
@@ -1197,8 +1182,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
                 return
         
         if self.project.getProjectType() in [
-            "Qt4", "Qt4C", "PyQt5", "PyQt5C", "E6Plugin",
-            "PySide", "PySideC", "PySide2", "PySideC2"
+            "PyQt5", "PyQt5C", "E6Plugin", "PySide2", "PySide2C"
         ]:
             lrelease = os.path.join(
                 Utilities.getQtBinariesPath(),
