@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module to get the object name, class name or signatures of a Qt form (*.ui).
 """
 
+import os
 import sys
 import json
 import xml.etree.ElementTree            # secok
@@ -24,6 +25,9 @@ try:
 except ImportError:
     pass
 
+sys.path.append(os.path.dirname(os.path.dirname(__file__)))
+# add the eric package directory
+
 
 def objectName(formFile, projectPath):
     """
