@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the UI to the pyunit package.
 """
 
-
 import unittest
 import sys
 import time
@@ -30,7 +29,6 @@ from .Ui_UnittestDialog import Ui_UnittestDialog
 
 import UI.PixmapCache
 
-import Utilities
 import Preferences
 
 
@@ -120,7 +118,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         self.setWindowFlags(
             self.windowFlags() | Qt.WindowFlags(
                 Qt.WindowContextHelpButtonHint))
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         self.setWindowTitle(self.tr("Unittest"))
         if dbs:
             self.ui = ui
@@ -288,17 +286,13 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         Private slot called before the test suite selection dialog is shown.
         """
         if self.__dbs:
-            py2Extensions = ' '.join(
-                ["*{0}".format(ext)
-                 for ext in self.__dbs.getExtensions('Python2')]
-            )
             py3Extensions = ' '.join(
                 ["*{0}".format(ext)
                  for ext in self.__dbs.getExtensions('Python3')]
             )
             fileFilter = self.tr(
-                "Python3 Files ({1});;Python2 Files ({0});;All Files (*)"
-            ).format(py2Extensions, py3Extensions)
+                "Python3 Files ({0});;All Files (*)"
+            ).format(py3Extensions)
         else:
             fileFilter = self.tr("Python Files (*.py);;All Files (*)")
         self.testsuitePicker.setFilters(fileFilter)
@@ -407,10 +401,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                     return
                 
                 workdir = ""
-                clientType = self.__venvManager.getVirtualenvVariant(venvName)
-                if not clientType:
-                    # assume Python 3
-                    clientType = "Python3"
+                clientType = "Python3"
                 sysPath = []
             self.__dbs.remoteUTDiscover(clientType, self.__forProject,
                                         venvName, sysPath, workdir,
@@ -756,34 +747,16 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
                     
                     coverageFile = os.path.join(discoveryStart, "unittest")
                     workdir = ""
-                    clientType = self.__venvManager.getVirtualenvVariant(
-                        venvName)
-                    if not clientType:
-                        # assume Python 3
-                        clientType = "Python3"
+                    clientType = "Python3"
                 elif testFileName:
                     mainScript = os.path.abspath(testFileName)
-                    flags = Utilities.extractFlagsFromFile(mainScript)
                     workdir = os.path.dirname(mainScript)
-                    if (
-                        mainScript.endswith(tuple(
-                            Preferences.getPython("PythonExtensions"))) or
-                        ("FileType" in flags and
-                         flags["FileType"] in ["Python", "Python2"])
-                    ):
-                        clientType = "Python2"
-                    else:
-                        # if it is not Python2 it must be Python3!
-                        clientType = "Python3"
+                    clientType = "Python3"
                     coverageFile = os.path.splitext(mainScript)[0]
                 else:
                     coverageFile = os.path.abspath("unittest")
                     workdir = ""
-                    clientType = self.__venvManager.getVirtualenvVariant(
-                        venvName)
-                    if not clientType:
-                        # assume Python 3
-                        clientType = "Python3"
+                    clientType = "Python3"
                 sysPath = []
             if failedOnly and self.__failedTests:
                 failed = self.__failedTests[:]
@@ -1178,7 +1151,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         
         # and now fire it up
         self.dlg.show()
-        self.dlg.exec_()
+        self.dlg.exec()
     
     def __showSource(self):
         """
@@ -1239,7 +1212,7 @@ class UnittestDialog(QWidget, Ui_UnittestDialog):
         for editor in self.__editors:
             try:
                 editor.close()
-            except Exception:
+            except Exception:           # secok
                 # ignore all exceptions
                 pass
 
