@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an exporter for HTML.
 """
 
-
 # This code is a port of the C++ code found in SciTE 1.74
 # Original code: Copyright 1998-2006 by Neil Hodgson <neilh@scintilla.org>
 
@@ -15,12 +14,12 @@ import os
 import sys
 import io
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QCursor, QFontInfo
-from PyQt5.QtWidgets import QApplication
+from PyQt5.QtGui import QFontInfo
+from PyQt5.QtWidgets import QInputDialog
 from PyQt5.Qsci import QsciScintilla
 
 from E5Gui import E5MessageBox
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 from .ExporterBase import ExporterBase
 
@@ -392,42 +391,56 @@ class ExporterHTML(ExporterBase):
         if not filename:
             return
         
-        try:
-            QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-            QApplication.processEvents()
-            
-            fn = self.editor.getFileName()
-            if fn:
-                extension = os.path.normcase(os.path.splitext(fn)[1][1:])
+        fn = self.editor.getFileName()
+        if fn:
+            extension = os.path.normcase(os.path.splitext(fn)[1][1:])
+        else:
+            extension = ""
+        
+        if (
+            extension in Preferences.getEditor(
+                "PreviewMarkdownFileNameExtensions") or
+            self.editor.getLanguage().lower() == "markdown"
+        ):
+            # export markdown to HTML
+            colorSchemes = [
+                self.tr("Light Background Color"),
+                self.tr("Dark Background Color"),
+            ]
+            colorScheme, ok = QInputDialog.getItem(
+                None,
+                self.tr("Markdown Export"),
+                self.tr("Select color scheme:"),
+                colorSchemes,
+                0, False)
+            if ok:
+                colorSchemeIndex = colorSchemes.index(colorScheme)
             else:
-                extension = ""
-            
-            if (
-                extension in Preferences.getEditor(
-                    "PreviewMarkdownFileNameExtensions") or
-                self.editor.getLanguage().lower() == "markdown"
-            ):
-                # export markdown to HTML
-                html = self.__generateFromMarkdown()
-            elif (
-                extension in Preferences.getEditor(
-                    "PreviewRestFileNameExtensions") or
-                self.editor.getLanguage().lower() == "restructuredtext"
-            ):
-                # export ReST to HTML
+                # light background as default
+                colorSchemeIndex = 0
+            with E5OverrideCursor():
+                html = self.__generateFromMarkdown(colorSchemeIndex == 1)
+        elif (
+            extension in Preferences.getEditor(
+                "PreviewRestFileNameExtensions") or
+            self.editor.getLanguage().lower() == "restructuredtext"
+        ):
+            # export ReST to HTML
+            with E5OverrideCursor():
                 html = self.__generateFromReSTDocutils()
-            else:
-                tabSize = self.editor.getEditorConfig("TabWidth")
-                if tabSize == 0:
-                    tabSize = 4
-                wysiwyg = Preferences.getEditorExporter("HTML/WYSIWYG")
-                folding = Preferences.getEditorExporter("HTML/Folding")
-                onlyStylesUsed = Preferences.getEditorExporter(
-                    "HTML/OnlyStylesUsed")
-                titleFullPath = Preferences.getEditorExporter(
-                    "HTML/FullPathAsTitle")
-                tabs = Preferences.getEditorExporter("HTML/UseTabs")
-                
+        else:
+            tabSize = self.editor.getEditorConfig("TabWidth")
+            if tabSize == 0:
+                tabSize = 4
+            wysiwyg = Preferences.getEditorExporter("HTML/WYSIWYG")
+            folding = Preferences.getEditorExporter("HTML/Folding")
+            onlyStylesUsed = Preferences.getEditorExporter(
+                "HTML/OnlyStylesUsed")
+            titleFullPath = Preferences.getEditorExporter(
+                "HTML/FullPathAsTitle")
+            tabs = Preferences.getEditorExporter("HTML/UseTabs")
+            
+            with E5OverrideCursor():
                 generator = HTMLGenerator(self.editor)
                 html = generator.generate(
                     tabSize=tabSize,
@@ -437,33 +450,29 @@ class ExporterHTML(ExporterBase):
                     onlyStylesUsed=onlyStylesUsed,
                     titleFullPath=titleFullPath
                 )
-            
-            if html:
-                try:
-                    f = open(filename, "w", encoding="utf-8")
-                    f.write(html)
-                    f.close()
-                except IOError as err:
-                    QApplication.restoreOverrideCursor()
-                    E5MessageBox.critical(
-                        self.editor,
-                        self.tr("Export source"),
-                        self.tr(
-                            """<p>The source could not be exported to"""
-                            """ <b>{0}</b>.</p><p>Reason: {1}</p>""")
-                        .format(filename, str(err)))
-            else:
-                QApplication.restoreOverrideCursor()
+        
+        if html:
+            try:
+                with E5OverrideCursor():
+                    with open(filename, "w", encoding="utf-8") as f:
+                        f.write(html)
+            except OSError as err:
                 E5MessageBox.critical(
                     self.editor,
                     self.tr("Export source"),
                     self.tr(
                         """<p>The source could not be exported to"""
-                        """ <b>{0}</b>.</p><p>Reason: No HTML code"""
-                        """ generated.</p>""")
-                    .format(filename))
-        finally:
-            QApplication.restoreOverrideCursor()
+                        """ <b>{0}</b>.</p><p>Reason: {1}</p>""")
+                    .format(filename, str(err)))
+        else:
+            E5MessageBox.critical(
+                self.editor,
+                self.tr("Export source"),
+                self.tr(
+                    """<p>The source could not be exported to"""
+                    """ <b>{0}</b>.</p><p>Reason: No HTML code"""
+                    """ generated.</p>""")
+                .format(filename))
     
     def __generateFromReSTDocutils(self):
         """
@@ -503,10 +512,13 @@ class ExporterHTML(ExporterBase):
         sys.stderr = origStderr
         return html
     
-    def __generateFromMarkdown(self):
+    def __generateFromMarkdown(self, useDarkScheme):
         """
         Private method to convert Markdown text into HTML.
         
+        @param useDarkScheme flag indicating to export using a dark color
+            scheme
+        @type bool
         @return processed HTML
         @rtype str
         """
@@ -534,7 +546,7 @@ class ExporterHTML(ExporterBase):
         
         mermaidNeeded = False
         if Preferences.getEditor("PreviewMarkdownMermaid"):
-            if MarkdownExtensions.MermaidRegex.search(text):
+            if MarkdownExtensions.MermaidRegexFullText.search(text):
                 extensions.append(MarkdownExtensions.MermaidExtension())
                 mermaidNeeded = True
         
@@ -592,12 +604,37 @@ class ExporterHTML(ExporterBase):
                 " src='https://unpkg.com/mermaid@8/dist/mermaid.min.js'>\n"
                 "</script>\n"
             )
+            if useDarkScheme:
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'dark', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
+            else:
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'default', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
         else:
             mermaid = ""
+            mermaid_initialize = ""
         
         htmlFormat = Preferences.getEditor("PreviewMarkdownHTMLFormat").lower()
         body = markdown.markdown(text, extensions=extensions,
                                  output_format=htmlFormat)
+        if useDarkScheme:
+            style = (
+                PreviewerHTMLStyles.css_markdown_dark +
+                PreviewerHTMLStyles.css_pygments_dark
+            )
+        else:
+            style = (
+                PreviewerHTMLStyles.css_markdown_light +
+                PreviewerHTMLStyles.css_pygments_light
+            )
         
         if htmlFormat == "xhtml1":
             head = (
@@ -632,12 +669,8 @@ class ExporterHTML(ExporterBase):
             '''</style>\n'''
             '''</head>\n'''
             '''<body>\n'''
-        ).format(
-            mathjax, mermaid,
-            PreviewerHTMLStyles.css_markdown +
-            PreviewerHTMLStyles.css_pygments
-        )
+        ).format(mathjax, mermaid, style)
         
         foot = '''\n</body>\n</html>\n'''
         
-        return head + body + foot
+        return head + body + mermaid_initialize + foot
