@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a custom lexer using pygments.
 """
 
-
 from pygments.token import Token
 from pygments.lexers import (
     guess_lexer_for_filename, guess_lexer, find_lexer_class
@@ -85,8 +84,11 @@ TOKEN_MAP = {
     Token.Comment.Single: PYGMENTS_COMMENT,
     Token.Comment.Special: PYGMENTS_COMMENT,
     
+    Token.Escape: PYGMENTS_ESCAPE,
+    
     Token.Error: PYGMENTS_ERROR,
     
+    Token.Generic: PYGMENTS_DEFAULT,
     Token.Generic.Deleted: PYGMENTS_DELETED,
     Token.Generic.Emph: PYGMENTS_EMPHASIZE,
     Token.Generic.Error: PYGMENTS_GENERIC_ERROR,
@@ -97,7 +99,7 @@ TOKEN_MAP = {
     Token.Generic.Strong: PYGMENTS_STRONG,
     Token.Generic.Subheading: PYGMENTS_SUBHEADING,
     Token.Generic.Traceback: PYGMENTS_TRACEBACK,
-
+    
     Token.Keyword: PYGMENTS_KEYWORD,
     Token.Keyword.Constant: PYGMENTS_KEYWORD,
     Token.Keyword.Declaration: PYGMENTS_KEYWORD,
@@ -105,10 +107,10 @@ TOKEN_MAP = {
     Token.Keyword.Pseudo: PYGMENTS_PSEUDOKEYWORD,
     Token.Keyword.Reserved: PYGMENTS_RESERVEDKEYWORD,
     Token.Keyword.Type: PYGMENTS_TYPEKEYWORD,
-
+    
     Token.Literal: PYGMENTS_LITERAL,
     Token.Literal.Date: PYGMENTS_LITERAL,
-
+    
     Token.Name: PYGMENTS_DEFAULT,
     Token.Name.Attribute: PYGMENTS_ATTRIBUTE,
     Token.Name.Builtin: PYGMENTS_BUILTIN,
@@ -119,6 +121,7 @@ TOKEN_MAP = {
     Token.Name.Entity: PYGMENTS_ENTITY,
     Token.Name.Exception: PYGMENTS_EXCEPTION,
     Token.Name.Function: PYGMENTS_FUNCTION,
+    Token.Name.Function.Magic: PYGMENTS_FUNCTION,
     Token.Name.Label: PYGMENTS_LABEL,
     Token.Name.Namespace: PYGMENTS_NAMESPACE,
     Token.Name.Other: PYGMENTS_VARIABLE,
@@ -128,7 +131,8 @@ TOKEN_MAP = {
     Token.Name.Variable.Class: PYGMENTS_VARIABLE,
     Token.Name.Variable.Global: PYGMENTS_VARIABLE,
     Token.Name.Variable.Instance: PYGMENTS_VARIABLE,
-
+    Token.Name.Variable.Magic: PYGMENTS_VARIABLE,
+    
     Token.Number: PYGMENTS_NUMBER,
     Token.Number.Bin: PYGMENTS_NUMBER,
     Token.Number.Float: PYGMENTS_NUMBER,
@@ -136,15 +140,19 @@ TOKEN_MAP = {
     Token.Number.Integer: PYGMENTS_NUMBER,
     Token.Number.Integer.Long: PYGMENTS_NUMBER,
     Token.Number.Oct: PYGMENTS_NUMBER,
-
+    
     Token.Operator: PYGMENTS_OPERATOR,
     Token.Operator.Word: PYGMENTS_WORD,
-
+    
+    Token.Other: PYGMENTS_DEFAULT,
+    
     Token.Punctuation: PYGMENTS_PUNCTUATION,
-
+    
     Token.String: PYGMENTS_STRING,
+    Token.String.Affix: PYGMENTS_STRING,
     Token.String.Backtick: PYGMENTS_BACKTICKSTRING,
     Token.String.Char: PYGMENTS_CHAR,
+    Token.String.Delimiter: PYGMENTS_STRING,
     Token.String.Doc: PYGMENTS_DOCSTRING,
     Token.String.Double: PYGMENTS_DOUBLESTRING,
     Token.String.Escape: PYGMENTS_ESCAPE,
@@ -156,6 +164,8 @@ TOKEN_MAP = {
     Token.String.Symbol: PYGMENTS_SYMBOL,
     
     Token.Whitespace: PYGMENTS_WHITESPACE,
+    
+    Token.Text: PYGMENTS_DEFAULT,
 }
 
 #-----------------------------------------------------------------------------#
@@ -174,7 +184,12 @@ class LexerPygments(LexerContainer):
         """
         LexerContainer.__init__(self, parent)
         
-        self.__pygmentsName = name
+        if name.startswith("Pygments|"):
+            self.__forcedPygmentsName = True
+            self.__pygmentsName = name.replace("Pygments|", "")
+        else:
+            self.__pygmentsName = name
+            self.__forcedPygmentsName = True
         
         self.descriptions = {
             PYGMENTS_DEFAULT: self.tr("Default"),
@@ -302,7 +317,10 @@ class LexerPygments(LexerContainer):
         @return language of the lexer (string)
         """
         if self.__pygmentsName:
-            return self.__pygmentsName
+            if self.__forcedPygmentsName:
+                return "Guessed"
+            else:
+                return self.__pygmentsName
         else:
             return "Guessed"
     
