@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the search and replace widget.
 """
 
-
 from PyQt5.QtCore import pyqtSignal, Qt, pyqtSlot, QEvent
 from PyQt5.QtWidgets import (
     QWidget, QHBoxLayout, QToolButton, QScrollArea, QSizePolicy, QFrame
@@ -127,19 +126,19 @@ the documentation of your C++ runtime for details on what is supported.<p>
         self.setWhatsThis(whatsThis)
         
         # set icons
-        self.ui.closeButton.setIcon(UI.PixmapCache.getIcon("close.png"))
+        self.ui.closeButton.setIcon(UI.PixmapCache.getIcon("close"))
         self.ui.findPrevButton.setIcon(
-            UI.PixmapCache.getIcon("1leftarrow.png"))
+            UI.PixmapCache.getIcon("1leftarrow"))
         self.ui.findNextButton.setIcon(
-            UI.PixmapCache.getIcon("1rightarrow.png"))
+            UI.PixmapCache.getIcon("1rightarrow"))
         
         if replace:
             self.ui.replaceButton.setIcon(
-                UI.PixmapCache.getIcon("editReplace.png"))
+                UI.PixmapCache.getIcon("editReplace"))
             self.ui.replaceSearchButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceSearch.png"))
+                UI.PixmapCache.getIcon("editReplaceSearch"))
             self.ui.replaceAllButton.setIcon(
-                UI.PixmapCache.getIcon("editReplaceAll.png"))
+                UI.PixmapCache.getIcon("editReplaceAll"))
         
         # set line edit completers
         self.ui.findtextCombo.setCompleter(None)
