@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a stand alone shell window.
 """
 
-
 import sys
 import os
 
@@ -60,7 +59,7 @@ class ShellWindow(E5MainWindow):
         super(ShellWindow, self).__init__(parent)
         if name is not None:
             self.setObjectName(name)
-        self.setWindowIcon(UI.PixmapCache.getIcon("shell.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("shell"))
         self.setWindowTitle(self.tr("eric6 Shell"))
         
         self.setStyle(Preferences.getUI("Style"),
@@ -205,7 +204,7 @@ class ShellWindow(E5MainWindow):
         """
         self.exitAct = E5Action(
             self.tr('Quit'),
-            UI.PixmapCache.getIcon("exit.png"),
+            UI.PixmapCache.getIcon("exit"),
             self.tr('&Quit'),
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")),
             0, self, 'quit')
@@ -220,7 +219,7 @@ class ShellWindow(E5MainWindow):
 
         self.newWindowAct = E5Action(
             self.tr('New Window'),
-            UI.PixmapCache.getIcon("newWindow.png"),
+            UI.PixmapCache.getIcon("newWindow"),
             self.tr('New &Window'),
             QKeySequence(self.tr("Ctrl+Shift+N", "File|New Window")),
             0, self, 'new_window')
@@ -235,21 +234,22 @@ class ShellWindow(E5MainWindow):
 
         self.restartAct = E5Action(
             self.tr('Restart'),
-            UI.PixmapCache.getIcon("restart.png"),
+            UI.PixmapCache.getIcon("restart"),
             self.tr('Restart'),
             0, 0, self, 'shell_restart')
         self.restartAct.setStatusTip(self.tr(
             'Restart the shell'))
         self.restartAct.setWhatsThis(self.tr(
             """<b>Restart</b>"""
-            """<p>Restart the shell for the currently selected language.</p>"""
+            """<p>Restart the shell for the currently selected"""
+            """ environment.</p>"""
         ))
         self.restartAct.triggered.connect(self.__shell.doRestart)
         self.fileActions.append(self.restartAct)
 
         self.clearRestartAct = E5Action(
             self.tr('Restart and Clear'),
-            UI.PixmapCache.getIcon("restartDelete.png"),
+            UI.PixmapCache.getIcon("restartDelete"),
             self.tr('Restart and Clear'),
             Qt.Key_F4, 0, self, 'shell_clear_restart')
         self.clearRestartAct.setStatusTip(self.tr(
@@ -257,7 +257,7 @@ class ShellWindow(E5MainWindow):
         self.clearRestartAct.setWhatsThis(self.tr(
             """<b>Restart and Clear</b>"""
             """<p>Clear the shell window and restart the shell for the"""
-            """ currently selected language.</p>"""
+            """ currently selected environment.</p>"""
         ))
         self.clearRestartAct.triggered.connect(self.__shell.doClearRestart)
         self.fileActions.append(self.clearRestartAct)
@@ -272,7 +272,7 @@ class ShellWindow(E5MainWindow):
         
         self.cutAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Cut'),
-            UI.PixmapCache.getIcon("editCut.png"),
+            UI.PixmapCache.getIcon("editCut"),
             QCoreApplication.translate('ViewManager', 'Cu&t'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+X", "Edit|Cut")),
@@ -281,18 +281,16 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_cut')
         self.cutAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Cut the selection'))
-        self.cutAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.cutAct.setWhatsThis(self.tr(
             """<b>Cut</b>"""
-            """<p>Cut the selected text of the current editor to the"""
-            """ clipboard.</p>"""
+            """<p>Cut the selected text to the clipboard.</p>"""
         ))
         self.cutAct.triggered.connect(self.__shell.cut)
         self.editActions.append(self.cutAct)
         
         self.copyAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Copy'),
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             QCoreApplication.translate('ViewManager', '&Copy'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+C", "Edit|Copy")),
@@ -301,18 +299,16 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_copy')
         self.copyAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Copy the selection'))
-        self.copyAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.copyAct.setWhatsThis(self.tr(
             """<b>Copy</b>"""
-            """<p>Copy the selected text of the current editor to the"""
-            """ clipboard.</p>"""
+            """<p>Copy the selected text to the clipboard.</p>"""
         ))
         self.copyAct.triggered.connect(self.__shell.copy)
         self.editActions.append(self.copyAct)
         
         self.pasteAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Paste'),
-            UI.PixmapCache.getIcon("editPaste.png"),
+            UI.PixmapCache.getIcon("editPaste"),
             QCoreApplication.translate('ViewManager', '&Paste'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+V", "Edit|Paste")),
@@ -321,18 +317,16 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_paste')
         self.pasteAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Paste the last cut/copied text'))
-        self.pasteAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.pasteAct.setWhatsThis(self.tr(
             """<b>Paste</b>"""
-            """<p>Paste the last cut/copied text from the clipboard to"""
-            """ the current editor.</p>"""
+            """<p>Paste the last cut/copied text from the clipboard.</p>"""
         ))
         self.pasteAct.triggered.connect(self.__shell.paste)
         self.editActions.append(self.pasteAct)
         
         self.clearAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Clear'),
-            UI.PixmapCache.getIcon("editDelete.png"),
+            UI.PixmapCache.getIcon("editDelete"),
             QCoreApplication.translate('ViewManager', 'Clear'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Alt+Shift+C", "Edit|Clear")),
@@ -340,10 +334,9 @@ class ShellWindow(E5MainWindow):
             self.copyActGrp, 'vm_edit_clear')
         self.clearAct.setStatusTip(QCoreApplication.translate(
             'ViewManager', 'Clear all text'))
-        self.clearAct.setWhatsThis(QCoreApplication.translate(
-            'ViewManager',
+        self.clearAct.setWhatsThis(self.tr(
             """<b>Clear</b>"""
-            """<p>Delete all text of the current editor.</p>"""
+            """<p>Delete all text.</p>"""
         ))
         self.clearAct.triggered.connect(self.__shell.clear)
         self.editActions.append(self.clearAct)
@@ -740,7 +733,7 @@ class ShellWindow(E5MainWindow):
         
         self.searchAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Search'),
-            UI.PixmapCache.getIcon("find.png"),
+            UI.PixmapCache.getIcon("find"),
             QCoreApplication.translate('ViewManager', '&Search...'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+F", "Search|Search")),
@@ -751,8 +744,8 @@ class ShellWindow(E5MainWindow):
         self.searchAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search</b>"""
-            """<p>Search for some text in the current editor. A"""
-            """ dialog is shown to enter the searchtext and options"""
+            """<p>Search for some text in the shell window. A"""
+            """ dialog is shown to enter the search text and options"""
             """ for the search.</p>"""
         ))
         self.searchAct.triggered.connect(self.__showFind)
@@ -761,7 +754,7 @@ class ShellWindow(E5MainWindow):
         self.searchNextAct = E5Action(
             QCoreApplication.translate(
                 'ViewManager', 'Search next'),
-            UI.PixmapCache.getIcon("findNext.png"),
+            UI.PixmapCache.getIcon("findNext"),
             QCoreApplication.translate('ViewManager', 'Search &next'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "F3", "Search|Search next")),
@@ -772,8 +765,8 @@ class ShellWindow(E5MainWindow):
         self.searchNextAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search next</b>"""
-            """<p>Search the next occurrence of some text in the current"""
-            """ editor. The previously entered searchtext and options are"""
+            """<p>Search the next occurrence of some text in the shell"""
+            """ window. The previously entered search text and options are"""
             """ reused.</p>"""
         ))
         self.searchNextAct.triggered.connect(
@@ -782,7 +775,7 @@ class ShellWindow(E5MainWindow):
         
         self.searchPrevAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Search previous'),
-            UI.PixmapCache.getIcon("findPrev.png"),
+            UI.PixmapCache.getIcon("findPrev"),
             QCoreApplication.translate('ViewManager', 'Search &previous'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Shift+F3", "Search|Search previous")),
@@ -793,8 +786,8 @@ class ShellWindow(E5MainWindow):
         self.searchPrevAct.setWhatsThis(QCoreApplication.translate(
             'ViewManager',
             """<b>Search previous</b>"""
-            """<p>Search the previous occurrence of some text in the current"""
-            """ editor. The previously entered searchtext and options are"""
+            """<p>Search the previous occurrence of some text in the shell"""
+            """ window. The previously entered search text and options are"""
             """ reused.</p>"""
         ))
         self.searchPrevAct.triggered.connect(
@@ -810,7 +803,7 @@ class ShellWindow(E5MainWindow):
         
         self.zoomInAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Zoom in'),
-            UI.PixmapCache.getIcon("zoomIn.png"),
+            UI.PixmapCache.getIcon("zoomIn"),
             QCoreApplication.translate('ViewManager', 'Zoom &in'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl++", "View|Zoom in")),
@@ -829,7 +822,7 @@ class ShellWindow(E5MainWindow):
         
         self.zoomOutAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Zoom out'),
-            UI.PixmapCache.getIcon("zoomOut.png"),
+            UI.PixmapCache.getIcon("zoomOut"),
             QCoreApplication.translate('ViewManager', 'Zoom &out'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+-", "View|Zoom out")),
@@ -848,7 +841,7 @@ class ShellWindow(E5MainWindow):
         
         self.zoomResetAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Zoom reset'),
-            UI.PixmapCache.getIcon("zoomReset.png"),
+            UI.PixmapCache.getIcon("zoomReset"),
             QCoreApplication.translate('ViewManager', 'Zoom &reset'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+0", "View|Zoom reset")),
@@ -867,7 +860,7 @@ class ShellWindow(E5MainWindow):
         
         self.zoomToAct = E5Action(
             QCoreApplication.translate('ViewManager', 'Zoom'),
-            UI.PixmapCache.getIcon("zoomTo.png"),
+            UI.PixmapCache.getIcon("zoomTo"),
             QCoreApplication.translate('ViewManager', '&Zoom'),
             QKeySequence(QCoreApplication.translate(
                 'ViewManager', "Ctrl+#", "View|Zoom")),
@@ -891,7 +884,7 @@ class ShellWindow(E5MainWindow):
         """
         self.showHistoryAct = E5Action(
             self.tr('Show History'),
-            UI.PixmapCache.getIcon("history.png"),
+            UI.PixmapCache.getIcon("history"),
             self.tr('&Show History...'),
             0, 0,
             self, 'shell_show_history')
@@ -901,7 +894,7 @@ class ShellWindow(E5MainWindow):
         
         self.clearHistoryAct = E5Action(
             self.tr('Clear History'),
-            UI.PixmapCache.getIcon("historyClear.png"),
+            UI.PixmapCache.getIcon("historyClear"),
             self.tr('&Clear History...'),
             0, 0,
             self, 'shell_clear_history')
@@ -949,7 +942,7 @@ class ShellWindow(E5MainWindow):
         
         self.whatsThisAct = E5Action(
             self.tr('What\'s This?'),
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'),
             QKeySequence(self.tr("Shift+F1", "Help|What's This?'")),
             0, self, 'help_help_whats_this')
@@ -1067,7 +1060,7 @@ class ShellWindow(E5MainWindow):
         """
         from QScintilla.ZoomDialog import ZoomDialog
         dlg = ZoomDialog(self.__shell.getZoom(), self, None, True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             value = dlg.getZoomSize()
             self.__zoomTo(value)
         
@@ -1250,9 +1243,9 @@ class ShellWindow(E5MainWindow):
         self.__statusBar.setSizeGripEnabled(True)
 
         self.__sbZoom = E5ZoomWidget(
-            UI.PixmapCache.getPixmap("zoomOut.png"),
-            UI.PixmapCache.getPixmap("zoomIn.png"),
-            UI.PixmapCache.getPixmap("zoomReset.png"),
+            UI.PixmapCache.getPixmap("zoomOut"),
+            UI.PixmapCache.getPixmap("zoomIn"),
+            UI.PixmapCache.getPixmap("zoomReset"),
             self.__statusBar)
         self.__statusBar.addPermanentWidget(self.__sbZoom)
         self.__sbZoom.setWhatsThis(self.tr(
