@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,7 @@ Module implementing the spell checker for the editor component.
 The spell checker is based on pyenchant.
 """
 
-
 import os
-import sys
 
 from PyQt5.QtCore import QTimer, QObject
 
@@ -330,7 +328,7 @@ class SpellChecker(QObject):
         
         if pos >= 0 and self.__checkRegion(pos):
             pos0 = pos
-            pos1 = sys.maxsize
+            pos1 = 0xffffffff
             if not self.editor.charAt(pos).isalnum():
                 line, index = self.editor.lineIndexFromPosition(pos)
                 self.editor.clearIndicator(
