@@ -1,17 +1,13 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the snapshot mode enumeration.
 """
 
-
-try:
-    from enum import Enum
-except ImportError:
-    from ThirdParty.enum import Enum
+from enum import Enum
 
 
 class SnapshotModes(Enum):
