@@ -1,21 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the SQL Browser main window.
 """
 
-
 from PyQt5.QtCore import QTimer, QUrl
 from PyQt5.QtGui import QKeySequence
-from PyQt5.QtWidgets import qApp
 from PyQt5.QtSql import QSqlError, QSqlDatabase
 
 from E5Gui.E5Action import E5Action
 from E5Gui import E5MessageBox
 from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
 import UI.Config
@@ -126,7 +125,7 @@ class SqlBrowser(E5MainWindow):
             """<b>Quit</b>"""
             """<p>Quit the SQL browser.</p>"""
         ))
-        self.exitAct.triggered.connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(e5App().closeAllWindows)
         
         self.aboutAct = E5Action(
             self.tr('About'),
