@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,6 @@ generated tasks are derived from a comment with a special
 introductory text. This text is configurable.
 """
 
-
 import os
 import fnmatch
 import threading
@@ -472,7 +471,7 @@ class TaskViewer(QTreeWidget):
         ro = task.getFilename() != ""
         if ro:
             dlg.setReadOnly()
-        if dlg.exec_() == QDialog.Accepted and not ro:
+        if dlg.exec() == QDialog.Accepted and not ro:
             summary, priority, completed, isProjectTask, description = (
                 dlg.getData()
             )
@@ -489,7 +488,7 @@ class TaskViewer(QTreeWidget):
         """
         from .TaskPropertiesDialog import TaskPropertiesDialog
         dlg = TaskPropertiesDialog(None, self, self.projectOpen)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             summary, priority, completed, isProjectTask, description = (
                 dlg.getData()
             )
@@ -506,7 +505,7 @@ class TaskViewer(QTreeWidget):
         from .TaskPropertiesDialog import TaskPropertiesDialog
         dlg = TaskPropertiesDialog(None, self, self.projectOpen)
         dlg.setSubTaskMode(projectTask)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             summary, priority, completed, isProjectTask, description = (
                 dlg.getData()
             )
@@ -668,7 +667,7 @@ class TaskViewer(QTreeWidget):
         """
         from .TaskFilterConfigDialog import TaskFilterConfigDialog
         dlg = TaskFilterConfigDialog(self.taskFilter)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             dlg.configureTaskFilter(self.taskFilter)
             self.__refreshDisplay()
 
@@ -694,11 +693,8 @@ class TaskViewer(QTreeWidget):
         @type bool
         """
         markers = {
-            Task.TypeWarning:
-            Preferences.getTasks("TasksWarningMarkers").split(),
-            Task.TypeNote: Preferences.getTasks("TasksNoteMarkers").split(),
-            Task.TypeTodo: Preferences.getTasks("TasksTodoMarkers").split(),
-            Task.TypeFixme: Preferences.getTasks("TasksFixmeMarkers").split(),
+            taskType: Preferences.getTasks(markersName).split()
+            for taskType, markersName in Task.TaskType2MarkersName.items()
         }
         files = self.project.pdata["SOURCES"]
         
@@ -740,7 +736,7 @@ class TaskViewer(QTreeWidget):
                 try:
                     text, encoding = Utilities.readEncodedFile(fn)
                     lines = text.splitlines()
-                except (UnicodeError, IOError):
+                except (UnicodeError, OSError):
                     count += 1
                     progress.setValue(count)
                     continue
@@ -856,7 +852,7 @@ class ProjectTaskExtractionThread(QThread):
             try:
                 text, encoding = Utilities.readEncodedFile(fn)
                 lines = text.splitlines()
-            except (UnicodeError, IOError):
+            except (UnicodeError, OSError):
                 continue
             
             # now search tasks and record them
