@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a template viewer and associated classes.
 """
 
-
 import datetime
 import os
 import re
@@ -491,7 +490,7 @@ class TemplateViewer(QTreeWidget):
         from .TemplatePropertiesDialog import TemplatePropertiesDialog
         dlg = TemplatePropertiesDialog(self)
         dlg.setSelectedGroup(groupName)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             name, description, groupName, template = dlg.getData()
             self.addEntry(groupName, name, description, template)
             self.__dirty = True
@@ -502,7 +501,7 @@ class TemplateViewer(QTreeWidget):
         """
         from .TemplatePropertiesDialog import TemplatePropertiesDialog
         dlg = TemplatePropertiesDialog(self, True)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             name, language = dlg.getData()
             self.addGroup(name, language)
             self.__dirty = True
@@ -519,7 +518,7 @@ class TemplateViewer(QTreeWidget):
         
         from .TemplatePropertiesDialog import TemplatePropertiesDialog
         dlg = TemplatePropertiesDialog(self, editGroup, itm)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             if editGroup:
                 name, language = dlg.getData()
                 self.changeGroup(itm.getName(), name, language)
@@ -714,7 +713,7 @@ class TemplateViewer(QTreeWidget):
                     TemplateMultipleVariablesDialog
                 )
                 dlg = TemplateMultipleVariablesDialog(variables, self)
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     varValues.update(dlg.getVariables())
                     ok = True
             else:
@@ -723,7 +722,7 @@ class TemplateViewer(QTreeWidget):
                 )
                 for var in variables:
                     dlg = TemplateSingleVariableDialog(var, self)
-                    if dlg.exec_() == QDialog.Accepted:
+                    if dlg.exec() == QDialog.Accepted:
                         varValues[var] = dlg.getVariable()
                     else:
                         return
