@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the TR Previewer main window.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -17,13 +16,14 @@ from PyQt5.QtCore import (
 from PyQt5.QtGui import QKeySequence
 from PyQt5.QtWidgets import (
     QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, QWhatsThis, QMdiArea,
-    qApp, QApplication, QComboBox, QVBoxLayout, QAction, QLabel
+    QApplication, QComboBox, QVBoxLayout, QAction, QLabel
 )
 from PyQt5 import uic
 
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5Application import e5App
 
 import UI.PixmapCache
 import UI.Config
@@ -62,7 +62,7 @@ class TRPreviewer(E5MainWindow):
         self.resize(QSize(800, 600).expandedTo(self.minimumSizeHint()))
         self.statusBar()
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         self.setWindowTitle(self.tr("Translations Previewer"))
 
         self.cw = QWidget(self)
@@ -162,7 +162,7 @@ class TRPreviewer(E5MainWindow):
         Private method to define the user interface actions.
         """
         self.openUIAct = QAction(
-            UI.PixmapCache.getIcon("openUI.png"),
+            UI.PixmapCache.getIcon("openUI"),
             self.tr('&Open UI Files...'), self)
         self.openUIAct.setStatusTip(self.tr('Open UI files for display'))
         self.openUIAct.setWhatsThis(self.tr(
@@ -172,7 +172,7 @@ class TRPreviewer(E5MainWindow):
         self.openUIAct.triggered.connect(self.__openWidget)
         
         self.openQMAct = QAction(
-            UI.PixmapCache.getIcon("openQM.png"),
+            UI.PixmapCache.getIcon("openQM"),
             self.tr('Open &Translation Files...'), self)
         self.openQMAct.setStatusTip(self.tr(
             'Open Translation files for display'))
@@ -183,7 +183,7 @@ class TRPreviewer(E5MainWindow):
         self.openQMAct.triggered.connect(self.__openTranslation)
         
         self.reloadAct = QAction(
-            UI.PixmapCache.getIcon("reload.png"),
+            UI.PixmapCache.getIcon("reload"),
             self.tr('&Reload Translations'), self)
         self.reloadAct.setStatusTip(self.tr(
             'Reload the loaded translations'))
@@ -195,7 +195,7 @@ class TRPreviewer(E5MainWindow):
         self.reloadAct.triggered.connect(self.translations.reload)
         
         self.exitAct = QAction(
-            UI.PixmapCache.getIcon("exit.png"), self.tr('&Quit'), self)
+            UI.PixmapCache.getIcon("exit"), self.tr('&Quit'), self)
         self.exitAct.setShortcut(QKeySequence(
             self.tr("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.tr('Quit the application'))
@@ -203,10 +203,10 @@ class TRPreviewer(E5MainWindow):
             """<b>Quit</b>"""
             """<p>Quit the application.</p>"""
         ))
-        self.exitAct.triggered.connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(e5App().closeAllWindows)
         
         self.whatsThisAct = QAction(
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'), self)
         self.whatsThisAct.setShortcut(QKeySequence(self.tr("Shift+F1")))
         self.whatsThisAct.setStatusTip(self.tr('Context sensitive help'))
@@ -257,7 +257,7 @@ class TRPreviewer(E5MainWindow):
         self.cascadeAct.triggered.connect(self.preview.cascadeSubWindows)
         
         self.closeAct = QAction(
-            UI.PixmapCache.getIcon("close.png"), self.tr('&Close'), self)
+            UI.PixmapCache.getIcon("close"), self.tr('&Close'), self)
         self.closeAct.setShortcut(QKeySequence(self.tr(
             "Ctrl+W", "File|Close")))
         self.closeAct.setStatusTip(self.tr('Close the current window'))
@@ -723,7 +723,7 @@ class WidgetView(QWidget):
         
         try:
             self.__widget = uic.loadUi(self.__uiFileName)
-        except Exception:
+        except Exception:       # secok
             pass
         
         if not self.__widget:
