@@ -1,18 +1,17 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the UI Previewer main window.
 """
 
-
 from PyQt5.QtCore import QDir, QFileInfo, QEvent, QSize, Qt
-from PyQt5.QtGui import QCursor, QKeySequence, QImageWriter, QPainter
+from PyQt5.QtGui import QKeySequence, QImageWriter, QPainter
 from PyQt5.QtWidgets import (
     QSizePolicy, QSpacerItem, QWidget, QHBoxLayout, QWhatsThis, QDialog,
-    QScrollArea, qApp, QApplication, QStyleFactory, QFrame, QMainWindow,
+    QScrollArea, QApplication, QStyleFactory, QFrame, QMainWindow,
     QComboBox, QVBoxLayout, QAction, QLabel
 )
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog
@@ -21,6 +20,8 @@ from PyQt5 import uic
 
 from E5Gui import E5MessageBox, E5FileDialog
 from E5Gui.E5MainWindow import E5MainWindow
+from E5Gui.E5Application import e5App
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 import Preferences
 import UI.PixmapCache
@@ -54,7 +55,7 @@ class UIPreviewer(E5MainWindow):
         self.resize(QSize(600, 480).expandedTo(self.minimumSizeHint()))
         self.statusBar()
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         self.setWindowTitle(self.tr("UI Previewer"))
 
         self.cw = QWidget(self)
@@ -128,7 +129,7 @@ class UIPreviewer(E5MainWindow):
         Private method to define the user interface actions.
         """
         self.openAct = QAction(
-            UI.PixmapCache.getIcon("openUI.png"),
+            UI.PixmapCache.getIcon("openUI"),
             self.tr('&Open File'), self)
         self.openAct.setShortcut(
             QKeySequence(self.tr("Ctrl+O", "File|Open")))
@@ -140,7 +141,7 @@ class UIPreviewer(E5MainWindow):
         self.openAct.triggered.connect(self.__openFile)
         
         self.printAct = QAction(
-            UI.PixmapCache.getIcon("print.png"),
+            UI.PixmapCache.getIcon("print"),
             self.tr('&Print'), self)
         self.printAct.setShortcut(
             QKeySequence(self.tr("Ctrl+P", "File|Print")))
@@ -152,7 +153,7 @@ class UIPreviewer(E5MainWindow):
         self.printAct.triggered.connect(self.__printImage)
         
         self.printPreviewAct = QAction(
-            UI.PixmapCache.getIcon("printPreview.png"),
+            UI.PixmapCache.getIcon("printPreview"),
             self.tr('Print Preview'), self)
         self.printPreviewAct.setStatusTip(self.tr(
             'Print preview a screen capture'))
@@ -163,7 +164,7 @@ class UIPreviewer(E5MainWindow):
         self.printPreviewAct.triggered.connect(self.__printPreviewImage)
         
         self.imageAct = QAction(
-            UI.PixmapCache.getIcon("screenCapture.png"),
+            UI.PixmapCache.getIcon("screenCapture"),
             self.tr('&Screen Capture'), self)
         self.imageAct.setShortcut(
             QKeySequence(self.tr("Ctrl+S", "File|Screen Capture")))
@@ -176,7 +177,7 @@ class UIPreviewer(E5MainWindow):
         self.imageAct.triggered.connect(self.__saveImage)
         
         self.exitAct = QAction(
-            UI.PixmapCache.getIcon("exit.png"), self.tr('&Quit'), self)
+            UI.PixmapCache.getIcon("exit"), self.tr('&Quit'), self)
         self.exitAct.setShortcut(
             QKeySequence(self.tr("Ctrl+Q", "File|Quit")))
         self.exitAct.setStatusTip(self.tr('Quit the application'))
@@ -184,10 +185,10 @@ class UIPreviewer(E5MainWindow):
             """<b>Quit</b>"""
             """<p>Quit the application.</p>"""
         ))
-        self.exitAct.triggered.connect(qApp.closeAllWindows)
+        self.exitAct.triggered.connect(e5App().closeAllWindows)
         
         self.copyAct = QAction(
-            UI.PixmapCache.getIcon("editCopy.png"), self.tr('&Copy'), self)
+            UI.PixmapCache.getIcon("editCopy"), self.tr('&Copy'), self)
         self.copyAct.setShortcut(
             QKeySequence(self.tr("Ctrl+C", "Edit|Copy")))
         self.copyAct.setStatusTip(
@@ -199,7 +200,7 @@ class UIPreviewer(E5MainWindow):
         self.copyAct.triggered.connect(self.__copyImageToClipboard)
         
         self.whatsThisAct = QAction(
-            UI.PixmapCache.getIcon("whatsThis.png"),
+            UI.PixmapCache.getIcon("whatsThis"),
             self.tr('&What\'s This?'), self)
         self.whatsThisAct.setShortcut(QKeySequence(self.tr("Shift+F1")))
         self.whatsThisAct.setStatusTip(self.tr('Context sensitive help'))
@@ -345,7 +346,7 @@ class UIPreviewer(E5MainWindow):
         # load the file
         try:
             self.mainWidget = uic.loadUi(fn)
-        except Exception:
+        except Exception:       # secok
             pass
         
         if self.mainWidget:
@@ -375,26 +376,25 @@ class UIPreviewer(E5MainWindow):
         
         @param sstyle name of the selected style (string)
         """
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        qstyle = QStyleFactory.create(sstyle)
-        self.mainWidget.setStyle(qstyle)
-        
-        lst = self.mainWidget.findChildren(QWidget)
-        for obj in lst:
-            try:
-                obj.setStyle(qstyle)
-            except AttributeError:
-                pass
-        del lst
-        
-        self.mainWidget.hide()
-        self.mainWidget.show()
-        
-        self.lastQStyle = qstyle
-        self.lastStyle = sstyle
-        Preferences.Prefs.settings.setValue(
-            'UIPreviewer/style', self.styleCombo.currentIndex())
-        QApplication.restoreOverrideCursor()
+        with E5OverrideCursor():
+            qstyle = QStyleFactory.create(sstyle)
+            self.mainWidget.setStyle(qstyle)
+            
+            lst = self.mainWidget.findChildren(QWidget)
+            for obj in lst:
+                try:
+                    obj.setStyle(qstyle)
+                except AttributeError:
+                    pass
+            del lst
+            
+            self.mainWidget.hide()
+            self.mainWidget.show()
+            
+            self.lastQStyle = qstyle
+            self.lastStyle = sstyle
+            Preferences.Prefs.settings.setValue(
+                'UIPreviewer/style', self.styleCombo.currentIndex())
     
     def __updateActions(self):
         """
@@ -530,7 +530,7 @@ class UIPreviewer(E5MainWindow):
             QPrinter.ColorMode(int(settings.value("UIPreviewer/colormode"))))
         
         printDialog = QPrintDialog(printer, self)
-        if printDialog.exec_() == QDialog.Accepted:
+        if printDialog.exec() == QDialog.Accepted:
             self.statusBar().showMessage(self.tr("Printing the image..."))
             self.__print(printer)
             
@@ -574,7 +574,7 @@ class UIPreviewer(E5MainWindow):
         
         preview = QPrintPreviewDialog(printer, self)
         preview.paintRequested.connect(self.__print)
-        preview.exec_()
+        preview.exec()
         
     def __print(self, printer):
         """
