@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a dialog to compare two files and show the result side by
 side.
 """
 
-
 import re
 from difflib import _mdiff, IS_CHARACTER_JUNK
 
@@ -111,10 +110,10 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         self.diffButton.setEnabled(False)
         self.diffButton.setDefault(True)
         
-        self.firstButton.setIcon(UI.PixmapCache.getIcon("2uparrow.png"))
-        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow.png"))
-        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow.png"))
-        self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow.png"))
+        self.firstButton.setIcon(UI.PixmapCache.getIcon("2uparrow"))
+        self.upButton.setIcon(UI.PixmapCache.getIcon("1uparrow"))
+        self.downButton.setIcon(UI.PixmapCache.getIcon("1downarrow"))
+        self.lastButton.setIcon(UI.PixmapCache.getIcon("2downarrow"))
         
         self.totalLabel.setText(self.tr('Total: {0}').format(0))
         self.changedLabel.setText(self.tr('Changed: {0}').format(0))
@@ -238,10 +237,9 @@ class CompareDialog(QWidget, Ui_CompareDialog):
         """
         filename1 = self.file1Picker.text()
         try:
-            f1 = open(filename1, "r", encoding="utf-8")
-            lines1 = f1.readlines()
-            f1.close()
-        except IOError:
+            with open(filename1, "r", encoding="utf-8") as f1:
+                lines1 = f1.readlines()
+        except OSError:
             E5MessageBox.critical(
                 self,
                 self.tr("Compare Files"),
@@ -252,10 +250,9 @@ class CompareDialog(QWidget, Ui_CompareDialog):
 
         filename2 = self.file2Picker.text()
         try:
-            f2 = open(filename2, "r", encoding="utf-8")
-            lines2 = f2.readlines()
-            f2.close()
-        except IOError:
+            with open(filename2, "r", encoding="utf-8") as f2:
+                lines2 = f2.readlines()
+        except OSError:
             E5MessageBox.critical(
                 self,
                 self.tr("Compare Files"),
