@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a dialog to search for text in files.
 """
 
-
 import os
 import re
 
@@ -463,7 +462,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
             try:
                 text, encoding, hashStr = Utilities.readEncodedFileWithHash(fn)
                 lines = text.splitlines(True)
-            except (UnicodeError, IOError):
+            except (UnicodeError, OSError):
                 progress += 1
                 self.findProgress.setValue(progress)
                 continue
@@ -626,7 +625,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                         Utilities.readEncodedFileWithHash(fn)
                     )
                     lines = text.splitlines(True)
-                except (UnicodeError, IOError) as err:
+                except (UnicodeError, OSError) as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
@@ -667,7 +666,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
                 txt = "".join(lines)
                 try:
                     Utilities.writeEncodedFile(fn, txt, encoding)
-                except (IOError, Utilities.CodingError, UnicodeError) as err:
+                except (OSError, Utilities.CodingError, UnicodeError) as err:
                     E5MessageBox.critical(
                         self,
                         self.tr("Replace in Files"),
@@ -699,7 +698,7 @@ class FindFileDialog(QDialog, Ui_FindFileDialog):
         menu.addAction(self.tr("Copy Path to Clipboard"),
                        self.__copyToClipboard)
         
-        menu.exec_(QCursor.pos())
+        menu.exec(QCursor.pos())
         
     def __openFile(self):
         """
