@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a previewer widget for HTML, Markdown and ReST files.
 """
 
-
 import os
 import threading
 import re
@@ -57,7 +56,7 @@ class PreviewerHTML(QWidget):
             self.__previewAvailable = False
             self.titleLabel.setText(self.tr(
                 "<b>HTML Preview is not available!<br/>"
-                "Install QtWebEngine.</b>"))
+                "Install PyQtWebEngine.</b>"))
             self.titleLabel.setAlignment(Qt.AlignHCenter)
             self.__layout.addStretch()
             return
@@ -314,7 +313,7 @@ class PreviewerHTML(QWidget):
         self.previewView.page().runJavaScript(
             script, resultCallback)
         
-        loop.exec_()
+        loop.exec()
         return resultDict["res"]
 
 
@@ -498,10 +497,9 @@ class PreviewProcessingThread(QThread):
                 incFile = ""
             if os.path.exists(incFile):
                 try:
-                    f = open(incFile, "r")
-                    incTxt = f.read()
-                    f.close()
-                except (IOError, OSError):
+                    with open(incFile, "r") as f:
+                        incTxt = f.read()
+                except OSError:
                     # remove SSI include
                     incTxt = ""
             else:
@@ -580,14 +578,15 @@ class PreviewProcessingThread(QThread):
                 """<p>Alternatively you may disable Sphinx usage"""
                 """ on the Editor, Filehandling configuration page.</p>""")
         
-        tempDir = tempfile.mkdtemp(prefix='eric-rest-')
+        srcTempDir = tempfile.mkdtemp(prefix="eric-rest-src-")
+        outTempDir = tempfile.mkdtemp(prefix="eric-rest-out-")
+        doctreeTempDir = tempfile.mkdtemp(prefix="eric-rest-doctree-")
         try:
             filename = 'sphinx_preview'
-            basePath = os.path.join(tempDir, filename)
-            fh = open(basePath + '.rst', 'w', encoding='utf-8')
-            fh.write(text)
-            fh.close()
-
+            basePath = os.path.join(srcTempDir, filename)
+            with open(basePath + '.rst', 'w', encoding='utf-8') as fh:
+                fh.write(text)
+            
             overrides = {'html_add_permalinks': False,
                          'html_copy_source': False,
                          'html_title': 'Sphinx preview',
@@ -595,17 +594,19 @@ class PreviewProcessingThread(QThread):
                          'html_use_modindex': False,
                          'html_use_smartypants': True,
                          'master_doc': filename}
-            app = Sphinx(srcdir=tempDir, confdir=None, outdir=tempDir,
-                         doctreedir=tempDir, buildername='html',
+            app = Sphinx(srcdir=srcTempDir, confdir=None, outdir=outTempDir,
+                         doctreedir=doctreeTempDir, buildername='html',
                          confoverrides=overrides, status=None,
                          warning=io.StringIO())
             app.build(force_all=True, filenames=None)
 
-            fh = open(basePath + '.html', 'r', encoding='utf-8')
-            html = fh.read()
-            fh.close()
+            basePath = os.path.join(outTempDir, filename)
+            with open(basePath + '.html', 'r', encoding='utf-8') as fh:
+                html = fh.read()
         finally:
-            shutil.rmtree(tempDir)
+            shutil.rmtree(srcTempDir)
+            shutil.rmtree(outTempDir)
+            shutil.rmtree(doctreeTempDir)
         
         return html
     
@@ -743,12 +744,37 @@ class PreviewProcessingThread(QThread):
                 " src='https://unpkg.com/mermaid@8/dist/mermaid.min.js'>\n"
                 "</script>\n"
             )
+            if e5App().usesDarkPalette():
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'dark', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
+            else:
+                mermaid_initialize = (
+                    "<script>mermaid.initialize({"
+                    "theme: 'default', "
+                    "startOnLoad:true"
+                    "});</script>"
+                )
         else:
             mermaid = ""
+            mermaid_initialize = ""
         
         htmlFormat = Preferences.getEditor("PreviewMarkdownHTMLFormat").lower()
         body = markdown.markdown(text, extensions=extensions,
                                  output_format=htmlFormat.lower())
+        if e5App().usesDarkPalette():
+            style = (
+                PreviewerHTMLStyles.css_markdown_dark +
+                PreviewerHTMLStyles.css_pygments_dark
+            )
+        else:
+            style = (
+                PreviewerHTMLStyles.css_markdown_light +
+                PreviewerHTMLStyles.css_pygments_light
+            )
         
         if htmlFormat == "xhtml1":
             head = (
@@ -777,12 +803,8 @@ class PreviewProcessingThread(QThread):
             '''</style>\n'''
             '''</head>\n'''
             '''<body>\n'''
-        ).format(
-            mathjax, mermaid,
-            PreviewerHTMLStyles.css_markdown +
-            PreviewerHTMLStyles.css_pygments
-        )
+        ).format(mathjax, mermaid, style)
         
         foot = '''\n</body>\n</html>\n'''
         
-        return head + body + foot
+        return head + body + mermaid_initialize + foot
