@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,18 +8,20 @@ Module implementing a widget to visualize the Python AST for some Python
 sources.
 """
 
-
 import ast
 
 from PyQt5.QtCore import pyqtSlot, Qt, QTimer
-from PyQt5.QtGui import QCursor, QBrush
+from PyQt5.QtGui import QBrush
 from PyQt5.QtWidgets import (
-    QTreeWidget, QApplication, QTreeWidgetItem, QAbstractItemView, QWidget,
-    QVBoxLayout
+    QTreeWidget, QTreeWidgetItem, QAbstractItemView, QWidget, QVBoxLayout
 )
 
 from ThirdParty.asttokens.asttokens import ASTTokens
 
+from E5Gui.E5OverrideCursor import E5OverrideCursor
+
+import Preferences
+
 
 class PythonAstViewer(QWidget):
     """
@@ -61,6 +63,9 @@ class PythonAstViewer(QWidget):
         self.__astWidget.setSelectionMode(QAbstractItemView.SingleSelection)
         self.__astWidget.setAlternatingRowColors(True)
         
+        self.__errorColor = QBrush(
+            Preferences.getPython("ASTViewerErrorColor"))
+        
         self.__astWidget.itemClicked.connect(self.__astItemClicked)
         
         self.__vm.astViewerStateChanged.connect(self.__astViewerStateChanged)
@@ -106,10 +111,20 @@ class PythonAstViewer(QWidget):
             if editor.isModified():
                 # reload the source
                 QTimer.singleShot(0, self.__loadAST)
-            else:
-                # highlight the corresponding entry
-                QTimer.singleShot(0, self.__selectItemForEditorSelection)
-                QTimer.singleShot(0, self.__grabFocus)
+            
+            # highlight the corresponding entry
+            QTimer.singleShot(0, self.__selectItemForEditorSelection)
+            QTimer.singleShot(0, self.__grabFocus)
+    
+    def __editorLanguageChanged(self, editor):
+        """
+        Private slot to handle a change of the editor language.
+        
+        @param editor reference to the editor which changed language
+        @type Editor
+        """
+        if editor is self.__editor:
+            QTimer.singleShot(0, self.__loadDIS)
     
     def __lastEditorClosed(self):
         """
@@ -128,6 +143,8 @@ class PythonAstViewer(QWidget):
             self.__vm.editorChangedEd.connect(self.__editorChanged)
             self.__vm.editorSavedEd.connect(self.__editorSaved)
             self.__vm.editorDoubleClickedEd.connect(self.__editorDoubleClicked)
+            self.__vm.editorLanguageChanged.connect(
+                self.__editorLanguageChanged)
             self.__vmConnected = True
     
     def hide(self):
@@ -144,6 +161,8 @@ class PythonAstViewer(QWidget):
             self.__vm.editorSavedEd.disconnect(self.__editorSaved)
             self.__vm.editorDoubleClickedEd.disconnect(
                 self.__editorDoubleClicked)
+            self.__vm.editorLanguageChanged.disconnect(
+                self.__editorLanguageChanged)
             self.__vmConnected = False
     
     def shutdown(self):
@@ -160,7 +179,7 @@ class PythonAstViewer(QWidget):
         @type bool
         """
         editor = self.__vm.activeWindow()
-        if on and editor and editor.isPyFile():
+        if on:
             if editor is not self.__editor:
                 self.__editor = editor
             self.show()
@@ -180,7 +199,7 @@ class PythonAstViewer(QWidget):
         """
         itm = QTreeWidgetItem(self.__astWidget, [error])
         itm.setFirstColumnSpanned(True)
-        itm.setForeground(0, QBrush(Qt.red))
+        itm.setForeground(0, self.__errorColor)
         return itm
     
     def __loadAST(self):
@@ -189,43 +208,47 @@ class PythonAstViewer(QWidget):
         editor and visualize it.
         """
         if not self.__editor:
+            self.__createErrorItem(self.tr(
+                "No editor has been opened."
+            ))
             return
         
         self.__astWidget.clear()
         self.__editor.clearAllHighlights()
         
-        if not self.__editor.isPyFile():
-            self.__createErrorItem(self.tr(
-                "The current editor text does not contain Python source."
-            ))
-            return
-        
         source = self.__editor.text()
         if not source.strip():
             # empty editor or white space only
+            self.__createErrorItem(self.tr(
+                "The current editor does not contain any source code."
+            ))
             return
         
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-        try:
-            # generate the AST
-            root = ast.parse(source, self.__editor.getFileName(), "exec")
-            self.__markTextRanges(root, source)
-            astValid = True
-        except Exception as exc:
-            self.__createErrorItem(str(exc))
-            astValid = False
+        if not self.__editor.isPyFile():
+            self.__createErrorItem(self.tr(
+                "The current editor does not contain Python source code."
+            ))
+            return
         
-        if astValid:
-            self.setUpdatesEnabled(False)
+        with E5OverrideCursor():
+            try:
+                # generate the AST
+                root = ast.parse(source, self.__editor.getFileName(), "exec")
+                self.__markTextRanges(root, source)
+                astValid = True
+            except Exception as exc:
+                self.__createErrorItem(str(exc))
+                astValid = False
             
-            # populate the AST tree
-            self.__populateNode(self.tr("Module"), root, self.__astWidget)
-            self.__selectItemForEditorSelection()
-            QTimer.singleShot(0, self.__resizeColumns)
-            
-            self.setUpdatesEnabled(True)
-        
-        QApplication.restoreOverrideCursor()
+            if astValid:
+                self.setUpdatesEnabled(False)
+                
+                # populate the AST tree
+                self.__populateNode(self.tr("Module"), root, self.__astWidget)
+                self.__selectItemForEditorSelection()
+                QTimer.singleShot(0, self.__resizeColumns)
+                
+                self.setUpdatesEnabled(True)
         
         self.__grabFocus()
     
@@ -498,3 +521,11 @@ class PythonAstViewer(QWidget):
                                        expand=True)
                 self.__editor.setHighlight(startLine - 1, startIndex,
                                            endLine - 1, endIndex)
+    
+    @pyqtSlot()
+    def preferencesChanged(self):
+        """
+        Public slot handling changes of the AST viewer settings.
+        """
+        self.__errorColor = QBrush(
+            Preferences.getPython("ASTViewerErrorColor"))
