@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a widget to select a symbol in various formats.
 """
 
-
 import sys
 import unicodedata
 import html.entities
@@ -494,7 +493,7 @@ class SymbolsWidget(QWidget, Ui_SymbolsWidget):
         super(SymbolsWidget, self).__init__(parent)
         self.setupUi(self)
         
-        self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
+        self.setWindowIcon(UI.PixmapCache.getIcon("eric"))
         
         self.__model = SymbolsModel(self)
         self.symbolsTable.setModel(self.__model)
