@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,6 @@ rpc methods.
 It is based on the Python class browser found in this package.
 """
 
-
 import re
 
 import Utilities
@@ -204,8 +203,6 @@ def readmodule_ex(module, path=None):
     """
     global _modules
     
-    dictionary = {}
-
     if module in _modules:
         # we've seen this file before...
         return _modules[module]
@@ -218,22 +215,71 @@ def readmodule_ex(module, path=None):
         f.close()
     if type not in SUPPORTED_TYPES:
         # not ProtoBuf protocol source, can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
+        _modules[module] = {}
+        return {}
 
-    _modules[module] = dictionary
-    classstack = []  # stack of (class, indent) pairs
-    indent = 0
     try:
         src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, IOError):
+    except (UnicodeError, OSError):
         # can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
+        _modules[module] = {}
+        return {}
+    
+    _modules[module] = scan(src, file, module)
+    return _modules[module]
+
+
+def scan(src, file, module):
+    """
+    Public method to scan the given source text.
+    
+    @param src source text to be scanned
+    @type str
+    @param file file name associated with the source text
+    @type str
+    @param module module name associated with the source text
+    @type str
+    @return dictionary containing the extracted data
+    @rtype dict
+    """
+    def calculateEndline(lineno, lines):
+        """
+        Function to calculate the end line.
+        
+        @param lineno line number to start at (one based)
+        @type int
+        @param lines list of source lines
+        @type list of str
+        @return end line (one based)
+        @rtype int
+        """
+        # convert lineno to be zero based
+        lineno -= 1
+        # 1. search for opening brace '{'
+        while lineno < len(lines) and "{" not in lines[lineno]:
+            lineno += 1
+        depth = lines[lineno].count("{") - lines[lineno].count("}")
+        # 2. search for ending line, i.e. matching closing brace '}'
+        while depth > 0 and lineno < len(lines) - 1:
+            lineno += 1
+            depth += lines[lineno].count("{") - lines[lineno].count("}")
+        if depth == 0:
+            # found a matching brace
+            return lineno + 1
+        else:
+            # nothing found
+            return -1
+    
+    # convert eol markers the Python style
+    src = src.replace("\r\n", "\n").replace("\r", "\n")
+    srcLines = src.splitlines()
+
+    dictionary = {}
+
+    classstack = []  # stack of (class, indent) pairs
+    indent = 0
 
     lineno, last_lineno_pos = 1, 0
-    lastGlobalEntry = None
-    cur_obj = None
     i = 0
     while True:
         m = _getnext(src, i)
@@ -257,9 +303,6 @@ def readmodule_ex(module, path=None):
             last_lineno_pos = start
             # close all interfaces/modules indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             if classstack:
                 # it's an interface/module method
@@ -275,13 +318,9 @@ def readmodule_ex(module, path=None):
             else:
                 # the file is incorrect, ignore the entry
                 continue
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = f
-            if cur_obj and isinstance(cur_obj, ServiceMethod):
-                cur_obj.setEndLine(lineno - 1)
-            cur_obj = f
+            if f:
+                endline = calculateEndline(lineno, srcLines)
+                f.setEndLine(endline)
             classstack.append((f, thisindent))  # Marker for nested fns
 
         elif m.start("String") >= 0:
@@ -294,27 +333,21 @@ def readmodule_ex(module, path=None):
             # we found a message definition
             thisindent = indent
             indent += 1
-            # close all messages/services indented at least as much
-            while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
-                del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
             message_name = m.group("MessageName")
+            # close all messages/services indented at least as much
+            while classstack and classstack[-1][1] >= thisindent:
+                del classstack[-1]
             # remember this message
             cur_class = Message(module, message_name, file, lineno)
+            endline = calculateEndline(lineno, srcLines)
+            cur_class.setEndLine(endline)
             if not classstack:
                 dictionary[message_name] = cur_class
             else:
                 msg = classstack[-1][0]
                 msg._addclass(message_name, cur_class)
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = cur_class
-            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Enum") >= 0:
@@ -323,25 +356,19 @@ def readmodule_ex(module, path=None):
             indent += 1
             # close all messages/services indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
             enum_name = m.group("EnumName")
             # remember this Enum
             cur_class = Enum(module, enum_name, file, lineno)
+            endline = calculateEndline(lineno, srcLines)
+            cur_class.setEndLine(endline)
             if not classstack:
                 dictionary[enum_name] = cur_class
             else:
                 enum = classstack[-1][0]
                 enum._addclass(enum_name, cur_class)
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = cur_class
-            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Service") >= 0:
@@ -350,25 +377,19 @@ def readmodule_ex(module, path=None):
             indent += 1
             # close all messages/services indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
             service_name = m.group("ServiceName")
             # remember this Service
             cur_class = Service(module, service_name, file, lineno)
+            endline = calculateEndline(lineno, srcLines)
+            cur_class.setEndLine(endline)
             if not classstack:
                 dictionary[service_name] = cur_class
             else:
                 service = classstack[-1][0]
                 service._addclass(service_name, cur_class)
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = cur_class
-            cur_obj = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Begin") >= 0:
