@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,19 +8,15 @@ Parse a Python file and retrieve classes, functions/methods and attributes.
 
 Parse enough of a Python file to recognize class and method definitions and
 to find out the superclasses of a class as well as its attributes.
-
-This is module is based on pyclbr found in the Python 2.2.2 distribution.
 """
 
-
 import sys
-import imp
 import re
+from functools import reduce
 
 import Utilities
 import Utilities.ClassBrowsers as ClassBrowsers
 from . import ClbrBaseClasses
-from functools import reduce
 
 TABWIDTH = 4
 
@@ -28,7 +24,11 @@ SUPPORTED_TYPES = [ClassBrowsers.PY_SOURCE, ClassBrowsers.PTL_SOURCE]
 
 _getnext = re.compile(
     r"""
-    (?P<String>
+   (?P<CodingLine>
+        ^ \# \s* [*_-]* \s* coding[:=] \s* (?P<Coding> [-\w_.]+ ) \s* [*_-]* $
+    )
+
+|   (?P<String>
         \# .*? $   # ignore everything in comments
     |
         \""" [^"\\]* (?:
@@ -130,10 +130,6 @@ _getnext = re.compile(
             (?: \( \s* .*? \s* \) )
             |
             (?: [^#;\\\n]* (?: \\\n )* )* )
-    )
-
-|   (?P<CodingLine>
-        ^ \# \s* [*_-]* \s* coding[:=] \s* (?P<Coding> [-\w_.]+ ) \s* [*_-]* $
     )""",
     re.VERBOSE | re.DOTALL | re.MULTILINE).search
 
@@ -338,24 +334,26 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
     module and return a dictionary with one entry for each class
     found in the module.
     
-    @param module name of the module file (string)
-    @param path path the module should be searched in (list of strings)
+    @param module name of the module file
+    @type str
+    @param path path the module should be searched in
+    @type list of str
     @param inpackage flag indicating a module inside a package is scanned
-    @param isPyFile flag indicating a Python file (boolean)
+    @type bool
+    @param isPyFile flag indicating a Python file
+    @type bool
     @return the resulting dictionary
+    @rtype dict
     """
     global _modules
     
-    dictionary = {}
-    dict_counts = {}
-
     if module in _modules:
         # we've seen this module before...
         return _modules[module]
     if module in sys.builtin_module_names:
         # this is a built-in module
-        _modules[module] = dictionary
-        return dictionary
+        _modules[module] = {}
+        return {}
 
     # search the path for the module
     path = [] if path is None else path[:]
@@ -370,37 +368,77 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
         fullpath = path[:] + sys.path[:]
         f, file, (suff, mode, type) = ClassBrowsers.find_module(
             module, fullpath, isPyFile)
-    if module.endswith(".py") and type == imp.PKG_DIRECTORY:
-        return dictionary
-    if type == imp.PKG_DIRECTORY:
-        dictionary['__path__'] = [file]
-        _modules[module] = dictionary
-        path = [file] + path
-        f, file, (suff, mode, type) = ClassBrowsers.find_module(
-            '__init__', [file])
     if f:
         f.close()
     if type not in SUPPORTED_TYPES:
         # not Python source, can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
+        _modules[module] = {}
+        return {}
 
-    _modules[module] = dictionary
+    try:
+        src = Utilities.readEncodedFile(file)[0]
+    except (UnicodeError, OSError):
+        # can't do anything with this module
+        _modules[module] = {}
+        return {}
+    
+    _modules[module] = scan(src, file, module)
+    return _modules[module]
+
+
+def scan(src, file, module):
+    """
+    Public method to scan the given source text.
+    
+    @param src source text to be scanned
+    @type str
+    @param file file name associated with the source text
+    @type str
+    @param module module name associated with the source text
+    @type str
+    @return dictionary containing the extracted data
+    @rtype dict
+    """
+    def calculateEndline(lineno, lines, indent):
+        """
+        Function to calculate the end line of a class or method/function.
+        
+        @param lineno line number to start at (one based)
+        @type int
+        @param lines list of source lines
+        @type list of str
+        @param indent indent length the class/method/function definition
+        @type int
+        @return end line of the class/method/function (one based)
+        @rtype int
+        """
+        # start with zero based line after start line
+        while lineno < len(lines):
+            line = lines[lineno]
+            if line.strip():
+                # line contains some text
+                lineIndent = _indent(line.replace(line.lstrip(), ""))
+                if lineIndent <= indent:
+                    return lineno
+            lineno += 1
+        
+        # nothing found
+        return -1
+    
+    # convert eol markers the Python style
+    src = src.replace("\r\n", "\n").replace("\r", "\n")
+    srcLines = src.splitlines()
+    
+    dictionary = {}
+    dict_counts = {}
+    
     classstack = []  # stack of (class, indent) pairs
     conditionalsstack = []  # stack of indents of conditional defines
     deltastack = []
     deltaindent = 0
     deltaindentcalculated = 0
-    try:
-        src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, IOError):
-        # can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
-
+    
     lineno, last_lineno_pos = 1, 0
-    lastGlobalEntry = None
-    cur_obj = None
     i = 0
     modifierType = ClbrBaseClasses.Function.General
     modifierIndent = -1
@@ -454,9 +492,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
                     deltaindentcalculated = 0
             # close all classes indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             if classstack:
                 # it's a class method
@@ -467,6 +502,8 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
                                  file, lineno, meth_sig, annotation=meth_ret,
                                  modifierType=modifier)
                     cur_class._addmethod(meth_name, f)
+                else:
+                    f = None
             else:
                 # it's a function
                 f = Function(module, meth_name,
@@ -479,14 +516,10 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
                 else:
                     dict_counts[meth_name] = 0
                 dictionary[meth_name] = f
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = f
-            if cur_obj and isinstance(cur_obj, Function):
-                cur_obj.setEndLine(lineno - 1)
-            cur_obj = f
-            classstack.append((f, thisindent))  # Marker for nested fns
+            if f:
+                endlineno = calculateEndline(lineno, srcLines, thisindent)
+                f.setEndLine(endlineno)
+                classstack.append((f, thisindent))  # Marker for nested fns
             
             # reset the modifier settings
             modifierType = ClbrBaseClasses.Function.General
@@ -500,9 +533,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
             thisindent = _indent(m.group("ClassIndent"))
             # close all classes indented at least as much
             while classstack and classstack[-1][1] >= thisindent:
-                if classstack[-1][0] is not None:
-                    # record the end line
-                    classstack[-1][0].setEndLine(lineno - 1)
                 del classstack[-1]
             lineno = lineno + src.count('\n', last_lineno_pos, start)
             last_lineno_pos = start
@@ -537,6 +567,8 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
             # remember this class
             cur_class = Class(module, class_name, inherit,
                               file, lineno)
+            endlineno = calculateEndline(lineno, srcLines, thisindent)
+            cur_class.setEndLine(endlineno)
             if not classstack:
                 if class_name in dict_counts:
                     dict_counts[class_name] += 1
@@ -547,10 +579,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
                 dictionary[class_name] = cur_class
             else:
                 classstack[-1][0]._addclass(class_name, cur_class)
-            if not classstack:
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = cur_class
             classstack.append((cur_class, thisindent))
 
         elif m.start("Attribute") >= 0:
@@ -589,9 +617,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
                         module, "Globals", file, lineno)
                 dictionary["@@Globals@@"]._addglobal(
                     Attribute(module, variable_name, file, lineno))
-                if lastGlobalEntry:
-                    lastGlobalEntry.setEndLine(lineno - 1)
-                lastGlobalEntry = None
             else:
                 index = -1
                 while index >= -len(classstack):
@@ -658,9 +683,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
             if "@@Coding@@" not in dictionary:
                 dictionary["@@Coding@@"] = ClbrBaseClasses.Coding(
                     module, file, lineno, coding)
-        
-        else:
-            assert 0, "regexp _getnext found something unexpected"
 
     if '__all__' in dictionary:
         # set visibility of all top level elements
