@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,6 @@ and to find out the superclasses of a class as well as its attributes.
 It is based on the Python class browser found in this package.
 """
 
-
 import re
 
 import Utilities
@@ -260,9 +259,6 @@ def readmodule_ex(module, path=None):
     """
     global _modules
     
-    dictionary = {}
-    dict_counts = {}
-
     if module in _modules:
         # we've seen this file before...
         return _modules[module]
@@ -275,19 +271,42 @@ def readmodule_ex(module, path=None):
         f.close()
     if type not in SUPPORTED_TYPES:
         # not Ruby source, can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
+        _modules[module] = {}
+        return {}
+
+    try:
+        src = Utilities.readEncodedFile(file)[0]
+    except (UnicodeError, OSError):
+        # can't do anything with this module
+        _modules[module] = {}
+        return {}
+    
+    _modules[module] = scan(src, file, module)
+    return _modules[module]
+
+
+def scan(src, file, module):
+    """
+    Public method to scan the given source text.
+    
+    @param src source text to be scanned
+    @type str
+    @param file file name associated with the source text
+    @type str
+    @param module module name associated with the source text
+    @type str
+    @return dictionary containing the extracted data
+    @rtype dict
+    """
+    # convert eol markers the Python style
+    src = src.replace("\r\n", "\n").replace("\r", "\n")
+
+    dictionary = {}
+    dict_counts = {}
 
-    _modules[module] = dictionary
     classstack = []  # stack of (class, indent) pairs
     acstack = []    # stack of (access control, indent) pairs
     indent = 0
-    try:
-        src = Utilities.readEncodedFile(file)[0]
-    except (UnicodeError, IOError):
-        # can't do anything with this module
-        _modules[module] = dictionary
-        return dictionary
 
     lineno, last_lineno_pos = 1, 0
     cur_obj = None
@@ -598,7 +617,4 @@ def readmodule_ex(module, path=None):
                 dictionary["@@Coding@@"] = ClbrBaseClasses.Coding(
                     module, file, lineno, coding)
 
-        else:
-            assert 0, "regexp _getnext found something unexpected"
-
     return dictionary
