@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Module to check for the presence of PySide/PySide2 by importing it.
+Module to check for the presence of PySide2 by importing it.
 """
 
 import sys
@@ -15,11 +15,8 @@ if __name__ == "__main__":
         pySideVariant = sys.argv[1].replace("-", "")
     
     if pySideVariant == "1":
-        try:
-            import PySide       # __IGNORE_EXCEPTION__ __IGNORE_WARNING__
-            ret = 0
-        except ImportError:
-            ret = 1
+        # no PySide support anymore
+        ret = 1
     
     elif pySideVariant == "2":
         try:
@@ -32,6 +29,3 @@ if __name__ == "__main__":
         ret = 1
     
     sys.exit(ret)
-    
-#
-# eflag: noqa = M702
