@@ -17,7 +17,7 @@
 #
 # Ported to Python3
 #
-# Copyright (c) 2011 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,7 +25,6 @@ Module implementing classes for encryption according
 Advanced Encryption Standard.
 """
 
-
 import os
 import math
 
@@ -240,8 +239,8 @@ class AES(object):
                 size == self.KeySize["SIZE_256"] and
                 ((currentSize % size) == 16)
             ):
-                for l in range(4):
-                    t[l] = self.__getSBoxValue(t[l])
+                for ll in range(4):
+                    t[ll] = self.__getSBoxValue(t[ll])
 
             # We XOR t with the four-byte block 16, 24, 32 bytes before the new
             # expanded key. This becomes the next four bytes in the expanded
@@ -547,10 +546,10 @@ class AES(object):
         block = self.__aes_main(block, expandedKey, nbrRounds)
 
         # unmap the block again into the output
-        for k in range(4):
+        for kk in range(4):
             # iterate over the rows
-            for l in range(4):
-                output[k * 4 + l] = block[k + l * 4]
+            for ll in range(4):
+                output[kk * 4 + ll] = block[kk + ll * 4]
         return bytes(output)
 
     # decrypts a 128 bit input block against the given key of size specified
@@ -600,10 +599,10 @@ class AES(object):
         # decrypt the block using the expandedKey
         block = self.__aes_invMain(block, expandedKey, nbrRounds)
         # unmap the block again into the output
-        for k in range(4):
+        for kk in range(4):
             # iterate over the rows
-            for l in range(4):
-                output[k * 4 + l] = block[k + l * 4]
+            for ll in range(4):
+                output[kk * 4 + ll] = block[kk + ll * 4]
         return output
 
 
@@ -833,13 +832,14 @@ def encryptData(key, data, mode=AESModeOfOperation.ModeOfOperation["CBC"]):
     @param data data to be encrypted (bytes)
     @param mode mode of operations (0, 1 or 2)
     @return encrypted data prepended with the initialization vector (bytes)
+    @exception ValueError raised to indicate an invalid key size
     """
     key = bytearray(key)
     if mode == AESModeOfOperation.ModeOfOperation["CBC"]:
         data = append_PKCS7_padding(data)
     keysize = len(key)
-    assert keysize in AES.KeySize.values(), \
-        'invalid key size: {0}'.format(keysize)
+    if keysize not in AES.KeySize.values():
+        raise ValueError('invalid key size: {0}'.format(keysize))
     # create a new iv using random data
     iv = bytearray([i for i in os.urandom(16)])
     moo = AESModeOfOperation()
@@ -859,11 +859,12 @@ def decryptData(key, data, mode=AESModeOfOperation.ModeOfOperation["CBC"]):
         (bytes)
     @param mode mode of operations (0, 1 or 2)
     @return decrypted data (bytes)
+    @exception ValueError raised to indicate an invalid key size
     """
     key = bytearray(key)
     keysize = len(key)
-    assert keysize in AES.KeySize.values(), \
-        'invalid key size: {0}'.format(keysize)
+    if keysize not in AES.KeySize.values():
+        raise ValueError('invalid key size: {0}'.format(keysize))
     # iv is first 16 bytes
     iv = bytearray(data[:16])
     data = bytearray(data[16:])
