@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a dialog to enter the parameters for the
 virtual environment.
 """
 
-
 import os
 import sys
 import re
@@ -171,6 +170,16 @@ class VirtualenvConfigurationDialog(QDialog, Ui_VirtualenvConfigurationDialog):
         else:
             self.venvStack.setCurrentWidget(self.venvPage)
     
+    @pyqtSlot(str)
+    def on_nameEdit_textChanged(self, txt):
+        """
+        Private slot handling a change of the virtual environment name.
+        
+        @param txt name of the virtual environment
+        @type str
+        """
+        self.__updateOK()
+    
     @pyqtSlot(str)
     def on_targetDirectoryPicker_textChanged(self, txt):
         """
