@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2018 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2018 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing a class to manage Python virtual environments.
 """
 
-
 import os
 import sys
 import shutil
@@ -174,7 +173,7 @@ class VirtualenvManager(QObject):
         )
         
         dlg = VirtualenvConfigurationDialog()
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             resultDict = dlg.getData()
             
             if resultDict["envType"] == "conda":
@@ -193,7 +192,7 @@ class VirtualenvManager(QObject):
                 dia = VirtualenvExecDialog(resultDict, self)
                 dia.show()
                 dia.start(resultDict["arguments"])
-                dia.exec_()
+                dia.exec()
     
     def addVirtualEnv(self, venvName, venvDirectory, venvInterpreter="",
                       isGlobal=False, isConda=False, isRemote=False,
@@ -230,7 +229,7 @@ class VirtualenvManager(QObject):
                 dlg = VirtualenvNameDialog(
                     list(self.__virtualEnvironments.keys()),
                     venvName)
-                if dlg.exec_() != QDialog.Accepted:
+                if dlg.exec() != QDialog.Accepted:
                     return
                 
                 venvName = dlg.getName()
@@ -240,7 +239,7 @@ class VirtualenvManager(QObject):
                 VirtualenvInterpreterSelectionDialog
             )
             dlg = VirtualenvInterpreterSelectionDialog(venvName, venvDirectory)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 venvInterpreter = dlg.getData()
         
         if venvInterpreter:
@@ -372,7 +371,7 @@ class VirtualenvManager(QObject):
                         """ environments?"""),
                 venvMessages
             )
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 for venvName in venvNames:
                     if self.__isEnvironmentDeleteable(venvName):
                         if self.isCondaEnvironment(venvName):
@@ -437,7 +436,7 @@ class VirtualenvManager(QObject):
                         """ environments?"""),
                 venvMessages
             )
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 for venvName in venvNames:
                     if venvName in self.__virtualEnvironments:
                         del self.__virtualEnvironments[venvName]
@@ -473,7 +472,7 @@ class VirtualenvManager(QObject):
                 self, self.__ui)
         
         if modal:
-            self.__virtualenvManagerDialog.exec_()
+            self.__virtualenvManagerDialog.exec()
         else:
             self.__virtualenvManagerDialog.show()
     
@@ -524,13 +523,15 @@ class VirtualenvManager(QObject):
         else:
             return ""
     
-    def getVirtualenvNames(self, noRemote=False):
+    def getVirtualenvNames(self, noRemote=False, noConda=False):
         """
         Public method to get a list of defined virtual environments.
         
         @param noRemote flag indicating to exclude environments for remote
             debugging
         @type bool
+        @param noConda flag indicating to exclude Conda environments
+        @type bool
         @return list of defined virtual environments
         @rtype list of str
         """
@@ -538,6 +539,9 @@ class VirtualenvManager(QObject):
         if noRemote:
             environments = [name for name in environments
                             if not self.isRemoteEnvironment(name)]
+        if noConda:
+            environments = [name for name in environments
+                            if not self.isCondaEnvironment(name)]
         
         return environments
     
