@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2018 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2018 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,6 @@ Module implementing a dialog to manage the list of defined virtual
 environments.
 """
 
-
 from PyQt5.QtCore import pyqtSlot, Qt
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem, QHeaderView
 
@@ -20,7 +19,6 @@ class VirtualenvManagerDialog(QDialog, Ui_VirtualenvManagerDialog):
     Class implementing a dialog to manage the list of defined virtual
     environments.
     """
-    PythonVariantRole = Qt.UserRole
     IsGlobalRole = Qt.UserRole + 1
     IsCondaRole = Qt.UserRole + 2
     IsRemoteRole = Qt.UserRole + 3
@@ -97,7 +95,7 @@ class VirtualenvManagerDialog(QDialog, Ui_VirtualenvManagerDialog):
         """
         from .VirtualenvAddEditDialog import VirtualenvAddEditDialog
         dlg = VirtualenvAddEditDialog(self.__manager)
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (venvName, venvDirectory, venvInterpreter, isGlobal, isConda,
              isRemote, execPath) = dlg.getData()
             
@@ -124,13 +122,12 @@ class VirtualenvManagerDialog(QDialog, Ui_VirtualenvManagerDialog):
         dlg = VirtualenvAddEditDialog(
             self.__manager, selectedItem.text(0),
             selectedItem.text(1), selectedItem.text(2),
-            selectedItem.data(0, VirtualenvManagerDialog.PythonVariantRole),
             selectedItem.data(0, VirtualenvManagerDialog.IsGlobalRole),
             selectedItem.data(0, VirtualenvManagerDialog.IsCondaRole),
             selectedItem.data(0, VirtualenvManagerDialog.IsRemoteRole),
             selectedItem.data(0, VirtualenvManagerDialog.ExecPathRole),
         )
-        if dlg.exec_() == QDialog.Accepted:
+        if dlg.exec() == QDialog.Accepted:
             (venvName, venvDirectory, venvInterpreter, isGlobal, isConda,
              isRemote, execPath) = dlg.getData()
             if venvName != oldVenvName:
@@ -234,8 +231,6 @@ class VirtualenvManagerDialog(QDialog, Ui_VirtualenvManagerDialog):
                 environments[venvName]["path"],
                 environments[venvName]["interpreter"],
             ])
-            itm.setData(0, VirtualenvManagerDialog.PythonVariantRole,
-                        environments[venvName]["variant"])
             itm.setData(0, VirtualenvManagerDialog.IsGlobalRole,
                         environments[venvName]["is_global"])
             itm.setData(0, VirtualenvManagerDialog.IsCondaRole,
