@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the AdBlock icon for the main window status bar.
 """
 
-
 from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QAction, QMenu
 
@@ -69,28 +68,24 @@ class AdBlockIcon(E5ClickableLabel):
             act = menu.addAction(
                 UI.PixmapCache.getIcon("adBlockPlusDisabled"),
                 self.tr("Disable AdBlock"))
-            act.setData(False)
-            act.triggered.connect(lambda: self.__enableAdBlock(act))
+            act.triggered.connect(lambda: self.__enableAdBlock(False))
         else:
             act = menu.addAction(
                 UI.PixmapCache.getIcon("adBlockPlus"),
                 self.tr("Enable AdBlock"))
-            act.setData(True)
-            act.triggered.connect(lambda: self.__enableAdBlock(act))
+            act.triggered.connect(lambda: self.__enableAdBlock(True))
         menu.addSeparator()
         if manager.isEnabled() and self.__mw.currentBrowser().url().host():
             if self.__isCurrentHostExcepted():
                 act = menu.addAction(
                     UI.PixmapCache.getIcon("adBlockPlus"),
                     self.tr("Remove AdBlock Exception"))
-                act.setData(False)
-                act.triggered.connect(lambda: self.__setException(act))
+                act.triggered.connect(lambda: self.__setException(False))
             else:
                 act = menu.addAction(
                     UI.PixmapCache.getIcon("adBlockPlusGreen"),
                     self.tr("Add AdBlock Exception"))
-                act.setData(True)
-                act.triggered.connect(lambda: self.__setException(act))
+                act.triggered.connect(lambda: self.__setException(True))
         menu.addAction(
             UI.PixmapCache.getIcon("adBlockPlusGreen"),
             self.tr("AdBlock Exceptions..."), manager.showExceptionsDialog)
@@ -130,16 +125,16 @@ class AdBlockIcon(E5ClickableLabel):
         """
         menu = QMenu()
         self.__createMenu(menu)
-        menu.exec_(pos)
+        menu.exec(pos)
     
-    def __enableAdBlock(self, act):
+    def __enableAdBlock(self, enable):
         """
         Private slot to enable or disable AdBlock.
         
-        @param act reference to the action
-        @type QAction
+        @param enable flag indicating the desired enable state
+        @type bool
         """
-        self.__mw.adBlockManager().setEnabled(act.data())
+        self.__mw.adBlockManager().setEnabled(enable)
     
     def __isCurrentHostExcepted(self):
         """
@@ -171,16 +166,16 @@ class AdBlockIcon(E5ClickableLabel):
             else:
                 self.setPixmap(UI.PixmapCache.getPixmap("adBlockPlus16"))
     
-    def __setException(self, act):
+    def __setException(self, enable):
         """
         Private slot to add or remove the current host from the list of
         exceptions.
         
-        @param act referenced to the action
-        @type QAction
+        @param enable flag indicating to set or remove an exception
+        @type bool
         """
         urlHost = self.__mw.currentBrowser().url().host()
-        if act.data():
+        if enable:
             self.__mw.adBlockManager().addException(urlHost)
         else:
             self.__mw.adBlockManager().removeException(urlHost)
