@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an importer for Chrome bookmarks.
 """
 
-
 import os
 import json
 
@@ -122,10 +121,9 @@ class ChromeImporter(BookmarksImporter):
         @return imported bookmarks (BookmarkNode)
         """
         try:
-            f = open(self.__fileName, "r", encoding="utf-8")
-            contents = json.load(f)
-            f.close()
-        except IOError as err:
+            with open(self.__fileName, "r", encoding="utf-8") as f:
+                contents = json.load(f)
+        except OSError as err:
             self._error = True
             self._errorString = self.tr(
                 "File '{0}' cannot be read.\nReason: {1}"
