@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing an importer for Apple Safari bookmarks.
 """
 
-
 import os
+import plistlib
 
 from PyQt5.QtCore import QCoreApplication, QDate, Qt
 
@@ -17,8 +17,6 @@ from .BookmarksImporter import BookmarksImporter
 import UI.PixmapCache
 import Globals
 
-from Utilities import binplistlib
-
 
 def getImporterInfo(sourceId):
     """
@@ -102,8 +100,9 @@ class SafariImporter(BookmarksImporter):
         @return imported bookmarks (BookmarkNode)
         """
         try:
-            bookmarksDict = binplistlib.readPlist(self.__fileName)
-        except binplistlib.InvalidPlistException as err:
+            with open(self.__fileName, "rb") as f:
+                bookmarksDict = plistlib.load(f)
+        except (plistlib.InvalidFileException, OSError) as err:
             self._error = True
             self._errorString = self.tr(
                 "Bookmarks file cannot be read.\nReason: {0}".format(str(err)))
