@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the download manager class.
 """
 
-
 from PyQt5.QtCore import (
     pyqtSlot, pyqtSignal, Qt, QModelIndex, QFileInfo, QUrl, QBasicTimer
 )
@@ -137,7 +136,7 @@ class DownloadManager(QDialog, Ui_DownloadManager):
                 self.tr("Remove From List"),
                 self.__contextMenuRemoveSelected)
         
-        menu.exec_(QCursor.pos())
+        menu.exec(QCursor.pos())
     
     def shutdown(self):
         """
