@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the history menu.
 """
 
-
 import sys
 
 from PyQt5.QtCore import (
@@ -375,14 +374,14 @@ class HistoryMenu(E5ModelMenu):
                 self.newPrivateWindow)
         self.addMenu(self.__mostVisitedMenu)
         act = self.addMenu(self.__closedTabsMenu)
-        act.setIcon(UI.PixmapCache.getIcon("trash.png"))
+        act.setIcon(UI.PixmapCache.getIcon("trash"))
         act.setEnabled(self.__tabWidget.canRestoreClosedTab())
         self.addSeparator()
         
-        act = self.addAction(UI.PixmapCache.getIcon("history.png"),
+        act = self.addAction(UI.PixmapCache.getIcon("history"),
                              self.tr("Show All History..."))
         act.triggered.connect(self.showHistoryDialog)
-        act = self.addAction(UI.PixmapCache.getIcon("historyClear.png"),
+        act = self.addAction(UI.PixmapCache.getIcon("historyClear"),
                              self.tr("Clear History..."))
         act.triggered.connect(self.__clearHistoryDialog)
     
