@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -151,21 +151,21 @@ class SafeBrowsingCache(QObject):
         try:
             query = QSqlQuery(db)
             # step 1: drop old tables
-            query.exec_(self.drop_threat_list_stmt)
-            query.exec_(self.drop_full_hashes_stmt)
-            query.exec_(self.drop_hash_prefix_stmt)
+            query.exec(self.drop_threat_list_stmt)
+            query.exec(self.drop_full_hashes_stmt)
+            query.exec(self.drop_hash_prefix_stmt)
             # step 2: drop old indices
-            query.exec_(self.drop_full_hash_cue_idx)
-            query.exec_(self.drop_full_hash_expires_idx)
-            query.exec_(self.drop_full_hash_value_idx)
+            query.exec(self.drop_full_hash_cue_idx)
+            query.exec(self.drop_full_hash_expires_idx)
+            query.exec(self.drop_full_hash_value_idx)
             # step 3: create tables
-            query.exec_(self.create_threat_list_stmt)
-            query.exec_(self.create_full_hashes_stmt)
-            query.exec_(self.create_hash_prefix_stmt)
+            query.exec(self.create_threat_list_stmt)
+            query.exec(self.create_full_hashes_stmt)
+            query.exec(self.create_hash_prefix_stmt)
             # step 4: create indices
-            query.exec_(self.create_full_hash_cue_idx)
-            query.exec_(self.create_full_hash_expires_idx)
-            query.exec_(self.create_full_hash_value_idx)
+            query.exec(self.create_full_hash_cue_idx)
+            query.exec(self.create_full_hash_expires_idx)
+            query.exec(self.create_full_hash_value_idx)
         finally:
             del query
             db.commit()
@@ -199,7 +199,7 @@ class SafeBrowsingCache(QObject):
                     query.addBindValue(QByteArray(hashValue),
                                        QSql.In | QSql.Binary)
                 
-                query.exec_()
+                query.exec()
                 
                 while query.next():             # __IGNORE_WARNING_M523__
                     threatType = query.value(0)
@@ -244,7 +244,7 @@ class SafeBrowsingCache(QObject):
                 for prefix in prefixes:
                     query.addBindValue(prefix)
                 
-                query.exec_()
+                query.exec()
                 
                 while query.next():             # __IGNORE_WARNING_M523__
                     fullHash = bytes(query.value(0))
@@ -284,12 +284,14 @@ class SafeBrowsingCache(QObject):
             VALUES
                 (?, ?, ?, ?, ?, current_timestamp)
         """
-        updateQueryStr = """
+        updateQueryStr = (
+            """
             UPDATE full_hash SET
-                expires_at=datetime(current_timestamp, '+{0} SECONDS')
+            expires_at=datetime(current_timestamp, '+{0} SECONDS')
             WHERE value=? AND threat_type=? AND platform_type=? AND
             threat_entry_type=?
-        """.format(int(cacheDuration))
+            """.format(int(cacheDuration))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -303,7 +305,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
                 query.addBindValue(malwareThreatType)
-                query.exec_()
+                query.exec()
                 del query
                 
                 query = QSqlQuery(db)
@@ -313,7 +315,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -339,7 +341,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -352,10 +354,12 @@ class SafeBrowsingCache(QObject):
         @param keepExpiredFor time period in seconds of entries to be expired
         @type int or float
         """
-        queryStr = """
+        queryStr = (
+            """
             DELETE FROM full_hash
-                WHERE expires_at=datetime(current_timestamp, '{0} SECONDS')
-        """.format(int(keepExpiredFor))
+            WHERE expires_at=datetime(current_timestamp, '{0} SECONDS')
+            """.format(int(keepExpiredFor))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -363,7 +367,7 @@ class SafeBrowsingCache(QObject):
             try:
                 query = QSqlQuery(db)
                 query.prepare(queryStr)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -381,12 +385,14 @@ class SafeBrowsingCache(QObject):
             in the cache
         @type int or float
         """
-        queryStr = """
+        queryStr = (
+            """
             UPDATE hash_prefix
             SET negative_expires_at=datetime(current_timestamp, '+{0} SECONDS')
             WHERE value=? AND threat_type=? AND platform_type=? AND
             threat_entry_type=?
-        """.format(int(negativeCacheDuration))
+            """.format(int(negativeCacheDuration))
+        )
         
         db = QSqlDatabase.database(self.__connectionName)
         if db.isOpen():
@@ -399,7 +405,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -424,7 +430,7 @@ class SafeBrowsingCache(QObject):
                 query = QSqlQuery(db)
                 query.prepare(queryStr)
                 
-                query.exec_()
+                query.exec()
                 
                 while query.next():             # __IGNORE_WARNING_M523__
                     threatType = query.value(0)
@@ -464,7 +470,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -490,7 +496,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -519,7 +525,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.threatType)
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
-                query.exec_()
+                query.exec()
                 del query
             finally:
                 db.commit()
@@ -552,7 +558,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
                 
-                query.exec_()
+                query.exec()
                 
                 while query.next():             # __IGNORE_WARNING_M523__
                     sha256Hash.addData(query.value(0))
@@ -595,7 +601,7 @@ class SafeBrowsingCache(QObject):
                     query.addBindValue(threatList.threatType)
                     query.addBindValue(threatList.platformType)
                     query.addBindValue(threatList.threatEntryType)
-                    query.exec_()
+                    query.exec()
                     del query
                     QCoreApplication.processEvents(QEventLoop.AllEvents,
                                                    self.maxProcessEventsTime)
@@ -632,7 +638,7 @@ class SafeBrowsingCache(QObject):
                 query.addBindValue(threatList.platformType)
                 query.addBindValue(threatList.threatEntryType)
                 
-                query.exec_()
+                query.exec()
                 
                 index = 0
                 while query.next():         # __IGNORE_WARNING_M523__
@@ -657,11 +663,13 @@ class SafeBrowsingCache(QObject):
         @param indexes list of indexes of prefixes to be removed
         @type list of int
         """
-        queryStr = """
+        queryStr = (
+            """
             DELETE FROM hash_prefix
             WHERE threat_type=? AND platform_type=? AND
             threat_entry_type=? AND value IN ({0})
-        """
+            """
+        )
         batchSize = 40
         
         prefixesToRemove = self.getHashPrefixValuesToRemove(
@@ -686,9 +694,12 @@ class SafeBrowsingCache(QObject):
                         for prefix in removeBatch:
                             query.addBindValue(QByteArray(prefix),
                                                QSql.In | QSql.Binary)
-                        query.exec_()
+                        query.exec()
                         del query
                         QCoreApplication.processEvents(
                             QEventLoop.AllEvents, self.maxProcessEventsTime)
                 finally:
                     db.commit()
+
+#
+# eflag: noqa = S608
