@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,6 @@ Module implementing the interface for Google Safe Browsing.
 # https://github.com/afilipovich/gglsbl
 #
 
-
 import os
 import base64
 
@@ -164,7 +163,7 @@ class SafeBrowsingManager(QObject):
         
         if WebBrowserWindow.notificationsEnabled():
             WebBrowserWindow.showNotification(
-                UI.PixmapCache.getPixmap("safeBrowsing48.png"),
+                UI.PixmapCache.getPixmap("safeBrowsing48"),
                 self.tr("Google Safe Browsing"),
                 message,
                 timeout=timeout,
