@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,6 @@ Module implementing a window for managing the web browser tabs.
 # Copyright (C) 2013  S. Razi Alavizadeh <s.r.alavizadeh@gmail.com>
 #
 
-
 import os
 import collections
 
@@ -126,7 +125,7 @@ class TabManagerWidget(QWidget):
         dlg = AddBookmarkDialog()
         dlg.setFolder(True)
         dlg.setTitle(self.tr("Saved Tabs"))
-        dlg.exec_()
+        dlg.exec()
         
         folder = dlg.addedNode()
         if folder is None:
@@ -289,7 +288,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading.png"))
+                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
                 
@@ -333,7 +332,7 @@ class TabManagerWidget(QWidget):
                 if not browser.isLoading():
                     tabItem.setIcon(0, browser.icon())
                 else:
-                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading.png"))
+                    tabItem.setIcon(0, UI.PixmapCache.getIcon("loading"))
                 tabItem.setText(0, browser.title())
                 tabItem.setToolTip(0, browser.title())
                 
@@ -527,17 +526,17 @@ class TabManagerWidget(QWidget):
         
         if self.__isBrowserSelected():
             act = menu.addAction(
-                UI.PixmapCache.getIcon("bookmark22.png"),
+                UI.PixmapCache.getIcon("bookmark22"),
                 self.tr("&Bookmark checked tabs"))
             act.setObjectName("bookmarkSelection")
             act.triggered.connect(lambda: self.__processActions(act))
             act = menu.addAction(
-                UI.PixmapCache.getIcon("tabClose.png"),
+                UI.PixmapCache.getIcon("tabClose"),
                 self.tr("&Close checked tabs"))
             act.setObjectName("closeSelection")
             act.triggered.connect(lambda: self.__processActions(act))
         
-        menu.exec_(self.__tree.viewport().mapToGlobal(pos))
+        menu.exec(self.__tree.viewport().mapToGlobal(pos))
     
     def mainWindowCreated(self, mainWin, refresh=True):
         """
@@ -564,7 +563,7 @@ class TabManagerWidget(QWidget):
         """
         icon = E5ClickableLabel()
         icon.setPixmap(
-            UI.PixmapCache.getPixmap("tabManager.png").scaled(16, 16))
+            UI.PixmapCache.getPixmap("tabManager").scaled(16, 16))
         icon.setToolTip(self.tr("Show Tab Manager"))
         icon.clicked.connect(lambda: self.raiseTabManager(icon))
         
