@@ -1,25 +1,25 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the central widget showing the web pages.
 """
 
-
 import os
 
 from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QUrl, QFile, QFileDevice
 from PyQt5.QtGui import QIcon, QPixmap, QPainter
 from PyQt5.QtWidgets import (
-    QWidget, QHBoxLayout, QMenu, QToolButton, QDialog, QApplication
+    QWidget, QHBoxLayout, QMenu, QToolButton, QDialog
 )
 from PyQt5.QtPrintSupport import QPrinter, QPrintDialog, QAbstractPrintDialog
 
 from E5Gui.E5TabWidget import E5TabWidget
 from E5Gui import E5MessageBox
 from E5Gui.E5Application import e5App
+from E5Gui.E5OverrideCursor import E5OverrideCursor
 
 from .WebBrowserView import WebBrowserView
 from .WebBrowserPage import WebBrowserPage
@@ -32,8 +32,6 @@ import Utilities
 import Preferences
 import Globals
 
-from eric6config import getConfig
-
 
 def isCupsAvailable():
     """
@@ -120,7 +118,7 @@ class WebBrowserTabWidget(E5TabWidget):
         
         self.__navigationButton = QToolButton(self)
         self.__navigationButton.setIcon(
-            UI.PixmapCache.getIcon("1downarrow.png"))
+            UI.PixmapCache.getIcon("1downarrow"))
         self.__navigationButton.setToolTip(
             self.tr("Show a navigation menu"))
         self.__navigationButton.setPopupMode(QToolButton.InstantPopup)
@@ -133,7 +131,7 @@ class WebBrowserTabWidget(E5TabWidget):
             self.__aboutToShowClosedTabsMenu)
         
         self.__closedTabsButton = QToolButton(self)
-        self.__closedTabsButton.setIcon(UI.PixmapCache.getIcon("trash.png"))
+        self.__closedTabsButton.setIcon(UI.PixmapCache.getIcon("trash"))
         self.__closedTabsButton.setToolTip(
             self.tr("Show a navigation menu for closed tabs"))
         self.__closedTabsButton.setPopupMode(QToolButton.InstantPopup)
@@ -147,7 +145,7 @@ class WebBrowserTabWidget(E5TabWidget):
         self.setCornerWidget(self.__rightCornerWidget, Qt.TopRightCorner)
         
         self.__newTabButton = QToolButton(self)
-        self.__newTabButton.setIcon(UI.PixmapCache.getIcon("plus.png"))
+        self.__newTabButton.setIcon(UI.PixmapCache.getIcon("plus"))
         self.__newTabButton.setToolTip(
             self.tr("Open a new web browser tab"))
         self.setCornerWidget(self.__newTabButton, Qt.TopLeftCorner)
@@ -163,36 +161,36 @@ class WebBrowserTabWidget(E5TabWidget):
         """
         self.__tabContextMenu = QMenu(self)
         self.tabContextNewAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabNew.png"),
+            UI.PixmapCache.getIcon("tabNew"),
             self.tr('New Tab'), self.newBrowser)
         self.__tabContextMenu.addSeparator()
         self.leftMenuAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("1leftarrow.png"),
+            UI.PixmapCache.getIcon("1leftarrow"),
             self.tr('Move Left'), self.__tabContextMenuMoveLeft)
         self.rightMenuAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("1rightarrow.png"),
+            UI.PixmapCache.getIcon("1rightarrow"),
             self.tr('Move Right'), self.__tabContextMenuMoveRight)
         self.__tabContextMenu.addSeparator()
         self.tabContextCloneAct = self.__tabContextMenu.addAction(
             self.tr("Duplicate Page"), self.__tabContextMenuClone)
         self.__tabContextMenu.addSeparator()
         self.tabContextCloseAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabClose.png"),
+            UI.PixmapCache.getIcon("tabClose"),
             self.tr('Close'), self.__tabContextMenuClose)
         self.tabContextCloseOthersAct = self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("tabCloseOther.png"),
+            UI.PixmapCache.getIcon("tabCloseOther"),
             self.tr("Close Others"), self.__tabContextMenuCloseOthers)
         self.__tabContextMenu.addAction(
             self.tr('Close All'), self.closeAllBrowsers)
         self.__tabContextMenu.addSeparator()
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("printPreview.png"),
+            UI.PixmapCache.getIcon("printPreview"),
             self.tr('Print Preview'), self.__tabContextMenuPrintPreview)
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("print.png"),
+            UI.PixmapCache.getIcon("print"),
             self.tr('Print'), self.__tabContextMenuPrint)
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("printPdf.png"),
+            UI.PixmapCache.getIcon("printPdf"),
             self.tr('Print as PDF'), self.__tabContextMenuPrintPdf)
         self.__tabContextMenu.addSeparator()
         if hasattr(WebBrowserPage, "isAudioMuted"):
@@ -202,25 +200,25 @@ class WebBrowserTabWidget(E5TabWidget):
         else:
             self.__audioAct = None
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("reload.png"),
+            UI.PixmapCache.getIcon("reload"),
             self.tr('Reload All'), self.reloadAllBrowsers)
         self.__tabContextMenu.addSeparator()
         self.__tabContextMenu.addAction(
-            UI.PixmapCache.getIcon("addBookmark.png"),
+            UI.PixmapCache.getIcon("addBookmark"),
             self.tr('Bookmark All Tabs'), self.__mainWindow.bookmarkAll)
         
         self.__tabBackContextMenu = QMenu(self)
         self.__tabBackContextMenu.addAction(
             self.tr('Close All'), self.closeAllBrowsers)
         self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("reload.png"),
+            UI.PixmapCache.getIcon("reload"),
             self.tr('Reload All'), self.reloadAllBrowsers)
         self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("addBookmark.png"),
+            UI.PixmapCache.getIcon("addBookmark"),
             self.tr('Bookmark All Tabs'), self.__mainWindow.bookmarkAll)
         self.__tabBackContextMenu.addSeparator()
         self.__restoreClosedTabAct = self.__tabBackContextMenu.addAction(
-            UI.PixmapCache.getIcon("trash.png"),
+            UI.PixmapCache.getIcon("trash"),
             self.tr('Restore Closed Tab'))
         self.__restoreClosedTabAct.setEnabled(False)
         self.__restoreClosedTabAct.setData(0)
@@ -251,11 +249,11 @@ class WebBrowserTabWidget(E5TabWidget):
                 ):
                     self.__audioAct.setText(self.tr("Unmute Tab"))
                     self.__audioAct.setIcon(
-                        UI.PixmapCache.getIcon("audioVolumeHigh.png"))
+                        UI.PixmapCache.getIcon("audioVolumeHigh"))
                 else:
                     self.__audioAct.setText(self.tr("Mute Tab"))
                     self.__audioAct.setIcon(
-                        UI.PixmapCache.getIcon("audioVolumeMuted.png"))
+                        UI.PixmapCache.getIcon("audioVolumeMuted"))
             
             self.__tabContextMenu.popup(coord)
     
@@ -356,9 +354,9 @@ class WebBrowserTabWidget(E5TabWidget):
             painter = QPainter(pix)
             icon.paint(painter, 0, 0, 22, 22)
             if page.isAudioMuted():
-                audioIcon = UI.PixmapCache.getIcon("audioMuted.png")
+                audioIcon = UI.PixmapCache.getIcon("audioMuted")
             else:
-                audioIcon = UI.PixmapCache.getIcon("audioPlaying.png")
+                audioIcon = UI.PixmapCache.getIcon("audioPlaying")
             audioIcon.paint(painter, 13, 13, 18, 18)
             painter.end()
             self.setTabIcon(index, QIcon(pix))
@@ -430,8 +428,8 @@ class WebBrowserTabWidget(E5TabWidget):
         browser.backwardAvailable.connect(
             self.__mainWindow.setBackwardAvailable)
         browser.forwardAvailable.connect(self.__mainWindow.setForwardAvailable)
-        browser.loadStarted.connect(
-            lambda: self.__loadStarted(browser))
+        browser.loadProgress.connect(
+            lambda progress: self.__loadProgress(progress, browser))
         browser.loadFinished.connect(
             lambda ok: self.__loadFinished(ok, browser))
         browser.faviconChanged.connect(
@@ -676,7 +674,7 @@ class WebBrowserTabWidget(E5TabWidget):
             if isCupsAvailable():
                 printDialog.setOption(QAbstractPrintDialog.PrintCollateCopies)
             printDialog.setOption(QAbstractPrintDialog.PrintPageRange)
-        if printDialog.exec_() == QDialog.Accepted:
+        if printDialog.exec() == QDialog.Accepted:
             browser.page().execPrintPage(printer, 10 * 1000)
     
     @pyqtSlot()
@@ -698,7 +696,7 @@ class WebBrowserTabWidget(E5TabWidget):
             if not name:
                 name = "printout.pdf"
             dlg = PrintToPdfDialog(name, self)
-            if dlg.exec_() == QDialog.Accepted:
+            if dlg.exec() == QDialog.Accepted:
                 filePath, pageLayout = dlg.getData()
                 if filePath:
                     if os.path.exists(filePath):
@@ -732,7 +730,7 @@ class WebBrowserTabWidget(E5TabWidget):
             printer.setResolution(Preferences.getPrinter("Resolution"))
             
             printDialog = QPrintDialog(printer, self)
-            if printDialog.exec_() == QDialog.Accepted:
+            if printDialog.exec() == QDialog.Accepted:
                 browser.render(printer)
     
     def __pdfGeneratedForSave(self, filePath, pdfData):
@@ -798,7 +796,7 @@ class WebBrowserTabWidget(E5TabWidget):
         preview.resize(800, 750)
         preview.paintRequested.connect(
             lambda p: self.__printPreviewRequested(p, browser))
-        preview.exec_()
+        preview.exec()
     
     def __printPreviewRequested(self, printer, browser):
         """
@@ -809,9 +807,8 @@ class WebBrowserTabWidget(E5TabWidget):
         @param browser reference to the browser to be printed
         @type WebBrowserView
         """
-        QApplication.setOverrideCursor(Qt.WaitCursor)
-        browser.page().execPrintPage(printer, 10 * 1000)
-        QApplication.restoreOverrideCursor()
+        with E5OverrideCursor():
+            browser.page().execPrintPage(printer, 10 * 1000)
     
     def __sourceChanged(self, url, browser):
         """
@@ -876,29 +873,6 @@ class WebBrowserTabWidget(E5TabWidget):
         for urlbar in self.__stackedUrlBar.urlBars():
             urlbar.preferencesChanged()
     
-    def __loadStarted(self, browser):
-        """
-        Private method to handle the loadStarted signal.
-        
-        @param browser reference to the web browser
-        @type WebBrowserView
-        """
-        index = self.indexOf(browser)
-        anim = self.animationLabel(
-            index, os.path.join(getConfig("ericPixDir"), "loading.gif"),
-            100)
-        if not anim:
-            loading = QIcon(os.path.join(getConfig("ericPixDir"),
-                            "loading.gif"))
-            self.setTabIcon(index, loading)
-        else:
-            self.setTabIcon(index, QIcon())
-        self.setTabText(index, self.tr("Loading..."))
-        self.setTabToolTip(index, self.tr("Loading..."))
-        self.showMessage.emit(self.tr("Loading..."))
-        
-        self.__mainWindow.setLoadingActions(True)
-    
     def __loadFinished(self, ok, browser):
         """
         Private method to handle the loadFinished signal.
@@ -908,18 +882,45 @@ class WebBrowserTabWidget(E5TabWidget):
         @param browser reference to the web browser
         @type WebBrowserView
         """
-        import WebBrowser.WebBrowserWindow
-        index = self.indexOf(browser)
-        self.resetAnimation(index)
-        self.setTabIcon(
-            index, WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(
-                browser.url()))
         if ok:
             self.showMessage.emit(self.tr("Finished loading"))
         else:
             self.showMessage.emit(self.tr("Failed to load"))
+    
+    def __loadProgress(self, progress, browser):
+        """
+        Private method to handle the loadProgress signal.
         
-        self.__mainWindow.setLoadingActions(False)
+        Note: This works around wegengine not sending a loadFinished
+        signal for navigation on the same page.
+        
+        @param progress load progress in percent
+        @type int
+        @param browser reference to the web browser
+        @type WebBrowserView
+        """
+        index = self.indexOf(browser)
+        if progress == 0:
+            # page loading has started
+            anim = self.animationLabel(index, "loadingAnimation", 40)
+            if not anim:
+                self.setTabIcon(index, UI.PixmapCache.getIcon("loading"))
+            else:
+                self.setTabIcon(index, QIcon())
+            self.setTabText(index, self.tr("Loading..."))
+            self.setTabToolTip(index, self.tr("Loading..."))
+            self.showMessage.emit(self.tr("Loading..."))
+            
+            self.__mainWindow.setLoadingActions(True)
+        elif progress == 100:
+            import WebBrowser.WebBrowserWindow
+            self.resetAnimation(index)
+            self.setTabIcon(
+                index, WebBrowser.WebBrowserWindow.WebBrowserWindow.icon(
+                    browser.url()))
+            self.showMessage.emit(self.tr("Finished loading"))
+            
+            self.__mainWindow.setLoadingActions(False)
     
     def __iconChanged(self, browser):
         """
@@ -967,12 +968,12 @@ class WebBrowserTabWidget(E5TabWidget):
                 parent=self)
             quitButton = mb.addButton(
                 self.tr("&Quit"), E5MessageBox.AcceptRole)
-            quitButton.setIcon(UI.PixmapCache.getIcon("exit.png"))
+            quitButton.setIcon(UI.PixmapCache.getIcon("exit"))
             closeTabButton = mb.addButton(
                 self.tr("C&lose Current Tab"), E5MessageBox.AcceptRole)
-            closeTabButton.setIcon(UI.PixmapCache.getIcon("tabClose.png"))
+            closeTabButton.setIcon(UI.PixmapCache.getIcon("tabClose"))
             mb.addButton(E5MessageBox.Cancel)
-            mb.exec_()
+            mb.exec()
             if mb.clickedButton() == quitButton:
                 return True
             else:
