@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -8,7 +8,6 @@
 Module implementing the web browser using QWebEngineView.
 """
 
-
 import os
 
 from PyQt5.QtCore import (
@@ -18,12 +17,13 @@ from PyQt5.QtCore import (
 from PyQt5.QtGui import (
     QDesktopServices, QClipboard, QIcon, QContextMenuEvent, QPixmap, QCursor
 )
-from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication, QDialog
+from PyQt5.QtWidgets import QStyle, QMenu, QApplication, QDialog
 from PyQt5.QtWebEngineWidgets import (
     QWebEngineView, QWebEnginePage, QWebEngineDownloadItem
 )
 
 from E5Gui import E5MessageBox, E5FileDialog
+from E5Gui.E5Application import e5App
 
 from WebBrowser.WebBrowserWindow import WebBrowserWindow
 from .WebBrowserPage import WebBrowserPage
@@ -32,7 +32,7 @@ from .Tools.WebIconLoader import WebIconLoader
 from .Tools import Scripts
 
 from . import WebInspector
-from .Tools.WebBrowserTools import readAllFileContents, pixmapToDataUrl
+from .Tools.WebBrowserTools import getHtmlPage, pixmapToDataUrl
 
 import Preferences
 import UI.PixmapCache
@@ -169,9 +169,12 @@ class WebBrowserView(QWebEngineView):
             # pre Qt 5.12
             pass
         try:
+            from PyQt5.QtWebEngineCore import QWebEngineFindTextResult
+            # __IGNORE_WARNING__
+            
             self.__page.findTextFinished.connect(
                 self.__findTextFinished)
-        except AttributeError:
+        except (AttributeError, ImportError):
             # pre Qt 5.14
             pass
     
@@ -585,7 +588,7 @@ class WebBrowserView(QWebEngineView):
         ):
             self.__menu.addSeparator()
             self.__menu.addAction(
-                UI.PixmapCache.getIcon("webInspector.png"),
+                UI.PixmapCache.getIcon("webInspector"),
                 self.tr("Inspect Element..."), self.__webInspector)
         
         if not self.__menu.isEmpty():
@@ -671,42 +674,42 @@ class WebBrowserView(QWebEngineView):
             menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab.png"),
+            UI.PixmapCache.getIcon("openNewTab"),
             self.tr("Open Link in New Tab\tCtrl+LMB"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
             lambda: self.__openLinkInNewTab(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("newWindow.png"),
+            UI.PixmapCache.getIcon("newWindow"),
             self.tr("Open Link in New Window"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
             lambda: self.__openLinkInNewWindow(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("privateMode.png"),
+            UI.PixmapCache.getIcon("privateMode"),
             self.tr("Open Link in New Private Window"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
             lambda: self.__openLinkInNewPrivateWindow(act))
         menu.addSeparator()
         menu.addAction(
-            UI.PixmapCache.getIcon("download.png"),
+            UI.PixmapCache.getIcon("download"),
             self.tr("Save Lin&k"), self.__downloadLink)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22.png"),
+            UI.PixmapCache.getIcon("bookmark22"),
             self.tr("Bookmark this Link"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
             lambda: self.__bookmarkLink(act))
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy Link to Clipboard"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
             lambda: self.__copyLink(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend.png"),
+            UI.PixmapCache.getIcon("mailSend"),
             self.tr("Send Link"))
         act.setData(hitTest.linkUrl())
         act.triggered.connect(
@@ -716,7 +719,7 @@ class WebBrowserView(QWebEngineView):
             Preferences.getWebBrowser("VirusTotalServiceKey") != ""
         ):
             act = menu.addAction(
-                UI.PixmapCache.getIcon("virustotal.png"),
+                UI.PixmapCache.getIcon("virustotal"),
                 self.tr("Scan Link with VirusTotal"))
             act.setData(hitTest.linkUrl())
             act.triggered.connect(
@@ -735,25 +738,25 @@ class WebBrowserView(QWebEngineView):
             menu.addSeparator()
         
         act = menu.addAction(
-            UI.PixmapCache.getIcon("openNewTab.png"),
+            UI.PixmapCache.getIcon("openNewTab"),
             self.tr("Open Image in New Tab"))
         act.setData(hitTest.imageUrl())
         act.triggered.connect(
             lambda: self.__openLinkInNewTab(act))
         menu.addSeparator()
         menu.addAction(
-            UI.PixmapCache.getIcon("download.png"),
+            UI.PixmapCache.getIcon("download"),
             self.tr("Save Image"), self.__downloadImage)
         menu.addAction(
             self.tr("Copy Image to Clipboard"), self.__copyImage)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy Image Location to Clipboard"))
         act.setData(hitTest.imageUrl())
         act.triggered.connect(
             lambda: self.__copyLink(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend.png"),
+            UI.PixmapCache.getIcon("mailSend"),
             self.tr("Send Image Link"))
         act.setData(hitTest.imageUrl())
         act.triggered.connect(
@@ -764,7 +767,7 @@ class WebBrowserView(QWebEngineView):
             engine = WebBrowserWindow.imageSearchEngine()
             searchEngineName = engine.searchEngine()
             act = menu.addAction(
-                UI.PixmapCache.getIcon("{0}.png".format(
+                UI.PixmapCache.getIcon("{0}".format(
                     searchEngineName.lower())),
                 self.tr("Search image in {0}").format(searchEngineName))
             act.setData(engine.getSearchQuery(hitTest.imageUrl()))
@@ -774,7 +777,7 @@ class WebBrowserView(QWebEngineView):
                 self.tr("Search image with..."))
             for searchEngineName in engine.searchEngineNames():
                 act = self.__imageSearchMenu.addAction(
-                    UI.PixmapCache.getIcon("{0}.png".format(
+                    UI.PixmapCache.getIcon("{0}".format(
                         searchEngineName.lower())),
                     self.tr("Search image in {0}").format(searchEngineName))
                 act.setData(engine.getSearchQuery(
@@ -784,7 +787,7 @@ class WebBrowserView(QWebEngineView):
         
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("adBlockPlus.png"),
+            UI.PixmapCache.getIcon("adBlockPlus"),
             self.tr("Block Image"))
         act.setData(hitTest.imageUrl().toString())
         act.triggered.connect(
@@ -794,7 +797,7 @@ class WebBrowserView(QWebEngineView):
             Preferences.getWebBrowser("VirusTotalServiceKey") != ""
         ):
             act = menu.addAction(
-                UI.PixmapCache.getIcon("virustotal.png"),
+                UI.PixmapCache.getIcon("virustotal"),
                 self.tr("Scan Image with VirusTotal"))
             act.setData(hitTest.imageUrl())
             act.triggered.connect(
@@ -814,35 +817,35 @@ class WebBrowserView(QWebEngineView):
         
         if hitTest.mediaPaused():
             menu.addAction(
-                UI.PixmapCache.getIcon("mediaPlaybackStart.png"),
+                UI.PixmapCache.getIcon("mediaPlaybackStart"),
                 self.tr("Play"), self.__pauseMedia)
         else:
             menu.addAction(
-                UI.PixmapCache.getIcon("mediaPlaybackPause.png"),
+                UI.PixmapCache.getIcon("mediaPlaybackPause"),
                 self.tr("Pause"), self.__pauseMedia)
         if hitTest.mediaMuted():
             menu.addAction(
-                UI.PixmapCache.getIcon("audioVolumeHigh.png"),
+                UI.PixmapCache.getIcon("audioVolumeHigh"),
                 self.tr("Unmute"), self.__muteMedia)
         else:
             menu.addAction(
-                UI.PixmapCache.getIcon("audioVolumeMuted.png"),
+                UI.PixmapCache.getIcon("audioVolumeMuted"),
                 self.tr("Mute"), self.__muteMedia)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy Media Address to Clipboard"))
         act.setData(hitTest.mediaUrl())
         act.triggered.connect(
             lambda: self.__copyLink(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend.png"),
+            UI.PixmapCache.getIcon("mailSend"),
             self.tr("Send Media Address"))
         act.setData(hitTest.mediaUrl())
         act.triggered.connect(
             lambda: self.__sendLink(act))
         menu.addAction(
-            UI.PixmapCache.getIcon("download.png"),
+            UI.PixmapCache.getIcon("download"),
             self.tr("Save Media"), self.__downloadMedia)
     
     def __createSelectedTextContextMenu(self, menu, hitTest):
@@ -860,7 +863,7 @@ class WebBrowserView(QWebEngineView):
         menu.addAction(self.__mw.copyAct)
         menu.addSeparator()
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend.png"),
+            UI.PixmapCache.getIcon("mailSend"),
             self.tr("Send Text"))
         act.setData(self.selectedText())
         act.triggered.connect(
@@ -898,7 +901,7 @@ class WebBrowserView(QWebEngineView):
                 "http://translate.google.com/#auto/{0}/{1}".format(
                     langCode, self.selectedText()))
             act = menu.addAction(
-                UI.PixmapCache.getIcon("translate.png"),
+                UI.PixmapCache.getIcon("translate"),
                 self.tr("Google Translate"))
             act.setData(googleTranslatorUrl)
             act.triggered.connect(
@@ -907,7 +910,7 @@ class WebBrowserView(QWebEngineView):
                 "http://{0}.wiktionary.org/wiki/Special:Search?search={1}"
                 .format(langCode, self.selectedText()))
             act = menu.addAction(
-                UI.PixmapCache.getIcon("wikipedia.png"),
+                UI.PixmapCache.getIcon("wikipedia"),
                 self.tr("Dictionary"))
             act.setData(wiktionaryUrl)
             act.triggered.connect(
@@ -942,14 +945,14 @@ class WebBrowserView(QWebEngineView):
             menu.addAction(self.__mw.forwardAct)
             menu.addSeparator()
             menu.addAction(
-                UI.PixmapCache.getIcon("plus.png"),
+                UI.PixmapCache.getIcon("plus"),
                 self.tr("Add New Page"), self.__addSpeedDial)
             menu.addAction(
-                UI.PixmapCache.getIcon("preferences-general.png"),
+                UI.PixmapCache.getIcon("preferences-general"),
                 self.tr("Configure Speed Dial"), self.__configureSpeedDial)
             menu.addSeparator()
             menu.addAction(
-                UI.PixmapCache.getIcon("reload.png"),
+                UI.PixmapCache.getIcon("reload"),
                 self.tr("Reload All Dials"), self.__reloadAllSpeedDials)
             menu.addSeparator()
             menu.addAction(
@@ -957,16 +960,16 @@ class WebBrowserView(QWebEngineView):
             return
         
         menu.addAction(
-            UI.PixmapCache.getIcon("bookmark22.png"),
+            UI.PixmapCache.getIcon("bookmark22"),
             self.tr("Bookmark this Page"), self.addBookmark)
         act = menu.addAction(
-            UI.PixmapCache.getIcon("editCopy.png"),
+            UI.PixmapCache.getIcon("editCopy"),
             self.tr("Copy Page Link"))
         act.setData(self.url())
         act.triggered.connect(
             lambda: self.__copyLink(act))
         act = menu.addAction(
-            UI.PixmapCache.getIcon("mailSend.png"),
+            UI.PixmapCache.getIcon("mailSend"),
             self.tr("Send Page Link"))
         act.setData(self.url())
         act.triggered.connect(
@@ -1002,7 +1005,7 @@ class WebBrowserView(QWebEngineView):
                 b"http://validator.w3.org/check?uri=" +
                 QUrl.toPercentEncoding(bytes(self.url().toEncoded()).decode()))
             act = menu.addAction(
-                UI.PixmapCache.getIcon("w3.png"),
+                UI.PixmapCache.getIcon("w3"),
                 self.tr("Validate Page"))
             act.setData(w3url)
             act.triggered.connect(
@@ -1023,7 +1026,7 @@ class WebBrowserView(QWebEngineView):
                     QUrl.toPercentEncoding(
                         bytes(self.url().toEncoded()).decode()))
                 act = menu.addAction(
-                    UI.PixmapCache.getIcon("translate.png"),
+                    UI.PixmapCache.getIcon("translate"),
                     self.tr("Google Translate"))
                 act.setData(googleTranslatorUrl)
             act.triggered.connect(
@@ -1147,7 +1150,7 @@ class WebBrowserView(QWebEngineView):
         from .Bookmarks.AddBookmarkDialog import AddBookmarkDialog
         dlg = AddBookmarkDialog()
         dlg.setUrl(bytes(url.toEncoded()).decode())
-        dlg.exec_()
+        dlg.exec()
     
     def __sendLink(self, act):
         """
@@ -1343,7 +1346,7 @@ class WebBrowserView(QWebEngineView):
         dlg.setUrl(bytes(self.url().toEncoded()).decode())
         dlg.setTitle(self.title())
         dlg.setDescription(description)
-        dlg.exec_()
+        dlg.exec()
     
     def dragEnterEvent(self, evt):
         """
@@ -1681,6 +1684,14 @@ class WebBrowserView(QWebEngineView):
             self.__siteIconLoader.deleteLater()
         self.__siteIconLoader = WebIconLoader(url, self)
         self.__siteIconLoader.iconLoaded.connect(self.__iconLoaded)
+        try:
+            self.__siteIconLoader.sslConfiguration.connect(
+                self.page().setSslConfiguration)
+            self.__siteIconLoader.clearSslConfiguration.connect(
+                self.page().clearSslConfiguration)
+        except AttributeError:
+            # no SSL available
+            pass
     
     def __iconLoaded(self, icon):
         """
@@ -1768,12 +1779,12 @@ class WebBrowserView(QWebEngineView):
         self.page().deleteLater()
         self.__createNewPage()
         
-        html = readAllFileContents(":/html/tabCrashPage.html")
+        html = getHtmlPage("tabCrashPage.html")
         html = html.replace("@IMAGE@", pixmapToDataUrl(
-            qApp.style().standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
+            e5App().style().standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
                 48, 48)).toString())
         html = html.replace("@FAVICON@", pixmapToDataUrl(
-            qApp.style() .standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
+            e5App().style() .standardIcon(QStyle.SP_MessageBoxWarning).pixmap(
                 16, 16)).toString())
         html = html.replace(
             "@TITLE@", self.tr("Render Process terminated abnormally"))
@@ -2325,7 +2336,7 @@ class WebBrowserView(QWebEngineView):
                     E5SslCertificateSelectionDialog
                 )
                 dlg = E5SslCertificateSelectionDialog(certificates, self)
-                if dlg.exec_() == QDialog.Accepted:
+                if dlg.exec() == QDialog.Accepted:
                     certificate = dlg.getSelectedCertificate()
                 
                 if certificate is None:
