@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6.
 
@@ -9,8 +9,6 @@
 Installation script for the eric6 IDE and all eric6 related tools.
 """
 
-from __future__ import print_function
-
 import sys
 import os
 import re
@@ -19,9 +17,13 @@ import py_compile
 import glob
 import shutil
 import fnmatch
-import subprocess
+import subprocess               # secok
 import time
 import io
+import json
+import shlex
+import datetime
+import getpass
 
 # Define the globals.
 progName = None
@@ -38,6 +40,7 @@ doCleanDesktopLinks = False
 forceCleanDesktopLinks = False
 doCompile = True
 yes2All = False
+ignorePyqt5Tools = False
 cfg = {}
 progLanguages = ["Python", "Ruby", "QSS"]
 sourceDir = "eric"
@@ -47,10 +50,17 @@ defaultMacAppBundleName = "eric6.app"
 defaultMacAppBundlePath = "/Applications"
 defaultMacPythonExe = "{0}/Resources/Python.app/Contents/MacOS/Python".format(
     sys.exec_prefix)
+if not os.path.exists(defaultMacPythonExe):
+    defaultMacPythonExe = ""
 macAppBundleName = defaultMacAppBundleName
 macAppBundlePath = defaultMacAppBundlePath
 macPythonExe = defaultMacPythonExe
 
+createInstallInfoFile = True
+installInfoName = "eric6install.json"
+installInfo = {}
+installCwd = ""
+
 # Define blacklisted versions of the prerequisites
 BlackLists = {
     "sip": [],
@@ -90,7 +100,7 @@ def exit(rcode=0):
     
     if sys.platform.startswith(("win", "cygwin")):
         try:
-            input("Press enter to continue...")
+            input("Press enter to continue...")             # secok
         except (EOFError, SyntaxError):
             pass
     
@@ -112,15 +122,16 @@ def usage(rcode=2):
     print("Usage:")
     if sys.platform == "darwin":
         print("    {0} [-chxz] [-a dir] [-b dir] [-d dir] [-f file] [-i dir]"
-              " [-m name] [-n path] [-p python] [--no-apis] [--yes]"
+              " [-m name] [-n path] [-p python] [--no-apis] [--no-info]"
+              " [--yes]"
               .format(progName))
     elif sys.platform.startswith(("win", "cygwin")):
         print("    {0} [-chxz] [-a dir] [-b dir] [-d dir] [-f file]"
-              " [--clean-desktop] [--no-apis] [--yes]"
+              " [--clean-desktop] [--no-apis] [--no-info] [--no-tools] [--yes]"
               .format(progName))
     else:
         print("    {0} [-chxz] [-a dir] [-b dir] [-d dir] [-f file] [-i dir]"
-              " [--no-apis] [--yes]"
+              " [--no-apis] [--no-info] [--no-tools] [--yes]"
               .format(progName))
     print("where:")
     print("    -h, --help display this help message")
@@ -149,7 +160,11 @@ def usage(rcode=2):
         print("               (default: {0})".format(macPythonExe))
     print("    -c         don't cleanup old installation first")
     if sys.platform.startswith(("win", "cygwin")):
-        ("    --clean-desktop delete desktop links before installation")
+        print("    --clean-desktop delete desktop links before installation")
+    print("    --no-info  don't create the install info file")
+    if sys.platform != "darwin":
+        print("    --no-tools don't ask for installation of pyqt5-tools"
+              "/qt5-applications")
     print("    -x         don't perform dependency checks (use on your own"
           " risk)")
     print("    -z         don't compile the installed python files")
@@ -234,9 +249,8 @@ def copyToFile(name, text):
     @param name the name of the file.
     @param text the contents to copy to the file.
     """
-    f = open(name, "w")
-    f.write(text)
-    f.close()
+    with open(name, "w") as f:
+        f.write(text)
 
 
 def copyDesktopFile(src, dst):
@@ -248,17 +262,15 @@ def copyDesktopFile(src, dst):
     """
     global cfg, platBinDir
     
-    f = open(src, "r", encoding="utf-8")
-    text = f.read()
-    f.close()
+    with open(src, "r", encoding="utf-8") as f:
+        text = f.read()
     
     text = text.replace("@BINDIR@", platBinDir)
     text = text.replace("@MARKER@", "")
     text = text.replace("@PY_MARKER@", "")
     
-    f = open(dst, "w", encoding="utf-8")
-    f.write(text)
-    f.close()
+    with open(dst, "w", encoding="utf-8") as f:
+        f.write(text)
     os.chmod(dst, 0o644)
 
 
@@ -278,9 +290,8 @@ def copyAppStreamFile(src, dst):
     else:
         Version = "Unknown"
     
-    f = open(src, "r", encoding="utf-8")
-    text = f.read()
-    f.close()
+    with open(src, "r", encoding="utf-8") as f:
+        text = f.read()
     
     text = (
         text.replace("@MARKER@", "")
@@ -288,9 +299,8 @@ def copyAppStreamFile(src, dst):
         .replace("@DATE@", time.strftime("%Y-%m-%d"))
     )
     
-    f = open(dst, "w", encoding="utf-8")
-    f.write(text)
-    f.close()
+    with open(dst, "w", encoding="utf-8") as f:
+        f.write(text)
     os.chmod(dst, 0o644)
 
 
@@ -363,7 +373,7 @@ def createPyWrapper(pydir, wfile, saveDir, isGuiScript=True):
     
     wname = os.path.join(saveDir, wname)
     copyToFile(wname, wrapper)
-    os.chmod(wname, 0o755)
+    os.chmod(wname, 0o755)                  # secok
 
     return wname
 
@@ -423,16 +433,15 @@ def createGlobalPluginsDir():
     if not os.path.exists(fname):
         if not os.path.exists(pdir):
             os.mkdir(pdir, 0o755)
-        f = open(fname, "w")
-        f.write(
-            '''# -*- coding: utf-8 -*-
+        with open(fname, "w") as f:
+            f.write(
+                '''# -*- coding: utf-8 -*-
 
 """
 Package containing the global plugins.
 """
 '''
-        )
-        f.close()
+            )
         os.chmod(fname, 0o644)
 
 
@@ -568,7 +577,7 @@ def cleanUp():
         if sys.platform == "darwin":
             # delete the Mac app bundle
             cleanUpMacAppBundle()
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write(
             'Error: {0}\nTry install with admin rights.\n'.format(msg))
         exit(7)
@@ -665,7 +674,7 @@ def cleanUpWindowsLinks():
                 if os.path.exists(linkPath):
                     try:
                         os.remove(linkPath)
-                    except EnvironmentError:
+                    except OSError:
                         # maybe restrictions prohibited link removal
                         print("Could not remove '{0}'.".format(linkPath))
     
@@ -678,7 +687,7 @@ def cleanUpWindowsLinks():
         if os.path.exists(eric6EntryPath):
             try:
                 shutil.rmtree(eric6EntryPath)
-            except EnvironmentError:
+            except OSError:
                 # maybe restrictions prohibited link removal
                 print("Could not remove '{0}'.".format(eric6EntryPath))
 
@@ -716,11 +725,10 @@ def installEric():
     for name in ["eric6_compare", "eric6_configure", "eric6_diff",
                  "eric6_editor", "eric6_hexeditor", "eric6_iconeditor",
                  "eric6_plugininstall", "eric6_pluginrepository",
-                 "eric6_pluginuninstall", "eric6_qregexp",
-                 "eric6_qregularexpression", "eric6_re", "eric6_snap",
-                 "eric6_sqlbrowser", "eric6_tray", "eric6_trpreviewer",
-                 "eric6_uipreviewer", "eric6_unittest", "eric6_browser",
-                 "eric6_shell", "eric6"]:
+                 "eric6_pluginuninstall", "eric6_qregularexpression",
+                 "eric6_re", "eric6_snap", "eric6_sqlbrowser", "eric6_tray",
+                 "eric6_trpreviewer", "eric6_uipreviewer", "eric6_unittest",
+                 "eric6_browser", "eric6_shell", "eric6"]:
         wnames.append(createPyWrapper(cfg['ericDir'], name, scriptsDir))
     
     # set install prefix, if not None
@@ -790,6 +798,24 @@ def installEric():
             cfg['ericCodeTemplatesDir'],
             ['*.tmpl'])
         
+        # copy some data files needed at various places
+        copyTree(
+            os.path.join(eric6SourceDir, "E5Network", "data"),
+            os.path.join(cfg['ericDir'], "E5Network", "data"),
+            ['*.dat', '*.txt'])
+        copyTree(
+            os.path.join(eric6SourceDir, "IconEditor", "cursors"),
+            os.path.join(cfg['ericDir'], "IconEditor", "cursors"),
+            ['*.xpm'])
+        copyTree(
+            os.path.join(eric6SourceDir, "UI", "data"),
+            os.path.join(cfg['ericDir'], "UI", "data"),
+            ['*.css'])
+        copyTree(
+            os.path.join(eric6SourceDir, "WebBrowser"),
+            os.path.join(cfg['ericDir'], "WebBrowser"),
+            ['*.xbel', '*.xml', '*.html', '*.png', '*.gif', '*.js'])
+        
         # copy the wrappers
         for wname in wnames:
             shutilCopy(wname, cfg['bindir'], perm=0o755)
@@ -803,7 +829,7 @@ def installEric():
         # create the global plugins directory
         createGlobalPluginsDir()
         
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write(
             'Error: {0}\nTry install with admin rights.\n'.format(msg))
         return(7)
@@ -813,13 +839,13 @@ def installEric():
         try:
             shutilCopy(os.path.join(sourceDir, "docs", name),
                        cfg['ericDocDir'])
-        except EnvironmentError:
+        except OSError:
             print("Could not install '{0}'.".format(
                 os.path.join(sourceDir, "docs", name)))
     for name in glob.glob(os.path.join(sourceDir, 'docs', 'README*.*')):
         try:
             shutilCopy(name, cfg['ericDocDir'])
-        except EnvironmentError:
+        except OSError:
             print("Could not install '{0}'.".format(name))
    
     # copy some more stuff
@@ -827,7 +853,7 @@ def installEric():
         try:
             shutilCopy(os.path.join(sourceDir, "others", name),
                        cfg['ericOthersDir'])
-        except EnvironmentError:
+        except OSError:
             print("Could not install '{0}'.".format(
                 os.path.join(sourceDir, "others", name)))
     
@@ -843,14 +869,14 @@ def installEric():
                                                   progLanguage, "*.api")):
                 try:
                     shutilCopy(apiName, apidir)
-                except EnvironmentError:
+                except OSError:
                     print("Could not install '{0}' (no permission)."
                           .format(apiName))
             for apiName in glob.glob(os.path.join(eric6SourceDir, "APIs",
                                                   progLanguage, "*.bas")):
                 try:
                     shutilCopy(apiName, apidir)
-                except EnvironmentError:
+                except OSError:
                     print("Could not install '{0}' (no permission)."
                           .format(apiName))
             if progLanguage == "Python":
@@ -859,7 +885,7 @@ def installEric():
                                                       "Python3", "*.api")):
                     try:
                         shutilCopy(apiName, apidir)
-                    except EnvironmentError:
+                    except OSError:
                         print("Could not install '{0}' (no permission)."
                               .format(apiName))
                 for apiName in glob.glob(os.path.join(eric6SourceDir, "APIs",
@@ -869,7 +895,7 @@ def installEric():
                             apiName.replace(".bas", ".api")))):
                         try:
                             shutilCopy(apiName, apidir)
-                        except EnvironmentError:
+                        except OSError:
                             print("Could not install '{0}' (no permission)."
                                   .format(apiName))
                 
@@ -878,7 +904,7 @@ def installEric():
                                                       "MicroPython", "*.api")):
                     try:
                         shutilCopy(apiName, apidir)
-                    except EnvironmentError:
+                    except OSError:
                         print("Could not install '{0}' (no permission)."
                               .format(apiName))
                 for apiName in glob.glob(os.path.join(eric6SourceDir, "APIs",
@@ -888,7 +914,7 @@ def installEric():
                             apiName.replace(".bas", ".api")))):
                         try:
                             shutilCopy(apiName, apidir)
-                        except EnvironmentError:
+                        except OSError:
                             print("Could not install '{0}' (no permission)."
                                   .format(apiName))
     
@@ -918,10 +944,10 @@ def createLinuxSpecifics():
         if not os.path.exists(dst):
             os.makedirs(dst)
         shutilCopy(
-            os.path.join(eric6SourceDir, "icons", "default", "eric.png"),
+            os.path.join(eric6SourceDir, "pixmaps", "eric_icon.png"),
             os.path.join(dst, "eric.png"))
         shutilCopy(
-            os.path.join(eric6SourceDir, "icons", "default", "ericWeb48.png"),
+            os.path.join(eric6SourceDir, "pixmaps", "ericWeb48_icon.png"),
             os.path.join(dst, "ericWeb.png"))
         dst = os.path.normpath(
             os.path.join(distDir, "usr/share/applications"))
@@ -940,8 +966,8 @@ def createLinuxSpecifics():
             os.path.join(sourceDir, "linux", "eric6.appdata.xml.in"),
             os.path.join(dst, "eric6.appdata.xml"))
     elif os.getuid() == 0:
-        shutilCopy(os.path.join(
-            eric6SourceDir, "icons", "default", "eric.png"),
+        shutilCopy(
+            os.path.join(eric6SourceDir, "pixmaps", "eric_icon.png"),
             "/usr/share/pixmaps/eric.png")
         copyDesktopFile(
             os.path.join(sourceDir, "linux", "eric6.desktop.in"),
@@ -954,8 +980,8 @@ def createLinuxSpecifics():
             copyAppStreamFile(
                 os.path.join(sourceDir, "linux", "eric6.appdata.xml.in"),
                 "/usr/share/appdata/eric6.appdata.xml")
-        shutilCopy(os.path.join(
-            eric6SourceDir, "icons", "default", "ericWeb48.png"),
+        shutilCopy(
+            os.path.join(eric6SourceDir, "pixmaps", "ericWeb48_icon.png"),
             "/usr/share/pixmaps/ericWeb.png")
         copyDesktopFile(
             os.path.join(sourceDir, "linux", "eric6_browser.desktop.in"),
@@ -972,7 +998,7 @@ def createLinuxSpecifics():
                 os.makedirs(directory)
         # now copy the files
         shutilCopy(
-            os.path.join(eric6SourceDir, "icons", "default", "eric.png"),
+            os.path.join(eric6SourceDir, "pixmaps", "eric_icon.png"),
             os.path.join(localPath, "pixmaps", "eric.png"))
         copyDesktopFile(
             os.path.join(sourceDir, "linux", "eric6.desktop.in"),
@@ -984,7 +1010,7 @@ def createLinuxSpecifics():
             os.path.join(sourceDir, "linux", "eric6.appdata.xml.in"),
             os.path.join(localPath, "appdata", "eric6.appdata.xml"))
         shutilCopy(
-            os.path.join(eric6SourceDir, "icons", "default", "ericWeb48.png"),
+            os.path.join(eric6SourceDir, "pixmaps", "ericWeb48_icon.png"),
             os.path.join(localPath, "pixmaps", "ericWeb.png"))
         copyDesktopFile(
             os.path.join(sourceDir, "linux", "eric6_browser.desktop.in"),
@@ -1011,7 +1037,7 @@ def createWindowsLinks():
                 os.path.join(os.path.dirname(__file__),
                              "create_windows_links.py"),
             ]
-            subprocess.call(args)
+            subprocess.call(args)               # secok
         else:
             print(
                 "\nThe Python package 'pywin32' is not installed. Desktop and"
@@ -1026,11 +1052,12 @@ def createWindowsLinks():
     
     # 1. create desktop shortcuts
     regName = "Desktop"
-    desktopFolder = os.path.normpath(
-        os.path.expandvars(getWinregEntry(regName, regPath)))
-    for linkName, targetPath, iconPath in windowsDesktopEntries():
-        linkPath = os.path.join(desktopFolder, linkName)
-        createWindowsShortcut(linkPath, targetPath, iconPath)
+    desktopEntry = getWinregEntry(regName, regPath)
+    if desktopEntry:
+        desktopFolder = os.path.normpath(os.path.expandvars(desktopEntry))
+        for linkName, targetPath, iconPath in windowsDesktopEntries():
+            linkPath = os.path.join(desktopFolder, linkName)
+            createWindowsShortcut(linkPath, targetPath, iconPath)
     
     # 2. create start menu entry and shortcuts
     regName = "Programs"
@@ -1041,7 +1068,7 @@ def createWindowsLinks():
         if not os.path.exists(eric6EntryPath):
             try:
                 os.makedirs(eric6EntryPath)
-            except EnvironmentError:
+            except OSError:
                 # maybe restrictions prohibited link creation
                 return
         
@@ -1072,7 +1099,7 @@ def createMacAppBundle(pydir):
         if not os.path.exists(directory):
             os.makedirs(directory)
     
-    if macPythonExe == defaultMacPythonExe:
+    if macPythonExe == defaultMacPythonExe and macPythonExe:
         starter = os.path.join(directories["exe"], "eric")
         os.symlink(macPythonExe, starter)
     else:
@@ -1110,7 +1137,7 @@ def createMacAppBundle(pydir):
                '''exec "{2}" "{3}/{4}.py" "$@"\n'''
                .format(pathLine, dyldLine, starter, pydir, "eric6"))
     copyToFile(wname, wrapper)
-    os.chmod(wname, 0o755)
+    os.chmod(wname, 0o755)                  # secok
     
     shutilCopy(os.path.join(eric6SourceDir, "pixmaps", "eric_2.icns"),
                os.path.join(directories["icns"], "eric.icns"))
@@ -1123,7 +1150,7 @@ def createMacAppBundle(pydir):
         from eric6.UI.Info import Version, CopyrightShort
     else:
         Version = "Unknown"
-        CopyrightShort = "(c) 2002 - 2020 Detlev Offenbach"
+        CopyrightShort = "(c) 2002 - 2021 Detlev Offenbach"
     
     copyToFile(
         os.path.join(directories["contents"], "Info.plist"),
@@ -1220,6 +1247,13 @@ def createConfig():
                                            "MicroPython", "*.api"))):
                     apis.append(os.path.basename(apiName))
     
+    if sys.platform == "darwin":
+        macConfig = (
+            """    'macAppBundlePath': r'{0}',\n"""
+            """    'macAppBundleName': r'{1}',\n"""
+        ).format(macAppBundlePath, macAppBundleName)
+    else:
+        macConfig = ""
     config = (
         """# -*- coding: utf-8 -*-\n"""
         """#\n"""
@@ -1244,8 +1278,7 @@ def createConfig():
         """    'mdir': r'{13}',\n"""
         """    'apidir': r'{14}',\n"""
         """    'apis': {15},\n"""
-        """    'macAppBundlePath': r'{16}',\n"""
-        """    'macAppBundleName': r'{17}',\n"""
+        """{16}"""
         """}}\n"""
         """\n"""
         """def getConfig(name):\n"""
@@ -1274,11 +1307,43 @@ def createConfig():
         cfg['ericCodeTemplatesDir'], cfg['ericOthersDir'],
         cfg['bindir'], cfg['mdir'],
         cfg['apidir'], sorted(apis),
-        macAppBundlePath, macAppBundleName,
+        macConfig,
     )
     copyToFile(configName, config)
 
 
+def createInstallInfo():
+    """
+    Record information about the way eric6 was installed.
+    """
+    global createInstallInfoFile, installInfo, installCwd, cfg
+    
+    if createInstallInfoFile:
+        installDateTime = datetime.datetime.now(tz=None)
+        try:
+            installInfo["sudo"] = os.getuid() == 0
+        except AttributeError:
+            installInfo["sudo"] = False
+        installInfo["user"] = getpass.getuser()
+        installInfo["exe"] = sys.executable
+        installInfo["argv"] = " ".join(shlex.quote(a) for a in sys.argv[:])
+        installInfo["install_cwd"] = installCwd
+        installInfo["eric"] = cfg["ericDir"]
+        installInfo["virtualenv"] = installInfo["eric"].startswith(
+            os.path.expanduser("~"))
+        installInfo["installed"] = True
+        installInfo["installed_on"] = installDateTime.strftime(
+            "%Y-%m-%d %H:%M:%S")
+        installInfo["guessed"] = False
+        installInfo["edited"] = False
+        installInfo["pip"] = False
+        installInfo["remarks"] = ""
+        installInfo["install_cwd_edited"] = False
+        installInfo["exe_edited"] = False
+        installInfo["argv_edited"] = False
+        installInfo["eric_edited"] = False
+
+
 def pipInstall(packageName, message):
     """
     Install the given package via pip.
@@ -1298,29 +1363,81 @@ def pipInstall(packageName, message):
     else:
         print("{0}\n\nShall '{1}' be installed using pip? (Y/n)"
               .format(message, packageName), end=" ")
-        answer = input()
+        answer = input()                            # secok
     if answer in ("", "Y", "y"):
-        exitCode = subprocess.call(
+        exitCode = subprocess.call(                 # secok
             [sys.executable, "-m", "pip", "install", packageName])
         ok = (exitCode == 0)
     
     return ok
 
 
+def isPipOutdated():
+    """
+    Check, if pip is outdated.
+    
+    @return flag indicating an outdated pip
+    @rtype bool
+    """
+    try:
+        pipOut = subprocess.check_output([          # secok
+            sys.executable, "-m", "pip", "list", "--outdated",
+            "--format=json"
+        ])
+        pipOut = pipOut.decode()
+    except (OSError, subprocess.CalledProcessError):
+        pipOut = "[]"       # default empty list
+    try:
+        jsonList = json.loads(pipOut)
+    except Exception:
+        jsonList = []
+    for package in jsonList:
+        if isinstance(package, dict) and package["name"] == "pip":
+            print("'pip' is outdated (installed {0}, available {1})".format(
+                package["version"], package["latest_version"]
+            ))
+            return True
+    
+    return False
+
+
+def updatePip():
+    """
+    Update the installed pip package.
+    """
+    global yes2All
+    
+    if yes2All:
+        answer = "y"
+    else:
+        print("Shall 'pip' be updated (recommended)? (Y/n)", end=" ")
+        answer = input()            # secok
+    if answer in ("", "Y", "y"):
+        subprocess.call(            # secok
+            [sys.executable, "-m", "pip", "install", "--upgrade", "pip"])
+
+
 def doDependancyChecks():
     """
     Perform some dependency checks.
     """
+    try:
+        isSudo = os.getuid() == 0
+    except AttributeError:
+        isSudo = False
+    
     print('Checking dependencies')
     
+    # update pip first even if we don't need to install anything
+    if not isSudo and isPipOutdated():
+        updatePip()
+        print("\n")
+    
     # perform dependency checks
     print("Python Version: {0:d}.{1:d}.{2:d}".format(*sys.version_info[:3]))
     if sys.version_info < (3, 5, 0):
         print('Sorry, you must have Python 3.5.0 or higher.')
         exit(5)
-    if sys.version_info[0] > 3:
-        print('Sorry, eric6 requires Python 3 for running.')
-        exit(5)
     
     try:
         import xml.etree            # __IGNORE_WARNING__
@@ -1332,9 +1449,9 @@ def doDependancyChecks():
     try:
         from PyQt5.QtCore import qVersion
     except ImportError as msg:
-        installed = pipInstall(
+        installed = not isSudo and pipInstall(
             "PyQt5",
-            "PyQt5 could not be detected.\nError: {0}".format(msg)
+            "'PyQt5' could not be detected.\nError: {0}".format(msg)
         )
         if installed:
             # try to import it again
@@ -1365,27 +1482,33 @@ def doDependancyChecks():
         from PyQt5.QtCore import PYQT_VERSION
         if PYQT_VERSION >= 0x050c00:
             # PyQt 5.12 separated QtWebEngine into a separate wheel
-            installed = pipInstall(
-                "PyQtWebEngine",
-                "PyQtWebEngine could not be detected.\nError: {0}"
-                .format(msg)
-            )
+            if isSudo:
+                print("Optional 'PyQtWebEngine' could not be detected.")
+            else:
+                pipInstall(
+                    "PyQtWebEngine",
+                    "Optional 'PyQtWebEngine' could not be detected.\n"
+                    "Error: {0}".format(msg)
+                )
     
     try:
         from PyQt5 import QtChart    # __IGNORE_WARNING__
     except ImportError as msg:
-        installed = pipInstall(
-            "PyQtChart",
-            "PyQtChart could not be detected.\nError: {0}"
-            .format(msg)
-        )
+        if isSudo:
+            print("Optional 'PyQtChart' could not be detected.")
+        else:
+            pipInstall(
+                "PyQtChart",
+                "Optional 'PyQtChart' could not be detected.\n"
+                "Error: {0}".format(msg)
+            )
     
     try:
         from PyQt5 import Qsci      # __IGNORE_WARNING__
     except ImportError as msg:
-        installed = pipInstall(
+        installed = not isSudo and pipInstall(
             "QScintilla",
-            "QScintilla could not be detected.\nError: {0}".format(msg)
+            "'QScintilla' could not be detected.\nError: {0}".format(msg)
         )
         if installed:
             # try to import it again
@@ -1412,6 +1535,10 @@ def doDependancyChecks():
         # available (e.g. for 32-Bit Windows)
         (("PyQt5.QtWebEngineWidgets", ), sys.maxsize <= 2**32),
     ]
+    optionalModulesList = {}
+    if sys.platform != "darwin" and not ignorePyqt5Tools:
+        optionalModulesList["qt5-applications"] = "qt5_applications"
+    
     # check mandatory modules
     modulesOK = True
     for impModule in impModulesList:
@@ -1445,6 +1572,21 @@ def doDependancyChecks():
                       .format(" or ".join(altModules)))
         if not altModulesOK:
             exit(1)
+    # check optional modules
+    for optPackage in optionalModulesList:
+        try:
+            __import__(optionalModulesList[optPackage])
+            print("Found", optPackage)
+        except ImportError as msg:
+            if isSudo:
+                print("Optional '{0}' could not be detected."
+                      .format(optPackage))
+            else:
+                pipInstall(
+                    optPackage,
+                    "Optional '{0}' could not be detected.\n"
+                    "Error: {1}".format(optPackage, msg)
+                )
     
     # determine the platform dependent black list
     if sys.platform.startswith(("win", "cygwin")):
@@ -1458,8 +1600,8 @@ def doDependancyChecks():
     qtMajor = int(qVersion().split('.')[0])
     qtMinor = int(qVersion().split('.')[1])
     print("Qt Version: {0}".format(qVersion().strip()))
-    if qtMajor == 5 and qtMinor < 9:
-        print('Sorry, you must have Qt version 5.9.0 or better.')
+    if qtMajor == 5 and qtMinor < 12:
+        print('Sorry, you must have Qt version 5.12.0 or better.')
         exit(2)
     
     # check version of sip
@@ -1509,8 +1651,8 @@ def doDependancyChecks():
         major = int(major)
         minor = int(minor)
         pat = int(pat)
-        if major == 5 and minor < 9:
-            print('Sorry, you must have PyQt 5.9.0 or better or'
+        if major == 5 and minor < 12:
+            print('Sorry, you must have PyQt 5.12.0 or better or'
                   ' a recent snapshot release.')
             exit(4)
         # check for blacklisted versions
@@ -1533,8 +1675,12 @@ def doDependancyChecks():
         major = int(major)
         minor = int(minor)
         pat = int(pat)
-        if major < 2 or (major == 2 and minor < 9):
-            print('Sorry, you must have QScintilla 2.9.0 or higher or'
+        if (
+            major < 2 or
+            (major == 2 and minor < 11) or
+            (major == 2 and minor == 11 and pat < 1)
+        ):
+            print('Sorry, you must have QScintilla 2.11.1 or higher or'
                   ' a recent snapshot release.')
             exit(5)
         # check for blacklisted versions
@@ -1595,10 +1741,10 @@ def prepareInfoFile(fileName):
     
     try:
         os.rename(fileName, fileName + ".orig")
-    except EnvironmentError:
+    except OSError:
         pass
     try:
-        hgOut = subprocess.check_output(["hg", "identify", "-i"])
+        hgOut = subprocess.check_output(["hg", "identify", "-i"])   # secok
         hgOut = hgOut.decode()
     except (OSError, subprocess.CalledProcessError):
         hgOut = ""
@@ -1606,9 +1752,8 @@ def prepareInfoFile(fileName):
         hgOut = hgOut.strip()
         if hgOut.endswith("+"):
             hgOut = hgOut[:-1]
-        f = open(fileName + ".orig", "r", encoding="utf-8")
-        text = f.read()
-        f.close()
+        with open(fileName + ".orig", "r", encoding="utf-8") as f:
+            text = f.read()
         text = (
             text.replace("@@REVISION@@", hgOut)
             .replace("@@VERSION@@", "rev_" + hgOut)
@@ -1731,6 +1876,8 @@ def main(argv):
     global sourceDir, eric6SourceDir, configName
     global macAppBundlePath, macAppBundleName, macPythonExe
     global installApis, doCleanDesktopLinks, yes2All
+    global createInstallInfoFile, installCwd
+    global ignorePyqt5Tools
     
     if sys.version_info < (3, 5, 0) or sys.version_info > (3, 99, 99):
         print('Sorry, eric6 requires at least Python 3.5 for running.')
@@ -1738,6 +1885,8 @@ def main(argv):
     
     progName = os.path.basename(argv[0])
     
+    installCwd = os.getcwd()
+    
     if os.path.dirname(argv[0]):
         os.chdir(os.path.dirname(argv[0]))
     
@@ -1747,15 +1896,15 @@ def main(argv):
         if sys.platform.startswith(("win", "cygwin")):
             optlist, args = getopt.getopt(
                 argv[1:], "chxza:b:d:f:",
-                ["help", "no-apis", "yes"])
+                ["help", "no-apis", "no-info", "no-tools", "yes"])
         elif sys.platform == "darwin":
             optlist, args = getopt.getopt(
                 argv[1:], "chxza:b:d:f:i:m:n:p:",
-                ["help", "no-apis", "yes"])
+                ["help", "no-apis", "no-info", "yes"])
         else:
             optlist, args = getopt.getopt(
                 argv[1:], "chxza:b:d:f:i:",
-                ["help", "no-apis", "yes"])
+                ["help", "no-apis", "no-info", "no-tools", "yes"])
     except getopt.GetoptError as err:
         print(err)
         usage()
@@ -1784,6 +1933,7 @@ def main(argv):
         elif opt == "-f":
             try:
                 exec(compile(open(arg).read(), arg, 'exec'), globals())
+                # secok
                 if len(cfg) != configLength:
                     print("The configuration dictionary in '{0}' is incorrect."
                           " Aborting".format(arg))
@@ -1802,6 +1952,10 @@ def main(argv):
             doCleanDesktopLinks = True
         elif opt == "--yes":
             yes2All = True
+        elif opt == "--no-tools":
+            ignorePyqt5Tools = True
+        elif opt == "--no-info":
+            createInstallInfoFile = False
     
     infoName = ""
     installFromSource = not os.path.isdir(sourceDir)
@@ -1838,7 +1992,7 @@ def main(argv):
             if os.path.exists(configNameC):
                 os.remove(configNameC)
         os.remove(configName)
-    except EnvironmentError:
+    except OSError:
         pass
     
     # cleanup old installation
@@ -1849,7 +2003,7 @@ def main(argv):
                 shutil.rmtree(distDir, True)
             else:
                 cleanUp()
-    except (IOError, OSError) as msg:
+    except OSError as msg:
         sys.stderr.write('Error: {0}\nTry install as root.\n'.format(msg))
         exit(7)
 
@@ -1857,6 +2011,8 @@ def main(argv):
     print("\nCreating configuration file ...")
     createConfig()
 
+    createInstallInfo()
+    
     # Compile .ui files
     print("\nCompiling user interface files ...")
     # step 1: remove old Ui_*.py files
@@ -1891,6 +2047,11 @@ def main(argv):
     print("\nInstalling eric6 ...")
     res = installEric()
     
+    if createInstallInfoFile:
+        with open(os.path.join(cfg["ericDir"],
+                               installInfoName), "w") as installInfoFile:
+            json.dump(installInfo, installInfoFile, indent=2)
+    
     # do some cleanup
     try:
         if installFromSource:
@@ -1899,7 +2060,7 @@ def main(argv):
             if os.path.exists(configNameC):
                 os.remove(configNameC)
             os.rename(configName + ".orig", configName)
-    except EnvironmentError:
+    except OSError:
         pass
     try:
         if installFromSource and infoName:
@@ -1908,7 +2069,7 @@ def main(argv):
             if os.path.exists(infoNameC):
                 os.remove(infoNameC)
             os.rename(infoName + ".orig", infoName)
-    except EnvironmentError:
+    except OSError:
         pass
     
     print("\nInstallation complete.")
