@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the install script for eric6's translation files.
 
@@ -9,7 +9,6 @@
 Installation script for the eric6 IDE translation files.
 """
 
-
 import sys
 import os
 import shutil
@@ -79,9 +78,9 @@ def installTranslations():
         for fn in glob.glob(os.path.join('eric', 'eric6', 'i18n', '*.qm')):
             shutil.copy2(fn, targetDir)
             os.chmod(os.path.join(targetDir, os.path.basename(fn)), 0o644)
-    except IOError as msg:
+    except OSError as msg:
         sys.stderr.write(
-            'IOError: {0}\nTry install-i18n as root.\n'.format(msg))
+            'OSError: {0}\nTry install-i18n as root.\n'.format(msg))
     except OSError as msg:
         sys.stderr.write(
             'OSError: {0}\nTry install-i18n with admin rights.\n'.format(msg))
